#ifndef __BNX2X_INIT_VALUES_H__
#define __BNX2X_INIT_VALUES_H__

/* This array contains the list of operations needed to initialize the chip.
 *
 * For each block in the chip there are three init stages:
 * common - HW used by both ports,
 * port1 and port2 - initialization for a specific Ethernet port.
 * When a port is opened or closed, the management CPU tells the driver
 * whether to init/disable common HW in addition to the port HW.
 * This way the first port going up will first initializes the common HW,
 * and the last port going down also resets the common HW
 *
 * For each init stage/block there is a list of actions needed in a format:
 * {operation, register, data}
 * where:
 * OP_WR - write a value to the chip.
 * OP_RD - read a register (usually a clear on read register).
 * OP_SW - string write, write a section of consecutive addresses to the chip.
 * OP_SI - copy a string using indirect writes.
 * OP_ZR - clear a range of memory.
 * OP_ZP - unzip and copy using DMAE.
 * OP_WB - string copy using DMAE.
 *
 * The #defines mark the stages.
 *
 */

static const struct raw_op init_ops[] = {
#define PRS_COMMON_START        0
	{OP_WR, PRS_REG_INC_VALUE, 0xf},
	{OP_WR, PRS_REG_EVENT_ID_1, 0x45},
	{OP_WR, PRS_REG_EVENT_ID_2, 0x84},
	{OP_WR, PRS_REG_EVENT_ID_3, 0x6},
	{OP_WR, PRS_REG_NO_MATCH_EVENT_ID, 0x4},
	{OP_WR, PRS_REG_CM_HDR_TYPE_0, 0x0},
	{OP_WR, PRS_REG_CM_HDR_TYPE_1, 0x12170000},
	{OP_WR, PRS_REG_CM_HDR_TYPE_2, 0x22170000},
	{OP_WR, PRS_REG_CM_HDR_TYPE_3, 0x32170000},
	{OP_ZR, PRS_REG_CM_HDR_TYPE_4, 0x5},
	{OP_WR, PRS_REG_CM_HDR_LOOPBACK_TYPE_1, 0x12150000},
	{OP_WR, PRS_REG_CM_HDR_LOOPBACK_TYPE_2, 0x22150000},
	{OP_WR, PRS_REG_CM_HDR_LOOPBACK_TYPE_3, 0x32150000},
	{OP_ZR, PRS_REG_CM_HDR_LOOPBACK_TYPE_4, 0x4},
	{OP_WR, PRS_REG_CM_NO_MATCH_HDR, 0x2100000},
	{OP_WR, PRS_REG_CM_HDR_FLUSH_NO_LOAD_TYPE_0, 0x100000},
	{OP_WR, PRS_REG_CM_HDR_FLUSH_NO_LOAD_TYPE_1, 0x10100000},
	{OP_WR, PRS_REG_CM_HDR_FLUSH_NO_LOAD_TYPE_2, 0x20100000},
	{OP_WR, PRS_REG_CM_HDR_FLUSH_NO_LOAD_TYPE_3, 0x30100000},
	{OP_ZR_E1, PRS_REG_CM_HDR_FLUSH_NO_LOAD_TYPE_4, 0x4},
	{OP_WR_E1H, PRS_REG_CM_HDR_FLUSH_NO_LOAD_TYPE_4, 0x40100000},
	{OP_ZR_E1H, PRS_REG_CM_HDR_FLUSH_NO_LOAD_TYPE_5, 0x3},
	{OP_WR, PRS_REG_CM_HDR_FLUSH_LOAD_TYPE_0, 0x100000},
	{OP_WR, PRS_REG_CM_HDR_FLUSH_LOAD_TYPE_1, 0x12140000},
	{OP_WR, PRS_REG_CM_HDR_FLUSH_LOAD_TYPE_2, 0x22140000},
	{OP_WR, PRS_REG_CM_HDR_FLUSH_LOAD_TYPE_3, 0x32140000},
	{OP_ZR_E1, PRS_REG_CM_HDR_FLUSH_LOAD_TYPE_4, 0x4},
	{OP_WR_E1H, PRS_REG_CM_HDR_FLUSH_LOAD_TYPE_4, 0x42140000},
	{OP_ZR_E1H, PRS_REG_CM_HDR_FLUSH_LOAD_TYPE_5, 0x3},
	{OP_RD, PRS_REG_NUM_OF_PACKETS, 0x0},
	{OP_RD, PRS_REG_NUM_OF_CFC_FLUSH_MESSAGES, 0x0},
	{OP_RD, PRS_REG_NUM_OF_TRANSPARENT_FLUSH_MESSAGES, 0x0},
	{OP_RD, PRS_REG_NUM_OF_DEAD_CYCLES, 0x0},
	{OP_WR_E1H, PRS_REG_FCOE_TYPE, 0x8906},
	{OP_WR, PRS_REG_FLUSH_REGIONS_TYPE_0, 0xff},
	{OP_WR, PRS_REG_FLUSH_REGIONS_TYPE_1, 0xff},
	{OP_WR, PRS_REG_FLUSH_REGIONS_TYPE_2, 0xff},
	{OP_WR, PRS_REG_FLUSH_REGIONS_TYPE_3, 0xff},
	{OP_WR, PRS_REG_FLUSH_REGIONS_TYPE_4, 0xff},
	{OP_WR, PRS_REG_FLUSH_REGIONS_TYPE_5, 0xff},
	{OP_WR, PRS_REG_FLUSH_REGIONS_TYPE_6, 0xff},
	{OP_WR, PRS_REG_FLUSH_REGIONS_TYPE_7, 0xff},
	{OP_WR, PRS_REG_PURE_REGIONS, 0x3e},
	{OP_WR, PRS_REG_PACKET_REGIONS_TYPE_0, 0x0},
	{OP_WR, PRS_REG_PACKET_REGIONS_TYPE_1, 0x3f},
	{OP_WR, PRS_REG_PACKET_REGIONS_TYPE_2, 0x3f},
	{OP_WR, PRS_REG_PACKET_REGIONS_TYPE_3, 0x3f},
	{OP_WR_E1, PRS_REG_PACKET_REGIONS_TYPE_4, 0x0},
	{OP_WR_E1H, PRS_REG_PACKET_REGIONS_TYPE_4, 0x3f},
	{OP_WR, PRS_REG_PACKET_REGIONS_TYPE_5, 0x3f},
	{OP_WR, PRS_REG_PACKET_REGIONS_TYPE_6, 0x3f},
	{OP_WR, PRS_REG_PACKET_REGIONS_TYPE_7, 0x3f},
#define PRS_COMMON_END          52
#define SRCH_COMMON_START       52
	{OP_WR_E1H, SRC_REG_E1HMF_ENABLE, 0x1},
#define SRCH_COMMON_END         53
#define TSDM_COMMON_START       53
	{OP_WR_E1, TSDM_REG_CFC_RSP_START_ADDR, 0x411},
	{OP_WR_E1H, TSDM_REG_CFC_RSP_START_ADDR, 0x211},
	{OP_WR_E1, TSDM_REG_CMP_COUNTER_START_ADDR, 0x400},
	{OP_WR_E1H, TSDM_REG_CMP_COUNTER_START_ADDR, 0x200},
	{OP_WR_E1, TSDM_REG_Q_COUNTER_START_ADDR, 0x404},
	{OP_WR_E1H, TSDM_REG_Q_COUNTER_START_ADDR, 0x204},
	{OP_WR_E1, TSDM_REG_PCK_END_MSG_START_ADDR, 0x419},
	{OP_WR_E1H, TSDM_REG_PCK_END_MSG_START_ADDR, 0x219},
	{OP_WR, TSDM_REG_CMP_COUNTER_MAX0, 0xffff},
	{OP_WR, TSDM_REG_CMP_COUNTER_MAX1, 0xffff},
	{OP_WR, TSDM_REG_CMP_COUNTER_MAX2, 0xffff},
	{OP_WR, TSDM_REG_CMP_COUNTER_MAX3, 0xffff},
	{OP_ZR, TSDM_REG_AGG_INT_EVENT_0, 0x2},
	{OP_WR, TSDM_REG_AGG_INT_EVENT_2, 0x34},
	{OP_WR, TSDM_REG_AGG_INT_EVENT_3, 0x35},
	{OP_ZR, TSDM_REG_AGG_INT_EVENT_4, 0x7c},
	{OP_WR, TSDM_REG_ENABLE_IN1, 0x7ffffff},
	{OP_WR, TSDM_REG_ENABLE_IN2, 0x3f},
	{OP_WR, TSDM_REG_ENABLE_OUT1, 0x7ffffff},
	{OP_WR, TSDM_REG_ENABLE_OUT2, 0xf},
	{OP_RD, TSDM_REG_NUM_OF_Q0_CMD, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_Q1_CMD, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_Q3_CMD, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_Q4_CMD, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_Q5_CMD, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_Q6_CMD, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_Q7_CMD, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_Q8_CMD, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_Q9_CMD, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_Q10_CMD, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_Q11_CMD, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_PKT_END_MSG, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_PXP_ASYNC_REQ, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_ACK_AFTER_PLACE, 0x0},
	{OP_WR_E1, TSDM_REG_INIT_CREDIT_PXP_CTRL, 0x1},
	{OP_WR_ASIC, TSDM_REG_TIMER_TICK, 0x3e8},
	{OP_WR_EMUL, TSDM_REG_TIMER_TICK, 0x1},
	{OP_WR_FPGA, TSDM_REG_TIMER_TICK, 0xa},
#define TSDM_COMMON_END         91
#define TCM_COMMON_START        91
	{OP_WR, TCM_REG_XX_MAX_LL_SZ, 0x20},
	{OP_WR, TCM_REG_XX_OVFL_EVNT_ID, 0x32},
	{OP_WR, TCM_REG_TQM_TCM_HDR_P, 0x2150020},
	{OP_WR, TCM_REG_TQM_TCM_HDR_S, 0x2150020},
	{OP_WR, TCM_REG_TM_TCM_HDR, 0x30},
	{OP_WR, TCM_REG_ERR_TCM_HDR, 0x8100000},
	{OP_WR, TCM_REG_ERR_EVNT_ID, 0x33},
	{OP_WR, TCM_REG_EXPR_EVNT_ID, 0x30},
	{OP_WR, TCM_REG_STOP_EVNT_ID, 0x31},
	{OP_WR, TCM_REG_PRS_WEIGHT, 0x4},
	{OP_WR, TCM_REG_PBF_WEIGHT, 0x5},
	{OP_WR, TCM_REG_CP_WEIGHT, 0x0},
	{OP_WR, TCM_REG_TSDM_WEIGHT, 0x4},
	{OP_WR, TCM_REG_TCM_TQM_USE_Q, 0x1},
	{OP_WR, TCM_REG_GR_ARB_TYPE, 0x1},
	{OP_WR, TCM_REG_GR_LD0_PR, 0x1},
	{OP_WR, TCM_REG_GR_LD1_PR, 0x2},
	{OP_WR, TCM_REG_CFC_INIT_CRD, 0x1},
	{OP_WR, TCM_REG_FIC0_INIT_CRD, 0x40},
	{OP_WR, TCM_REG_FIC1_INIT_CRD, 0x40},
	{OP_WR, TCM_REG_TQM_INIT_CRD, 0x20},
	{OP_WR, TCM_REG_XX_INIT_CRD, 0x13},
	{OP_WR, TCM_REG_XX_MSG_NUM, 0x20},
	{OP_ZR, TCM_REG_XX_TABLE, 0xa},
	{OP_SW, TCM_REG_XX_DESCR_TABLE, 0x200000},
	{OP_WR, TCM_REG_N_SM_CTX_LD_0, 0x7},
	{OP_WR, TCM_REG_N_SM_CTX_LD_1, 0x7},
	{OP_WR, TCM_REG_N_SM_CTX_LD_2, 0x8},
	{OP_WR, TCM_REG_N_SM_CTX_LD_3, 0x8},
	{OP_ZR_E1, TCM_REG_N_SM_CTX_LD_4, 0x4},
	{OP_WR_E1H, TCM_REG_N_SM_CTX_LD_4, 0x1},
	{OP_ZR_E1H, TCM_REG_N_SM_CTX_LD_5, 0x3},
	{OP_WR, TCM_REG_TCM_REG0_SZ, 0x6},
	{OP_WR_E1, TCM_REG_PHYS_QNUM0_0, 0xd},
	{OP_WR_E1, TCM_REG_PHYS_QNUM0_1, 0x2d},
	{OP_WR_E1, TCM_REG_PHYS_QNUM1_0, 0x7},
	{OP_WR_E1, TCM_REG_PHYS_QNUM1_1, 0x27},
	{OP_WR_E1, TCM_REG_PHYS_QNUM2_0, 0x7},
	{OP_WR_E1, TCM_REG_PHYS_QNUM2_1, 0x27},
	{OP_WR_E1, TCM_REG_PHYS_QNUM3_0, 0x7},
	{OP_WR_E1, TCM_REG_PHYS_QNUM3_1, 0x27},
	{OP_WR, TCM_REG_TCM_STORM0_IFEN, 0x1},
	{OP_WR, TCM_REG_TCM_STORM1_IFEN, 0x1},
	{OP_WR, TCM_REG_TCM_TQM_IFEN, 0x1},
	{OP_WR, TCM_REG_STORM_TCM_IFEN, 0x1},
	{OP_WR, TCM_REG_TQM_TCM_IFEN, 0x1},
	{OP_WR, TCM_REG_TSDM_IFEN, 0x1},
	{OP_WR, TCM_REG_TM_TCM_IFEN, 0x1},
	{OP_WR, TCM_REG_PRS_IFEN, 0x1},
	{OP_WR, TCM_REG_PBF_IFEN, 0x1},
	{OP_WR, TCM_REG_USEM_IFEN, 0x1},
	{OP_WR, TCM_REG_CSEM_IFEN, 0x1},
	{OP_WR, TCM_REG_CDU_AG_WR_IFEN, 0x1},
	{OP_WR, TCM_REG_CDU_AG_RD_IFEN, 0x1},
	{OP_WR, TCM_REG_CDU_SM_WR_IFEN, 0x1},
	{OP_WR, TCM_REG_CDU_SM_RD_IFEN, 0x1},
	{OP_WR, TCM_REG_TCM_CFC_IFEN, 0x1},
#define TCM_COMMON_END          148
#define TCM_FUNC0_START         148
	{OP_WR_E1H, TCM_REG_PHYS_QNUM0_0, 0xd},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM1_0, 0x7},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM2_0, 0x7},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM3_0, 0x7},
#define TCM_FUNC0_END           152
#define TCM_FUNC1_START         152
	{OP_WR_E1H, TCM_REG_PHYS_QNUM0_1, 0x2d},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM1_1, 0x27},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM2_1, 0x27},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM3_1, 0x27},
#define TCM_FUNC1_END           156
#define TCM_FUNC2_START         156
	{OP_WR_E1H, TCM_REG_PHYS_QNUM0_0, 0x1d},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM1_0, 0x17},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM2_0, 0x17},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM3_0, 0x17},
#define TCM_FUNC2_END           160
#define TCM_FUNC3_START         160
	{OP_WR_E1H, TCM_REG_PHYS_QNUM0_1, 0x3d},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM1_1, 0x37},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM2_1, 0x37},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM3_1, 0x37},
#define TCM_FUNC3_END           164
#define TCM_FUNC4_START         164
	{OP_WR_E1H, TCM_REG_PHYS_QNUM0_0, 0x4d},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM1_0, 0x47},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM2_0, 0x47},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM3_0, 0x47},
#define TCM_FUNC4_END           168
#define TCM_FUNC5_START         168
	{OP_WR_E1H, TCM_REG_PHYS_QNUM0_1, 0x6d},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM1_1, 0x67},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM2_1, 0x67},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM3_1, 0x67},
#define TCM_FUNC5_END           172
#define TCM_FUNC6_START         172
	{OP_WR_E1H, TCM_REG_PHYS_QNUM0_0, 0x5d},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM1_0, 0x57},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM2_0, 0x57},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM3_0, 0x57},
#define TCM_FUNC6_END           176
#define TCM_FUNC7_START         176
	{OP_WR_E1H, TCM_REG_PHYS_QNUM0_1, 0x7d},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM1_1, 0x77},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM2_1, 0x77},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM3_1, 0x77},
#define TCM_FUNC7_END           180
#define BRB1_COMMON_START       180
	{OP_SW, BRB1_REG_LL_RAM, 0x2000020},
	{OP_WR, BRB1_REG_SOFT_RESET, 0x1},
	{OP_RD, BRB1_REG_NUM_OF_FULL_CYCLES_4, 0x0},
	{OP_SW, BRB1_REG_FREE_LIST_PRS_CRDT, 0x30220},
	{OP_WR, BRB1_REG_SOFT_RESET, 0x0},
#define BRB1_COMMON_END         185
#define BRB1_PORT0_START        185
	{OP_WR_E1, BRB1_REG_PAUSE_LOW_THRESHOLD_0, 0xb8},
	{OP_WR_E1, BRB1_REG_PAUSE_HIGH_THRESHOLD_0, 0x114},
	{OP_RD, BRB1_REG_NUM_OF_PAUSE_CYCLES_0, 0x0},
	{OP_RD, BRB1_REG_NUM_OF_FULL_CYCLES_0, 0x0},
#define BRB1_PORT0_END          189
#define BRB1_PORT1_START        189
	{OP_WR_E1, BRB1_REG_PAUSE_LOW_THRESHOLD_1, 0xb8},
	{OP_WR_E1, BRB1_REG_PAUSE_HIGH_THRESHOLD_1, 0x114},
	{OP_RD, BRB1_REG_NUM_OF_PAUSE_CYCLES_1, 0x0},
	{OP_RD, BRB1_REG_NUM_OF_FULL_CYCLES_1, 0x0},
#define BRB1_PORT1_END          193
#define TSEM_COMMON_START       193
	{OP_RD, TSEM_REG_MSG_NUM_FIC0, 0x0},
	{OP_RD, TSEM_REG_MSG_NUM_FIC1, 0x0},
	{OP_RD, TSEM_REG_MSG_NUM_FOC0, 0x0},
	{OP_RD, TSEM_REG_MSG_NUM_FOC1, 0x0},
	{OP_RD, TSEM_REG_MSG_NUM_FOC2, 0x0},
	{OP_RD, TSEM_REG_MSG_NUM_FOC3, 0x0},
	{OP_WR, TSEM_REG_ARB_ELEMENT0, 0x1},
	{OP_WR, TSEM_REG_ARB_ELEMENT1, 0x2},
	{OP_WR, TSEM_REG_ARB_ELEMENT2, 0x3},
	{OP_WR, TSEM_REG_ARB_ELEMENT3, 0x0},
	{OP_WR, TSEM_REG_ARB_ELEMENT4, 0x4},
	{OP_WR, TSEM_REG_ARB_CYCLE_SIZE, 0x1},
	{OP_WR, TSEM_REG_TS_0_AS, 0x0},
	{OP_WR, TSEM_REG_TS_1_AS, 0x1},
	{OP_WR, TSEM_REG_TS_2_AS, 0x4},
	{OP_WR, TSEM_REG_TS_3_AS, 0x0},
	{OP_WR, TSEM_REG_TS_4_AS, 0x1},
	{OP_WR, TSEM_REG_TS_5_AS, 0x3},
	{OP_WR, TSEM_REG_TS_6_AS, 0x0},
	{OP_WR, TSEM_REG_TS_7_AS, 0x1},
	{OP_WR, TSEM_REG_TS_8_AS, 0x4},
	{OP_WR, TSEM_REG_TS_9_AS, 0x0},
	{OP_WR, TSEM_REG_TS_10_AS, 0x1},
	{OP_WR, TSEM_REG_TS_11_AS, 0x3},
	{OP_WR, TSEM_REG_TS_12_AS, 0x0},
	{OP_WR, TSEM_REG_TS_13_AS, 0x1},
	{OP_WR, TSEM_REG_TS_14_AS, 0x4},
	{OP_WR, TSEM_REG_TS_15_AS, 0x0},
	{OP_WR, TSEM_REG_TS_16_AS, 0x4},
	{OP_WR, TSEM_REG_TS_17_AS, 0x3},
	{OP_ZR, TSEM_REG_TS_18_AS, 0x2},
	{OP_WR, TSEM_REG_ENABLE_IN, 0x3fff},
	{OP_WR, TSEM_REG_ENABLE_OUT, 0x3ff},
	{OP_WR, TSEM_REG_FIC0_DISABLE, 0x0},
	{OP_WR, TSEM_REG_FIC1_DISABLE, 0x0},
	{OP_WR, TSEM_REG_PAS_DISABLE, 0x0},
	{OP_WR, TSEM_REG_THREADS_LIST, 0xff},
	{OP_ZR, TSEM_REG_PASSIVE_BUFFER, 0x400},
	{OP_WR, TSEM_REG_FAST_MEMORY + 0x18bc0, 0x1},
	{OP_WR, TSEM_REG_FAST_MEMORY + 0x18000, 0x34},
	{OP_WR, TSEM_REG_FAST_MEMORY + 0x18040, 0x18},
	{OP_WR, TSEM_REG_FAST_MEMORY + 0x18080, 0xc},
	{OP_WR, TSEM_REG_FAST_MEMORY + 0x180c0, 0x20},
	{OP_WR_ASIC, TSEM_REG_FAST_MEMORY + 0x18300, 0x7a120},
	{OP_WR_EMUL, TSEM_REG_FAST_MEMORY + 0x18300, 0x138},
	{OP_WR_FPGA, TSEM_REG_FAST_MEMORY + 0x18300, 0x1388},
	{OP_WR, TSEM_REG_FAST_MEMORY + 0x183c0, 0x1f4},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x2000, 0xb2},
	{OP_WR_E1H, TSEM_REG_FAST_MEMORY + 0x11480, 0x1},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x23c8, 0xc1},
	{OP_WR_EMUL_E1H, TSEM_REG_FAST_MEMORY + 0x11480, 0x0},
	{OP_SW_E1, TSEM_REG_FAST_MEMORY + 0x23c8 + 0x304, 0x10223},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x1000, 0x2b3},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x1020, 0xc8},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x1000 + 0xacc, 0x10223},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x1000, 0x2},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0xa020, 0xc8},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x1c18, 0x4},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0xa000, 0x2},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x1c10, 0x2},
	{OP_WR_E1H, TSEM_REG_FAST_MEMORY + 0x1ad0, 0x0},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x800, 0x2},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3678, 0x6},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x808, 0x2},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3670, 0x2},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x810, 0x4},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5000, 0x2},
	{OP_SW_E1, TSEM_REG_FAST_MEMORY + 0x1fb0, 0x40224},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5008, 0x4},
	{OP_SW_E1, TSEM_REG_FAST_MEMORY + 0x4cb0, 0x80228},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5018, 0x4},
	{OP_ZP_E1, TSEM_REG_INT_TABLE, 0x920000},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5028, 0x4},
	{OP_WR_64_E1, TSEM_REG_INT_TABLE + 0x360, 0x140230},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5038, 0x4},
	{OP_ZP_E1, TSEM_REG_PRAM, 0x32bb0000},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5048, 0x4},
	{OP_ZP_E1, TSEM_REG_PRAM + 0x8000, 0x32f50caf},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5058, 0x4},
	{OP_ZP_E1, TSEM_REG_PRAM + 0x10000, 0xd28196d},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5068, 0x4},
	{OP_WR_64_E1, TSEM_REG_PRAM + 0x11b00, 0x5ca00232},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5078, 0x2},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x4000, 0x2},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x4008, 0x2},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x6140, 0x200224},
	{OP_ZP_E1H, TSEM_REG_INT_TABLE, 0x980000},
	{OP_WR_64_E1H, TSEM_REG_INT_TABLE + 0x398, 0xd0244},
	{OP_ZP_E1H, TSEM_REG_PRAM, 0x310a0000},
	{OP_ZP_E1H, TSEM_REG_PRAM + 0x8000, 0x35590c43},
	{OP_ZP_E1H, TSEM_REG_PRAM + 0x10000, 0x1a3c199a},
	{OP_WR_64_E1H, TSEM_REG_PRAM + 0x14210, 0x57be0246},
#define TSEM_COMMON_END         285
#define TSEM_PORT0_START        285
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x22c8, 0x20},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x2000, 0x16c},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x4000, 0x16c},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0xb000, 0x28},
	{OP_WR_E1, TSEM_REG_FAST_MEMORY + 0x4b60, 0x0},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0xb140, 0xc},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x1400, 0xa},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x32c0, 0x12},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x1450, 0x6},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3350, 0x64},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x1500, 0x2},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x8108, 0x2},
	{OP_SW_E1, TSEM_REG_FAST_MEMORY + 0x1500 + 0x8, 0x50234},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x1500 + 0x1c, 0x7},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x1570, 0x12},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x9c0, 0x4c},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x800, 0x2},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x820, 0xe},
	{OP_SW_E1, TSEM_REG_FAST_MEMORY + 0x1fb0, 0x20239},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x2908, 0x2},
#define TSEM_PORT0_END          305
#define TSEM_PORT1_START        305
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x2348, 0x20},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x25b0, 0x16c},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x45b0, 0x16c},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0xb0a0, 0x28},
	{OP_WR_E1, TSEM_REG_FAST_MEMORY + 0x4b64, 0x0},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0xb170, 0xc},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x1428, 0xa},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3308, 0x12},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x1468, 0x6},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x34e0, 0x64},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x1538, 0x2},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x8110, 0x2},
	{OP_SW_E1, TSEM_REG_FAST_MEMORY + 0x1538 + 0x8, 0x5023b},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x1538 + 0x1c, 0x7},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x15b8, 0x12},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0xaf0, 0x4c},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x808, 0x2},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x858, 0xe},
	{OP_SW_E1, TSEM_REG_FAST_MEMORY + 0x1fb8, 0x20240},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x2910, 0x2},
#define TSEM_PORT1_END          325
#define TSEM_FUNC0_START        325
	{OP_WR_E1H, TSEM_REG_FAST_MEMORY + 0x2b60, 0x0},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3000, 0x2},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x3000 + 0x8, 0x50248},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3000 + 0x1c, 0x7},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x31c0, 0x8},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5000, 0x2},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5080, 0x12},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x4000, 0x2},
#define TSEM_FUNC0_END          333
#define TSEM_FUNC1_START        333
	{OP_WR_E1H, TSEM_REG_FAST_MEMORY + 0x2b64, 0x0},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3038, 0x2},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x3038 + 0x8, 0x5024d},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3038 + 0x1c, 0x7},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x31e0, 0x8},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5010, 0x2},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x50c8, 0x12},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x4008, 0x2},
#define TSEM_FUNC1_END          341
#define TSEM_FUNC2_START        341
	{OP_WR_E1H, TSEM_REG_FAST_MEMORY + 0x2b68, 0x0},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3070, 0x2},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x3070 + 0x8, 0x50252},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3070 + 0x1c, 0x7},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3200, 0x8},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5020, 0x2},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5110, 0x12},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x4010, 0x20257},
#define TSEM_FUNC2_END          349
#define TSEM_FUNC3_START        349
	{OP_WR_E1H, TSEM_REG_FAST_MEMORY + 0x2b6c, 0x0},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x30a8, 0x2},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x30a8 + 0x8, 0x50259},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x30a8 + 0x1c, 0x7},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3220, 0x8},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5030, 0x2},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5158, 0x12},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x4018, 0x2025e},
#define TSEM_FUNC3_END          357
#define TSEM_FUNC4_START        357
	{OP_WR_E1H, TSEM_REG_FAST_MEMORY + 0x2b70, 0x0},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x30e0, 0x2},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x30e0 + 0x8, 0x50260},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x30e0 + 0x1c, 0x7},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3240, 0x8},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5040, 0x2},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x51a0, 0x12},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x4020, 0x20265},
#define TSEM_FUNC4_END          365
#define TSEM_FUNC5_START        365
	{OP_WR_E1H, TSEM_REG_FAST_MEMORY + 0x2b74, 0x0},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3118, 0x2},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x3118 + 0x8, 0x50267},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3118 + 0x1c, 0x7},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3260, 0x8},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5050, 0x2},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x51e8, 0x12},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x4028, 0x2026c},
#define TSEM_FUNC5_END          373
#define TSEM_FUNC6_START        373
	{OP_WR_E1H, TSEM_REG_FAST_MEMORY + 0x2b78, 0x0},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3150, 0x2},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x3150 + 0x8, 0x5026e},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3150 + 0x1c, 0x7},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3280, 0x8},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5060, 0x2},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5230, 0x12},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x4030, 0x20273},
#define TSEM_FUNC6_END          381
#define TSEM_FUNC7_START        381
	{OP_WR_E1H, TSEM_REG_FAST_MEMORY + 0x2b7c, 0x0},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3188, 0x2},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x3188 + 0x8, 0x50275},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3188 + 0x1c, 0x7},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x32a0, 0x8},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5070, 0x2},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5278, 0x12},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x4038, 0x2027a},
#define TSEM_FUNC7_END          389
#define MISC_COMMON_START       389
	{OP_WR_E1, MISC_REG_GRC_TIMEOUT_EN, 0x1},
	{OP_WR, MISC_REG_PLL_STORM_CTRL_1, 0x71d2911},
	{OP_WR, MISC_REG_PLL_STORM_CTRL_2, 0x0},
	{OP_WR, MISC_REG_PLL_STORM_CTRL_3, 0x9c0424},
	{OP_WR, MISC_REG_PLL_STORM_CTRL_4, 0x0},
	{OP_WR, MISC_REG_LCPLL_CTRL_1, 0x209},
	{OP_WR_E1, MISC_REG_SPIO, 0xff000000},
#define MISC_COMMON_END         396
#define MISC_FUNC0_START        396
	{OP_WR_E1H, MISC_REG_NIG_WOL_P0, 0x0},
#define MISC_FUNC0_END          397
#define MISC_FUNC1_START        397
	{OP_WR_E1H, MISC_REG_NIG_WOL_P1, 0x0},
#define MISC_FUNC1_END          398
#define MISC_FUNC2_START        398
	{OP_WR_E1H, MISC_REG_NIG_WOL_P0, 0x0},
#define MISC_FUNC2_END          399
#define MISC_FUNC3_START        399
	{OP_WR_E1H, MISC_REG_NIG_WOL_P1, 0x0},
#define MISC_FUNC3_END          400
#define MISC_FUNC4_START        400
	{OP_WR_E1H, MISC_REG_NIG_WOL_P0, 0x0},
#define MISC_FUNC4_END          401
#define MISC_FUNC5_START        401
	{OP_WR_E1H, MISC_REG_NIG_WOL_P1, 0x0},
#define MISC_FUNC5_END          402
#define MISC_FUNC6_START        402
	{OP_WR_E1H, MISC_REG_NIG_WOL_P0, 0x0},
#define MISC_FUNC6_END          403
#define MISC_FUNC7_START        403
	{OP_WR_E1H, MISC_REG_NIG_WOL_P1, 0x0},
#define MISC_FUNC7_END          404
#define NIG_COMMON_START        404
	{OP_WR, NIG_REG_PBF_LB_IN_EN, 0x1},
	{OP_WR, NIG_REG_PRS_REQ_IN_EN, 0x1},
	{OP_WR, NIG_REG_EGRESS_DEBUG_IN_EN, 0x1},
	{OP_WR, NIG_REG_BRB_LB_OUT_EN, 0x1},
	{OP_WR, NIG_REG_PRS_EOP_OUT_EN, 0x1},
#define NIG_COMMON_END          409
#define NIG_PORT0_START         409
	{OP_WR, NIG_REG_LLH0_CM_HEADER, 0x300000},
	{OP_WR, NIG_REG_LLH0_EVENT_ID, 0x28},
	{OP_WR, NIG_REG_LLH0_ERROR_MASK, 0x0},
	{OP_WR, NIG_REG_LLH0_XCM_MASK, 0x4},
	{OP_WR, NIG_REG_LLH0_BRB1_NOT_MCP, 0x1},
	{OP_WR, NIG_REG_STATUS_INTERRUPT_PORT0, 0x0},
	{OP_WR_E1H, NIG_REG_LLH0_CLS_TYPE, 0x1},
	{OP_WR, NIG_REG_LLH0_XCM_INIT_CREDIT, 0x30},
	{OP_WR, NIG_REG_BRB0_PAUSE_IN_EN, 0x1},
	{OP_WR, NIG_REG_EGRESS_PBF0_IN_EN, 0x1},
	{OP_WR, NIG_REG_BRB0_OUT_EN, 0x1},
	{OP_WR, NIG_REG_XCM0_OUT_EN, 0x1},
#define NIG_PORT0_END           421
#define NIG_PORT1_START         421
	{OP_WR, NIG_REG_LLH1_CM_HEADER, 0x300000},
	{OP_WR, NIG_REG_LLH1_EVENT_ID, 0x28},
	{OP_WR, NIG_REG_LLH1_ERROR_MASK, 0x0},
	{OP_WR, NIG_REG_LLH1_XCM_MASK, 0x4},
	{OP_WR, NIG_REG_LLH1_BRB1_NOT_MCP, 0x1},
	{OP_WR, NIG_REG_STATUS_INTERRUPT_PORT1, 0x0},
	{OP_WR_E1H, NIG_REG_LLH1_CLS_TYPE, 0x1},
	{OP_WR, NIG_REG_LLH1_XCM_INIT_CREDIT, 0x30},
	{OP_WR, NIG_REG_BRB1_PAUSE_IN_EN, 0x1},
	{OP_WR, NIG_REG_EGRESS_PBF1_IN_EN, 0x1},
	{OP_WR, NIG_REG_BRB1_OUT_EN, 0x1},
	{OP_WR, NIG_REG_XCM1_OUT_EN, 0x1},
#define NIG_PORT1_END           433
#define UPB_COMMON_START        433
	{OP_WR, GRCBASE_UPB + PB_REG_CONTROL, 0x20},
#define UPB_COMMON_END          434
#define CSDM_COMMON_START       434
	{OP_WR_E1, CSDM_REG_CFC_RSP_START_ADDR, 0xa11},
	{OP_WR_E1H, CSDM_REG_CFC_RSP_START_ADDR, 0x211},
	{OP_WR_E1, CSDM_REG_CMP_COUNTER_START_ADDR, 0xa00},
	{OP_WR_E1H, CSDM_REG_CMP_COUNTER_START_ADDR, 0x200},
	{OP_WR_E1, CSDM_REG_Q_COUNTER_START_ADDR, 0xa04},
	{OP_WR_E1H, CSDM_REG_Q_COUNTER_START_ADDR, 0x204},
	{OP_WR, CSDM_REG_CMP_COUNTER_MAX0, 0xffff},
	{OP_WR, CSDM_REG_CMP_COUNTER_MAX1, 0xffff},
	{OP_WR, CSDM_REG_CMP_COUNTER_MAX2, 0xffff},
	{OP_WR, CSDM_REG_CMP_COUNTER_MAX3, 0xffff},
	{OP_WR, CSDM_REG_AGG_INT_EVENT_0, 0xc6},
	{OP_WR, CSDM_REG_AGG_INT_EVENT_1, 0x0},
	{OP_WR, CSDM_REG_AGG_INT_EVENT_2, 0x34},
	{OP_WR, CSDM_REG_AGG_INT_EVENT_3, 0x35},
	{OP_ZR, CSDM_REG_AGG_INT_EVENT_4, 0x1c},
	{OP_WR, CSDM_REG_AGG_INT_T_0, 0x1},
	{OP_ZR, CSDM_REG_AGG_INT_T_1, 0x5f},
	{OP_WR, CSDM_REG_ENABLE_IN1, 0x7ffffff},
	{OP_WR, CSDM_REG_ENABLE_IN2, 0x3f},
	{OP_WR, CSDM_REG_ENABLE_OUT1, 0x7ffffff},
	{OP_WR, CSDM_REG_ENABLE_OUT2, 0xf},
	{OP_RD, CSDM_REG_NUM_OF_Q0_CMD, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_Q1_CMD, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_Q3_CMD, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_Q4_CMD, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_Q5_CMD, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_Q6_CMD, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_Q7_CMD, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_Q8_CMD, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_Q9_CMD, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_Q10_CMD, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_Q11_CMD, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_PKT_END_MSG, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_PXP_ASYNC_REQ, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_ACK_AFTER_PLACE, 0x0},
	{OP_WR_E1, CSDM_REG_INIT_CREDIT_PXP_CTRL, 0x1},
	{OP_WR_ASIC, CSDM_REG_TIMER_TICK, 0x3e8},
	{OP_WR_EMUL, CSDM_REG_TIMER_TICK, 0x1},
	{OP_WR_FPGA, CSDM_REG_TIMER_TICK, 0xa},
#define CSDM_COMMON_END         473
#define USDM_COMMON_START       473
	{OP_WR_E1, USDM_REG_CFC_RSP_START_ADDR, 0xa11},
	{OP_WR_E1H, USDM_REG_CFC_RSP_START_ADDR, 0x411},
	{OP_WR_E1, USDM_REG_CMP_COUNTER_START_ADDR, 0xa00},
	{OP_WR_E1H, USDM_REG_CMP_COUNTER_START_ADDR, 0x400},
	{OP_WR_E1, USDM_REG_Q_COUNTER_START_ADDR, 0xa04},
	{OP_WR_E1H, USDM_REG_Q_COUNTER_START_ADDR, 0x404},
	{OP_WR_E1, USDM_REG_PCK_END_MSG_START_ADDR, 0xa21},
	{OP_WR_E1H, USDM_REG_PCK_END_MSG_START_ADDR, 0x421},
	{OP_WR, USDM_REG_CMP_COUNTER_MAX0, 0xffff},
	{OP_WR, USDM_REG_CMP_COUNTER_MAX1, 0xffff},
	{OP_WR, USDM_REG_CMP_COUNTER_MAX2, 0xffff},
	{OP_WR, USDM_REG_CMP_COUNTER_MAX3, 0xffff},
	{OP_WR, USDM_REG_AGG_INT_EVENT_0, 0x46},
	{OP_WR, USDM_REG_AGG_INT_EVENT_1, 0x5},
	{OP_WR, USDM_REG_AGG_INT_EVENT_2, 0x34},
	{OP_WR, USDM_REG_AGG_INT_EVENT_3, 0x35},
	{OP_ZR_E1, USDM_REG_AGG_INT_EVENT_4, 0x5c},
	{OP_WR_E1H, USDM_REG_AGG_INT_EVENT_4, 0x7},
	{OP_ZR_E1H, USDM_REG_AGG_INT_EVENT_5, 0x5b},
	{OP_WR, USDM_REG_AGG_INT_MODE_0, 0x1},
	{OP_ZR_E1, USDM_REG_AGG_INT_MODE_1, 0x1f},
	{OP_ZR_E1H, USDM_REG_AGG_INT_MODE_1, 0x3},
	{OP_WR_E1H, USDM_REG_AGG_INT_MODE_4, 0x1},
	{OP_ZR_E1H, USDM_REG_AGG_INT_MODE_5, 0x1b},
	{OP_WR, USDM_REG_ENABLE_IN1, 0x7ffffff},
	{OP_WR, USDM_REG_ENABLE_IN2, 0x3f},
	{OP_WR, USDM_REG_ENABLE_OUT1, 0x7ffffff},
	{OP_WR, USDM_REG_ENABLE_OUT2, 0xf},
	{OP_RD, USDM_REG_NUM_OF_Q0_CMD, 0x0},
	{OP_RD, USDM_REG_NUM_OF_Q1_CMD, 0x0},
	{OP_RD, USDM_REG_NUM_OF_Q2_CMD, 0x0},
	{OP_RD, USDM_REG_NUM_OF_Q3_CMD, 0x0},
	{OP_RD, USDM_REG_NUM_OF_Q4_CMD, 0x0},
	{OP_RD, USDM_REG_NUM_OF_Q5_CMD, 0x0},
	{OP_RD, USDM_REG_NUM_OF_Q6_CMD, 0x0},
	{OP_RD, USDM_REG_NUM_OF_Q7_CMD, 0x0},
	{OP_RD, USDM_REG_NUM_OF_Q8_CMD, 0x0},
	{OP_RD, USDM_REG_NUM_OF_Q9_CMD, 0x0},
	{OP_RD, USDM_REG_NUM_OF_Q10_CMD, 0x0},
	{OP_RD, USDM_REG_NUM_OF_Q11_CMD, 0x0},
	{OP_RD, USDM_REG_NUM_OF_PKT_END_MSG, 0x0},
	{OP_RD, USDM_REG_NUM_OF_PXP_ASYNC_REQ, 0x0},
	{OP_RD, USDM_REG_NUM_OF_ACK_AFTER_PLACE, 0x0},
	{OP_WR_E1, USDM_REG_INIT_CREDIT_PXP_CTRL, 0x1},
	{OP_WR_ASIC, USDM_REG_TIMER_TICK, 0x3e8},
	{OP_WR_EMUL, USDM_REG_TIMER_TICK, 0x1},
	{OP_WR_FPGA, USDM_REG_TIMER_TICK, 0xa},
#define USDM_COMMON_END         520
#define CCM_COMMON_START        520
	{OP_WR, CCM_REG_XX_OVFL_EVNT_ID, 0x32},
	{OP_WR, CCM_REG_CQM_CCM_HDR_P, 0x2150020},
	{OP_WR, CCM_REG_CQM_CCM_HDR_S, 0x2150020},
	{OP_WR, CCM_REG_ERR_CCM_HDR, 0x8100000},
	{OP_WR, CCM_REG_ERR_EVNT_ID, 0x33},
	{OP_WR, CCM_REG_TSEM_WEIGHT, 0x0},
	{OP_WR, CCM_REG_XSEM_WEIGHT, 0x4},
	{OP_WR, CCM_REG_USEM_WEIGHT, 0x4},
	{OP_ZR, CCM_REG_PBF_WEIGHT, 0x2},
	{OP_WR, CCM_REG_CQM_P_WEIGHT, 0x2},
	{OP_WR, CCM_REG_CCM_CQM_USE_Q, 0x1},
	{OP_WR, CCM_REG_CNT_AUX1_Q, 0x2},
	{OP_WR, CCM_REG_CNT_AUX2_Q, 0x2},
	{OP_WR, CCM_REG_INV_DONE_Q, 0x1},
	{OP_WR, CCM_REG_GR_ARB_TYPE, 0x1},
	{OP_WR, CCM_REG_GR_LD0_PR, 0x1},
	{OP_WR, CCM_REG_GR_LD1_PR, 0x2},
	{OP_WR, CCM_REG_CFC_INIT_CRD, 0x1},
	{OP_WR, CCM_REG_CQM_INIT_CRD, 0x20},
	{OP_WR, CCM_REG_FIC0_INIT_CRD, 0x40},
	{OP_WR, CCM_REG_FIC1_INIT_CRD, 0x40},
	{OP_WR, CCM_REG_XX_INIT_CRD, 0x3},
	{OP_WR, CCM_REG_XX_MSG_NUM, 0x18},
	{OP_ZR, CCM_REG_XX_TABLE, 0x12},
	{OP_SW_E1, CCM_REG_XX_DESCR_TABLE, 0x240242},
	{OP_SW_E1H, CCM_REG_XX_DESCR_TABLE, 0x24027c},
	{OP_WR, CCM_REG_N_SM_CTX_LD_0, 0x1},
	{OP_WR, CCM_REG_N_SM_CTX_LD_1, 0x2},
	{OP_WR, CCM_REG_N_SM_CTX_LD_2, 0x8},
	{OP_WR, CCM_REG_N_SM_CTX_LD_3, 0x8},
	{OP_ZR, CCM_REG_N_SM_CTX_LD_4, 0x4},
	{OP_WR, CCM_REG_CCM_REG0_SZ, 0x4},
	{OP_WR_E1, CCM_REG_QOS_PHYS_QNUM0_0, 0x9},
	{OP_WR_E1, CCM_REG_QOS_PHYS_QNUM0_1, 0x29},
	{OP_WR_E1, CCM_REG_QOS_PHYS_QNUM1_0, 0xa},
	{OP_WR_E1, CCM_REG_QOS_PHYS_QNUM1_1, 0x2a},
	{OP_WR_E1, CCM_REG_QOS_PHYS_QNUM2_0, 0x7},
	{OP_WR_E1, CCM_REG_QOS_PHYS_QNUM2_1, 0x27},
	{OP_WR_E1, CCM_REG_QOS_PHYS_QNUM3_0, 0x7},
	{OP_WR_E1, CCM_REG_QOS_PHYS_QNUM3_1, 0x27},
	{OP_WR_E1, CCM_REG_PHYS_QNUM1_0, 0xc},
	{OP_WR_E1, CCM_REG_PHYS_QNUM1_1, 0x2c},
	{OP_WR_E1, CCM_REG_PHYS_QNUM2_0, 0xc},
	{OP_WR_E1, CCM_REG_PHYS_QNUM2_1, 0x2c},
	{OP_WR_E1, CCM_REG_PHYS_QNUM3_0, 0xc},
	{OP_WR_E1, CCM_REG_PHYS_QNUM3_1, 0x2c},
	{OP_WR, CCM_REG_CCM_STORM0_IFEN, 0x1},
	{OP_WR, CCM_REG_CCM_STORM1_IFEN, 0x1},
	{OP_WR, CCM_REG_CCM_CQM_IFEN, 0x1},
	{OP_WR, CCM_REG_STORM_CCM_IFEN, 0x1},
	{OP_WR, CCM_REG_CQM_CCM_IFEN, 0x1},
	{OP_WR, CCM_REG_CSDM_IFEN, 0x1},
	{OP_WR, CCM_REG_TSEM_IFEN, 0x1},
	{OP_WR, CCM_REG_XSEM_IFEN, 0x1},
	{OP_WR, CCM_REG_USEM_IFEN, 0x1},
	{OP_WR, CCM_REG_PBF_IFEN, 0x1},
	{OP_WR, CCM_REG_CDU_AG_WR_IFEN, 0x1},
	{OP_WR, CCM_REG_CDU_AG_RD_IFEN, 0x1},
	{OP_WR, CCM_REG_CDU_SM_WR_IFEN, 0x1},
	{OP_WR, CCM_REG_CDU_SM_RD_IFEN, 0x1},
	{OP_WR, CCM_REG_CCM_CFC_IFEN, 0x1},
#define CCM_COMMON_END          581
#define CCM_FUNC0_START         581
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM0_0, 0x9},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM1_0, 0xa},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM2_0, 0x7},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM3_0, 0x7},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM1_0, 0xc},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM2_0, 0xb},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM3_0, 0x7},
#define CCM_FUNC0_END           588
#define CCM_FUNC1_START         588
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM0_1, 0x29},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM1_1, 0x2a},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM2_1, 0x27},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM3_1, 0x27},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM1_1, 0x2c},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM2_1, 0x2b},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM3_1, 0x27},
#define CCM_FUNC1_END           595
#define CCM_FUNC2_START         595
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM0_0, 0x19},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM1_0, 0x1a},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM2_0, 0x17},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM3_0, 0x17},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM1_0, 0x1c},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM2_0, 0x1b},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM3_0, 0x17},
#define CCM_FUNC2_END           602
#define CCM_FUNC3_START         602
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM0_1, 0x39},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM1_1, 0x3a},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM2_1, 0x37},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM3_1, 0x37},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM1_1, 0x3c},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM2_1, 0x3b},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM3_1, 0x37},
#define CCM_FUNC3_END           609
#define CCM_FUNC4_START         609
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM0_0, 0x49},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM1_0, 0x4a},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM2_0, 0x47},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM3_0, 0x47},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM1_0, 0x4c},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM2_0, 0x4b},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM3_0, 0x47},
#define CCM_FUNC4_END           616
#define CCM_FUNC5_START         616
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM0_1, 0x69},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM1_1, 0x6a},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM2_1, 0x67},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM3_1, 0x67},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM1_1, 0x6c},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM2_1, 0x6b},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM3_1, 0x67},
#define CCM_FUNC5_END           623
#define CCM_FUNC6_START         623
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM0_0, 0x59},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM1_0, 0x5a},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM2_0, 0x57},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM3_0, 0x57},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM1_0, 0x5c},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM2_0, 0x5b},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM3_0, 0x57},
#define CCM_FUNC6_END           630
#define CCM_FUNC7_START         630
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM0_1, 0x79},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM1_1, 0x7a},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM2_1, 0x77},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM3_1, 0x77},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM1_1, 0x7c},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM2_1, 0x7b},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM3_1, 0x77},
#define CCM_FUNC7_END           637
#define UCM_COMMON_START        637
	{OP_WR, UCM_REG_XX_OVFL_EVNT_ID, 0x32},
	{OP_WR, UCM_REG_UQM_UCM_HDR_P, 0x2150020},
	{OP_WR, UCM_REG_UQM_UCM_HDR_S, 0x2150020},
	{OP_WR, UCM_REG_TM_UCM_HDR, 0x30},
	{OP_WR, UCM_REG_ERR_UCM_HDR, 0x8100000},
	{OP_WR, UCM_REG_ERR_EVNT_ID, 0x33},
	{OP_WR, UCM_REG_EXPR_EVNT_ID, 0x30},
	{OP_WR, UCM_REG_STOP_EVNT_ID, 0x31},
	{OP_WR, UCM_REG_TSEM_WEIGHT, 0x3},
	{OP_WR, UCM_REG_CSEM_WEIGHT, 0x0},
	{OP_WR, UCM_REG_CP_WEIGHT, 0x0},
	{OP_WR, UCM_REG_UQM_P_WEIGHT, 0x6},
	{OP_WR, UCM_REG_UCM_UQM_USE_Q, 0x1},
	{OP_WR, UCM_REG_INV_CFLG_Q, 0x1},
	{OP_WR, UCM_REG_GR_ARB_TYPE, 0x1},
	{OP_WR, UCM_REG_GR_LD0_PR, 0x1},
	{OP_WR, UCM_REG_GR_LD1_PR, 0x2},
	{OP_WR, UCM_REG_CFC_INIT_CRD, 0x1},
	{OP_WR, UCM_REG_FIC0_INIT_CRD, 0x40},
	{OP_WR, UCM_REG_FIC1_INIT_CRD, 0x40},
	{OP_WR, UCM_REG_TM_INIT_CRD, 0x4},
	{OP_WR, UCM_REG_UQM_INIT_CRD, 0x20},
	{OP_WR, UCM_REG_XX_INIT_CRD, 0xe},
	{OP_WR, UCM_REG_XX_MSG_NUM, 0x1b},
	{OP_ZR, UCM_REG_XX_TABLE, 0x12},
	{OP_SW_E1, UCM_REG_XX_DESCR_TABLE, 0x1b0266},
	{OP_SW_E1H, UCM_REG_XX_DESCR_TABLE, 0x1b02a0},
	{OP_WR, UCM_REG_N_SM_CTX_LD_0, 0x10},
	{OP_WR, UCM_REG_N_SM_CTX_LD_1, 0x7},
	{OP_WR, UCM_REG_N_SM_CTX_LD_2, 0xf},
	{OP_WR, UCM_REG_N_SM_CTX_LD_3, 0x10},
	{OP_ZR_E1, UCM_REG_N_SM_CTX_LD_4, 0x4},
	{OP_WR_E1H, UCM_REG_N_SM_CTX_LD_4, 0xb},
	{OP_ZR_E1H, UCM_REG_N_SM_CTX_LD_5, 0x3},
	{OP_WR, UCM_REG_UCM_REG0_SZ, 0x3},
	{OP_WR_E1, UCM_REG_PHYS_QNUM0_0, 0xf},
	{OP_WR_E1, UCM_REG_PHYS_QNUM0_1, 0x2f},
	{OP_WR_E1, UCM_REG_PHYS_QNUM1_0, 0xe},
	{OP_WR_E1, UCM_REG_PHYS_QNUM1_1, 0x2e},
	{OP_WR, UCM_REG_UCM_STORM0_IFEN, 0x1},
	{OP_WR, UCM_REG_UCM_STORM1_IFEN, 0x1},
	{OP_WR, UCM_REG_UCM_UQM_IFEN, 0x1},
	{OP_WR, UCM_REG_STORM_UCM_IFEN, 0x1},
	{OP_WR, UCM_REG_UQM_UCM_IFEN, 0x1},
	{OP_WR, UCM_REG_USDM_IFEN, 0x1},
	{OP_WR, UCM_REG_TM_UCM_IFEN, 0x1},
	{OP_WR, UCM_REG_UCM_TM_IFEN, 0x1},
	{OP_WR, UCM_REG_TSEM_IFEN, 0x1},
	{OP_WR, UCM_REG_CSEM_IFEN, 0x1},
	{OP_WR, UCM_REG_XSEM_IFEN, 0x1},
	{OP_WR, UCM_REG_DORQ_IFEN, 0x1},
	{OP_WR, UCM_REG_CDU_AG_WR_IFEN, 0x1},
	{OP_WR, UCM_REG_CDU_AG_RD_IFEN, 0x1},
	{OP_WR, UCM_REG_CDU_SM_WR_IFEN, 0x1},
	{OP_WR, UCM_REG_CDU_SM_RD_IFEN, 0x1},
	{OP_WR, UCM_REG_UCM_CFC_IFEN, 0x1},
#define UCM_COMMON_END          693
#define UCM_FUNC0_START         693
	{OP_WR_E1H, UCM_REG_PHYS_QNUM0_0, 0xf},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM1_0, 0xe},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM2_0, 0x0},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM3_0, 0x0},
#define UCM_FUNC0_END           697
#define UCM_FUNC1_START         697
	{OP_WR_E1H, UCM_REG_PHYS_QNUM0_1, 0x2f},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM1_1, 0x2e},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM2_1, 0x0},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM3_1, 0x0},
#define UCM_FUNC1_END           701
#define UCM_FUNC2_START         701
	{OP_WR_E1H, UCM_REG_PHYS_QNUM0_0, 0x1f},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM1_0, 0x1e},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM2_0, 0x0},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM3_0, 0x0},
#define UCM_FUNC2_END           705
#define UCM_FUNC3_START         705
	{OP_WR_E1H, UCM_REG_PHYS_QNUM0_1, 0x3f},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM1_1, 0x3e},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM2_1, 0x0},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM3_1, 0x0},
#define UCM_FUNC3_END           709
#define UCM_FUNC4_START         709
	{OP_WR_E1H, UCM_REG_PHYS_QNUM0_0, 0x4f},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM1_0, 0x4e},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM2_0, 0x0},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM3_0, 0x0},
#define UCM_FUNC4_END           713
#define UCM_FUNC5_START         713
	{OP_WR_E1H, UCM_REG_PHYS_QNUM0_1, 0x6f},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM1_1, 0x6e},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM2_1, 0x0},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM3_1, 0x0},
#define UCM_FUNC5_END           717
#define UCM_FUNC6_START         717
	{OP_WR_E1H, UCM_REG_PHYS_QNUM0_0, 0x5f},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM1_0, 0x5e},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM2_0, 0x0},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM3_0, 0x0},
#define UCM_FUNC6_END           721
#define UCM_FUNC7_START         721
	{OP_WR_E1H, UCM_REG_PHYS_QNUM0_1, 0x7f},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM1_1, 0x7e},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM2_1, 0x0},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM3_1, 0x0},
#define UCM_FUNC7_END           725
#define USEM_COMMON_START       725
	{OP_RD, USEM_REG_MSG_NUM_FIC0, 0x0},
	{OP_RD, USEM_REG_MSG_NUM_FIC1, 0x0},
	{OP_RD, USEM_REG_MSG_NUM_FOC0, 0x0},
	{OP_RD, USEM_REG_MSG_NUM_FOC1, 0x0},
	{OP_RD, USEM_REG_MSG_NUM_FOC2, 0x0},
	{OP_RD, USEM_REG_MSG_NUM_FOC3, 0x0},
	{OP_WR, USEM_REG_ARB_ELEMENT0, 0x1},
	{OP_WR, USEM_REG_ARB_ELEMENT1, 0x2},
	{OP_WR, USEM_REG_ARB_ELEMENT2, 0x3},
	{OP_WR, USEM_REG_ARB_ELEMENT3, 0x0},
	{OP_WR, USEM_REG_ARB_ELEMENT4, 0x4},
	{OP_WR, USEM_REG_ARB_CYCLE_SIZE, 0x1},
	{OP_WR, USEM_REG_TS_0_AS, 0x0},
	{OP_WR, USEM_REG_TS_1_AS, 0x1},
	{OP_WR, USEM_REG_TS_2_AS, 0x4},
	{OP_WR, USEM_REG_TS_3_AS, 0x0},
	{OP_WR, USEM_REG_TS_4_AS, 0x1},
	{OP_WR, USEM_REG_TS_5_AS, 0x3},
	{OP_WR, USEM_REG_TS_6_AS, 0x0},
	{OP_WR, USEM_REG_TS_7_AS, 0x1},
	{OP_WR, USEM_REG_TS_8_AS, 0x4},
	{OP_WR, USEM_REG_TS_9_AS, 0x0},
	{OP_WR, USEM_REG_TS_10_AS, 0x1},
	{OP_WR, USEM_REG_TS_11_AS, 0x3},
	{OP_WR, USEM_REG_TS_12_AS, 0x0},
	{OP_WR, USEM_REG_TS_13_AS, 0x1},
	{OP_WR, USEM_REG_TS_14_AS, 0x4},
	{OP_WR, USEM_REG_TS_15_AS, 0x0},
	{OP_WR, USEM_REG_TS_16_AS, 0x4},
	{OP_WR, USEM_REG_TS_17_AS, 0x3},
	{OP_ZR, USEM_REG_TS_18_AS, 0x2},
	{OP_WR, USEM_REG_ENABLE_IN, 0x3fff},
	{OP_WR, USEM_REG_ENABLE_OUT, 0x3ff},
	{OP_WR, USEM_REG_FIC0_DISABLE, 0x0},
	{OP_WR, USEM_REG_FIC1_DISABLE, 0x0},
	{OP_WR, USEM_REG_PAS_DISABLE, 0x0},
	{OP_WR, USEM_REG_THREADS_LIST, 0xffff},
	{OP_ZR, USEM_REG_PASSIVE_BUFFER, 0x800},
	{OP_WR, USEM_REG_FAST_MEMORY + 0x18bc0, 0x1},
	{OP_WR, USEM_REG_FAST_MEMORY + 0x18000, 0x1a},
	{OP_WR, USEM_REG_FAST_MEMORY + 0x18040, 0x4e},
	{OP_WR, USEM_REG_FAST_MEMORY + 0x18080, 0x10},
	{OP_WR, USEM_REG_FAST_MEMORY + 0x180c0, 0x20},
	{OP_WR_ASIC, USEM_REG_FAST_MEMORY + 0x18300, 0x7a120},
	{OP_WR_EMUL, USEM_REG_FAST_MEMORY + 0x18300, 0x138},
	{OP_WR_FPGA, USEM_REG_FAST_MEMORY + 0x18300, 0x1388},
	{OP_WR, USEM_REG_FAST_MEMORY + 0x183c0, 0x1f4},
	{OP_WR_ASIC, USEM_REG_FAST_MEMORY + 0x18380, 0x1dcd6500},
	{OP_WR_EMUL, USEM_REG_FAST_MEMORY + 0x18380, 0x4c4b4},
	{OP_WR_FPGA, USEM_REG_FAST_MEMORY + 0x18380, 0x4c4b40},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x5000, 0xc2},
	{OP_WR_EMUL_E1H, USEM_REG_FAST_MEMORY + 0x11480, 0x0},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1020, 0xc8},
	{OP_WR_E1H, USEM_REG_FAST_MEMORY + 0x11480, 0x1},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1000, 0x2},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x2000, 0x102},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x4f00, 0x40},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x8980, 0xc8},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x57f0, 0x4},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x8960, 0x2},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x57d8, 0x5},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3228, 0x4},
	{OP_SW_E1, USEM_REG_FAST_MEMORY + 0x57d8 + 0x14, 0x10281},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3200, 0x9},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1c60, 0x20},
	{OP_SW_E1H, USEM_REG_FAST_MEMORY + 0x3200 + 0x24, 0x102bb},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x4b68, 0x2},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3180, 0x20},
	{OP_SW_E1, USEM_REG_FAST_MEMORY + 0x4b68 + 0x8, 0x20282},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5000, 0x400},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x4b10, 0x2},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x4000, 0x2},
	{OP_SW_E1, USEM_REG_FAST_MEMORY + 0x2830, 0x20284},
	{OP_SW_E1H, USEM_REG_FAST_MEMORY + 0x4000 + 0x8, 0x102bc},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x4000 + 0xc, 0x3},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x6b68, 0x2},
	{OP_SW_E1H, USEM_REG_FAST_MEMORY + 0x6b68 + 0x8, 0x202bd},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x6b10, 0x2},
	{OP_SW_E1H, USEM_REG_FAST_MEMORY + 0x74c0, 0x202bf},
	{OP_WR, USEM_REG_FAST_MEMORY + 0x10800, 0x1000000},
	{OP_SW_E1, USEM_REG_FAST_MEMORY + 0x10c00, 0x100286},
	{OP_SW_E1H, USEM_REG_FAST_MEMORY + 0x10c00, 0x1002c1},
	{OP_WR, USEM_REG_FAST_MEMORY + 0x10800, 0x0},
	{OP_SW_E1, USEM_REG_FAST_MEMORY + 0x10c40, 0x100296},
	{OP_SW_E1H, USEM_REG_FAST_MEMORY + 0x10c40, 0x1002d1},
	{OP_ZP_E1, USEM_REG_INT_TABLE, 0xc50000},
	{OP_ZP_E1H, USEM_REG_INT_TABLE, 0xcd0000},
	{OP_WR_64_E1, USEM_REG_INT_TABLE + 0x368, 0x1302a6},
	{OP_WR_64_E1H, USEM_REG_INT_TABLE + 0x3a8, 0xb02e1},
	{OP_ZP_E1, USEM_REG_PRAM, 0x31fb0000},
	{OP_ZP_E1H, USEM_REG_PRAM, 0x32200000},
	{OP_ZP_E1, USEM_REG_PRAM + 0x8000, 0x36490c7f},
	{OP_ZP_E1H, USEM_REG_PRAM + 0x8000, 0x36020c88},
	{OP_ZP_E1, USEM_REG_PRAM + 0x10000, 0x358d1a12},
	{OP_ZP_E1H, USEM_REG_PRAM + 0x10000, 0x33b61a09},
	{OP_ZP_E1, USEM_REG_PRAM + 0x18000, 0x4152776},
	{OP_ZP_E1H, USEM_REG_PRAM + 0x18000, 0x26a126f7},
	{OP_WR_64_E1, USEM_REG_PRAM + 0x188b0, 0x4eea02a8},
	{OP_ZP_E1H, USEM_REG_PRAM + 0x20000, 0x71230a0},
	{OP_WR_64_E1H, USEM_REG_PRAM + 0x20e70, 0x3e3202e3},
#define USEM_COMMON_END         825
#define USEM_PORT0_START        825
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1400, 0xa0},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x9000, 0xa0},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1900, 0x10},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x9500, 0x40},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1980, 0x30},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x9700, 0x3c},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1d80, 0x48},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x2450, 0x48},
	{OP_WR_E1, USEM_REG_FAST_MEMORY + 0x1fd0, 0x0},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x2770, 0x2},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1b40, 0x4},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3080, 0x20},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1b60, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x8000, 0x12c},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x5318, 0x98},
	{OP_WR_E1H, USEM_REG_FAST_MEMORY + 0x3238, 0x0},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x4b78, 0x52},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5000, 0x20},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x4e08, 0xc},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5100, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5200, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5300, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5400, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5500, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5600, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5700, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5800, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5900, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5a00, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5b00, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5c00, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5d00, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5e00, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5f00, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x6b78, 0x52},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x6e08, 0xc},
#define USEM_PORT0_END          861
#define USEM_PORT1_START        861
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1680, 0xa0},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x9280, 0xa0},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1940, 0x10},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x9600, 0x40},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1a40, 0x30},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x97f0, 0x3c},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1ea0, 0x48},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x2570, 0x48},
	{OP_WR_E1, USEM_REG_FAST_MEMORY + 0x1fd4, 0x0},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x2778, 0x2},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1b50, 0x4},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3100, 0x20},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1be0, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x84b0, 0x12c},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x5578, 0x98},
	{OP_WR_E1H, USEM_REG_FAST_MEMORY + 0x323c, 0x0},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x4cc0, 0x52},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5080, 0x20},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x4e38, 0xc},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5180, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5280, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5380, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5480, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5580, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5680, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5780, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5880, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5980, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5a80, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5b80, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5c80, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5d80, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5e80, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5f80, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x6cc0, 0x52},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x6e38, 0xc},
#define USEM_PORT1_END          897
#define USEM_FUNC0_START        897
	{OP_WR_E1H, USEM_REG_FAST_MEMORY + 0x26d0, 0x0},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3000, 0x4},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x4018, 0x2},
#define USEM_FUNC0_END          900
#define USEM_FUNC1_START        900
	{OP_WR_E1H, USEM_REG_FAST_MEMORY + 0x26d4, 0x0},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3010, 0x4},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x4028, 0x2},
#define USEM_FUNC1_END          903
#define USEM_FUNC2_START        903
	{OP_WR_E1H, USEM_REG_FAST_MEMORY + 0x26d8, 0x0},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3020, 0x4},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x4038, 0x2},
#define USEM_FUNC2_END          906
#define USEM_FUNC3_START        906
	{OP_WR_E1H, USEM_REG_FAST_MEMORY + 0x26dc, 0x0},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3030, 0x4},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x4048, 0x2},
#define USEM_FUNC3_END          909
#define USEM_FUNC4_START        909
	{OP_WR_E1H, USEM_REG_FAST_MEMORY + 0x26e0, 0x0},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3040, 0x4},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x4058, 0x2},
#define USEM_FUNC4_END          912
#define USEM_FUNC5_START        912
	{OP_WR_E1H, USEM_REG_FAST_MEMORY + 0x26e4, 0x0},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3050, 0x4},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x4068, 0x2},
#define USEM_FUNC5_END          915
#define USEM_FUNC6_START        915
	{OP_WR_E1H, USEM_REG_FAST_MEMORY + 0x26e8, 0x0},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3060, 0x4},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x4078, 0x2},
#define USEM_FUNC6_END          918
#define USEM_FUNC7_START        918
	{OP_WR_E1H, USEM_REG_FAST_MEMORY + 0x26ec, 0x0},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3070, 0x4},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x4088, 0x2},
#define USEM_FUNC7_END          921
#define CSEM_COMMON_START       921
	{OP_RD, CSEM_REG_MSG_NUM_FIC0, 0x0},
	{OP_RD, CSEM_REG_MSG_NUM_FIC1, 0x0},
	{OP_RD, CSEM_REG_MSG_NUM_FOC0, 0x0},
	{OP_RD, CSEM_REG_MSG_NUM_FOC1, 0x0},
	{OP_RD, CSEM_REG_MSG_NUM_FOC2, 0x0},
	{OP_RD, CSEM_REG_MSG_NUM_FOC3, 0x0},
	{OP_WR, CSEM_REG_ARB_ELEMENT0, 0x1},
	{OP_WR, CSEM_REG_ARB_ELEMENT1, 0x2},
	{OP_WR, CSEM_REG_ARB_ELEMENT2, 0x3},
	{OP_WR, CSEM_REG_ARB_ELEMENT3, 0x0},
	{OP_WR, CSEM_REG_ARB_ELEMENT4, 0x4},
	{OP_WR, CSEM_REG_ARB_CYCLE_SIZE, 0x1},
	{OP_WR, CSEM_REG_TS_0_AS, 0x0},
	{OP_WR, CSEM_REG_TS_1_AS, 0x1},
	{OP_WR, CSEM_REG_TS_2_AS, 0x4},
	{OP_WR, CSEM_REG_TS_3_AS, 0x0},
	{OP_WR, CSEM_REG_TS_4_AS, 0x1},
	{OP_WR, CSEM_REG_TS_5_AS, 0x3},
	{OP_WR, CSEM_REG_TS_6_AS, 0x0},
	{OP_WR, CSEM_REG_TS_7_AS, 0x1},
	{OP_WR, CSEM_REG_TS_8_AS, 0x4},
	{OP_WR, CSEM_REG_TS_9_AS, 0x0},
	{OP_WR, CSEM_REG_TS_10_AS, 0x1},
	{OP_WR, CSEM_REG_TS_11_AS, 0x3},
	{OP_WR, CSEM_REG_TS_12_AS, 0x0},
	{OP_WR, CSEM_REG_TS_13_AS, 0x1},
	{OP_WR, CSEM_REG_TS_14_AS, 0x4},
	{OP_WR, CSEM_REG_TS_15_AS, 0x0},
	{OP_WR, CSEM_REG_TS_16_AS, 0x4},
	{OP_WR, CSEM_REG_TS_17_AS, 0x3},
	{OP_ZR, CSEM_REG_TS_18_AS, 0x2},
	{OP_WR, CSEM_REG_ENABLE_IN, 0x3fff},
	{OP_WR, CSEM_REG_ENABLE_OUT, 0x3ff},
	{OP_WR, CSEM_REG_FIC0_DISABLE, 0x0},
	{OP_WR, CSEM_REG_FIC1_DISABLE, 0x0},
	{OP_WR, CSEM_REG_PAS_DISABLE, 0x0},
	{OP_WR, CSEM_REG_THREADS_LIST, 0xffff},
	{OP_ZR, CSEM_REG_PASSIVE_BUFFER, 0x800},
	{OP_WR, CSEM_REG_FAST_MEMORY + 0x18bc0, 0x1},
	{OP_WR, CSEM_REG_FAST_MEMORY + 0x18000, 0x10},
	{OP_WR, CSEM_REG_FAST_MEMORY + 0x18040, 0x12},
	{OP_WR, CSEM_REG_FAST_MEMORY + 0x18080, 0x30},
	{OP_WR, CSEM_REG_FAST_MEMORY + 0x180c0, 0xe},
	{OP_WR, CSEM_REG_FAST_MEMORY + 0x183c0, 0x1f4},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x5000, 0x42},
	{OP_WR_E1H, CSEM_REG_FAST_MEMORY + 0x11480, 0x1},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x1020, 0xc8},
	{OP_WR_EMUL_E1H, CSEM_REG_FAST_MEMORY + 0x11480, 0x0},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x1000, 0x2},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x1000, 0x42},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x2000, 0xc0},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x7020, 0xc8},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x3070, 0x80},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x7000, 0x2},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x4280, 0x4},
	{OP_WR_E1H, CSEM_REG_FAST_MEMORY + 0x11e8, 0x0},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x25c0, 0x240},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x3000, 0xc0},
	{OP_SW_E1, CSEM_REG_FAST_MEMORY + 0x2ec8, 0x802aa},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x4070, 0x80},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x5280, 0x4},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x6280, 0x240},
	{OP_SW_E1H, CSEM_REG_FAST_MEMORY + 0x6b88, 0x2002e5},
	{OP_WR, CSEM_REG_FAST_MEMORY + 0x10800, 0x13fffff},
	{OP_SW_E1, CSEM_REG_FAST_MEMORY + 0x10c00, 0x1002b2},
	{OP_SW_E1H, CSEM_REG_FAST_MEMORY + 0x10c00, 0x100305},
	{OP_WR, CSEM_REG_FAST_MEMORY + 0x10800, 0x0},
	{OP_SW_E1, CSEM_REG_FAST_MEMORY + 0x10c40, 0x1002c2},
	{OP_SW_E1H, CSEM_REG_FAST_MEMORY + 0x10c40, 0x100315},
	{OP_ZP_E1, CSEM_REG_INT_TABLE, 0x710000},
	{OP_ZP_E1H, CSEM_REG_INT_TABLE, 0x740000},
	{OP_WR_64_E1, CSEM_REG_INT_TABLE + 0x380, 0x1002d2},
	{OP_WR_64_E1H, CSEM_REG_INT_TABLE + 0x380, 0x100325},
	{OP_ZP_E1, CSEM_REG_PRAM, 0x32300000},
	{OP_ZP_E1H, CSEM_REG_PRAM, 0x321c0000},
	{OP_ZP_E1, CSEM_REG_PRAM + 0x8000, 0x229a0c8c},
	{OP_ZP_E1H, CSEM_REG_PRAM + 0x8000, 0x23960c87},
	{OP_WR_64_E1, CSEM_REG_PRAM + 0xc810, 0x656402d4},
	{OP_WR_64_E1H, CSEM_REG_PRAM + 0xca30, 0x65200327},
#define CSEM_COMMON_END         1000
#define CSEM_PORT0_START        1000
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x1400, 0xa0},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x8000, 0xa0},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x1900, 0x10},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x8500, 0x40},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x1980, 0x30},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x8700, 0x3c},
	{OP_WR_E1, CSEM_REG_FAST_MEMORY + 0x5118, 0x0},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x4040, 0x6},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x2300, 0xe},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x6040, 0x30},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x3040, 0x6},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x2410, 0x30},
#define CSEM_PORT0_END          1012
#define CSEM_PORT1_START        1012
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x1680, 0xa0},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x8280, 0xa0},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x1940, 0x10},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x8600, 0x40},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x1a40, 0x30},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x87f0, 0x3c},
	{OP_WR_E1, CSEM_REG_FAST_MEMORY + 0x511c, 0x0},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x4058, 0x6},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x2338, 0xe},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x6100, 0x30},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x3058, 0x6},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x24d0, 0x30},
#define CSEM_PORT1_END          1024
#define CSEM_FUNC0_START        1024
	{OP_WR_E1H, CSEM_REG_FAST_MEMORY + 0x1148, 0x0},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x3300, 0x2},
#define CSEM_FUNC0_END          1026
#define CSEM_FUNC1_START        1026
	{OP_WR_E1H, CSEM_REG_FAST_MEMORY + 0x114c, 0x0},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x3308, 0x2},
#define CSEM_FUNC1_END          1028
#define CSEM_FUNC2_START        1028
	{OP_WR_E1H, CSEM_REG_FAST_MEMORY + 0x1150, 0x0},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x3310, 0x2},
#define CSEM_FUNC2_END          1030
#define CSEM_FUNC3_START        1030
	{OP_WR_E1H, CSEM_REG_FAST_MEMORY + 0x1154, 0x0},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x3318, 0x2},
#define CSEM_FUNC3_END          1032
#define CSEM_FUNC4_START        1032
	{OP_WR_E1H, CSEM_REG_FAST_MEMORY + 0x1158, 0x0},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x3320, 0x2},
#define CSEM_FUNC4_END          1034
#define CSEM_FUNC5_START        1034
	{OP_WR_E1H, CSEM_REG_FAST_MEMORY + 0x115c, 0x0},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x3328, 0x2},
#define CSEM_FUNC5_END          1036
#define CSEM_FUNC6_START        1036
	{OP_WR_E1H, CSEM_REG_FAST_MEMORY + 0x1160, 0x0},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x3330, 0x2},
#define CSEM_FUNC6_END          1038
#define CSEM_FUNC7_START        1038
	{OP_WR_E1H, CSEM_REG_FAST_MEMORY + 0x1164, 0x0},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x3338, 0x2},
#define CSEM_FUNC7_END          1040
#define XPB_COMMON_START        1040
	{OP_WR, GRCBASE_XPB + PB_REG_CONTROL, 0x20},
#define XPB_COMMON_END          1041
#define DQ_COMMON_START         1041
	{OP_WR, DORQ_REG_MODE_ACT, 0x2},
	{OP_WR, DORQ_REG_NORM_CID_OFST, 0x3},
	{OP_WR, DORQ_REG_OUTST_REQ, 0x4},
	{OP_WR, DORQ_REG_DPM_CID_ADDR, 0x8},
	{OP_WR, DORQ_REG_RSP_INIT_CRD, 0x2},
	{OP_WR, DORQ_REG_NORM_CMHEAD_TX, 0x90},
	{OP_WR, DORQ_REG_CMHEAD_RX, 0x90},
	{OP_WR, DORQ_REG_SHRT_CMHEAD, 0x800090},
	{OP_WR, DORQ_REG_ERR_CMHEAD, 0x8140000},
	{OP_WR, DORQ_REG_AGG_CMD0, 0x8a},
	{OP_WR, DORQ_REG_AGG_CMD1, 0x80},
	{OP_WR, DORQ_REG_AGG_CMD2, 0x90},
	{OP_WR, DORQ_REG_AGG_CMD3, 0x80},
	{OP_WR, DORQ_REG_SHRT_ACT_CNT, 0x6},
	{OP_WR, DORQ_REG_DQ_FIFO_FULL_TH, 0x7d0},
	{OP_WR, DORQ_REG_DQ_FIFO_AFULL_TH, 0x76c},
	{OP_WR, DORQ_REG_REGN, 0x7c1004},
	{OP_WR, DORQ_REG_IF_EN, 0xf},
#define DQ_COMMON_END           1059
#define TIMERS_COMMON_START     1059
	{OP_ZR, TM_REG_CLIN_PRIOR0_CLIENT, 0x2},
	{OP_WR, TM_REG_LIN_SETCLR_FIFO_ALFULL_THR, 0x1c},
	{OP_WR, TM_REG_CFC_AC_CRDCNT_VAL, 0x1},
	{OP_WR, TM_REG_CFC_CLD_CRDCNT_VAL, 0x1},
	{OP_WR, TM_REG_CLOUT_CRDCNT0_VAL, 0x1},
	{OP_WR, TM_REG_CLOUT_CRDCNT1_VAL, 0x1},
	{OP_WR, TM_REG_CLOUT_CRDCNT2_VAL, 0x1},
	{OP_WR, TM_REG_EXP_CRDCNT_VAL, 0x1},
	{OP_WR_E1, TM_REG_PCIARB_CRDCNT_VAL, 0x1},
	{OP_WR_E1H, TM_REG_PCIARB_CRDCNT_VAL, 0x2},
	{OP_WR_ASIC, TM_REG_TIMER_TICK_SIZE, 0x3d090},
	{OP_WR_EMUL, TM_REG_TIMER_TICK_SIZE, 0x9c},
	{OP_WR_FPGA, TM_REG_TIMER_TICK_SIZE, 0x9c4},
	{OP_WR, TM_REG_CL0_CONT_REGION, 0x8},
	{OP_WR, TM_REG_CL1_CONT_REGION, 0xc},
	{OP_WR, TM_REG_CL2_CONT_REGION, 0x10},
	{OP_WR, TM_REG_TM_CONTEXT_REGION, 0x20},
	{OP_WR, TM_REG_EN_TIMERS, 0x1},
	{OP_WR, TM_REG_EN_REAL_TIME_CNT, 0x1},
	{OP_WR, TM_REG_EN_CL0_INPUT, 0x1},
	{OP_WR, TM_REG_EN_CL1_INPUT, 0x1},
	{OP_WR, TM_REG_EN_CL2_INPUT, 0x1},
#define TIMERS_COMMON_END       1081
#define TIMERS_PORT0_START      1081
	{OP_WR, TM_REG_LIN0_LOGIC_ADDR, 0x0},
	{OP_WR, TM_REG_LIN0_PHY_ADDR_VALID, 0x0},
	{OP_ZR, TM_REG_LIN0_PHY_ADDR, 0x2},
#define TIMERS_PORT0_END        1084
#define TIMERS_PORT1_START      1084
	{OP_WR, TM_REG_LIN1_LOGIC_ADDR, 0x0},
	{OP_WR, TM_REG_LIN1_PHY_ADDR_VALID, 0x0},
	{OP_ZR, TM_REG_LIN1_PHY_ADDR, 0x2},
#define TIMERS_PORT1_END        1087
#define XSDM_COMMON_START       1087
	{OP_WR_E1, XSDM_REG_CFC_RSP_START_ADDR, 0x614},
	{OP_WR_E1H, XSDM_REG_CFC_RSP_START_ADDR, 0x424},
	{OP_WR_E1, XSDM_REG_CMP_COUNTER_START_ADDR, 0x600},
	{OP_WR_E1H, XSDM_REG_CMP_COUNTER_START_ADDR, 0x410},
	{OP_WR_E1, XSDM_REG_Q_COUNTER_START_ADDR, 0x604},
	{OP_WR_E1H, XSDM_REG_Q_COUNTER_START_ADDR, 0x414},
	{OP_WR, XSDM_REG_CMP_COUNTER_MAX0, 0xffff},
	{OP_WR, XSDM_REG_CMP_COUNTER_MAX1, 0xffff},
	{OP_WR, XSDM_REG_CMP_COUNTER_MAX2, 0xffff},
	{OP_WR, XSDM_REG_CMP_COUNTER_MAX3, 0xffff},
	{OP_WR, XSDM_REG_AGG_INT_EVENT_0, 0x20},
	{OP_WR, XSDM_REG_AGG_INT_EVENT_1, 0x20},
	{OP_WR, XSDM_REG_AGG_INT_EVENT_2, 0x34},
	{OP_WR, XSDM_REG_AGG_INT_EVENT_3, 0x35},
	{OP_WR, XSDM_REG_AGG_INT_EVENT_4, 0x23},
	{OP_WR, XSDM_REG_AGG_INT_EVENT_5, 0x24},
	{OP_WR, XSDM_REG_AGG_INT_EVENT_6, 0x25},
	{OP_WR, XSDM_REG_AGG_INT_EVENT_7, 0x26},
	{OP_WR, XSDM_REG_AGG_INT_EVENT_8, 0x27},
	{OP_WR, XSDM_REG_AGG_INT_EVENT_9, 0x29},
	{OP_WR, XSDM_REG_AGG_INT_EVENT_10, 0x2a},
	{OP_WR, XSDM_REG_AGG_INT_EVENT_11, 0x2b},
	{OP_ZR, XSDM_REG_AGG_INT_EVENT_12, 0x54},
	{OP_WR, XSDM_REG_AGG_INT_MODE_0, 0x1},
	{OP_ZR, XSDM_REG_AGG_INT_MODE_1, 0x1f},
	{OP_WR, XSDM_REG_ENABLE_IN1, 0x7ffffff},
	{OP_WR, XSDM_REG_ENABLE_IN2, 0x3f},
	{OP_WR, XSDM_REG_ENABLE_OUT1, 0x7ffffff},
	{OP_WR, XSDM_REG_ENABLE_OUT2, 0xf},
	{OP_RD, XSDM_REG_NUM_OF_Q0_CMD, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_Q1_CMD, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_Q3_CMD, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_Q4_CMD, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_Q5_CMD, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_Q6_CMD, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_Q7_CMD, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_Q8_CMD, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_Q9_CMD, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_Q10_CMD, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_Q11_CMD, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_PKT_END_MSG, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_PXP_ASYNC_REQ, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_ACK_AFTER_PLACE, 0x0},
	{OP_WR_E1, XSDM_REG_INIT_CREDIT_PXP_CTRL, 0x1},
	{OP_WR_ASIC, XSDM_REG_TIMER_TICK, 0x3e8},
	{OP_WR_EMUL, XSDM_REG_TIMER_TICK, 0x1},
	{OP_WR_FPGA, XSDM_REG_TIMER_TICK, 0xa},
#define XSDM_COMMON_END         1134
#define QM_COMMON_START         1134
	{OP_WR, QM_REG_ACTCTRINITVAL_0, 0x6},
	{OP_WR, QM_REG_ACTCTRINITVAL_1, 0x5},
	{OP_WR, QM_REG_ACTCTRINITVAL_2, 0xa},
	{OP_WR, QM_REG_ACTCTRINITVAL_3, 0x5},
	{OP_WR, QM_REG_PCIREQAT, 0x2},
	{OP_WR, QM_REG_CMINITCRD_0, 0x4},
	{OP_WR, QM_REG_CMINITCRD_1, 0x4},
	{OP_WR, QM_REG_CMINITCRD_2, 0x4},
	{OP_WR, QM_REG_CMINITCRD_3, 0x4},
	{OP_WR, QM_REG_CMINITCRD_4, 0x4},
	{OP_WR, QM_REG_CMINITCRD_5, 0x4},
	{OP_WR, QM_REG_CMINITCRD_6, 0x4},
	{OP_WR, QM_REG_CMINITCRD_7, 0x4},
	{OP_WR, QM_REG_OUTLDREQ, 0x4},
	{OP_WR, QM_REG_CTXREG_0, 0x7c},
	{OP_WR, QM_REG_CTXREG_1, 0x3d},
	{OP_WR, QM_REG_CTXREG_2, 0x3f},
	{OP_WR, QM_REG_CTXREG_3, 0x9c},
	{OP_WR, QM_REG_ENSEC, 0x7},
	{OP_ZR, QM_REG_QVOQIDX_0, 0x5},
	{OP_WR, QM_REG_WRRWEIGHTS_0, 0x1010101},
	{OP_WR, QM_REG_QVOQIDX_5, 0x0},
	{OP_WR, QM_REG_QVOQIDX_6, 0x4},
	{OP_WR, QM_REG_QVOQIDX_7, 0x4},
	{OP_WR, QM_REG_QVOQIDX_8, 0x2},
	{OP_WR, QM_REG_WRRWEIGHTS_1, 0x8012004},
	{OP_WR, QM_REG_QVOQIDX_9, 0x5},
	{OP_WR, QM_REG_QVOQIDX_10, 0x5},
	{OP_WR, QM_REG_QVOQIDX_11, 0x5},
	{OP_WR, QM_REG_QVOQIDX_12, 0x5},
	{OP_WR, QM_REG_WRRWEIGHTS_2, 0x20081001},
	{OP_WR, QM_REG_QVOQIDX_13, 0x8},
	{OP_WR, QM_REG_QVOQIDX_14, 0x6},
	{OP_WR, QM_REG_QVOQIDX_15, 0x7},
	{OP_WR, QM_REG_QVOQIDX_16, 0x0},
	{OP_WR, QM_REG_WRRWEIGHTS_3, 0x1010120},
	{OP_ZR, QM_REG_QVOQIDX_17, 0x4},
	{OP_WR, QM_REG_WRRWEIGHTS_4, 0x1010101},
	{OP_ZR_E1, QM_REG_QVOQIDX_21, 0x4},
	{OP_WR_E1H, QM_REG_QVOQIDX_21, 0x0},
	{OP_WR_E1, QM_REG_WRRWEIGHTS_5, 0x1010101},
	{OP_WR_E1H, QM_REG_QVOQIDX_22, 0x4},
	{OP_ZR_E1, QM_REG_QVOQIDX_25, 0x4},
	{OP_WR_E1H, QM_REG_QVOQIDX_23, 0x4},
	{OP_WR_E1, QM_REG_WRRWEIGHTS_6, 0x1010101},
	{OP_WR_E1H, QM_REG_QVOQIDX_24, 0x2},
	{OP_ZR_E1, QM_REG_QVOQIDX_29, 0x3},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_5, 0x8012004},
	{OP_WR_E1H, QM_REG_QVOQIDX_25, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_26, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_27, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_28, 0x5},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_6, 0x20081001},
	{OP_WR_E1H, QM_REG_QVOQIDX_29, 0x8},
	{OP_WR_E1H, QM_REG_QVOQIDX_30, 0x6},
	{OP_WR_E1H, QM_REG_QVOQIDX_31, 0x7},
	{OP_WR, QM_REG_QVOQIDX_32, 0x1},
	{OP_WR_E1, QM_REG_WRRWEIGHTS_7, 0x1010101},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_7, 0x1010120},
	{OP_WR, QM_REG_QVOQIDX_33, 0x1},
	{OP_WR, QM_REG_QVOQIDX_34, 0x1},
	{OP_WR, QM_REG_QVOQIDX_35, 0x1},
	{OP_WR, QM_REG_QVOQIDX_36, 0x1},
	{OP_WR, QM_REG_WRRWEIGHTS_8, 0x1010101},
	{OP_WR, QM_REG_QVOQIDX_37, 0x1},
	{OP_WR, QM_REG_QVOQIDX_38, 0x4},
	{OP_WR, QM_REG_QVOQIDX_39, 0x4},
	{OP_WR, QM_REG_QVOQIDX_40, 0x2},
	{OP_WR, QM_REG_WRRWEIGHTS_9, 0x8012004},
	{OP_WR, QM_REG_QVOQIDX_41, 0x5},
	{OP_WR, QM_REG_QVOQIDX_42, 0x5},
	{OP_WR, QM_REG_QVOQIDX_43, 0x5},
	{OP_WR, QM_REG_QVOQIDX_44, 0x5},
	{OP_WR, QM_REG_WRRWEIGHTS_10, 0x20081001},
	{OP_WR, QM_REG_QVOQIDX_45, 0x8},
	{OP_WR, QM_REG_QVOQIDX_46, 0x6},
	{OP_WR, QM_REG_QVOQIDX_47, 0x7},
	{OP_WR, QM_REG_QVOQIDX_48, 0x1},
	{OP_WR, QM_REG_WRRWEIGHTS_11, 0x1010120},
	{OP_WR, QM_REG_QVOQIDX_49, 0x1},
	{OP_WR, QM_REG_QVOQIDX_50, 0x1},
	{OP_WR, QM_REG_QVOQIDX_51, 0x1},
	{OP_WR, QM_REG_QVOQIDX_52, 0x1},
	{OP_WR, QM_REG_WRRWEIGHTS_12, 0x1010101},
	{OP_WR, QM_REG_QVOQIDX_53, 0x1},
	{OP_WR_E1, QM_REG_QVOQIDX_54, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_54, 0x4},
	{OP_WR_E1, QM_REG_QVOQIDX_55, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_55, 0x4},
	{OP_WR_E1, QM_REG_QVOQIDX_56, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_56, 0x2},
	{OP_WR_E1, QM_REG_WRRWEIGHTS_13, 0x1010101},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_13, 0x8012004},
	{OP_WR_E1, QM_REG_QVOQIDX_57, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_57, 0x5},
	{OP_WR_E1, QM_REG_QVOQIDX_58, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_58, 0x5},
	{OP_WR_E1, QM_REG_QVOQIDX_59, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_59, 0x5},
	{OP_WR_E1, QM_REG_QVOQIDX_60, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_60, 0x5},
	{OP_WR_E1, QM_REG_WRRWEIGHTS_14, 0x1010101},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_14, 0x20081001},
	{OP_WR_E1, QM_REG_QVOQIDX_61, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_61, 0x8},
	{OP_WR_E1, QM_REG_QVOQIDX_62, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_62, 0x6},
	{OP_WR_E1, QM_REG_QVOQIDX_63, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_63, 0x7},
	{OP_WR_E1, QM_REG_WRRWEIGHTS_15, 0x1010101},
	{OP_WR_E1H, QM_REG_QVOQIDX_64, 0x0},
	{OP_WR_E1, QM_REG_VOQQMASK_0_LSB, 0xffff003f},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_15, 0x1010120},
	{OP_ZR_E1, QM_REG_VOQQMASK_0_MSB, 0x2},
	{OP_ZR_E1H, QM_REG_QVOQIDX_65, 0x4},
	{OP_WR_E1, QM_REG_VOQQMASK_1_MSB, 0xffff003f},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_16, 0x1010101},
	{OP_WR_E1, QM_REG_VOQQMASK_2_LSB, 0x100},
	{OP_WR_E1H, QM_REG_QVOQIDX_69, 0x0},
	{OP_WR_E1, QM_REG_VOQQMASK_2_MSB, 0x100},
	{OP_WR_E1H, QM_REG_QVOQIDX_70, 0x4},
	{OP_WR_E1H, QM_REG_QVOQIDX_71, 0x4},
	{OP_WR_E1H, QM_REG_QVOQIDX_72, 0x2},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_17, 0x8012004},
	{OP_WR_E1H, QM_REG_QVOQIDX_73, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_74, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_75, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_76, 0x5},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_18, 0x20081001},
	{OP_WR_E1H, QM_REG_QVOQIDX_77, 0x8},
	{OP_WR_E1H, QM_REG_QVOQIDX_78, 0x6},
	{OP_WR_E1H, QM_REG_QVOQIDX_79, 0x7},
	{OP_WR_E1H, QM_REG_QVOQIDX_80, 0x0},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_19, 0x1010120},
	{OP_ZR_E1H, QM_REG_QVOQIDX_81, 0x4},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_20, 0x1010101},
	{OP_WR_E1H, QM_REG_QVOQIDX_85, 0x0},
	{OP_WR_E1H, QM_REG_QVOQIDX_86, 0x4},
	{OP_WR_E1H, QM_REG_QVOQIDX_87, 0x4},
	{OP_WR_E1H, QM_REG_QVOQIDX_88, 0x2},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_21, 0x8012004},
	{OP_WR_E1H, QM_REG_QVOQIDX_89, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_90, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_91, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_92, 0x5},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_22, 0x20081001},
	{OP_WR_E1H, QM_REG_QVOQIDX_93, 0x8},
	{OP_WR_E1H, QM_REG_QVOQIDX_94, 0x6},
	{OP_WR_E1H, QM_REG_QVOQIDX_95, 0x7},
	{OP_WR_E1H, QM_REG_QVOQIDX_96, 0x1},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_23, 0x1010120},
	{OP_WR_E1H, QM_REG_QVOQIDX_97, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_98, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_99, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_100, 0x1},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_24, 0x1010101},
	{OP_WR_E1H, QM_REG_QVOQIDX_101, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_102, 0x4},
	{OP_WR_E1H, QM_REG_QVOQIDX_103, 0x4},
	{OP_WR_E1H, QM_REG_QVOQIDX_104, 0x2},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_25, 0x8012004},
	{OP_WR_E1H, QM_REG_QVOQIDX_105, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_106, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_107, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_108, 0x5},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_26, 0x20081001},
	{OP_WR_E1H, QM_REG_QVOQIDX_109, 0x8},
	{OP_WR_E1H, QM_REG_QVOQIDX_110, 0x6},
	{OP_WR_E1H, QM_REG_QVOQIDX_111, 0x7},
	{OP_WR_E1H, QM_REG_QVOQIDX_112, 0x1},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_27, 0x1010120},
	{OP_WR_E1H, QM_REG_QVOQIDX_113, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_114, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_115, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_116, 0x1},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_28, 0x1010101},
	{OP_WR_E1H, QM_REG_QVOQIDX_117, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_118, 0x4},
	{OP_WR_E1H, QM_REG_QVOQIDX_119, 0x4},
	{OP_WR_E1H, QM_REG_QVOQIDX_120, 0x2},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_29, 0x8012004},
	{OP_WR_E1H, QM_REG_QVOQIDX_121, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_122, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_123, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_124, 0x5},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_30, 0x20081001},
	{OP_WR_E1H, QM_REG_QVOQIDX_125, 0x8},
	{OP_WR_E1H, QM_REG_QVOQIDX_126, 0x6},
	{OP_WR_E1H, QM_REG_QVOQIDX_127, 0x7},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_31, 0x1010120},
	{OP_WR_E1H, QM_REG_VOQQMASK_0_LSB, 0x3f003f},
	{OP_WR_E1H, QM_REG_VOQQMASK_0_MSB, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_0_LSB_EXT_A, 0x3f003f},
	{OP_WR_E1H, QM_REG_VOQQMASK_0_MSB_EXT_A, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_1_LSB, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_1_MSB, 0x3f003f},
	{OP_WR_E1H, QM_REG_VOQQMASK_1_LSB_EXT_A, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_1_MSB_EXT_A, 0x3f003f},
	{OP_WR_E1H, QM_REG_VOQQMASK_2_LSB, 0x1000100},
	{OP_WR_E1H, QM_REG_VOQQMASK_2_MSB, 0x1000100},
	{OP_WR_E1H, QM_REG_VOQQMASK_2_LSB_EXT_A, 0x1000100},
	{OP_WR_E1H, QM_REG_VOQQMASK_2_MSB_EXT_A, 0x1000100},
	{OP_ZR, QM_REG_VOQQMASK_3_LSB, 0x2},
	{OP_WR_E1, QM_REG_VOQQMASK_4_LSB, 0xc0},
	{OP_WR_E1H, QM_REG_VOQQMASK_3_LSB_EXT_A, 0x0},
	{OP_WR_E1, QM_REG_VOQQMASK_4_MSB, 0xc0},
	{OP_WR_E1H, QM_REG_VOQQMASK_3_MSB_EXT_A, 0x0},
	{OP_WR_E1, QM_REG_VOQQMASK_5_LSB, 0x1e00},
	{OP_WR_E1H, QM_REG_VOQQMASK_4_LSB, 0xc000c0},
	{OP_WR_E1, QM_REG_VOQQMASK_5_MSB, 0x1e00},
	{OP_WR_E1H, QM_REG_VOQQMASK_4_MSB, 0xc000c0},
	{OP_WR_E1, QM_REG_VOQQMASK_6_LSB, 0x4000},
	{OP_WR_E1H, QM_REG_VOQQMASK_4_LSB_EXT_A, 0xc000c0},
	{OP_WR_E1, QM_REG_VOQQMASK_6_MSB, 0x4000},
	{OP_WR_E1H, QM_REG_VOQQMASK_4_MSB_EXT_A, 0xc000c0},
	{OP_WR_E1, QM_REG_VOQQMASK_7_LSB, 0x8000},
	{OP_WR_E1H, QM_REG_VOQQMASK_5_LSB, 0x1e001e00},
	{OP_WR_E1, QM_REG_VOQQMASK_7_MSB, 0x8000},
	{OP_WR_E1H, QM_REG_VOQQMASK_5_MSB, 0x1e001e00},
	{OP_WR_E1, QM_REG_VOQQMASK_8_LSB, 0x2000},
	{OP_WR_E1H, QM_REG_VOQQMASK_5_LSB_EXT_A, 0x1e001e00},
	{OP_WR_E1, QM_REG_VOQQMASK_8_MSB, 0x2000},
	{OP_WR_E1H, QM_REG_VOQQMASK_5_MSB_EXT_A, 0x1e001e00},
	{OP_ZR_E1, QM_REG_VOQQMASK_9_LSB, 0x7},
	{OP_WR_E1H, QM_REG_VOQQMASK_6_LSB, 0x40004000},
	{OP_WR_E1H, QM_REG_VOQQMASK_6_MSB, 0x40004000},
	{OP_WR_E1H, QM_REG_VOQQMASK_6_LSB_EXT_A, 0x40004000},
	{OP_WR_E1H, QM_REG_VOQQMASK_6_MSB_EXT_A, 0x40004000},
	{OP_WR_E1H, QM_REG_VOQQMASK_7_LSB, 0x80008000},
	{OP_WR_E1H, QM_REG_VOQQMASK_7_MSB, 0x80008000},
	{OP_WR_E1H, QM_REG_VOQQMASK_7_LSB_EXT_A, 0x80008000},
	{OP_WR_E1H, QM_REG_VOQQMASK_7_MSB_EXT_A, 0x80008000},
	{OP_WR_E1H, QM_REG_VOQQMASK_8_LSB, 0x20002000},
	{OP_WR_E1H, QM_REG_VOQQMASK_8_MSB, 0x20002000},
	{OP_WR_E1H, QM_REG_VOQQMASK_8_LSB_EXT_A, 0x20002000},
	{OP_WR_E1H, QM_REG_VOQQMASK_8_MSB_EXT_A, 0x20002000},
	{OP_ZR_E1H, QM_REG_VOQQMASK_9_LSB, 0x2},
	{OP_WR_E1H, QM_REG_VOQQMASK_9_LSB_EXT_A, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_9_MSB_EXT_A, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_10_LSB, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_10_MSB, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_10_LSB_EXT_A, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_10_MSB_EXT_A, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_11_LSB, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_11_MSB, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_11_LSB_EXT_A, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_11_MSB_EXT_A, 0x0},
	{OP_WR_E1H, QM_REG_VOQPORT_0, 0x0},
	{OP_WR, QM_REG_VOQPORT_1, 0x1},
	{OP_ZR, QM_REG_VOQPORT_2, 0xa},
	{OP_WR, QM_REG_CMINTVOQMASK_0, 0xc08},
	{OP_WR, QM_REG_CMINTVOQMASK_1, 0x40},
	{OP_WR, QM_REG_CMINTVOQMASK_2, 0x100},
	{OP_WR, QM_REG_CMINTVOQMASK_3, 0x20},
	{OP_WR, QM_REG_CMINTVOQMASK_4, 0x17},
	{OP_WR, QM_REG_CMINTVOQMASK_5, 0x80},
	{OP_WR, QM_REG_CMINTVOQMASK_6, 0x200},
	{OP_WR, QM_REG_CMINTVOQMASK_7, 0x0},
	{OP_WR_E1, QM_REG_HWAEMPTYMASK_LSB, 0xffff01ff},
	{OP_WR_E1H, QM_REG_HWAEMPTYMASK_LSB, 0x1ff01ff},
	{OP_WR_E1, QM_REG_HWAEMPTYMASK_MSB, 0xffff01ff},
	{OP_WR_E1H, QM_REG_HWAEMPTYMASK_MSB, 0x1ff01ff},
	{OP_WR_E1H, QM_REG_HWAEMPTYMASK_LSB_EXT_A, 0x1ff01ff},
	{OP_WR_E1H, QM_REG_HWAEMPTYMASK_MSB_EXT_A, 0x1ff01ff},
	{OP_WR, QM_REG_ENBYPVOQMASK, 0x13},
	{OP_WR, QM_REG_VOQCREDITAFULLTHR, 0x13f},
	{OP_WR, QM_REG_VOQINITCREDIT_0, 0x140},
	{OP_WR, QM_REG_VOQINITCREDIT_1, 0x140},
	{OP_ZR, QM_REG_VOQINITCREDIT_2, 0x2},
	{OP_WR, QM_REG_VOQINITCREDIT_4, 0xc0},
	{OP_ZR, QM_REG_VOQINITCREDIT_5, 0x7},
	{OP_WR, QM_REG_TASKCRDCOST_0, 0x48},
	{OP_WR, QM_REG_TASKCRDCOST_1, 0x48},
	{OP_ZR, QM_REG_TASKCRDCOST_2, 0x2},
	{OP_WR, QM_REG_TASKCRDCOST_4, 0x48},
	{OP_ZR, QM_REG_TASKCRDCOST_5, 0x7},
	{OP_WR, QM_REG_BYTECRDINITVAL, 0x8000},
	{OP_WR, QM_REG_BYTECRDCOST, 0x25e4},
	{OP_WR, QM_REG_BYTECREDITAFULLTHR, 0x7fff},
	{OP_WR_E1, QM_REG_ENBYTECRD_LSB, 0x7},
	{OP_WR_E1H, QM_REG_ENBYTECRD_LSB, 0x70007},
	{OP_WR_E1, QM_REG_ENBYTECRD_MSB, 0x7},
	{OP_WR_E1H, QM_REG_ENBYTECRD_MSB, 0x70007},
	{OP_WR_E1H, QM_REG_ENBYTECRD_LSB_EXT_A, 0x70007},
	{OP_WR_E1H, QM_REG_ENBYTECRD_MSB_EXT_A, 0x70007},
	{OP_WR, QM_REG_BYTECRDPORT_LSB, 0x0},
	{OP_WR, QM_REG_BYTECRDPORT_MSB, 0xffffffff},
	{OP_WR_E1, QM_REG_FUNCNUMSEL_LSB, 0x0},
	{OP_WR_E1H, QM_REG_BYTECRDPORT_LSB_EXT_A, 0x0},
	{OP_WR_E1, QM_REG_FUNCNUMSEL_MSB, 0xffffffff},
	{OP_WR_E1H, QM_REG_BYTECRDPORT_MSB_EXT_A, 0xffffffff},
	{OP_WR_E1H, QM_REG_PQ2PCIFUNC_0, 0x0},
	{OP_WR_E1H, QM_REG_PQ2PCIFUNC_1, 0x2},
	{OP_WR_E1H, QM_REG_PQ2PCIFUNC_2, 0x1},
	{OP_WR_E1H, QM_REG_PQ2PCIFUNC_3, 0x3},
	{OP_WR_E1H, QM_REG_PQ2PCIFUNC_4, 0x4},
	{OP_WR_E1H, QM_REG_PQ2PCIFUNC_5, 0x6},
	{OP_WR_E1H, QM_REG_PQ2PCIFUNC_6, 0x5},
	{OP_WR_E1H, QM_REG_PQ2PCIFUNC_7, 0x7},
	{OP_WR, QM_REG_CMINTEN, 0xff},
#define QM_COMMON_END           1434
#define PBF_COMMON_START        1434
	{OP_WR, PBF_REG_INIT, 0x1},
	{OP_WR, PBF_REG_INIT_P4, 0x1},
	{OP_WR, PBF_REG_MAC_LB_ENABLE, 0x1},
	{OP_WR, PBF_REG_IF_ENABLE_REG, 0x7fff},
	{OP_WR, PBF_REG_INIT_P4, 0x0},
	{OP_WR, PBF_REG_INIT, 0x0},
	{OP_WR, PBF_REG_DISABLE_NEW_TASK_PROC_P4, 0x0},
#define PBF_COMMON_END          1441
#define PBF_PORT0_START         1441
	{OP_WR, PBF_REG_INIT_P0, 0x1},
	{OP_WR, PBF_REG_MAC_IF0_ENABLE, 0x1},
	{OP_WR, PBF_REG_INIT_P0, 0x0},
	{OP_WR, PBF_REG_DISABLE_NEW_TASK_PROC_P0, 0x0},
#define PBF_PORT0_END           1445
#define PBF_PORT1_START         1445
	{OP_WR, PBF_REG_INIT_P1, 0x1},
	{OP_WR, PBF_REG_MAC_IF1_ENABLE, 0x1},
	{OP_WR, PBF_REG_INIT_P1, 0x0},
	{OP_WR, PBF_REG_DISABLE_NEW_TASK_PROC_P1, 0x0},
#define PBF_PORT1_END           1449
#define XCM_COMMON_START        1449
	{OP_WR, XCM_REG_XX_OVFL_EVNT_ID, 0x32},
	{OP_WR, XCM_REG_XQM_XCM_HDR_P, 0x3150020},
	{OP_WR, XCM_REG_XQM_XCM_HDR_S, 0x3150020},
	{OP_WR, XCM_REG_TM_XCM_HDR, 0x1000030},
	{OP_WR, XCM_REG_ERR_XCM_HDR, 0x8100000},
	{OP_WR, XCM_REG_ERR_EVNT_ID, 0x33},
	{OP_WR, XCM_REG_EXPR_EVNT_ID, 0x30},
	{OP_WR, XCM_REG_STOP_EVNT_ID, 0x31},
	{OP_WR, XCM_REG_STORM_WEIGHT, 0x2},
	{OP_WR, XCM_REG_TSEM_WEIGHT, 0x5},
	{OP_WR, XCM_REG_CSEM_WEIGHT, 0x2},
	{OP_WR, XCM_REG_USEM_WEIGHT, 0x2},
	{OP_WR, XCM_REG_PBF_WEIGHT, 0x7},
	{OP_WR, XCM_REG_NIG1_WEIGHT, 0x1},
	{OP_WR, XCM_REG_CP_WEIGHT, 0x0},
	{OP_WR, XCM_REG_XSDM_WEIGHT, 0x5},
	{OP_WR, XCM_REG_XQM_P_WEIGHT, 0x3},
	{OP_WR, XCM_REG_XCM_XQM_USE_Q, 0x1},
	{OP_WR, XCM_REG_XQM_BYP_ACT_UPD, 0x6},
	{OP_WR, XCM_REG_UNA_GT_NXT_Q, 0x0},
	{OP_WR, XCM_REG_AUX1_Q, 0x2},
	{OP_WR, XCM_REG_AUX_CNT_FLG_Q_19, 0x1},
	{OP_WR, XCM_REG_GR_ARB_TYPE, 0x1},
	{OP_WR, XCM_REG_GR_LD0_PR, 0x1},
	{OP_WR, XCM_REG_GR_LD1_PR, 0x2},
	{OP_WR, XCM_REG_CFC_INIT_CRD, 0x1},
	{OP_WR, XCM_REG_FIC0_INIT_CRD, 0x40},
	{OP_WR, XCM_REG_FIC1_INIT_CRD, 0x40},
	{OP_WR, XCM_REG_TM_INIT_CRD, 0x4},
	{OP_WR, XCM_REG_XQM_INIT_CRD, 0x20},
	{OP_WR, XCM_REG_XX_INIT_CRD, 0x2},
	{OP_WR_E1, XCM_REG_XX_MSG_NUM, 0x1f},
	{OP_WR_E1H, XCM_REG_XX_MSG_NUM, 0x20},
	{OP_ZR, XCM_REG_XX_TABLE, 0x12},
	{OP_SW_E1, XCM_REG_XX_DESCR_TABLE, 0x1f02d6},
	{OP_SW_E1H, XCM_REG_XX_DESCR_TABLE, 0x1f0329},
	{OP_WR, XCM_REG_N_SM_CTX_LD_0, 0xf},
	{OP_WR, XCM_REG_N_SM_CTX_LD_1, 0x7},
	{OP_WR, XCM_REG_N_SM_CTX_LD_2, 0xb},
	{OP_WR, XCM_REG_N_SM_CTX_LD_3, 0xe},
	{OP_ZR_E1, XCM_REG_N_SM_CTX_LD_4, 0x4},
	{OP_WR_E1H, XCM_REG_N_SM_CTX_LD_4, 0xe},
	{OP_ZR_E1H, XCM_REG_N_SM_CTX_LD_5, 0x3},
	{OP_WR, XCM_REG_XCM_REG0_SZ, 0x4},
	{OP_WR, XCM_REG_XCM_STORM0_IFEN, 0x1},
	{OP_WR, XCM_REG_XCM_STORM1_IFEN, 0x1},
	{OP_WR, XCM_REG_XCM_XQM_IFEN, 0x1},
	{OP_WR, XCM_REG_STORM_XCM_IFEN, 0x1},
	{OP_WR, XCM_REG_XQM_XCM_IFEN, 0x1},
	{OP_WR, XCM_REG_XSDM_IFEN, 0x1},
	{OP_WR, XCM_REG_TM_XCM_IFEN, 0x1},
	{OP_WR, XCM_REG_XCM_TM_IFEN, 0x1},
	{OP_WR, XCM_REG_TSEM_IFEN, 0x1},
	{OP_WR, XCM_REG_CSEM_IFEN, 0x1},
	{OP_WR, XCM_REG_USEM_IFEN, 0x1},
	{OP_WR, XCM_REG_DORQ_IFEN, 0x1},
	{OP_WR, XCM_REG_PBF_IFEN, 0x1},
	{OP_WR, XCM_REG_NIG0_IFEN, 0x1},
	{OP_WR, XCM_REG_NIG1_IFEN, 0x1},
	{OP_WR, XCM_REG_CDU_AG_WR_IFEN, 0x1},
	{OP_WR, XCM_REG_CDU_AG_RD_IFEN, 0x1},
	{OP_WR, XCM_REG_CDU_SM_WR_IFEN, 0x1},
	{OP_WR, XCM_REG_CDU_SM_RD_IFEN, 0x1},
	{OP_WR, XCM_REG_XCM_CFC_IFEN, 0x1},
#define XCM_COMMON_END          1513
#define XCM_PORT0_START         1513
	{OP_WR_E1, XCM_REG_GLB_DEL_ACK_TMR_VAL_0, 0xc8},
	{OP_WR_E1, XCM_REG_GLB_DEL_ACK_MAX_CNT_0, 0x2},
	{OP_WR_E1, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD00, 0x0},
	{OP_WR_E1, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD10, 0x0},
	{OP_WR_E1, XCM_REG_WU_DA_CNT_CMD00, 0x2},
	{OP_WR_E1, XCM_REG_WU_DA_CNT_CMD10, 0x2},
	{OP_WR_E1, XCM_REG_WU_DA_CNT_UPD_VAL00, 0xff},
	{OP_WR_E1, XCM_REG_WU_DA_CNT_UPD_VAL10, 0xff},
#define XCM_PORT0_END           1521
#define XCM_PORT1_START         1521
	{OP_WR_E1, XCM_REG_GLB_DEL_ACK_TMR_VAL_1, 0xc8},
	{OP_WR_E1, XCM_REG_GLB_DEL_ACK_MAX_CNT_1, 0x2},
	{OP_WR_E1, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD01, 0x0},
	{OP_WR_E1, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD11, 0x0},
	{OP_WR_E1, XCM_REG_WU_DA_CNT_CMD01, 0x2},
	{OP_WR_E1, XCM_REG_WU_DA_CNT_CMD11, 0x2},
	{OP_WR_E1, XCM_REG_WU_DA_CNT_UPD_VAL01, 0xff},
	{OP_WR_E1, XCM_REG_WU_DA_CNT_UPD_VAL11, 0xff},
#define XCM_PORT1_END           1529
#define XCM_FUNC0_START         1529
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_TMR_VAL_0, 0xc8},
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_MAX_CNT_0, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD00, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD10, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD00, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD10, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL00, 0xff},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL10, 0xff},
	{OP_WR_E1H, XCM_REG_PHYS_QNUM3_0, 0x0},
#define XCM_FUNC0_END           1538
#define XCM_FUNC1_START         1538
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_TMR_VAL_1, 0xc8},
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_MAX_CNT_1, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD01, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD11, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD01, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD11, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL01, 0xff},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL11, 0xff},
	{OP_WR_E1H, XCM_REG_PHYS_QNUM3_1, 0x0},
#define XCM_FUNC1_END           1547
#define XCM_FUNC2_START         1547
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_TMR_VAL_0, 0xc8},
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_MAX_CNT_0, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD00, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD10, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD00, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD10, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL00, 0xff},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL10, 0xff},
	{OP_WR_E1H, XCM_REG_PHYS_QNUM3_0, 0x0},
#define XCM_FUNC2_END           1556
#define XCM_FUNC3_START         1556
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_TMR_VAL_1, 0xc8},
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_MAX_CNT_1, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD01, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD11, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD01, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD11, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL01, 0xff},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL11, 0xff},
	{OP_WR_E1H, XCM_REG_PHYS_QNUM3_1, 0x0},
#define XCM_FUNC3_END           1565
#define XCM_FUNC4_START         1565
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_TMR_VAL_0, 0xc8},
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_MAX_CNT_0, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD00, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD10, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD00, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD10, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL00, 0xff},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL10, 0xff},
	{OP_WR_E1H, XCM_REG_PHYS_QNUM3_0, 0x0},
#define XCM_FUNC4_END           1574
#define XCM_FUNC5_START         1574
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_TMR_VAL_1, 0xc8},
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_MAX_CNT_1, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD01, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD11, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD01, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD11, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL01, 0xff},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL11, 0xff},
	{OP_WR_E1H, XCM_REG_PHYS_QNUM3_1, 0x0},
#define XCM_FUNC5_END           1583
#define XCM_FUNC6_START         1583
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_TMR_VAL_0, 0xc8},
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_MAX_CNT_0, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD00, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD10, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD00, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD10, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL00, 0xff},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL10, 0xff},
	{OP_WR_E1H, XCM_REG_PHYS_QNUM3_0, 0x0},
#define XCM_FUNC6_END           1592
#define XCM_FUNC7_START         1592
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_TMR_VAL_1, 0xc8},
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_MAX_CNT_1, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD01, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD11, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD01, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD11, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL01, 0xff},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL11, 0xff},
	{OP_WR_E1H, XCM_REG_PHYS_QNUM3_1, 0x0},
#define XCM_FUNC7_END           1601
#define XSEM_COMMON_START       1601
	{OP_RD, XSEM_REG_MSG_NUM_FIC0, 0x0},
	{OP_RD, XSEM_REG_MSG_NUM_FIC1, 0x0},
	{OP_RD, XSEM_REG_MSG_NUM_FOC0, 0x0},
	{OP_RD, XSEM_REG_MSG_NUM_FOC1, 0x0},
	{OP_RD, XSEM_REG_MSG_NUM_FOC2, 0x0},
	{OP_RD, XSEM_REG_MSG_NUM_FOC3, 0x0},
	{OP_WR, XSEM_REG_ARB_ELEMENT0, 0x1},
	{OP_WR, XSEM_REG_ARB_ELEMENT1, 0x2},
	{OP_WR, XSEM_REG_ARB_ELEMENT2, 0x3},
	{OP_WR, XSEM_REG_ARB_ELEMENT3, 0x0},
	{OP_WR, XSEM_REG_ARB_ELEMENT4, 0x4},
	{OP_WR, XSEM_REG_ARB_CYCLE_SIZE, 0x1},
	{OP_WR, XSEM_REG_TS_0_AS, 0x0},
	{OP_WR, XSEM_REG_TS_1_AS, 0x1},
	{OP_WR, XSEM_REG_TS_2_AS, 0x4},
	{OP_WR, XSEM_REG_TS_3_AS, 0x0},
	{OP_WR, XSEM_REG_TS_4_AS, 0x1},
	{OP_WR, XSEM_REG_TS_5_AS, 0x3},
	{OP_WR, XSEM_REG_TS_6_AS, 0x0},
	{OP_WR, XSEM_REG_TS_7_AS, 0x1},
	{OP_WR, XSEM_REG_TS_8_AS, 0x4},
	{OP_WR, XSEM_REG_TS_9_AS, 0x0},
	{OP_WR, XSEM_REG_TS_10_AS, 0x1},
	{OP_WR, XSEM_REG_TS_11_AS, 0x3},
	{OP_WR, XSEM_REG_TS_12_AS, 0x0},
	{OP_WR, XSEM_REG_TS_13_AS, 0x1},
	{OP_WR, XSEM_REG_TS_14_AS, 0x4},
	{OP_WR, XSEM_REG_TS_15_AS, 0x0},
	{OP_WR, XSEM_REG_TS_16_AS, 0x4},
	{OP_WR, XSEM_REG_TS_17_AS, 0x3},
	{OP_ZR, XSEM_REG_TS_18_AS, 0x2},
	{OP_WR, XSEM_REG_ENABLE_IN, 0x3fff},
	{OP_WR, XSEM_REG_ENABLE_OUT, 0x3ff},
	{OP_WR, XSEM_REG_FIC0_DISABLE, 0x0},
	{OP_WR, XSEM_REG_FIC1_DISABLE, 0x0},
	{OP_WR, XSEM_REG_PAS_DISABLE, 0x0},
	{OP_WR, XSEM_REG_THREADS_LIST, 0xffff},
	{OP_ZR, XSEM_REG_PASSIVE_BUFFER, 0x800},
	{OP_WR, XSEM_REG_FAST_MEMORY + 0x18bc0, 0x1},
	{OP_WR, XSEM_REG_FAST_MEMORY + 0x18000, 0x0},
	{OP_WR, XSEM_REG_FAST_MEMORY + 0x18040, 0x18},
	{OP_WR, XSEM_REG_FAST_MEMORY + 0x18080, 0xc},
	{OP_WR, XSEM_REG_FAST_MEMORY + 0x180c0, 0x66},
	{OP_WR_ASIC, XSEM_REG_FAST_MEMORY + 0x18300, 0x7a120},
	{OP_WR_EMUL, XSEM_REG_FAST_MEMORY + 0x18300, 0x138},
	{OP_WR_FPGA, XSEM_REG_FAST_MEMORY + 0x18300, 0x1388},
	{OP_WR, XSEM_REG_FAST_MEMORY + 0x183c0, 0x1f4},
	{OP_WR_ASIC, XSEM_REG_FAST_MEMORY + 0x18340, 0x1f4},
	{OP_WR_EMUL, XSEM_REG_FAST_MEMORY + 0x18340, 0x0},
	{OP_WR_FPGA, XSEM_REG_FAST_MEMORY + 0x18340, 0x5},
	{OP_WR_EMUL, XSEM_REG_FAST_MEMORY + 0x18380, 0x4c4b4},
	{OP_WR_ASIC, XSEM_REG_FAST_MEMORY + 0x18380, 0x1dcd6500},
	{OP_WR_EMUL_E1H, XSEM_REG_FAST_MEMORY + 0x11480, 0x0},
	{OP_WR_FPGA, XSEM_REG_FAST_MEMORY + 0x18380, 0x4c4b40},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x3d20, 0x4},
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0x11480, 0x1},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x3000, 0x48},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x28c8, 0x4},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x1020, 0xc8},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x2080, 0x48},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x1000, 0x2},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x9020, 0xc8},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x3128, 0x8e},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x9000, 0x2},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x3368, 0x0},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x21a8, 0x86},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x3370, 0x202f5},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x2000, 0x20},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x3b90, 0x402f7},
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0x23c8, 0x0},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x1518, 0x1},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x23d0, 0x20348},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x1830, 0x0},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x2498, 0x4034a},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x1838, 0x0},
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0x2ae8, 0x0},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x1820, 0x202fb},
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0x2ad8, 0x0},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x4ac0, 0x2},
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0x3010, 0x1},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x4b00, 0x4},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x4040, 0x10},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x1f48, 0x202fd},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x4000, 0x10034e},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x6ac0, 0x2},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x6b00, 0x4},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x83a8, 0x2035e},
	{OP_WR, XSEM_REG_FAST_MEMORY + 0x10800, 0x0},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x10c00, 0x1002ff},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x10c00, 0x100360},
	{OP_WR, XSEM_REG_FAST_MEMORY + 0x10800, 0x1000000},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x10c40, 0x8030f},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x10c40, 0x80370},
	{OP_WR, XSEM_REG_FAST_MEMORY + 0x10800, 0x2000000},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x10c60, 0x80317},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x10c60, 0x80378},
	{OP_ZP_E1, XSEM_REG_INT_TABLE, 0xae0000},
	{OP_ZP_E1H, XSEM_REG_INT_TABLE, 0xbb0000},
	{OP_WR_64_E1, XSEM_REG_INT_TABLE + 0x368, 0x13031f},
	{OP_WR_64_E1H, XSEM_REG_INT_TABLE + 0x3a8, 0xb0380},
	{OP_ZP_E1, XSEM_REG_PRAM, 0x342d0000},
	{OP_ZP_E1H, XSEM_REG_PRAM, 0x34530000},
	{OP_ZP_E1, XSEM_REG_PRAM + 0x8000, 0x38640d0c},
	{OP_ZP_E1H, XSEM_REG_PRAM + 0x8000, 0x37e90d15},
	{OP_ZP_E1, XSEM_REG_PRAM + 0x10000, 0x3c161b25},
	{OP_ZP_E1H, XSEM_REG_PRAM + 0x10000, 0x3be21b10},
	{OP_ZP_E1, XSEM_REG_PRAM + 0x18000, 0x249b2a2b},
	{OP_ZP_E1H, XSEM_REG_PRAM + 0x18000, 0x33ed2a09},
	{OP_WR_64_E1, XSEM_REG_PRAM + 0x1cbc0, 0x46880321},
	{OP_ZP_E1H, XSEM_REG_PRAM + 0x20000, 0x13903705},
	{OP_WR_64_E1H, XSEM_REG_PRAM + 0x224f0, 0x3b620382},
#define XSEM_COMMON_END         1712
#define XSEM_PORT0_START        1712
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x3ba0, 0x14},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0xc000, 0xfc},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x3c40, 0x1c},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x24a8, 0x14},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x1400, 0xa},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x2548, 0x1c},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x1450, 0x6},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x2628, 0x1c},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x3378, 0xfc},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x2708, 0x1c},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x3b58, 0x0},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x27e8, 0x1c},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x3d30, 0x100323},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0xa000, 0x28},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x1500, 0x0},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0xa140, 0xc},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x1508, 0x1},
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0x3000, 0x1},
	{OP_ZR, XSEM_REG_FAST_MEMORY + 0x5020, 0x2},
	{OP_ZR, XSEM_REG_FAST_MEMORY + 0x5030, 0x2},
	{OP_ZR, XSEM_REG_FAST_MEMORY + 0x5000, 0x2},
	{OP_ZR, XSEM_REG_FAST_MEMORY + 0x5010, 0x2},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x5040, 0x0},
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0x5208, 0x1},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x5048, 0xe},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x6ac8, 0x20384},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x50b8, 0x1},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x6b10, 0x42},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x4ac8, 0x20333},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x6d20, 0x4},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x4b10, 0x42},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x4d20, 0x4},
#define XSEM_PORT0_END          1744
#define XSEM_PORT1_START        1744
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x3bf0, 0x14},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0xc3f0, 0xfc},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x3cb0, 0x1c},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x24f8, 0x14},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x1428, 0xa},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x25b8, 0x1c},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x1468, 0x6},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x2698, 0x1c},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x3768, 0xfc},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x2778, 0x1c},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x3b5c, 0x0},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x2858, 0x1c},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x3d70, 0x100335},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0xa0a0, 0x28},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x1504, 0x0},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0xa170, 0xc},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x150c, 0x1},
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0x3004, 0x1},
	{OP_ZR, XSEM_REG_FAST_MEMORY + 0x5028, 0x2},
	{OP_ZR, XSEM_REG_FAST_MEMORY + 0x5038, 0x2},
	{OP_ZR, XSEM_REG_FAST_MEMORY + 0x5008, 0x2},
	{OP_ZR, XSEM_REG_FAST_MEMORY + 0x5018, 0x2},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x5044, 0x0},
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0x520c, 0x1},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x5080, 0xe},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x6ad0, 0x20386},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x50bc, 0x1},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x6c18, 0x42},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x4ad0, 0x20345},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x6d30, 0x4},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x4c18, 0x42},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x4d30, 0x4},
#define XSEM_PORT1_END          1776
#define XSEM_FUNC0_START        1776
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0xc7e0, 0x0},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x28d8, 0x100388},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x5048, 0xe},
#define XSEM_FUNC0_END          1779
#define XSEM_FUNC1_START        1779
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0xc7e4, 0x0},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x2918, 0x100398},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x5080, 0xe},
#define XSEM_FUNC1_END          1782
#define XSEM_FUNC2_START        1782
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0xc7e8, 0x0},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x2958, 0x1003a8},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x50b8, 0xe},
#define XSEM_FUNC2_END          1785
#define XSEM_FUNC3_START        1785
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0xc7ec, 0x0},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x2998, 0x1003b8},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x50f0, 0xe},
#define XSEM_FUNC3_END          1788
#define XSEM_FUNC4_START        1788
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0xc7f0, 0x0},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x29d8, 0x1003c8},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x5128, 0xe},
#define XSEM_FUNC4_END          1791
#define XSEM_FUNC5_START        1791
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0xc7f4, 0x0},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x2a18, 0x1003d8},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x5160, 0xe},
#define XSEM_FUNC5_END          1794
#define XSEM_FUNC6_START        1794
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0xc7f8, 0x0},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x2a58, 0x1003e8},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x5198, 0xe},
#define XSEM_FUNC6_END          1797
#define XSEM_FUNC7_START        1797
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0xc7fc, 0x0},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x2a98, 0x1003f8},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x51d0, 0xe},
#define XSEM_FUNC7_END          1800
#define CDU_COMMON_START        1800
	{OP_WR, CDU_REG_CDU_CONTROL0, 0x1},
	{OP_WR_E1H, CDU_REG_MF_MODE, 0x1},
	{OP_WR, CDU_REG_CDU_CHK_MASK0, 0x3d000},
	{OP_WR, CDU_REG_CDU_CHK_MASK1, 0x3d},
	{OP_WB_E1, CDU_REG_L1TT, 0x2000347},
	{OP_WB_E1H, CDU_REG_L1TT, 0x2000408},
	{OP_WB_E1, CDU_REG_MATT, 0x200547},
	{OP_WB_E1H, CDU_REG_MATT, 0x280608},
	{OP_ZR_E1, CDU_REG_MATT + 0x80, 0x2},
	{OP_WB_E1, CDU_REG_MATT + 0x88, 0x60567},
	{OP_ZR, CDU_REG_MATT + 0xa0, 0x18},
#define CDU_COMMON_END          1811
#define DMAE_COMMON_START       1811
	{OP_ZR, DMAE_REG_CMD_MEM, 0xe0},
	{OP_WR, DMAE_REG_CRC16C_INIT, 0x0},
	{OP_WR, DMAE_REG_CRC16T10_INIT, 0x1},
	{OP_WR_E1, DMAE_REG_PXP_REQ_INIT_CRD, 0x1},
	{OP_WR_E1H, DMAE_REG_PXP_REQ_INIT_CRD, 0x2},
	{OP_WR, DMAE_REG_PCI_IFEN, 0x1},
	{OP_WR, DMAE_REG_GRC_IFEN, 0x1},
#define DMAE_COMMON_END         1818
#define PXP_COMMON_START        1818
	{OP_WB_E1, PXP_REG_HST_INBOUND_INT + 0x400, 0x5056d},
	{OP_WB_E1H, PXP_REG_HST_INBOUND_INT + 0x400, 0x50630},
	{OP_WB_E1, PXP_REG_HST_INBOUND_INT + 0x420, 0x50572},
	{OP_WB_E1H, PXP_REG_HST_INBOUND_INT, 0x50635},
	{OP_WB_E1, PXP_REG_HST_INBOUND_INT, 0x50577},
	{OP_WB_E1H, PXP_REG_HST_INBOUND_INT + 0x20, 0x5063a},
#define PXP_COMMON_END          1824
#define CFC_COMMON_START        1824
	{OP_ZR_E1H, CFC_REG_LINK_LIST, 0x100},
	{OP_WR, CFC_REG_CONTROL0, 0x10},
	{OP_WR, CFC_REG_DISABLE_ON_ERROR, 0x3fff},
	{OP_WR, CFC_REG_LCREQ_WEIGHTS, 0x84924a},
#define CFC_COMMON_END          1828
#define HC_COMMON_START         1828
	{OP_ZR_E1, HC_REG_USTORM_ADDR_FOR_COALESCE, 0x4},
#define HC_COMMON_END           1829
#define HC_PORT0_START          1829
	{OP_WR_E1, HC_REG_CONFIG_0, 0x1080},
	{OP_ZR_E1, HC_REG_UC_RAM_ADDR_0, 0x2},
	{OP_WR_E1, HC_REG_ATTN_NUM_P0, 0x10},
	{OP_WR_E1, HC_REG_LEADING_EDGE_0, 0xffff},
	{OP_WR_E1, HC_REG_TRAILING_EDGE_0, 0xffff},
	{OP_WR_E1, HC_REG_AGG_INT_0, 0x0},
	{OP_WR_E1, HC_REG_ATTN_IDX, 0x0},
	{OP_ZR_E1, HC_REG_ATTN_BIT, 0x2},
	{OP_WR_E1, HC_REG_VQID_0, 0x2b5},
	{OP_WR_E1, HC_REG_PCI_CONFIG_0, 0x0},
	{OP_ZR_E1, HC_REG_P0_PROD_CONS, 0x4a},
	{OP_WR_E1, HC_REG_INT_MASK, 0x1ffff},
	{OP_ZR_E1, HC_REG_PBA_COMMAND, 0x2},
	{OP_WR_E1, HC_REG_CONFIG_0, 0x1a80},
	{OP_ZR_E1, HC_REG_STATISTIC_COUNTERS, 0x24},
	{OP_ZR_E1, HC_REG_STATISTIC_COUNTERS + 0x120, 0x4a},
	{OP_ZR_E1, HC_REG_STATISTIC_COUNTERS + 0x370, 0x4a},
	{OP_ZR_E1, HC_REG_STATISTIC_COUNTERS + 0x5c0, 0x4a},
#define HC_PORT0_END            1847
#define HC_PORT1_START          1847
	{OP_WR_E1, HC_REG_CONFIG_1, 0x1080},
	{OP_ZR_E1, HC_REG_UC_RAM_ADDR_1, 0x2},
	{OP_WR_E1, HC_REG_ATTN_NUM_P1, 0x10},
	{OP_WR_E1, HC_REG_LEADING_EDGE_1, 0xffff},
	{OP_WR_E1, HC_REG_TRAILING_EDGE_1, 0xffff},
	{OP_WR_E1, HC_REG_AGG_INT_1, 0x0},
	{OP_WR_E1, HC_REG_ATTN_IDX + 0x4, 0x0},
	{OP_ZR_E1, HC_REG_ATTN_BIT + 0x8, 0x2},
	{OP_WR_E1, HC_REG_VQID_1, 0x2b5},
	{OP_WR_E1, HC_REG_PCI_CONFIG_1, 0x0},
	{OP_ZR_E1, HC_REG_P1_PROD_CONS, 0x4a},
	{OP_WR_E1, HC_REG_INT_MASK + 0x4, 0x1ffff},
	{OP_ZR_E1, HC_REG_PBA_COMMAND + 0x8, 0x2},
	{OP_WR_E1, HC_REG_CONFIG_1, 0x1a80},
	{OP_ZR_E1, HC_REG_STATISTIC_COUNTERS + 0x90, 0x24},
	{OP_ZR_E1, HC_REG_STATISTIC_COUNTERS + 0x248, 0x4a},
	{OP_ZR_E1, HC_REG_STATISTIC_COUNTERS + 0x498, 0x4a},
	{OP_ZR_E1, HC_REG_STATISTIC_COUNTERS + 0x6e8, 0x4a},
#define HC_PORT1_END            1865
#define HC_FUNC0_START          1865
	{OP_WR_E1H, HC_REG_CONFIG_0, 0x1080},
	{OP_WR_E1H, HC_REG_FUNC_NUM_P0, 0x0},
	{OP_WR_E1H, HC_REG_ATTN_NUM_P0, 0x10},
	{OP_WR_E1H, HC_REG_ATTN_IDX, 0x0},
	{OP_ZR_E1H, HC_REG_ATTN_BIT, 0x2},
	{OP_WR_E1H, HC_REG_VQID_0, 0x2b5},
	{OP_WR_E1H, HC_REG_PCI_CONFIG_0, 0x0},
	{OP_ZR_E1H, HC_REG_P0_PROD_CONS, 0x4a},
	{OP_WR_E1H, HC_REG_INT_MASK, 0x1ffff},
	{OP_ZR_E1H, HC_REG_PBA_COMMAND, 0x2},
	{OP_WR_E1H, HC_REG_CONFIG_0, 0x1a80},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS, 0x24},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x120, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x370, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x5c0, 0x4a},
#define HC_FUNC0_END            1880
#define HC_FUNC1_START          1880
	{OP_WR_E1H, HC_REG_CONFIG_1, 0x1080},
	{OP_WR_E1H, HC_REG_FUNC_NUM_P1, 0x1},
	{OP_WR_E1H, HC_REG_ATTN_NUM_P1, 0x10},
	{OP_WR_E1H, HC_REG_ATTN_IDX + 0x4, 0x0},
	{OP_ZR_E1H, HC_REG_ATTN_BIT + 0x8, 0x2},
	{OP_WR_E1H, HC_REG_VQID_1, 0x2b5},
	{OP_WR_E1H, HC_REG_PCI_CONFIG_1, 0x0},
	{OP_ZR_E1H, HC_REG_P1_PROD_CONS, 0x4a},
	{OP_WR_E1H, HC_REG_INT_MASK + 0x4, 0x1ffff},
	{OP_ZR_E1H, HC_REG_PBA_COMMAND + 0x8, 0x2},
	{OP_WR_E1H, HC_REG_CONFIG_1, 0x1a80},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x90, 0x24},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x248, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x498, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x6e8, 0x4a},
#define HC_FUNC1_END            1895
#define HC_FUNC2_START          1895
	{OP_WR_E1H, HC_REG_CONFIG_0, 0x1080},
	{OP_WR_E1H, HC_REG_FUNC_NUM_P0, 0x2},
	{OP_WR_E1H, HC_REG_ATTN_NUM_P0, 0x10},
	{OP_WR_E1H, HC_REG_ATTN_IDX, 0x0},
	{OP_ZR_E1H, HC_REG_ATTN_BIT, 0x2},
	{OP_WR_E1H, HC_REG_VQID_0, 0x2b5},
	{OP_WR_E1H, HC_REG_PCI_CONFIG_0, 0x0},
	{OP_ZR_E1H, HC_REG_P0_PROD_CONS, 0x4a},
	{OP_WR_E1H, HC_REG_INT_MASK, 0x1ffff},
	{OP_ZR_E1H, HC_REG_PBA_COMMAND, 0x2},
	{OP_WR_E1H, HC_REG_CONFIG_0, 0x1a80},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS, 0x24},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x120, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x370, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x5c0, 0x4a},
#define HC_FUNC2_END            1910
#define HC_FUNC3_START          1910
	{OP_WR_E1H, HC_REG_CONFIG_1, 0x1080},
	{OP_WR_E1H, HC_REG_FUNC_NUM_P1, 0x3},
	{OP_WR_E1H, HC_REG_ATTN_NUM_P1, 0x10},
	{OP_WR_E1H, HC_REG_ATTN_IDX + 0x4, 0x0},
	{OP_ZR_E1H, HC_REG_ATTN_BIT + 0x8, 0x2},
	{OP_WR_E1H, HC_REG_VQID_1, 0x2b5},
	{OP_WR_E1H, HC_REG_PCI_CONFIG_1, 0x0},
	{OP_ZR_E1H, HC_REG_P1_PROD_CONS, 0x4a},
	{OP_WR_E1H, HC_REG_INT_MASK + 0x4, 0x1ffff},
	{OP_ZR_E1H, HC_REG_PBA_COMMAND + 0x8, 0x2},
	{OP_WR_E1H, HC_REG_CONFIG_1, 0x1a80},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x90, 0x24},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x248, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x498, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x6e8, 0x4a},
#define HC_FUNC3_END            1925
#define HC_FUNC4_START          1925
	{OP_WR_E1H, HC_REG_CONFIG_0, 0x1080},
	{OP_WR_E1H, HC_REG_FUNC_NUM_P0, 0x4},
	{OP_WR_E1H, HC_REG_ATTN_NUM_P0, 0x10},
	{OP_WR_E1H, HC_REG_ATTN_IDX, 0x0},
	{OP_ZR_E1H, HC_REG_ATTN_BIT, 0x2},
	{OP_WR_E1H, HC_REG_VQID_0, 0x2b5},
	{OP_WR_E1H, HC_REG_PCI_CONFIG_0, 0x0},
	{OP_ZR_E1H, HC_REG_P0_PROD_CONS, 0x4a},
	{OP_WR_E1H, HC_REG_INT_MASK, 0x1ffff},
	{OP_ZR_E1H, HC_REG_PBA_COMMAND, 0x2},
	{OP_WR_E1H, HC_REG_CONFIG_0, 0x1a80},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS, 0x24},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x120, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x370, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x5c0, 0x4a},
#define HC_FUNC4_END            1940
#define HC_FUNC5_START          1940
	{OP_WR_E1H, HC_REG_CONFIG_1, 0x1080},
	{OP_WR_E1H, HC_REG_FUNC_NUM_P1, 0x5},
	{OP_WR_E1H, HC_REG_ATTN_NUM_P1, 0x10},
	{OP_WR_E1H, HC_REG_ATTN_IDX + 0x4, 0x0},
	{OP_ZR_E1H, HC_REG_ATTN_BIT + 0x8, 0x2},
	{OP_WR_E1H, HC_REG_VQID_1, 0x2b5},
	{OP_WR_E1H, HC_REG_PCI_CONFIG_1, 0x0},
	{OP_ZR_E1H, HC_REG_P1_PROD_CONS, 0x4a},
	{OP_WR_E1H, HC_REG_INT_MASK + 0x4, 0x1ffff},
	{OP_ZR_E1H, HC_REG_PBA_COMMAND + 0x8, 0x2},
	{OP_WR_E1H, HC_REG_CONFIG_1, 0x1a80},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x90, 0x24},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x248, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x498, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x6e8, 0x4a},
#define HC_FUNC5_END            1955
#define HC_FUNC6_START          1955
	{OP_WR_E1H, HC_REG_CONFIG_0, 0x1080},
	{OP_WR_E1H, HC_REG_FUNC_NUM_P0, 0x6},
	{OP_WR_E1H, HC_REG_ATTN_NUM_P0, 0x10},
	{OP_WR_E1H, HC_REG_ATTN_IDX, 0x0},
	{OP_ZR_E1H, HC_REG_ATTN_BIT, 0x2},
	{OP_WR_E1H, HC_REG_VQID_0, 0x2b5},
	{OP_WR_E1H, HC_REG_PCI_CONFIG_0, 0x0},
	{OP_ZR_E1H, HC_REG_P0_PROD_CONS, 0x4a},
	{OP_WR_E1H, HC_REG_INT_MASK, 0x1ffff},
	{OP_ZR_E1H, HC_REG_PBA_COMMAND, 0x2},
	{OP_WR_E1H, HC_REG_CONFIG_0, 0x1a80},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS, 0x24},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x120, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x370, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x5c0, 0x4a},
#define HC_FUNC6_END            1970
#define HC_FUNC7_START          1970
	{OP_WR_E1H, HC_REG_CONFIG_1, 0x1080},
	{OP_WR_E1H, HC_REG_FUNC_NUM_P1, 0x7},
	{OP_WR_E1H, HC_REG_ATTN_NUM_P1, 0x10},
	{OP_WR_E1H, HC_REG_ATTN_IDX + 0x4, 0x0},
	{OP_ZR_E1H, HC_REG_ATTN_BIT + 0x8, 0x2},
	{OP_WR_E1H, HC_REG_VQID_1, 0x2b5},
	{OP_WR_E1H, HC_REG_PCI_CONFIG_1, 0x0},
	{OP_ZR_E1H, HC_REG_P1_PROD_CONS, 0x4a},
	{OP_WR_E1H, HC_REG_INT_MASK + 0x4, 0x1ffff},
	{OP_ZR_E1H, HC_REG_PBA_COMMAND + 0x8, 0x2},
	{OP_WR_E1H, HC_REG_CONFIG_1, 0x1a80},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x90, 0x24},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x248, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x498, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x6e8, 0x4a},
#define HC_FUNC7_END            1985
#define PXP2_COMMON_START       1985
	{OP_WR_E1H, PXP2_REG_RQ_DRAM_ALIGN, 0x1},
	{OP_WR, PXP2_REG_PGL_CONTROL0, 0xe38340},
	{OP_WR, PXP2_REG_PGL_CONTROL1, 0x3c10},
	{OP_WR_E1H, PXP2_REG_RQ_ELT_DISABLE, 0x1},
	{OP_WR_E1H, PXP2_REG_WR_REV_MODE, 0x0},
	{OP_WR, PXP2_REG_PGL_INT_TSDM_0, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_TSDM_1, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_TSDM_2, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_TSDM_3, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_TSDM_4, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_TSDM_5, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_TSDM_6, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_TSDM_7, 0xffffffff},
	{OP_WR_E1, PXP2_REG_PGL_INT_USDM_1, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_USDM_2, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_USDM_3, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_USDM_4, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_USDM_5, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_USDM_6, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_USDM_7, 0xffffffff},
	{OP_WR_E1H, PXP2_REG_PGL_INT_XSDM_1, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_XSDM_2, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_XSDM_3, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_XSDM_4, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_XSDM_5, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_XSDM_6, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_XSDM_7, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_CSDM_0, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_CSDM_1, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_CSDM_2, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_CSDM_3, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_CSDM_4, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_CSDM_5, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_CSDM_6, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_CSDM_7, 0xffffffff},
	{OP_WR_E1, PXP2_REG_PGL_INT_XSDM_0, 0xffff3330},
	{OP_WR_E1H, PXP2_REG_PGL_INT_XSDM_0, 0xff802000},
	{OP_WR_E1, PXP2_REG_PGL_INT_XSDM_1, 0xffff3340},
	{OP_WR_E1H, PXP2_REG_PGL_INT_USDM_0, 0xf0005000},
	{OP_WR_E1, PXP2_REG_PGL_INT_USDM_0, 0xf0003000},
	{OP_WR_E1H, PXP2_REG_PGL_INT_USDM_1, 0xf0008000},
	{OP_WR, PXP2_REG_RD_MAX_BLKS_VQ6, 0x8},
	{OP_WR, PXP2_REG_RD_MAX_BLKS_VQ9, 0x8},
	{OP_WR, PXP2_REG_RD_MAX_BLKS_VQ10, 0x8},
	{OP_WR, PXP2_REG_RD_MAX_BLKS_VQ11, 0x2},
	{OP_WR, PXP2_REG_RD_MAX_BLKS_VQ17, 0x4},
	{OP_WR, PXP2_REG_RD_MAX_BLKS_VQ18, 0x5},
	{OP_WR, PXP2_REG_RD_MAX_BLKS_VQ19, 0x4},
	{OP_WR, PXP2_REG_RD_MAX_BLKS_VQ22, 0x0},
	{OP_WR, PXP2_REG_RD_START_INIT, 0x1},
	{OP_WR, PXP2_REG_WR_DMAE_TH, 0x3f},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD0, 0x40},
	{OP_WR, PXP2_REG_PSWRQ_BW_ADD1, 0x1808},
	{OP_WR, PXP2_REG_PSWRQ_BW_ADD2, 0x803},
	{OP_WR, PXP2_REG_PSWRQ_BW_ADD3, 0x803},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD4, 0x40},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD5, 0x3},
	{OP_WR, PXP2_REG_PSWRQ_BW_ADD6, 0x803},
	{OP_WR, PXP2_REG_PSWRQ_BW_ADD7, 0x803},
	{OP_WR, PXP2_REG_PSWRQ_BW_ADD8, 0x803},
	{OP_WR, PXP2_REG_PSWRQ_BW_ADD9, 0x10003},
	{OP_WR, PXP2_REG_PSWRQ_BW_ADD10, 0x803},
	{OP_WR, PXP2_REG_PSWRQ_BW_ADD11, 0x803},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD12, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD13, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD14, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD15, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD16, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD17, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD18, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD19, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD20, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD22, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD23, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD24, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD25, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD26, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD27, 0x3},
	{OP_WR, PXP2_REG_PSWRQ_BW_ADD28, 0x2403},
	{OP_WR, PXP2_REG_RQ_BW_WR_ADD29, 0x2f},
	{OP_WR, PXP2_REG_RQ_BW_WR_ADD30, 0x9},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND0, 0x19},
	{OP_WR, PXP2_REG_PSWRQ_BW_UB1, 0x184},
	{OP_WR, PXP2_REG_PSWRQ_BW_UB2, 0x183},
	{OP_WR, PXP2_REG_PSWRQ_BW_UB3, 0x306},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND4, 0x19},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND5, 0x6},
	{OP_WR, PXP2_REG_PSWRQ_BW_UB6, 0x306},
	{OP_WR, PXP2_REG_PSWRQ_BW_UB7, 0x306},
	{OP_WR, PXP2_REG_PSWRQ_BW_UB8, 0x306},
	{OP_WR, PXP2_REG_PSWRQ_BW_UB9, 0xc86},
	{OP_WR, PXP2_REG_PSWRQ_BW_UB10, 0x306},
	{OP_WR, PXP2_REG_PSWRQ_BW_UB11, 0x306},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND12, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND13, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND14, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND15, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND16, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND17, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND18, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND19, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND20, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND22, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND23, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND24, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND25, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND26, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND27, 0x6},
	{OP_WR, PXP2_REG_PSWRQ_BW_UB28, 0x306},
	{OP_WR, PXP2_REG_RQ_BW_WR_UBOUND29, 0x13},
	{OP_WR, PXP2_REG_RQ_BW_WR_UBOUND30, 0x6},
	{OP_WR, PXP2_REG_PSWRQ_BW_L1, 0x1004},
	{OP_WR, PXP2_REG_PSWRQ_BW_L2, 0x1004},
	{OP_WR, PXP2_REG_PSWRQ_BW_RD, 0x106440},
	{OP_WR, PXP2_REG_PSWRQ_BW_WR, 0x106440},
	{OP_WR_E1H, PXP2_REG_RQ_ILT_MODE, 0x1},
	{OP_WR, PXP2_REG_RQ_RBC_DONE, 0x1},
#define PXP2_COMMON_END         2102
#define MISC_AEU_COMMON_START   2102
	{OP_ZR, MISC_REG_AEU_GENERAL_ATTN_0, 0x16},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE1_NIG_0, 0x55540000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE2_NIG_0, 0x55555555},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE3_NIG_0, 0x5555},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_NIG_0, 0xf0000000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE1_PXP_0, 0x55540000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE2_PXP_0, 0x55555555},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE3_PXP_0, 0x5555},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_PXP_0, 0xf0000000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE1_NIG_1, 0x55540000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE2_NIG_1, 0x55555555},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE3_NIG_1, 0x5555},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_NIG_1, 0xf0000000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE1_PXP_1, 0x0},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE2_PXP_1, 0x10000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE3_PXP_1, 0x5014},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_PXP_1, 0x0},
	{OP_WR_E1H, MISC_REG_AEU_CLR_LATCH_SIGNAL, 0xc00},
	{OP_WR_E1H, MISC_REG_AEU_GENERAL_MASK, 0x3},
#define MISC_AEU_COMMON_END     2121
#define MISC_AEU_PORT0_START    2121
	{OP_WR_E1, MISC_REG_AEU_ENABLE1_FUNC_0_OUT_0, 0xbf5c0000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE1_FUNC_0_OUT_0, 0xff5c0000},
	{OP_WR_E1, MISC_REG_AEU_ENABLE2_FUNC_0_OUT_0, 0xfff51fef},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE2_FUNC_0_OUT_0, 0xfff55fff},
	{OP_WR, MISC_REG_AEU_ENABLE3_FUNC_0_OUT_0, 0xffff},
	{OP_WR_E1, MISC_REG_AEU_ENABLE4_FUNC_0_OUT_0, 0x500003e0},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_FUNC_0_OUT_0, 0xf00003e0},
	{OP_WR, MISC_REG_AEU_ENABLE1_FUNC_0_OUT_1, 0x0},
	{OP_WR, MISC_REG_AEU_ENABLE2_FUNC_0_OUT_1, 0xa000},
	{OP_ZR, MISC_REG_AEU_ENABLE3_FUNC_0_OUT_1, 0x5},
	{OP_WR, MISC_REG_AEU_ENABLE4_FUNC_0_OUT_2, 0xfe00000},
	{OP_ZR_E1, MISC_REG_AEU_ENABLE1_FUNC_0_OUT_3, 0x14},
	{OP_ZR_E1H, MISC_REG_AEU_ENABLE1_FUNC_0_OUT_3, 0x7},
	{OP_WR_E1, MISC_REG_AEU_ENABLE1_NIG_0, 0x55540000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_FUNC_0_OUT_4, 0x400},
	{OP_WR_E1, MISC_REG_AEU_ENABLE2_NIG_0, 0x55555555},
	{OP_ZR_E1H, MISC_REG_AEU_ENABLE1_FUNC_0_OUT_5, 0x3},
	{OP_WR_E1, MISC_REG_AEU_ENABLE3_NIG_0, 0x5555},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_FUNC_0_OUT_5, 0x1000},
	{OP_WR_E1, MISC_REG_AEU_ENABLE4_NIG_0, 0x0},
	{OP_ZR_E1H, MISC_REG_AEU_ENABLE1_FUNC_0_OUT_6, 0x3},
	{OP_WR_E1, MISC_REG_AEU_ENABLE1_PXP_0, 0x55540000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_FUNC_0_OUT_6, 0x4000},
	{OP_WR_E1, MISC_REG_AEU_ENABLE2_PXP_0, 0x55555555},
	{OP_ZR_E1H, MISC_REG_AEU_ENABLE1_FUNC_0_OUT_7, 0x3},
	{OP_WR_E1, MISC_REG_AEU_ENABLE3_PXP_0, 0x5555},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_FUNC_0_OUT_7, 0x10000},
	{OP_WR_E1, MISC_REG_AEU_ENABLE4_PXP_0, 0x0},
	{OP_ZR_E1H, MISC_REG_AEU_INVERTER_1_FUNC_0, 0x4},
	{OP_WR_E1, MISC_REG_AEU_INVERTER_1_FUNC_0, 0x0},
	{OP_ZR_E1, MISC_REG_AEU_INVERTER_2_FUNC_0, 0x3},
	{OP_WR_E1, MISC_REG_AEU_MASK_ATTN_FUNC_0, 0x7},
#define MISC_AEU_PORT0_END      2153
#define MISC_AEU_PORT1_START    2153
	{OP_WR_E1, MISC_REG_AEU_ENABLE1_FUNC_1_OUT_0, 0xbf5c0000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE1_FUNC_1_OUT_0, 0xff5c0000},
	{OP_WR_E1, MISC_REG_AEU_ENABLE2_FUNC_1_OUT_0, 0xfff51fef},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE2_FUNC_1_OUT_0, 0xfff55fff},
	{OP_WR, MISC_REG_AEU_ENABLE3_FUNC_1_OUT_0, 0xffff},
	{OP_WR_E1, MISC_REG_AEU_ENABLE4_FUNC_1_OUT_0, 0x500003e0},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_FUNC_1_OUT_0, 0xf00003e0},
	{OP_WR, MISC_REG_AEU_ENABLE1_FUNC_1_OUT_1, 0x0},
	{OP_WR, MISC_REG_AEU_ENABLE2_FUNC_1_OUT_1, 0xa000},
	{OP_ZR, MISC_REG_AEU_ENABLE3_FUNC_1_OUT_1, 0x5},
	{OP_WR, MISC_REG_AEU_ENABLE4_FUNC_1_OUT_2, 0xfe00000},
	{OP_ZR_E1, MISC_REG_AEU_ENABLE1_FUNC_1_OUT_3, 0x14},
	{OP_ZR_E1H, MISC_REG_AEU_ENABLE1_FUNC_1_OUT_3, 0x7},
	{OP_WR_E1, MISC_REG_AEU_ENABLE1_NIG_1, 0x55540000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_FUNC_1_OUT_4, 0x800},
	{OP_WR_E1, MISC_REG_AEU_ENABLE2_NIG_1, 0x55555555},
	{OP_ZR_E1H, MISC_REG_AEU_ENABLE1_FUNC_1_OUT_5, 0x3},
	{OP_WR_E1, MISC_REG_AEU_ENABLE3_NIG_1, 0x5555},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_FUNC_1_OUT_5, 0x2000},
	{OP_WR_E1, MISC_REG_AEU_ENABLE4_NIG_1, 0x0},
	{OP_ZR_E1H, MISC_REG_AEU_ENABLE1_FUNC_1_OUT_6, 0x3},
	{OP_WR_E1, MISC_REG_AEU_ENABLE1_PXP_1, 0x55540000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_FUNC_1_OUT_6, 0x8000},
	{OP_WR_E1, MISC_REG_AEU_ENABLE2_PXP_1, 0x55555555},
	{OP_ZR_E1H, MISC_REG_AEU_ENABLE1_FUNC_1_OUT_7, 0x3},
	{OP_WR_E1, MISC_REG_AEU_ENABLE3_PXP_1, 0x5555},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_FUNC_1_OUT_7, 0x20000},
	{OP_WR_E1, MISC_REG_AEU_ENABLE4_PXP_1, 0x0},
	{OP_ZR_E1H, MISC_REG_AEU_INVERTER_1_FUNC_1, 0x4},
	{OP_WR_E1, MISC_REG_AEU_INVERTER_1_FUNC_1, 0x0},
	{OP_ZR_E1, MISC_REG_AEU_INVERTER_2_FUNC_1, 0x3},
	{OP_WR_E1, MISC_REG_AEU_MASK_ATTN_FUNC_1, 0x7},
#define MISC_AEU_PORT1_END      2185

};

static const u32 init_data_e1[] = {
	0x00010000, 0x000204c0, 0x00030980, 0x00040e40, 0x00051300, 0x000617c0,
	0x00071c80, 0x00082140, 0x00092600, 0x000a2ac0, 0x000b2f80, 0x000c3440,
	0x000d3900, 0x000e3dc0, 0x000f4280, 0x00104740, 0x00114c00, 0x001250c0,
	0x00135580, 0x00145a40, 0x00155f00, 0x001663c0, 0x00176880, 0x00186d40,
	0x00197200, 0x001a76c0, 0x001b7b80, 0x001c8040, 0x001d8500, 0x001e89c0,
	0x001f8e80, 0x00209340, 0x00002000, 0x00004000, 0x00006000, 0x00008000,
	0x0000a000, 0x0000c000, 0x0000e000, 0x00010000, 0x00012000, 0x00014000,
	0x00016000, 0x00018000, 0x0001a000, 0x0001c000, 0x0001e000, 0x00020000,
	0x00022000, 0x00024000, 0x00026000, 0x00028000, 0x0002a000, 0x0002c000,
	0x0002e000, 0x00030000, 0x00032000, 0x00034000, 0x00036000, 0x00038000,
	0x0003a000, 0x0003c000, 0x0003e000, 0x00040000, 0x00042000, 0x00044000,
	0x00046000, 0x00048000, 0x0004a000, 0x0004c000, 0x0004e000, 0x00050000,
	0x00052000, 0x00054000, 0x00056000, 0x00058000, 0x0005a000, 0x0005c000,
	0x0005e000, 0x00060000, 0x00062000, 0x00064000, 0x00066000, 0x00068000,
	0x0006a000, 0x0006c000, 0x0006e000, 0x00070000, 0x00072000, 0x00074000,
	0x00076000, 0x00078000, 0x0007a000, 0x0007c000, 0x0007e000, 0x00080000,
	0x00082000, 0x00084000, 0x00086000, 0x00088000, 0x0008a000, 0x0008c000,
	0x0008e000, 0x00090000, 0x00092000, 0x00094000, 0x00096000, 0x00098000,
	0x0009a000, 0x0009c000, 0x0009e000, 0x000a0000, 0x000a2000, 0x000a4000,
	0x000a6000, 0x000a8000, 0x000aa000, 0x000ac000, 0x000ae000, 0x000b0000,
	0x000b2000, 0x000b4000, 0x000b6000, 0x000b8000, 0x000ba000, 0x000bc000,
	0x000be000, 0x000c0000, 0x000c2000, 0x000c4000, 0x000c6000, 0x000c8000,
	0x000ca000, 0x000cc000, 0x000ce000, 0x000d0000, 0x000d2000, 0x000d4000,
	0x000d6000, 0x000d8000, 0x000da000, 0x000dc000, 0x000de000, 0x000e0000,
	0x000e2000, 0x000e4000, 0x000e6000, 0x000e8000, 0x000ea000, 0x000ec000,
	0x000ee000, 0x000f0000, 0x000f2000, 0x000f4000, 0x000f6000, 0x000f8000,
	0x000fa000, 0x000fc000, 0x000fe000, 0x00100000, 0x00102000, 0x00104000,
	0x00106000, 0x00108000, 0x0010a000, 0x0010c000, 0x0010e000, 0x00110000,
	0x00112000, 0x00114000, 0x00116000, 0x00118000, 0x0011a000, 0x0011c000,
	0x0011e000, 0x00120000, 0x00122000, 0x00124000, 0x00126000, 0x00128000,
	0x0012a000, 0x0012c000, 0x0012e000, 0x00130000, 0x00132000, 0x00134000,
	0x00136000, 0x00138000, 0x0013a000, 0x0013c000, 0x0013e000, 0x00140000,
	0x00142000, 0x00144000, 0x00146000, 0x00148000, 0x0014a000, 0x0014c000,
	0x0014e000, 0x00150000, 0x00152000, 0x00154000, 0x00156000, 0x00158000,
	0x0015a000, 0x0015c000, 0x0015e000, 0x00160000, 0x00162000, 0x00164000,
	0x00166000, 0x00168000, 0x0016a000, 0x0016c000, 0x0016e000, 0x00170000,
	0x00172000, 0x00174000, 0x00176000, 0x00178000, 0x0017a000, 0x0017c000,
	0x0017e000, 0x00180000, 0x00182000, 0x00184000, 0x00186000, 0x00188000,
	0x0018a000, 0x0018c000, 0x0018e000, 0x00190000, 0x00192000, 0x00194000,
	0x00196000, 0x00198000, 0x0019a000, 0x0019c000, 0x0019e000, 0x001a0000,
	0x001a2000, 0x001a4000, 0x001a6000, 0x001a8000, 0x001aa000, 0x001ac000,
	0x001ae000, 0x001b0000, 0x001b2000, 0x001b4000, 0x001b6000, 0x001b8000,
	0x001ba000, 0x001bc000, 0x001be000, 0x001c0000, 0x001c2000, 0x001c4000,
	0x001c6000, 0x001c8000, 0x001ca000, 0x001cc000, 0x001ce000, 0x001d0000,
	0x001d2000, 0x001d4000, 0x001d6000, 0x001d8000, 0x001da000, 0x001dc000,
	0x001de000, 0x001e0000, 0x001e2000, 0x001e4000, 0x001e6000, 0x001e8000,
	0x001ea000, 0x001ec000, 0x001ee000, 0x001f0000, 0x001f2000, 0x001f4000,
	0x001f6000, 0x001f8000, 0x001fa000, 0x001fc000, 0x001fe000, 0x00200000,
	0x00202000, 0x00204000, 0x00206000, 0x00208000, 0x0020a000, 0x0020c000,
	0x0020e000, 0x00210000, 0x00212000, 0x00214000, 0x00216000, 0x00218000,
	0x0021a000, 0x0021c000, 0x0021e000, 0x00220000, 0x00222000, 0x00224000,
	0x00226000, 0x00228000, 0x0022a000, 0x0022c000, 0x0022e000, 0x00230000,
	0x00232000, 0x00234000, 0x00236000, 0x00238000, 0x0023a000, 0x0023c000,
	0x0023e000, 0x00240000, 0x00242000, 0x00244000, 0x00246000, 0x00248000,
	0x0024a000, 0x0024c000, 0x0024e000, 0x00250000, 0x00252000, 0x00254000,
	0x00256000, 0x00258000, 0x0025a000, 0x0025c000, 0x0025e000, 0x00260000,
	0x00262000, 0x00264000, 0x00266000, 0x00268000, 0x0026a000, 0x0026c000,
	0x0026e000, 0x00270000, 0x00272000, 0x00274000, 0x00276000, 0x00278000,
	0x0027a000, 0x0027c000, 0x0027e000, 0x00280000, 0x00282000, 0x00284000,
	0x00286000, 0x00288000, 0x0028a000, 0x0028c000, 0x0028e000, 0x00290000,
	0x00292000, 0x00294000, 0x00296000, 0x00298000, 0x0029a000, 0x0029c000,
	0x0029e000, 0x002a0000, 0x002a2000, 0x002a4000, 0x002a6000, 0x002a8000,
	0x002aa000, 0x002ac000, 0x002ae000, 0x002b0000, 0x002b2000, 0x002b4000,
	0x002b6000, 0x002b8000, 0x002ba000, 0x002bc000, 0x002be000, 0x002c0000,
	0x002c2000, 0x002c4000, 0x002c6000, 0x002c8000, 0x002ca000, 0x002cc000,
	0x002ce000, 0x002d0000, 0x002d2000, 0x002d4000, 0x002d6000, 0x002d8000,
	0x002da000, 0x002dc000, 0x002de000, 0x002e0000, 0x002e2000, 0x002e4000,
	0x002e6000, 0x002e8000, 0x002ea000, 0x002ec000, 0x002ee000, 0x002f0000,
	0x002f2000, 0x002f4000, 0x002f6000, 0x002f8000, 0x002fa000, 0x002fc000,
	0x002fe000, 0x00300000, 0x00302000, 0x00304000, 0x00306000, 0x00308000,
	0x0030a000, 0x0030c000, 0x0030e000, 0x00310000, 0x00312000, 0x00314000,
	0x00316000, 0x00318000, 0x0031a000, 0x0031c000, 0x0031e000, 0x00320000,
	0x00322000, 0x00324000, 0x00326000, 0x00328000, 0x0032a000, 0x0032c000,
	0x0032e000, 0x00330000, 0x00332000, 0x00334000, 0x00336000, 0x00338000,
	0x0033a000, 0x0033c000, 0x0033e000, 0x00340000, 0x00342000, 0x00344000,
	0x00346000, 0x00348000, 0x0034a000, 0x0034c000, 0x0034e000, 0x00350000,
	0x00352000, 0x00354000, 0x00356000, 0x00358000, 0x0035a000, 0x0035c000,
	0x0035e000, 0x00360000, 0x00362000, 0x00364000, 0x00366000, 0x00368000,
	0x0036a000, 0x0036c000, 0x0036e000, 0x00370000, 0x00372000, 0x00374000,
	0x00376000, 0x00378000, 0x0037a000, 0x0037c000, 0x0037e000, 0x00380000,
	0x00382000, 0x00384000, 0x00386000, 0x00388000, 0x0038a000, 0x0038c000,
	0x0038e000, 0x00390000, 0x00392000, 0x00394000, 0x00396000, 0x00398000,
	0x0039a000, 0x0039c000, 0x0039e000, 0x003a0000, 0x003a2000, 0x003a4000,
	0x003a6000, 0x003a8000, 0x003aa000, 0x003ac000, 0x003ae000, 0x003b0000,
	0x003b2000, 0x003b4000, 0x003b6000, 0x003b8000, 0x003ba000, 0x003bc000,
	0x003be000, 0x003c0000, 0x003c2000, 0x003c4000, 0x003c6000, 0x003c8000,
	0x003ca000, 0x003cc000, 0x003ce000, 0x003d0000, 0x003d2000, 0x003d4000,
	0x003d6000, 0x003d8000, 0x003da000, 0x003dc000, 0x003de000, 0x003e0000,
	0x003e2000, 0x003e4000, 0x003e6000, 0x003e8000, 0x003ea000, 0x003ec000,
	0x003ee000, 0x003f0000, 0x003f2000, 0x003f4000, 0x003f6000, 0x003f8000,
	0x003fa000, 0x003fc000, 0x003fe000, 0x003fe001, 0x00000000, 0x000001ff,
	0x00000200, 0x00000001, 0x00000003, 0x00bebc20, 0x00000003, 0x00bebc20,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0x00000000, 0x00007ff8, 0x00000000, 0x00003500,
	0xffffffff, 0x00000000, 0xffffffff, 0x00000000, 0xffffffff, 0x00000003,
	0x00bebc20, 0xffffffff, 0x00000000, 0xffffffff, 0x00000000, 0xffffffff,
	0x00000003, 0x00bebc20, 0x00002000, 0x000040c0, 0x00006180, 0x00008240,
	0x0000a300, 0x0000c3c0, 0x0000e480, 0x00010540, 0x00012600, 0x000146c0,
	0x00016780, 0x00018840, 0x0001a900, 0x0001c9c0, 0x0001ea80, 0x00020b40,
	0x00022c00, 0x00024cc0, 0x00026d80, 0x00028e40, 0x0002af00, 0x0002cfc0,
	0x0002f080, 0x00031140, 0x00033200, 0x000352c0, 0x00037380, 0x00039440,
	0x0003b500, 0x0003d5c0, 0x0003f680, 0x00041740, 0x00043800, 0x000458c0,
	0x00047980, 0x00049a40, 0x00008000, 0x00010380, 0x00018700, 0x00020a80,
	0x00028e00, 0x00031180, 0x00039500, 0x00041880, 0x00049c00, 0x00051f80,
	0x0005a300, 0x00062680, 0x0006aa00, 0x00072d80, 0x0007b100, 0x00083480,
	0x0008b800, 0x00093b80, 0x0009bf00, 0x000a4280, 0x000ac600, 0x000b4980,
	0x000bcd00, 0x000c5080, 0x000cd400, 0x000d5780, 0x000ddb00, 0x00001900,
	0x00100000, 0x00000000, 0x00000000, 0xffffffff, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x00000000, 0x00007ff8, 0x00000000, 0x00003500, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x00000000, 0x00007ff8, 0x00000000, 0x00001500,
	0x00001000, 0x00002080, 0x00003100, 0x00004180, 0x00005200, 0x00006280,
	0x00007300, 0x00008380, 0x00009400, 0x0000a480, 0x0000b500, 0x0000c580,
	0x0000d600, 0x0000e680, 0x0000f700, 0x00010780, 0x00011800, 0x00012880,
	0x00013900, 0x00014980, 0x00015a00, 0x00016a80, 0x00017b00, 0x00018b80,
	0x00019c00, 0x0001ac80, 0x0001bd00, 0x0001cd80, 0x0001de00, 0x0001ee80,
	0x0001ff00, 0x00000000, 0x00010001, 0x00150604, 0xccccccc1, 0xffffffff,
	0xffffffff, 0xcccc0201, 0xcccccccc, 0x00000000, 0xffffffff, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x00000000, 0x00007ff8, 0x00000000, 0x00003500, 0x0000ffff,
	0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff,
	0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff,
	0x00000000, 0x0000ffff, 0x00000000, 0x00100000, 0x00000000, 0x0000ffff,
	0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff,
	0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff,
	0x00000000, 0x0000ffff, 0x00000000, 0x00100000, 0x00000000, 0xfffffff3,
	0x320fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0000cf3c,
	0xcdcdcdcd, 0xfffffff1, 0x30efffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300,
	0xf3cf3cf3, 0x0001cf3c, 0xcdcdcdcd, 0xfffffff6, 0x305fffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0002cf3c, 0xcdcdcdcd, 0xfffff406,
	0x1cbfffff, 0x0c30c305, 0xc30c30c3, 0xcf300014, 0xf3cf3cf3, 0x0004cf3c,
	0xcdcdcdcd, 0xfffffff2, 0x304fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300,
	0xf3cf3cf3, 0x0008cf3c, 0xcdcdcdcd, 0xfffffffa, 0x302fffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0010cf3c, 0xcdcdcdcd, 0xfffffff7,
	0x31efffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0020cf3c,
	0xcdcdcdcd, 0xfffffff5, 0x302fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300,
	0xf3cf3cf3, 0x0040cf3c, 0xcdcdcdcd, 0xfffffff3, 0x310fffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0000cf3c, 0xcdcdcdcd, 0xfffffff1,
	0x310fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0001cf3c,
	0xcdcdcdcd, 0xfffffff6, 0x305fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300,
	0xf3cf3cf3, 0x0002cf3c, 0xcdcdcdcd, 0xfffff406, 0x1cbfffff, 0x0c30c305,
	0xc30c30c3, 0xcf300014, 0xf3cf3cf3, 0x0004cf3c, 0xcdcdcdcd, 0xfffffff2,
	0x304fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0008cf3c,
	0xcdcdcdcd, 0xfffffffa, 0x302fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300,
	0xf3cf3cf3, 0x0010cf3c, 0xcdcdcdcd, 0xfffffff7, 0x30efffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0020cf3c, 0xcdcdcdcd, 0xfffffff5,
	0x304fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0040cf3c,
	0xcdcdcdcd, 0xfffffff3, 0x31efffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300,
	0xf3cf3cf3, 0x0000cf3c, 0xcdcdcdcd, 0xfffffff1, 0x310fffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0001cf3c, 0xcdcdcdcd, 0xfffffff6,
	0x305fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0002cf3c,
	0xcdcdcdcd, 0xfffff406, 0x1cbfffff, 0x0c30c305, 0xc30c30c3, 0xcf300014,
	0xf3cf3cf3, 0x0004cf3c, 0xcdcdcdcd, 0xfffffff2, 0x304fffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0008cf3c, 0xcdcdcdcd, 0xfffffffa,
	0x302fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0010cf3c,
	0xcdcdcdcd, 0xffffff97, 0x056fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cc000,
	0xf3cf3cf3, 0x0020cf3c, 0xcdcdcdcd, 0xfffffff5, 0x310fffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0040cf3c, 0xcdcdcdcd, 0xfffffff3,
	0x320fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0000cf3c,
	0xcdcdcdcd, 0xfffffff1, 0x310fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300,
	0xf3cf3cf3, 0x0001cf3c, 0xcdcdcdcd, 0xfffffff6, 0x305fffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0002cf3c, 0xcdcdcdcd, 0xfffff406,
	0x1cbfffff, 0x0c30c305, 0xc30c30c3, 0xcf300014, 0xf3cf3cf3, 0x0004cf3c,
	0xcdcdcdcd, 0xfffffff2, 0x304fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300,
	0xf3cf3cf3, 0x0008cf3c, 0xcdcdcdcd, 0xffffff8a, 0x042fffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cc000, 0xf3cf3cf3, 0x0010cf3c, 0xcdcdcdcd, 0xffffff97,
	0x05cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cc000, 0xf3cf3cf3, 0x0020cf3c,
	0xcdcdcdcd, 0xfffffff5, 0x310fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300,
	0xf3cf3cf3, 0x0040cf3c, 0xcdcdcdcd, 0xfffffff3, 0x300fffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0000cf3c, 0xcdcdcdcd, 0xfffffff1,
	0x300fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0001cf3c,
	0xcdcdcdcd, 0xfffffff6, 0x305fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300,
	0xf3cf3cf3, 0x0002cf3c, 0xcdcdcdcd, 0xfffff406, 0x1cbfffff, 0x0c30c305,
	0xc30c30c3, 0xcf300014, 0xf3cf3cf3, 0x0004cf3c, 0xcdcdcdcd, 0xfffffff2,
	0x304fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0008cf3c,
	0xcdcdcdcd, 0xfffffffa, 0x302fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300,
	0xf3cf3cf3, 0x0010cf3c, 0xcdcdcdcd, 0xffffff97, 0x040fffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cc000, 0xf3cf3cf3, 0x0020cf3c, 0xcdcdcdcd, 0xfffffff5,
	0x300fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0040cf3c,
	0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc,
	0xf3cf3cf3, 0x0000cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0001cf3c, 0xcdcdcdcd, 0xffffffff,
	0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0002cf3c,
	0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc,
	0xf3cf3cf3, 0x0004cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0008cf3c, 0xcdcdcdcd, 0xffffffff,
	0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0010cf3c,
	0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc,
	0xf3cf3cf3, 0x0020cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0040cf3c, 0xcdcdcdcd, 0xffffffff,
	0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0000cf3c,
	0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc,
	0xf3cf3cf3, 0x0001cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0002cf3c, 0xcdcdcdcd, 0xffffffff,
	0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0004cf3c,
	0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc,
	0xf3cf3cf3, 0x0008cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0010cf3c, 0xcdcdcdcd, 0xffffffff,
	0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0020cf3c,
	0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc,
	0xf3cf3cf3, 0x0040cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0000cf3c, 0xcdcdcdcd, 0xffffffff,
	0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0001cf3c,
	0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc,
	0xf3cf3cf3, 0x0002cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0004cf3c, 0xcdcdcdcd, 0xffffffff,
	0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0008cf3c,
	0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc,
	0xf3cf3cf3, 0x0010cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0020cf3c, 0xcdcdcdcd, 0xffffffff,
	0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0040cf3c,
	0xcdcdcdcd, 0x00100000, 0x00070100, 0x00028170, 0x000b8198, 0x00020250,
	0x00010270, 0x000f0280, 0x00010370, 0x00080000, 0x00080080, 0x00028100,
	0x000b8128, 0x000201e0, 0x00010200, 0x00070210, 0x00020280, 0x000f0000,
	0x000800f0, 0x00028170, 0x000b8198, 0x00020250, 0x00010270, 0x000b8280,
	0x00080338, 0x00100000, 0x00080100, 0x00028180, 0x000b81a8, 0x00020260,
	0x00018280, 0x000e8298, 0x00080380, 0x00028000, 0x000b8028, 0x000200e0,
	0x00010100, 0x00008110, 0x00000118, 0xcccccccc, 0xcccccccc, 0xcccccccc,
	0xcccccccc, 0x00002000, 0xcccccccc, 0xcccccccc, 0xcccccccc, 0xcccccccc,
	0x00002000, 0xcccccccc, 0xcccccccc, 0xcccccccc, 0xcccccccc, 0x00002000
};

static const u32 init_data_e1h[] = {
	0x00010000, 0x000204c0, 0x00030980, 0x00040e40, 0x00051300, 0x000617c0,
	0x00071c80, 0x00082140, 0x00092600, 0x000a2ac0, 0x000b2f80, 0x000c3440,
	0x000d3900, 0x000e3dc0, 0x000f4280, 0x00104740, 0x00114c00, 0x001250c0,
	0x00135580, 0x00145a40, 0x00155f00, 0x001663c0, 0x00176880, 0x00186d40,
	0x00197200, 0x001a76c0, 0x001b7b80, 0x001c8040, 0x001d8500, 0x001e89c0,
	0x001f8e80, 0x00209340, 0x00002000, 0x00004000, 0x00006000, 0x00008000,
	0x0000a000, 0x0000c000, 0x0000e000, 0x00010000, 0x00012000, 0x00014000,
	0x00016000, 0x00018000, 0x0001a000, 0x0001c000, 0x0001e000, 0x00020000,
	0x00022000, 0x00024000, 0x00026000, 0x00028000, 0x0002a000, 0x0002c000,
	0x0002e000, 0x00030000, 0x00032000, 0x00034000, 0x00036000, 0x00038000,
	0x0003a000, 0x0003c000, 0x0003e000, 0x00040000, 0x00042000, 0x00044000,
	0x00046000, 0x00048000, 0x0004a000, 0x0004c000, 0x0004e000, 0x00050000,
	0x00052000, 0x00054000, 0x00056000, 0x00058000, 0x0005a000, 0x0005c000,
	0x0005e000, 0x00060000, 0x00062000, 0x00064000, 0x00066000, 0x00068000,
	0x0006a000, 0x0006c000, 0x0006e000, 0x00070000, 0x00072000, 0x00074000,
	0x00076000, 0x00078000, 0x0007a000, 0x0007c000, 0x0007e000, 0x00080000,
	0x00082000, 0x00084000, 0x00086000, 0x00088000, 0x0008a000, 0x0008c000,
	0x0008e000, 0x00090000, 0x00092000, 0x00094000, 0x00096000, 0x00098000,
	0x0009a000, 0x0009c000, 0x0009e000, 0x000a0000, 0x000a2000, 0x000a4000,
	0x000a6000, 0x000a8000, 0x000aa000, 0x000ac000, 0x000ae000, 0x000b0000,
	0x000b2000, 0x000b4000, 0x000b6000, 0x000b8000, 0x000ba000, 0x000bc000,
	0x000be000, 0x000c0000, 0x000c2000, 0x000c4000, 0x000c6000, 0x000c8000,
	0x000ca000, 0x000cc000, 0x000ce000, 0x000d0000, 0x000d2000, 0x000d4000,
	0x000d6000, 0x000d8000, 0x000da000, 0x000dc000, 0x000de000, 0x000e0000,
	0x000e2000, 0x000e4000, 0x000e6000, 0x000e8000, 0x000ea000, 0x000ec000,
	0x000ee000, 0x000f0000, 0x000f2000, 0x000f4000, 0x000f6000, 0x000f8000,
	0x000fa000, 0x000fc000, 0x000fe000, 0x00100000, 0x00102000, 0x00104000,
	0x00106000, 0x00108000, 0x0010a000, 0x0010c000, 0x0010e000, 0x00110000,
	0x00112000, 0x00114000, 0x00116000, 0x00118000, 0x0011a000, 0x0011c000,
	0x0011e000, 0x00120000, 0x00122000, 0x00124000, 0x00126000, 0x00128000,
	0x0012a000, 0x0012c000, 0x0012e000, 0x00130000, 0x00132000, 0x00134000,
	0x00136000, 0x00138000, 0x0013a000, 0x0013c000, 0x0013e000, 0x00140000,
	0x00142000, 0x00144000, 0x00146000, 0x00148000, 0x0014a000, 0x0014c000,
	0x0014e000, 0x00150000, 0x00152000, 0x00154000, 0x00156000, 0x00158000,
	0x0015a000, 0x0015c000, 0x0015e000, 0x00160000, 0x00162000, 0x00164000,
	0x00166000, 0x00168000, 0x0016a000, 0x0016c000, 0x0016e000, 0x00170000,
	0x00172000, 0x00174000, 0x00176000, 0x00178000, 0x0017a000, 0x0017c000,
	0x0017e000, 0x00180000, 0x00182000, 0x00184000, 0x00186000, 0x00188000,
	0x0018a000, 0x0018c000, 0x0018e000, 0x00190000, 0x00192000, 0x00194000,
	0x00196000, 0x00198000, 0x0019a000, 0x0019c000, 0x0019e000, 0x001a0000,
	0x001a2000, 0x001a4000, 0x001a6000, 0x001a8000, 0x001aa000, 0x001ac000,
	0x001ae000, 0x001b0000, 0x001b2000, 0x001b4000, 0x001b6000, 0x001b8000,
	0x001ba000, 0x001bc000, 0x001be000, 0x001c0000, 0x001c2000, 0x001c4000,
	0x001c6000, 0x001c8000, 0x001ca000, 0x001cc000, 0x001ce000, 0x001d0000,
	0x001d2000, 0x001d4000, 0x001d6000, 0x001d8000, 0x001da000, 0x001dc000,
	0x001de000, 0x001e0000, 0x001e2000, 0x001e4000, 0x001e6000, 0x001e8000,
	0x001ea000, 0x001ec000, 0x001ee000, 0x001f0000, 0x001f2000, 0x001f4000,
	0x001f6000, 0x001f8000, 0x001fa000, 0x001fc000, 0x001fe000, 0x00200000,
	0x00202000, 0x00204000, 0x00206000, 0x00208000, 0x0020a000, 0x0020c000,
	0x0020e000, 0x00210000, 0x00212000, 0x00214000, 0x00216000, 0x00218000,
	0x0021a000, 0x0021c000, 0x0021e000, 0x00220000, 0x00222000, 0x00224000,
	0x00226000, 0x00228000, 0x0022a000, 0x0022c000, 0x0022e000, 0x00230000,
	0x00232000, 0x00234000, 0x00236000, 0x00238000, 0x0023a000, 0x0023c000,
	0x0023e000, 0x00240000, 0x00242000, 0x00244000, 0x00246000, 0x00248000,
	0x0024a000, 0x0024c000, 0x0024e000, 0x00250000, 0x00252000, 0x00254000,
	0x00256000, 0x00258000, 0x0025a000, 0x0025c000, 0x0025e000, 0x00260000,
	0x00262000, 0x00264000, 0x00266000, 0x00268000, 0x0026a000, 0x0026c000,
	0x0026e000, 0x00270000, 0x00272000, 0x00274000, 0x00276000, 0x00278000,
	0x0027a000, 0x0027c000, 0x0027e000, 0x00280000, 0x00282000, 0x00284000,
	0x00286000, 0x00288000, 0x0028a000, 0x0028c000, 0x0028e000, 0x00290000,
	0x00292000, 0x00294000, 0x00296000, 0x00298000, 0x0029a000, 0x0029c000,
	0x0029e000, 0x002a0000, 0x002a2000, 0x002a4000, 0x002a6000, 0x002a8000,
	0x002aa000, 0x002ac000, 0x002ae000, 0x002b0000, 0x002b2000, 0x002b4000,
	0x002b6000, 0x002b8000, 0x002ba000, 0x002bc000, 0x002be000, 0x002c0000,
	0x002c2000, 0x002c4000, 0x002c6000, 0x002c8000, 0x002ca000, 0x002cc000,
	0x002ce000, 0x002d0000, 0x002d2000, 0x002d4000, 0x002d6000, 0x002d8000,
	0x002da000, 0x002dc000, 0x002de000, 0x002e0000, 0x002e2000, 0x002e4000,
	0x002e6000, 0x002e8000, 0x002ea000, 0x002ec000, 0x002ee000, 0x002f0000,
	0x002f2000, 0x002f4000, 0x002f6000, 0x002f8000, 0x002fa000, 0x002fc000,
	0x002fe000, 0x00300000, 0x00302000, 0x00304000, 0x00306000, 0x00308000,
	0x0030a000, 0x0030c000, 0x0030e000, 0x00310000, 0x00312000, 0x00314000,
	0x00316000, 0x00318000, 0x0031a000, 0x0031c000, 0x0031e000, 0x00320000,
	0x00322000, 0x00324000, 0x00326000, 0x00328000, 0x0032a000, 0x0032c000,
	0x0032e000, 0x00330000, 0x00332000, 0x00334000, 0x00336000, 0x00338000,
	0x0033a000, 0x0033c000, 0x0033e000, 0x00340000, 0x00342000, 0x00344000,
	0x00346000, 0x00348000, 0x0034a000, 0x0034c000, 0x0034e000, 0x00350000,
	0x00352000, 0x00354000, 0x00356000, 0x00358000, 0x0035a000, 0x0035c000,
	0x0035e000, 0x00360000, 0x00362000, 0x00364000, 0x00366000, 0x00368000,
	0x0036a000, 0x0036c000, 0x0036e000, 0x00370000, 0x00372000, 0x00374000,
	0x00376000, 0x00378000, 0x0037a000, 0x0037c000, 0x0037e000, 0x00380000,
	0x00382000, 0x00384000, 0x00386000, 0x00388000, 0x0038a000, 0x0038c000,
	0x0038e000, 0x00390000, 0x00392000, 0x00394000, 0x00396000, 0x00398000,
	0x0039a000, 0x0039c000, 0x0039e000, 0x003a0000, 0x003a2000, 0x003a4000,
	0x003a6000, 0x003a8000, 0x003aa000, 0x003ac000, 0x003ae000, 0x003b0000,
	0x003b2000, 0x003b4000, 0x003b6000, 0x003b8000, 0x003ba000, 0x003bc000,
	0x003be000, 0x003c0000, 0x003c2000, 0x003c4000, 0x003c6000, 0x003c8000,
	0x003ca000, 0x003cc000, 0x003ce000, 0x003d0000, 0x003d2000, 0x003d4000,
	0x003d6000, 0x003d8000, 0x003da000, 0x003dc000, 0x003de000, 0x003e0000,
	0x003e2000, 0x003e4000, 0x003e6000, 0x003e8000, 0x003ea000, 0x003ec000,
	0x003ee000, 0x003f0000, 0x003f2000, 0x003f4000, 0x003f6000, 0x003f8000,
	0x003fa000, 0x003fc000, 0x003fe000, 0x003fe001, 0x00000000, 0x000001ff,
	0x00000200, 0x00000001, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0x00000000, 0x00007ff8,
	0x00000000, 0x00001500, 0xffffffff, 0x00000000, 0xffffffff, 0x00000000,
	0xffffffff, 0xffffffff, 0x00000000, 0xffffffff, 0x00000000, 0xffffffff,
	0xffffffff, 0x00000000, 0xffffffff, 0x00000000, 0xffffffff, 0x00000003,
	0x00bebc20, 0xffffffff, 0x00000000, 0xffffffff, 0x00000000, 0xffffffff,
	0x00000003, 0x00bebc20, 0xffffffff, 0x00000000, 0xffffffff, 0x00000000,
	0xffffffff, 0x00000003, 0x00bebc20, 0xffffffff, 0x00000000, 0xffffffff,
	0x00000000, 0xffffffff, 0x00000003, 0x00bebc20, 0xffffffff, 0x00000000,
	0xffffffff, 0x00000000, 0xffffffff, 0x00000003, 0x00bebc20, 0xffffffff,
	0x00000000, 0xffffffff, 0x00000000, 0xffffffff, 0x00000003, 0x00bebc20,
	0x00002000, 0x000040c0, 0x00006180, 0x00008240, 0x0000a300, 0x0000c3c0,
	0x0000e480, 0x00010540, 0x00012600, 0x000146c0, 0x00016780, 0x00018840,
	0x0001a900, 0x0001c9c0, 0x0001ea80, 0x00020b40, 0x00022c00, 0x00024cc0,
	0x00026d80, 0x00028e40, 0x0002af00, 0x0002cfc0, 0x0002f080, 0x00031140,
	0x00033200, 0x000352c0, 0x00037380, 0x00039440, 0x0003b500, 0x0003d5c0,
	0x0003f680, 0x00041740, 0x00043800, 0x000458c0, 0x00047980, 0x00049a40,
	0x00008000, 0x00010380, 0x00018700, 0x00020a80, 0x00028e00, 0x00031180,
	0x00039500, 0x00041880, 0x00049c00, 0x00051f80, 0x0005a300, 0x00062680,
	0x0006aa00, 0x00072d80, 0x0007b100, 0x00083480, 0x0008b800, 0x00093b80,
	0x0009bf00, 0x000a4280, 0x000ac600, 0x000b4980, 0x000bcd00, 0x000c5080,
	0x000cd400, 0x000d5780, 0x000ddb00, 0x00001900, 0x00000028, 0x00100000,
	0x00000000, 0x00000000, 0xffffffff, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x00000000,
	0x00007ff8, 0x00000000, 0x00001500, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x00000000, 0x00007ff8, 0x00000000, 0x00001500, 0x00001000,
	0x00002080, 0x00003100, 0x00004180, 0x00005200, 0x00006280, 0x00007300,
	0x00008380, 0x00009400, 0x0000a480, 0x0000b500, 0x0000c580, 0x0000d600,
	0x0000e680, 0x0000f700, 0x00010780, 0x00011800, 0x00012880, 0x00013900,
	0x00014980, 0x00015a00, 0x00016a80, 0x00017b00, 0x00018b80, 0x00019c00,
	0x0001ac80, 0x0001bd00, 0x0001cd80, 0x0001de00, 0x0001ee80, 0x0001ff00,
	0x00000000, 0x00010001, 0x00150604, 0xccccccc5, 0xffffffff, 0xffffffff,
	0xcccc0201, 0xcccccccc, 0xcccc0201, 0xcccccccc, 0xcccc0201, 0xcccccccc,
	0xcccc0201, 0xcccccccc, 0xcccc0201, 0xcccccccc, 0xcccc0201, 0xcccccccc,
	0xcccc0201, 0xcccccccc, 0xcccc0201, 0xcccccccc, 0x00000000, 0xffffffff,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x00000000, 0x00007ff8, 0x00000000, 0x00003500,
	0x00100000, 0x00000000, 0x00100000, 0x00000000, 0x0000ffff, 0x00000000,
	0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000,
	0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000,
	0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000,
	0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000,
	0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000,
	0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000,
	0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000,
	0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000,
	0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000,
	0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000,
	0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000,
	0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000,
	0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000,
	0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000,
	0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000,
	0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000,
	0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000,
	0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000,
	0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000,
	0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000,
	0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000, 0x0000ffff, 0x00000000,
	0xfffffff3, 0x320fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3,
	0x0000cf3c, 0xcdcdcdcd, 0xfffffff1, 0x30efffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf300, 0xf3cf3cf3, 0x0001cf3c, 0xcdcdcdcd, 0xfffffff6, 0x305fffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0002cf3c, 0xcdcdcdcd,
	0xfffff406, 0x1cbfffff, 0x0c30c305, 0xc30c30c3, 0xcf300014, 0xf3cf3cf3,
	0x0004cf3c, 0xcdcdcdcd, 0xfffffff2, 0x304fffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf300, 0xf3cf3cf3, 0x0008cf3c, 0xcdcdcdcd, 0xfffffffa, 0x302fffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0010cf3c, 0xcdcdcdcd,
	0xfffffff7, 0x31efffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3,
	0x0020cf3c, 0xcdcdcdcd, 0xfffffff5, 0x302fffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf300, 0xf3cf3cf3, 0x0040cf3c, 0xcdcdcdcd, 0xfffffff3, 0x310fffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0000cf3c, 0xcdcdcdcd,
	0xfffffff1, 0x310fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3,
	0x0001cf3c, 0xcdcdcdcd, 0xfffffff6, 0x305fffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf300, 0xf3cf3cf3, 0x0002cf3c, 0xcdcdcdcd, 0xfffff406, 0x1cbfffff,
	0x0c30c305, 0xc30c30c3, 0xcf300014, 0xf3cf3cf3, 0x0004cf3c, 0xcdcdcdcd,
	0xfffffff2, 0x304fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3,
	0x0008cf3c, 0xcdcdcdcd, 0xfffffffa, 0x302fffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf300, 0xf3cf3cf3, 0x0010cf3c, 0xcdcdcdcd, 0xfffffff7, 0x30efffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0020cf3c, 0xcdcdcdcd,
	0xfffffff5, 0x304fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3,
	0x0040cf3c, 0xcdcdcdcd, 0xfffffff3, 0x31efffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf300, 0xf3cf3cf3, 0x0000cf3c, 0xcdcdcdcd, 0xfffffff1, 0x310fffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0001cf3c, 0xcdcdcdcd,
	0xfffffff6, 0x305fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3,
	0x0002cf3c, 0xcdcdcdcd, 0xfffff406, 0x1cbfffff, 0x0c30c305, 0xc30c30c3,
	0xcf300014, 0xf3cf3cf3, 0x0004cf3c, 0xcdcdcdcd, 0xfffffff2, 0x304fffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0008cf3c, 0xcdcdcdcd,
	0xfffffffa, 0x302fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3,
	0x0010cf3c, 0xcdcdcdcd, 0xffffff97, 0x056fffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cc000, 0xf3cf3cf3, 0x0020cf3c, 0xcdcdcdcd, 0xfffffff5, 0x310fffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0040cf3c, 0xcdcdcdcd,
	0xfffffff3, 0x320fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3,
	0x0000cf3c, 0xcdcdcdcd, 0xfffffff1, 0x310fffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf300, 0xf3cf3cf3, 0x0001cf3c, 0xcdcdcdcd, 0xfffffff6, 0x305fffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0002cf3c, 0xcdcdcdcd,
	0xfffff406, 0x1cbfffff, 0x0c30c305, 0xc30c30c3, 0xcf300014, 0xf3cf3cf3,
	0x0004cf3c, 0xcdcdcdcd, 0xfffffff2, 0x304fffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf300, 0xf3cf3cf3, 0x0008cf3c, 0xcdcdcdcd, 0xffffff8a, 0x042fffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cc000, 0xf3cf3cf3, 0x0010cf3c, 0xcdcdcdcd,
	0xffffff97, 0x05cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cc000, 0xf3cf3cf3,
	0x0020cf3c, 0xcdcdcdcd, 0xfffffff5, 0x310fffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf300, 0xf3cf3cf3, 0x0040cf3c, 0xcdcdcdcd, 0xfffffff3, 0x316fffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0000cf3c, 0xcdcdcdcd,
	0xfffffff1, 0x302fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3,
	0x0001cf3c, 0xcdcdcdcd, 0xfffffff6, 0x305fffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf300, 0xf3cf3cf3, 0x0002cf3c, 0xcdcdcdcd, 0xfffffff6, 0x30bfffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf314, 0xf3cf3cf3, 0x0004cf3c, 0xcdcdcdcd,
	0xfffffff2, 0x304fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3,
	0x0008cf3c, 0xcdcdcdcd, 0xfffffffa, 0x302fffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf300, 0xf3cf3cf3, 0x0010cf3c, 0xcdcdcdcd, 0xfffffff7, 0x31cfffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0020cf3c, 0xcdcdcdcd,
	0xfffffff0, 0x307fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3,
	0x0040cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf3cc, 0xf3cf3cf3, 0x0000cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0001cf3c, 0xcdcdcdcd,
	0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3,
	0x0002cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf3cc, 0xf3cf3cf3, 0x0004cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0008cf3c, 0xcdcdcdcd,
	0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3,
	0x0010cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf3cc, 0xf3cf3cf3, 0x0020cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0040cf3c, 0xcdcdcdcd,
	0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3,
	0x0000cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf3cc, 0xf3cf3cf3, 0x0001cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0002cf3c, 0xcdcdcdcd,
	0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3,
	0x0004cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf3cc, 0xf3cf3cf3, 0x0008cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0010cf3c, 0xcdcdcdcd,
	0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3,
	0x0020cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf3cc, 0xf3cf3cf3, 0x0040cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0000cf3c, 0xcdcdcdcd,
	0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3,
	0x0001cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf3cc, 0xf3cf3cf3, 0x0002cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0004cf3c, 0xcdcdcdcd,
	0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3,
	0x0008cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf3cc, 0xf3cf3cf3, 0x0010cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0020cf3c, 0xcdcdcdcd,
	0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3,
	0x0040cf3c, 0xcdcdcdcd, 0x00100000, 0x00070100, 0x00028170, 0x000b8198,
	0x00020250, 0x00010270, 0x000f0280, 0x00010370, 0x00080000, 0x00080080,
	0x00028100, 0x000b8128, 0x000201e0, 0x00010200, 0x00070210, 0x00020280,
	0x000f0000, 0x000800f0, 0x00028170, 0x000b8198, 0x00020250, 0x00010270,
	0x000b8280, 0x00080338, 0x00100000, 0x00080100, 0x00028180, 0x000b81a8,
	0x00020260, 0x00018280, 0x000e8298, 0x00080380, 0x000b0000, 0x000100b0,
	0x000280c0, 0x000580e8, 0x00020140, 0x00010160, 0x000e0170, 0x00038250,
	0xcccccccc, 0xcccccccc, 0xcccccccc, 0xcccccccc, 0x00002000, 0xcccccccc,
	0xcccccccc, 0xcccccccc, 0xcccccccc, 0x00002000, 0xcccccccc, 0xcccccccc,
	0xcccccccc, 0xcccccccc, 0x04002000
};

static const u32 tsem_int_table_data_e1[] = {
	0x00088b1f, 0x00000000, 0x51fbff00, 0x03f0c0cf, 0x19d8c58a, 0x1138fc18,
	0x5980a1fc, 0xd8181998, 0x88039880, 0x81b8803d, 0x91a18191, 0x57fd7891,
	0x6f6c1144, 0x72860661, 0xc82d3e20, 0x8229a0c0, 0x6313b710, 0xe40a9860,
	0x1ec54047, 0x517ce903, 0xa07fb8ea, 0xa6349471, 0x8224a598, 0x1e458d1d,
	0xc9a0c719, 0xe54494cf, 0x3fd012c7, 0x12af78d0, 0x02a1ff2a, 0x8a84f684,
	0x7f9343ef, 0x81af9504, 0x12bf6bfa, 0xa16b7376, 0xc73200f2, 0x0360ecb6,
	0x00000360
};

static const u32 tsem_pram_data_e1[] = {
	0x00088b1f, 0x00000000, 0x7dedff00, 0xd5547c0f, 0xf37df095, 0x4999bcde,
	0x425e4cde, 0x60109212, 0x85444092, 0xa88bfc30, 0x10909db8, 0xc075b569,
	0x1daad07f, 0xff908420, 0xa5ba5522, 0x8126265f, 0x1761a888, 0x03a8ba2d,
	0x358a8b42, 0x168681d0, 0xb88200ec, 0xbac1bbb5, 0x46ebab16, 0x921888a5,
	0x57f15588, 0xe739dfad, 0x379997de, 0x6ed40199, 0xbf7efd7f, 0x737b5d8f,
	0xdeefbbdf, 0x7bbfcf73, 0xdee7b9ce, 0xa60cd451, 0x2fb1837e, 0xff941ff0,
	0x4d8c6162, 0x5b0f948b, 0x1a7df7d9, 0x0c9c5763, 0xc674aec8, 0x76f2ba1a,
	0xcb19bb24, 0x9a473bd8, 0x7a33cf09, 0x2d42d27d, 0x0e4bfdf2, 0xdfff097c,
	0x192a4735, 0x9f71e50f, 0xecca00b4, 0x86eb12d5, 0x14ee2992, 0xf319ed06,
	0x58c99632, 0xff4674c1, 0x09223664, 0x6b9f07fe, 0xe58cc5d9, 0xd5d09fe2,
	0xc2798d19, 0xbbcb1953, 0x4350f34f, 0xe0d6e6b7, 0x19fe48fd, 0x5d57f5cb,
	0x3d8c5ccb, 0xa766f001, 0xe546f3c1, 0x7f3b1eed, 0x37fc05f7, 0x669e96fa,
	0xcc2b962b, 0x6dccddcf, 0x6fd00561, 0xa0bcfcc0, 0x642f5cdd, 0xc913f4ce,
	0x399387f0, 0xcce390bf, 0x632a78e3, 0x9d32cf00, 0x80d8cbc3, 0xc1109bea,
	0x9626c6c7, 0xd4898da9, 0xd9694b63, 0x80d5bc91, 0x247b65d7, 0x7fbe0d8f,
	0x8c2bdb0c, 0x9b77c505, 0xa02ebd45, 0x94226c2a, 0xf1cea080, 0xcc59fb43,
	0xbc44ae4a, 0xa4cd88ff, 0x501941b2, 0xa1af8075, 0xb506f551, 0x646feda1,
	0x5ea9d10a, 0xc3b01cf1, 0xcccd03f8, 0x5fc619b3, 0x6267d566, 0xdd0fd97d,
	0xf3d4009e, 0x19ca7bdb, 0x497747d4, 0x7c8bce4c, 0x7cf0017f, 0xe007f91b,
	0x195eb2a1, 0xc7406728, 0xdb127d81, 0xf0e3879c, 0xc9ed977e, 0xc4bc8163,
	0x56664e70, 0x933e7382, 0x17481394, 0x1d217317, 0x1ff2aa5a, 0xb66a8728,
	0xfb05bde6, 0x53f35abf, 0x5acf3c69, 0x1f9c7d38, 0xcd1ecbfa, 0xb4aaf44c,
	0xf9628e37, 0x3afb558c, 0xde2f91cb, 0x2afcf65d, 0x19cf012c, 0xa17be00a,
	0xe38157cd, 0x58d2ddd5, 0x6ea780c8, 0x183971b5, 0x9ef255dd, 0xdd067c02,
	0x90d25205, 0x3b7b189f, 0xdff04f8a, 0x5d44e3db, 0xf3ef4c4e, 0x8fd81595,
	0x72e2f882, 0x87fefb17, 0x1c34d408, 0xf74a83a5, 0x1828ff8a, 0xfeba2c33,
	0x2998c152, 0x8262a002, 0x8c27e197, 0x7cd148f5, 0xf7a39469, 0x8a511c94,
	0xbff3c312, 0x27404f3d, 0x7001b7d1, 0xe751fc8b, 0x03778354, 0xb2ee943f,
	0xfc01bf86, 0x0a49b751, 0x796ea0da, 0xfbef41ce, 0xd87af236, 0x7f917aa9,
	0xba816f4e, 0xbadbdf04, 0xf912bfef, 0x36cc976b, 0x92e3b763, 0x4e5fa82c,
	0x54d9d808, 0x2a3e03a8, 0xb75abc1d, 0xf86dff69, 0x8d97557d, 0xbabfa039,
	0x73be4b3d, 0x1c97d425, 0x526c32b1, 0xcd59b5b7, 0xa0d2fa81, 0xfef589d4,
	0xc0be1c99, 0x15b8396e, 0xbabbf7da, 0xfa046f33, 0x33b26a9c, 0xe77c0ab7,
	0x01bcceec, 0xb83aacf8, 0xabbf1ca3, 0x10792ede, 0xb6bba5ed, 0x79c6ce1e,
	0xbbe5c93d, 0x73325b66, 0xff83f81b, 0xf0e4844e, 0x32fde037, 0x7e832798,
	0x728eb097, 0x5b7583d4, 0x676ea9d7, 0x9aa75f04, 0x50671a74, 0x71849efe,
	0x9ffabbe0, 0x629c1e4b, 0x51f985bd, 0x38f6fb0e, 0xe1a13de6, 0x42d59afc,
	0xb56bce27, 0x0496ed8a, 0xd546ec17, 0xa4dc1d5c, 0xeafbc396, 0xcad49b8d,
	0xd9adb928, 0xd70ccc36, 0xfee18286, 0x811d7238, 0x30ad7807, 0x3d46af52,
	0x0950fa80, 0xf8a273aa, 0x254a5eac, 0x26d9acbe, 0x8f89b733, 0xff03dd38,
	0xbe027f05, 0x849cfb02, 0x836e8357, 0xedd054fa, 0xa8e82e8c, 0x89cf140c,
	0x23f7c7c3, 0x0e9e001d, 0x6b9413c4, 0x19ae7c05, 0xfe8144ac, 0x4ba65e5d,
	0xd97cfcec, 0x180b6561, 0xeecfd58c, 0x43972af0, 0x33b7655d, 0xca87ac0f,
	0xd4196f4a, 0x7bff24b3, 0xc9569f38, 0xabd7c55f, 0xe01f2cce, 0xe6c49579,
	0x42dffce1, 0xab5e61a0, 0x013f81b2, 0x8ab31def, 0x0125909f, 0x2bd63a7b,
	0x8f26ba7f, 0xfd4339fa, 0x829fa158, 0x97a3f7f3, 0xa3f5374f, 0xfd195797,
	0x71fa85fc, 0x1d3f585c, 0xe19857e5, 0xfa36af29, 0xd7682451, 0x79b0bcea,
	0x30cf57e9, 0x2d7573c3, 0xe65a93f5, 0x6577a861, 0xb7581f83, 0xdaf78657,
	0x6bc9d4f6, 0xcc5f3458, 0xdb8025d4, 0xcd125209, 0x93d32917, 0xea987c4c,
	0xa1d5334d, 0xa5c4fd27, 0x4e13fd11, 0x357c6955, 0x50bd2547, 0xfaa76392,
	0xe91a399d, 0xf0af3b85, 0x20eb845f, 0xa1b2cd8e, 0xea27faae, 0xe01af871,
	0x96165894, 0x0d641760, 0xcadabf7d, 0xc47330f1, 0xc16f8567, 0x81960df7,
	0x5fa854c2, 0x04b92964, 0xb891e6f1, 0x59924e5e, 0xb24bb623, 0xab4fd231,
	0x089f8af3, 0x7da9e144, 0x8a5fd024, 0xf56edbf4, 0x4d7f2167, 0xa0247e6d,
	0x46ab7c00, 0xa0727cc2, 0x7091e92b, 0xd5a3d600, 0x10b32b23, 0xe415369f,
	0x157c7a3b, 0xe34f1fc6, 0xf478815f, 0x4319f8e2, 0x4fe5b7c7, 0x1f6f8d37,
	0xdf1a6555, 0xc0f8c2ae, 0x9bcd65ef, 0xbf80f8c5, 0x259b182b, 0x6df1a66d,
	0xfc68aaa3, 0x32ab2ad5, 0x38349f8d, 0xfe70b7fe, 0xcff344be, 0xff3cc2bf,
	0xf9e6d551, 0x37fe7cab, 0xc6253f34, 0xdff9a24f, 0xe7c53d28, 0xcf9aaa3f,
	0x1dfbc6df, 0x8835df1c, 0xfce2efff, 0xb7c609fd, 0xcf30cc15, 0x79ad747f,
	0x7e3e36fe, 0x314ef345, 0x2fe346be, 0xf9f27696, 0xf1a5ae8f, 0x83df9b55,
	0x488ea47c, 0x3da20c6a, 0x31020b91, 0x9794749c, 0x146071ca, 0x2d187e80,
	0x771c13e5, 0xfbbe7126, 0x4df80938, 0x163be88b, 0x7d028904, 0xbe782f56,
	0x8a897b66, 0x67de967a, 0xffc4dda2, 0xb4c97455, 0xb6f5b0de, 0xb78058e0,
	0x600e4baf, 0x55fd62bd, 0x3bd69941, 0xaec80fb0, 0xfe7c6161, 0x6c2707a7,
	0x6c579e8e, 0x7ac3b8b9, 0x4724c7a2, 0x4cc09e1c, 0xe011ae36, 0x982646eb,
	0x009fa916, 0x2fc60a3d, 0x28f41b7b, 0x3f0aef96, 0x59e838e0, 0x4dcb46a6,
	0x0247b733, 0x30f195ec, 0xfc049baf, 0xef8e1427, 0x20a5cb13, 0x75e3ffe2,
	0x9fa8abb7, 0x31807716, 0x0def251d, 0x7b034e82, 0x12cdc16c, 0xf88dd3e1,
	0x914499b9, 0x7616ffb1, 0xc30d92fd, 0xc2dddf4c, 0xd0596d82, 0x05dad17e,
	0xff987523, 0x26d9e6f7, 0x920a7da3, 0x7242c230, 0xc05846cc, 0x5a1798b7,
	0x95011d67, 0x4d59e79b, 0xbf7cfd76, 0x2abdfeb9, 0x1acfbd73, 0xded05ab4,
	0x4db12a58, 0x8dadefd0, 0x38c6f7e6, 0x4e34a51b, 0x4dde3157, 0x5bde1c99,
	0x8f8c9cb1, 0x6deba275, 0x80d6ff3a, 0x5647e1a7, 0xb2f5a616, 0x1d218327,
	0xaf641903, 0xef3e75f9, 0xb36f7858, 0x803ebdda, 0xca1fb6e7, 0xf858cf84,
	0xf64b9e7b, 0xeb8ec05a, 0x15a1f0d9, 0xf9d8dbed, 0xfdffc2c4, 0xd1f3b115,
	0x0bf7d455, 0x39cfb102, 0x53f2c49f, 0xb0c95743, 0xeaed51e3, 0xec39bf3a,
	0xd57f1478, 0xaa639b6c, 0x37ce0d2f, 0x61b25fb5, 0xe2fde981, 0xf7a6a58e,
	0x376fda8b, 0x7e0417d5, 0xfdff6a68, 0xf7a6cd15, 0x63de36b7, 0xaabdff7a,
	0x7cfaa675, 0xf6a6c3ff, 0x64dbcf37, 0xee796f7a, 0x8e50ebe2, 0x664bfe5a,
	0xa47c6eb8, 0xed1fb89d, 0xc5348fc1, 0xd938f483, 0x70724594, 0x654dc9aa,
	0xbb14d75f, 0x4ac1eb9f, 0x80ce2606, 0x7da071f4, 0x4665ea06, 0xd2cff3fa,
	0xd4008167, 0x09b922ff, 0x9506f27f, 0x25858185, 0xc7c83696, 0xfbd47203,
	0xdfbcf39e, 0x653e8200, 0x27b97be8, 0xcd86f3fe, 0x71eb460b, 0xdc8887fc,
	0xceb811b2, 0x3df58bf5, 0xc4ad7df6, 0x19cfd17c, 0xbce49bbb, 0xb533ac45,
	0xb507d72a, 0xa267b33b, 0x86ab5dff, 0x35cf1b0b, 0x1520275e, 0xe75a24f5,
	0x200fc819, 0x297e2605, 0xef77c930, 0xaae0997e, 0x7a009d47, 0x0df31d75,
	0x099ea0b7, 0xfd751c1f, 0x9bc38404, 0x0caef545, 0x9b7bd75a, 0xae3b0f66,
	0x547c7d20, 0x479a6c9e, 0x3f2689e5, 0xaa9bc795, 0xa9bb7ca8, 0xa69eca91,
	0xd9be5415, 0x8df2a014, 0xff2a76a6, 0xe541d4d8, 0x540da6b1, 0xa414dabe,
	0x4bc9afb2, 0x62bfa0e5, 0x6174dfe8, 0x02bf0aaf, 0x9faa1e56, 0x85697311,
	0xe724ddb6, 0xf3942c9e, 0x85c7da33, 0x399f8f68, 0x5e658e06, 0xf2c57c62,
	0x7a3a625b, 0x0ca95ec9, 0x0ca7fd02, 0xe248ef7d, 0xd8587274, 0xd9a6706c,
	0xea7f633d, 0xea9e3859, 0x2c0cb20a, 0xce399e48, 0xdac2fd38, 0x1f3af487,
	0xa077989d, 0xe3d02e68, 0x297f23c4, 0xc45b7ec6, 0x507497fa, 0x859875a6,
	0xbd20f09f, 0xeb46f0a2, 0xa12ec0da, 0xbf83cfef, 0xebf883d3, 0xfbfe851e,
	0xfea74921, 0x4c6c84cf, 0x4dee3c41, 0xb3f3020e, 0x709e4733, 0xcb2e3ca1,
	0xe3c7e8b2, 0xeb28c1e0, 0x2d74f33a, 0x32e9fd7a, 0x4874cfd7, 0x3d693bb3,
	0x30dca776, 0xd74af901, 0xfa418f8f, 0xf4695167, 0xd54b2cb3, 0x9ebc838f,
	0xc29056da, 0x5f20efd7, 0x12a7b707, 0x485f82bf, 0xf0d6ffed, 0x80c7ea24,
	0x7b10b187, 0x00fa8ec7, 0x797c15de, 0x7f299cbf, 0xdb15f8a6, 0xed18fd6b,
	0xf7fc1b05, 0x140fc505, 0x36fd1baa, 0xdb01ca74, 0xddbe7c44, 0xe77c1e34,
	0x2fee7c36, 0xb7c5cff2, 0x15113b0a, 0xe2275847, 0x1cdb358d, 0x495d79ba,
	0xba1bd535, 0x3ad375b2, 0xfc807f83, 0x414946b3, 0x5c15a9be, 0xed68afd4,
	0x6b57c012, 0x0dbf5371, 0x67576f12, 0xf0fd51ef, 0xd38874e8, 0xa77c112d,
	0x15b88e9a, 0x3b2af790, 0x5f008078, 0x65c5e755, 0x874ee7a8, 0x1ed1325a,
	0xdccf91ac, 0xfdf38be9, 0xe3448b4e, 0x075a0d2d, 0xe0a8ebcc, 0x1afd060f,
	0x62cfc9cf, 0x7aa889da, 0xd9db85af, 0x141efdb1, 0x3f0f9efd, 0x968fdbf5,
	0x8a1ee95f, 0x0faefaa7, 0x11c93f54, 0x04715ffc, 0x6afe064f, 0xa883be2d,
	0xbdb7ab4f, 0x49e8f645, 0x47f0a06b, 0x434fd0e7, 0x5165a7e7, 0x5798d49c,
	0x184a4c00, 0xef88a167, 0xfcdeff02, 0xefa7ac3a, 0xd6cad6fd, 0x33ec7c00,
	0x07051568, 0x502ca906, 0x0b6a245f, 0xd7143543, 0xedc2cf7d, 0x73e60aa8,
	0x47581d11, 0xa791da31, 0xe2366599, 0xd97b34e9, 0x0e8a2535, 0xd2545aef,
	0xcdda8b33, 0xbfd80c76, 0x0d92faa6, 0x9b257ae6, 0xa4fa899b, 0x0595bd72,
	0xe99f9a25, 0x3a2c1ffd, 0x6b097fe1, 0x6aeb855c, 0x3083fa0b, 0x299d42ee,
	0xbabe0023, 0x8c5a3e5f, 0x0b3eee71, 0xf88c43f7, 0x0e34d2c8, 0x26e7757f,
	0xdfef0bd5, 0xe9b94d09, 0x07df864a, 0x103ae157, 0xb67925d8, 0xf7e287ba,
	0x0b1fc2cb, 0x0f5eb1af, 0x3808d389, 0x7149b6ea, 0x099fade3, 0xf5f4333e,
	0xe4dd64b7, 0xf584dc17, 0x4521bf28, 0x99597116, 0xd3f748c9, 0x49603dba,
	0xb714f7a1, 0x79b4ec0f, 0x8f7e605a, 0xe4c37c5b, 0x14276469, 0x8f76a8b1,
	0xbcf4fc5b, 0x12a97a57, 0x84a656ed, 0x850ed08b, 0x54f88635, 0x2720fc15,
	0xde308ab9, 0x8eb064ec, 0x086dfd02, 0xcab3f41f, 0x2b2d7559, 0xc83778c2,
	0x9f77f43b, 0x0488fcab, 0x62168775, 0xcb2d9fd8, 0xb877cf1c, 0xfc06f5cd,
	0xd612f803, 0x253f8a38, 0xf062538f, 0x0fa86618, 0xf3f31e9d, 0x9184e809,
	0x3e261fdd, 0x438b1176, 0x32c2d769, 0x2ba6cf8c, 0x56fe83bd, 0x1c7bfa3e,
	0x402f8a7e, 0x6f3ae5fb, 0xe7e22f5f, 0x399b5fcb, 0xfa1ced3c, 0x682ce1a8,
	0x75516190, 0x567fbe23, 0x5f29c161, 0x61ba6f43, 0x9bd28d55, 0x59fe2df3,
	0x93d40f48, 0xe3049f08, 0x60764df8, 0xe72d1eae, 0xe3f8630b, 0xce91c32b,
	0xd6bbfa4c, 0xce49bfe2, 0x57c70a18, 0x486b3fee, 0xcde30bff, 0x3ff72bf3,
	0xf5ff4866, 0xfbaffaf1, 0x03bb33e5, 0xcfd54fc0, 0x6602e83e, 0x1d29ef66,
	0x7ba01e99, 0x1736d6ed, 0x2549e5ca, 0xbeba42e0, 0x07679417, 0x16c3f0e3,
	0xaf4f90d9, 0xff131526, 0x7a9d1f10, 0xa0efdeea, 0x56f1f55d, 0x81f14eab,
	0x0db0b66d, 0xb43eb298, 0x36c7cb94, 0xbebc5bdb, 0xcfe403fa, 0xbeb32e86,
	0x83d9fea8, 0x066f1899, 0x39ff0a4a, 0xfd41fe4c, 0xa3953f96, 0x06c0d5dd,
	0x7ec5ef48, 0x4d9fe387, 0x81607b23, 0xbdf4329a, 0x20d7cfb1, 0xba10d2f0,
	0x849903f7, 0xcdfc87a5, 0xc255f6d8, 0x76507fde, 0xef9c53a6, 0xf2197632,
	0x160f8199, 0xcb7ef6e4, 0x7a293f93, 0xdde9e00b, 0x34975bf2, 0xb93f9a3e,
	0xb9d33bde, 0xb95ff1e8, 0x1f53cb13, 0xbb68c5e8, 0xdd9f58da, 0xd94fc25d,
	0x6b5acbcb, 0x607e85d8, 0x27ab26ed, 0xe67d7480, 0x823e9f89, 0x6cd79971,
	0x7fd0b19e, 0x5e8733cd, 0x35ea02bd, 0xd7e9ac3b, 0x526869f2, 0x0d2e8466,
	0xc98adff0, 0xff543a11, 0x9eea90e2, 0x4caf9fc0, 0x66a3d08b, 0x4d957ec7,
	0xd28f8a18, 0x8f6afdce, 0x9d2e8716, 0x3fa3956f, 0x27e4f2d1, 0xf7afea2a,
	0xf0d8939e, 0xdcf838bc, 0x62ec8874, 0x51d113c4, 0x6e9069d0, 0x801bed31,
	0x0d5fa82e, 0xbfbec53a, 0xec7fe84b, 0xf89e3dcf, 0xc2bfe7f9, 0xda3f947d,
	0xaaff383c, 0xc2e1df9f, 0x34abbc79, 0xb47ebe72, 0xe30bd32d, 0x99035956,
	0x79fc953a, 0x203f63d5, 0xf4725b7e, 0xff149907, 0x0b6cde60, 0x6c810ad9,
	0x8de2df9c, 0x2afcd237, 0xaef89f99, 0x87d951ea, 0x0a47d5eb, 0x8e23bd9b,
	0x5c28e45c, 0x19bbbf1f, 0xdf980c1c, 0xe070b8bb, 0x72cbc2be, 0xffc52b70,
	0xcaf8a76e, 0x20fd8c0f, 0x1fea8cb6, 0x3e9d39d9, 0x357d8d90, 0xf9a27958,
	0x6eeacb75, 0x91a9cfa4, 0x3718e1de, 0x404a606e, 0x02fa43e0, 0xce8f95fa,
	0xc3e9ce1a, 0xf8b14adc, 0x297df40e, 0xddf6c73e, 0xc8a3af56, 0x22fb1df4,
	0x72fe322f, 0x9dc03e31, 0xbbeaf684, 0xc5ff6099, 0x62b95f99, 0x576037ac,
	0x9457f145, 0xdf79737c, 0x6f970f72, 0x7383de43, 0x3ffbe366, 0x07e5c2bf,
	0x057b43bf, 0xa70f0ae0, 0x906ffbf7, 0x58d81f48, 0x6f5c9e38, 0x36b90ab1,
	0x04f837bf, 0xdd7056e0, 0xec17e41d, 0x4ff08d3f, 0x7ae56c76, 0x5f4a2ef8,
	0xae78e036, 0x7219fda1, 0x7fc844bb, 0x7f966286, 0x7dcb91b6, 0xc0227f62,
	0xe0d612e3, 0x79411f4f, 0xfdc4f905, 0xac67daeb, 0xfbf79c3e, 0xfabe0fdb,
	0xf7d3905d, 0x35390d3b, 0x3958cfeb, 0x8d39daad, 0xf7d393c5, 0x9e210d31,
	0xb8f3c29c, 0x10f5aa72, 0xf4bdff1f, 0xabbf81a7, 0xe867f062, 0x8c7844c3,
	0x947f87d5, 0x21f571dd, 0x15857bfc, 0x833fe50f, 0xab7e0cef, 0x346eba7e,
	0xbe0cc7c5, 0x906ef834, 0x1bbe0d2f, 0xe1346f12, 0x0dbdf62f, 0x97003063,
	0xe2958f6f, 0xf97bb508, 0x777c2ffe, 0xc254c478, 0x31969793, 0x447871d6,
	0x183d747a, 0x698cef53, 0xfba98def, 0x63fbda62, 0xf6a68dea, 0x55075db5,
	0x3612d79e, 0x3c5793b5, 0x1619dec2, 0xdc835f8f, 0xa07d0d2f, 0xb42f9006,
	0x7adefa01, 0x31380b37, 0xa64fbe1e, 0xe03f48f8, 0xd38c1578, 0x882f3dbf,
	0x0e6d1279, 0xc81a771e, 0x9ea15750, 0x5c07d7eb, 0x380e3768, 0xdfaf1c78,
	0x8d4ae037, 0xdaded7b2, 0xee9e932b, 0xf1d9b209, 0x41584afc, 0x587a6e48,
	0xbe3cf7a2, 0x46d64b3f, 0x4b78c0ad, 0x10c1ec87, 0xcdf3454e, 0xe82bcc2e,
	0xdd705bdf, 0xf8be783c, 0x0db69945, 0x4f4ed1fb, 0x95787241, 0xee7f28ec,
	0x343c0b24, 0x7bf5e303, 0xb1575fb9, 0x60fec636, 0x2a7f896b, 0xea2ae5b5,
	0xdec3f04f, 0x7057ef36, 0xfd16a839, 0xbf346d55, 0x1dc7be37, 0xabd7b45b,
	0xfbdf98b7, 0x541fff85, 0x24cf3e44, 0xdff84936, 0xf424fe3c, 0xfc792cf0,
	0xff00f375, 0x866447fd, 0xf667f5fb, 0x33ff84ca, 0x3cfef9db, 0x472fe9c5,
	0xfd201e7e, 0x17a9e067, 0xac4d47e5, 0xfd777a9f, 0x908ff177, 0x5ebf764f,
	0xf6506ff4, 0xf0ad7eee, 0xe5ff58d7, 0xcebd461f, 0x7d2fb686, 0x22fb41ce,
	0x8939cffd, 0xfdf7fbbf, 0xb08fd46e, 0xf146c7be, 0x3ee7fee8, 0xe97e4229,
	0x8556dbbf, 0x247fadfa, 0xf65b47f7, 0x43d4527d, 0xd12b69eb, 0xca8ab7ed,
	0x7fbda1ed, 0xc74a5379, 0x76856612, 0x24c973c2, 0x72bf0d3f, 0x7facfc50,
	0xd1c527df, 0x9dd7fe76, 0xafd8bd4f, 0x79b277ec, 0x54be113b, 0xf0d3cfbe,
	0x689fcbeb, 0xd08b7cc6, 0xbc11757e, 0xe7cdfd2f, 0xfb37a845, 0xa7fb7277,
	0x18f3dacf, 0xdabdc7ee, 0x2b6eef3a, 0x850fb9e0, 0xd3e80728, 0x944cf0f6,
	0xf978a193, 0x1782e29c, 0x0ad38f8a, 0xe3fc0f8f, 0x72f243e3, 0xda0ce6fd,
	0xa7f79c25, 0x7a8ebe6f, 0xf11b39e0, 0xf7df31a5, 0x3ec99b3b, 0x35bcdf39,
	0x7c2bffeb, 0x96f3a170, 0xef3217c2, 0xe7c1ff4b, 0x137143bd, 0x3072b17c,
	0xddf7cf94, 0x9c67f549, 0x02f7821e, 0x7f9afdf9, 0x697ff9f0, 0xba04efba,
	0xef3fcebb, 0x79f07fea, 0x8bfba627, 0xebba09b7, 0xf0d2cf98, 0xbe09cf9b,
	0xd6e7ab2f, 0xf5b1ff58, 0x1bf9a25c, 0x8b1afc76, 0xe31f23a7, 0xc025e871,
	0xe739ad3a, 0x707863b6, 0x3ab9b8cd, 0xcc7295da, 0xfe51a4fe, 0x24fdcada,
	0x3129f719, 0xc79237ae, 0x9bf098f5, 0x860f0b68, 0xb24ab456, 0x156d155b,
	0x4f15a7b7, 0xb2f017b7, 0x1e8592e6, 0x936215ca, 0x9eb1f98f, 0xf143c33b,
	0xb1ff18ea, 0x095e6255, 0x92e559ec, 0x7f411d6f, 0x12ce3ac6, 0xf95115b6,
	0x45ab9616, 0xabaad21c, 0x1b473f26, 0xdc3bae6f, 0xf44dbae6, 0x7e1c6767,
	0x620b167b, 0xf8be5a3c, 0x6c798e80, 0x498524f2, 0x8eb07750, 0xb613fa00,
	0x3ff7f32c, 0x8cd664c1, 0x35731e08, 0xb0be432f, 0x0cb43b0a, 0xe7ac14fd,
	0x5fed18fa, 0x49543b0a, 0xe200b2f7, 0xc430f755, 0x6103fa2f, 0xd85e07f0,
	0x1fc504fe, 0xd6f53f4e, 0x9a9e1077, 0x0ecccb5f, 0xeedbecf8, 0x5efc6164,
	0xdfe8aa09, 0x2f648754, 0x709467c5, 0xfb51f5f1, 0x597d8689, 0xe693acf3,
	0x16d3bd53, 0xafbe16bc, 0x114efdde, 0x0f77f7ad, 0x781cbd90, 0x256cf24a,
	0x708a7bb0, 0xe15ab0bf, 0x7d2c6e76, 0x3f72b0df, 0xf24f77bd, 0x48078c3c,
	0x671e78db, 0x56cde775, 0xcbfe545b, 0x6f3cadef, 0xff11da18, 0x28949e05,
	0x8be1068f, 0xec341fce, 0x2527dedb, 0x35975f0e, 0xd5a0f988, 0x61f476db,
	0x98faa35c, 0x62e683cd, 0x280fb6c3, 0xecfa5e6e, 0xf21eae33, 0x5f9364e3,
	0xdc9fc43b, 0xd43f1326, 0xdec8ea87, 0x45f13a85, 0xb8fc677d, 0x9efcf9ca,
	0xedf7679a, 0x6b0a000e, 0x1733f17e, 0x754e4dc6, 0x5f91756f, 0xf1dcedb9,
	0x63fe219c, 0xf4e73de7, 0x1fe14f1f, 0xd55b2760, 0xdb7bff18, 0x017bb230,
	0x7978e2be, 0xd5bf06c4, 0x63d1f33c, 0xddecdf18, 0x0863fef9, 0x3f5fed6f,
	0x56ed0c7c, 0xc7439cf6, 0xa7868e7d, 0x43e28bfe, 0x55a377c6, 0x7beccf1e,
	0x571467f2, 0x1dbf03eb, 0xf7dbeb7b, 0x5bf428ee, 0x9a7c76fa, 0xf2f87e89,
	0xe386b37d, 0x2aef977c, 0xc8e2ce1d, 0xdf2251bd, 0xae202f06, 0x83af4b17,
	0x5f6483a1, 0xa37a069f, 0x0f18337f, 0xf1e3ace8, 0x0388b715, 0x3f1f8f6c,
	0x87f7e21d, 0xaaeebfae, 0x3d5a58a9, 0xebce3ea8, 0x7402bfff, 0xf401789c,
	0xf08f7edb, 0xefd3e273, 0xfe81fe34, 0x1cfc2abf, 0x428fbf41, 0x047f1f8b,
	0x258685df, 0x17c3fff4, 0x3e233780, 0x677aa49b, 0x3b5f28ab, 0x0b78a69f,
	0x985aedd2, 0x1f33df68, 0xf6b8c28d, 0x6dc0eb49, 0xa6dfdf3c, 0xbd5b1fa3,
	0x3f240fef, 0x528ebb7d, 0x388993fc, 0xfc1b1f69, 0x225ae3c7, 0x8b61af57,
	0x040dc793, 0xe0ae31fe, 0x1173d176, 0x6c7ce03f, 0xc51215c4, 0x7cd49a13,
	0xe3c77791, 0x5e5b751e, 0x847a7e17, 0xa474d25e, 0x8ce75bd3, 0xd0781b73,
	0x45970f11, 0xc7e2c7c7, 0xa8e3066d, 0x5c465e82, 0x05fe306c, 0x878c5cf5,
	0xb03fa504, 0x6fa0fa38, 0xf5ab8f13, 0xe7e7e359, 0x7fb2f118, 0x31b3a18e,
	0x61f244cf, 0xe0f9e9c8, 0xa9f8b2ff, 0x7e26dd51, 0xfbd4f031, 0xfe3d7c59,
	0xfb617aa8, 0x5bf709d9, 0x3ed3256a, 0xbfc5ad76, 0x2eb1f911, 0xcfca96f4,
	0x3873f03b, 0x457b7cc6, 0x53ef623e, 0x5651c532, 0x3d241e75, 0x8c2fab1e,
	0x7858b8fd, 0x5db9559f, 0xd7c5df51, 0xce9dde89, 0xf4fd06a0, 0xfc43d81e,
	0x2dfdbf5c, 0xde1ce38a, 0x27b50bf6, 0x75c55d6a, 0x7f051822, 0x17f7cfef,
	0xcf2078f1, 0x671d8e8f, 0x61a7189f, 0x1a71fc6f, 0x1a607fb6, 0xa9d026a7,
	0x73d2fcf2, 0xf14a778f, 0x9dfd8cde, 0xcc32b6ea, 0x29d53c1f, 0xffb78ecf,
	0xa6ad541b, 0x5eb825f3, 0x51f81e52, 0xea62de7e, 0x679449cb, 0xece8fcbd,
	0xb1d253d7, 0x7f43c204, 0xa7ce66a1, 0x477b1fa1, 0x4743bd20, 0x3ae32bbf,
	0x1bf11bb5, 0xbf164f65, 0x04ea58d2, 0x86fc50bd, 0x6bb22a6f, 0xecb9beac,
	0x3f04c598, 0xd71c338c, 0x07e85681, 0x1e603fcf, 0xbb23c215, 0x3c2367ca,
	0x1dd16eb2, 0xad5ef271, 0xd0f28f9a, 0xbaad7e8d, 0x7d9ccf39, 0xfd8dc536,
	0xe46c5df4, 0x1052f917, 0xdf751f4f, 0x2fbb4bc8, 0x73f95ce5, 0xecbe8527,
	0xb0b0f26d, 0x6081cfca, 0x1fe441bd, 0x483ded57, 0x3aaa9de7, 0x7c06e625,
	0x241d652d, 0xa9aa9f37, 0x6cc43f22, 0xfdef543f, 0x0eafb53d, 0xac35f6f1,
	0x79e3da93, 0x3e49b091, 0x1dd8c4a6, 0x45fbbf9c, 0xd9ed48de, 0x3423ca62,
	0xb8d874e0, 0xe936f59c, 0x8b5efd26, 0x7e7869f0, 0xa9c69bab, 0x1a661ceb,
	0x775768c7, 0x2fca0af6, 0xdd2bac1c, 0x67756fc4, 0x19c689ff, 0x2ca6af94,
	0xfee243c2, 0x8ee09847, 0x04dd3ff4, 0x19ffa46f, 0xfe6c6e34, 0x1e5cd669,
	0x9ebecc5f, 0x5ce30197, 0xb052654e, 0xfdf70f25, 0xd06d23fd, 0x3eb9cb3e,
	0x73a310ef, 0x3dbf9460, 0x942926c6, 0x8fce246f, 0x80b5d69d, 0x47dbd605,
	0x66ebcdb4, 0x1843ca30, 0x43ce8b67, 0xd422e160, 0x21bb461f, 0x14f263ef,
	0x5013f172, 0xaf80b281, 0x8c29e440, 0xfa123d64, 0xfc9d1b2f, 0x2d68e29c,
	0x3fdf82dd, 0xe303fc21, 0x7390e21c, 0x15e7318b, 0x314e77cf, 0xf6e4b4bd,
	0x1ac61ed1, 0xf14afb6d, 0xcdfa4adc, 0xe8463b25, 0x7f03398c, 0xf6bcc52c,
	0x4c959ff4, 0x9ffa86ca, 0x4651df56, 0x992cfff5, 0x9fea0a34, 0x329fffb7,
	0x51235f6a, 0xcda96ade, 0xc07e8653, 0x37cbd657, 0x7acc4600, 0xc7a43af9,
	0x371bdf69, 0x1e63762d, 0xf1ca80c4, 0x6ed87ccb, 0xb78e74e4, 0x1d8ded5c,
	0x96d1a788, 0x27d4669e, 0x24fbef8f, 0x9bb8f515, 0x9d1f84e9, 0x6798eab5,
	0x7fa68f02, 0xba7c8e71, 0x8332bcd8, 0xbf34aa7f, 0x7ab7e91f, 0xca07b8c1,
	0xaa47bc61, 0xde79db26, 0x819f399e, 0xcf44e9e9, 0x844f410a, 0x97951ed3,
	0xa80e44bf, 0x874c7cfc, 0x74ca5f58, 0xd40a4f1c, 0xfa5c5fca, 0x6e5ae1e5,
	0x5f38a5f0, 0xf1ae751a, 0xd5dbc42e, 0xd8ca9f9a, 0xd9d78d73, 0xf9c43f7c,
	0x1d9e5764, 0x9ce37585, 0x4779ec62, 0xe2580ca6, 0xc59bebd9, 0xf044c779,
	0x57fbb1ce, 0xbff9b8e3, 0x023cef71, 0x42b135f2, 0xe68a60f5, 0x335315c4,
	0x90be7e14, 0x041a1df2, 0x5c2cb2fd, 0x8c9dd90e, 0x6dfb5bf6, 0xe9fd1792,
	0x5a743bfe, 0xae2b736f, 0x3fb6bf25, 0xf313af39, 0xc47ffa82, 0xe66297cf,
	0xc8d1ca34, 0x876129bd, 0xe3e0e48b, 0xd8f83918, 0xc798976c, 0xddc2ffed,
	0xe9fd43d5, 0x98303fa2, 0x83e72333, 0x8ebe65fb, 0x09b937f6, 0xb02c918e,
	0x0bb1ed1f, 0x36a7ef1d, 0xc05ff9f3, 0xbc68b6fb, 0xbf4c4f6f, 0x9efd0567,
	0xd8bf478d, 0x6d0ba873, 0x7bb610fe, 0x2af0f2b7, 0xf9e87bab, 0x36ba58d3,
	0x630f1d28, 0xef7323a8, 0x18176407, 0xc2b89b74, 0x330ca193, 0x0837f1d1,
	0x1fbdc4ef, 0x835c7058, 0x90493f7e, 0x1b5bfdf7, 0xc7623fb7, 0x93d79ccb,
	0xfed38fe3, 0x45ce0c55, 0x7b22e7e9, 0xdc3f8d31, 0x4340e3c2, 0x3fec27db,
	0x98f95cff, 0x17ef3a45, 0xf10c7ff0, 0x0dffe064, 0x1b3fc89b, 0xc1ffff8a,
	0xa9fe0379, 0x1ffc00bc, 0x0dfe173f, 0xe846ac3f, 0x6fdc1a85, 0x93f9fe02,
	0x3e666e7b, 0x6b2e5b8c, 0xb74bffc4, 0xd23f62ca, 0x66766d7b, 0xbd2c8f44,
	0x15bf71bc, 0xa3e970f8, 0x8569f112, 0xbefeb738, 0x9b12df38, 0x2f3957df,
	0xfcf27a40, 0xd2417e79, 0xccdb3543, 0x09b73fcf, 0x46c9ddff, 0x806e5e51,
	0x8594a39f, 0xffe2c45c, 0x45f4268c, 0x5da9aa45, 0x36461d2c, 0xe0f94c5a,
	0xfd83a5d9, 0x659e5f90, 0xe281ff71, 0x656eff6e, 0x2af1cf18, 0x88c353e9,
	0x1952a98f, 0xe4225bf6, 0xf46fe8d6, 0x965db30a, 0xff9f3017, 0x9f37682b,
	0x91db1bff, 0xd17f6a63, 0xfbd37c86, 0x9897838b, 0x6dba5fde, 0xa13ea9b2,
	0xfb530af3, 0x4d335d89, 0x6fe149f5, 0x394fda99, 0x9f54d732, 0x535dfdd6,
	0x2d8ecbfb, 0xbcbfbd34, 0xfef4daa7, 0x4ccb93ca, 0xfe06abf5, 0xbc3ed4d9,
	0x03c5eb98, 0x78b9594d, 0xcbc0c0be, 0x8b55db81, 0x2f6fcf8e, 0xd145e8b4,
	0xeebd33cf, 0xbd8b2c22, 0x92270fe8, 0x767b5297, 0x5cfaf46e, 0xbd26acc2,
	0xad8f6a56, 0x05197e0b, 0x9fc402fc, 0xb5eb376d, 0xda338d11, 0x39647cc1,
	0xde50c74b, 0x35d7c834, 0xa8dfae76, 0xf2f900bc, 0xeb77bb61, 0x3ede74c3,
	0x9464be56, 0x032a02af, 0x3ccacfb4, 0xb0f97794, 0x59a7ccc3, 0xadcaf409,
	0x7b888b76, 0xf4fef076, 0x24c50e23, 0xb3f3c627, 0xa5cfd149, 0xfe52d725,
	0xad7ea24e, 0xd9af0b59, 0x9ad2fa02, 0x78d2a7ed, 0x12cf36de, 0x2eef3f37,
	0x6bf4d7fb, 0x9fb10c37, 0xbee3b2ee, 0x0fcbfa65, 0xfd59be61, 0xdfe4032d,
	0x78ccdb66, 0xc33dd489, 0x9b953e79, 0xf9d4279f, 0xda9b1b9f, 0xdef5c1af,
	0xd7e2e798, 0xde6266e6, 0x7f026e40, 0xeb9d9777, 0xaa9ac7e9, 0xb3c0a9ae,
	0x15876820, 0x8f65ce47, 0xa394370a, 0xe45a3e9d, 0x89643f43, 0xaff4b79f,
	0x51c31f02, 0xa07da281, 0x3f8f14a9, 0x4b86f95d, 0xd6fc7981, 0xe457ffe2,
	0xbb13858b, 0x65f9f98b, 0x4a5cd64f, 0x7e09d0b0, 0xd28d0f43, 0x5ea10f7c,
	0x99e60519, 0x3c286f3b, 0xcdf16fc3, 0xadf783ce, 0x468f1669, 0xc70901f5,
	0x36325753, 0xfeb7da0c, 0x5af82655, 0x794e5c0f, 0xa7e6aa3d, 0x4f31b778,
	0x8c00f226, 0xe947fef8, 0xd81f9037, 0xf9e0c97a, 0xa17e461d, 0x7ec6ebe6,
	0xa56f5a3f, 0x4a675b71, 0xb4a3f7a6, 0x030fdb8e, 0x64a1951c, 0x1b29fb8a,
	0x8c7e43be, 0x69e1c59a, 0xb9624c7d, 0xe3c3c112, 0x0f8e2ed2, 0x44a3c3c0,
	0xc7de6f67, 0xf0d26316, 0xa5452ebe, 0x13239d73, 0x125e0bc4, 0x0dfa65f8,
	0x65476899, 0x5786645f, 0xede0ff5e, 0x633f3187, 0xbb07b257, 0x10ad360c,
	0xb7cf34f4, 0x75ee7d2d, 0xcb5da1f3, 0xd4c3322b, 0x630f771f, 0x390f3469,
	0x6f838c18, 0xf7005e83, 0x793f484b, 0x33cd3943, 0x0979d04f, 0x7ef519d0,
	0x9b37c596, 0x61699ee8, 0xf858cf38, 0xf6e42f7f, 0xfdcebb15, 0x6bcaacf4,
	0xb2c30cb6, 0x98ede482, 0xf57da13d, 0xaf3fd0ba, 0xe73fd3c7, 0x76a3f7bb,
	0x2c61f75e, 0xd845af65, 0xd1858db3, 0xabe83276, 0xa30f4813, 0x2caca72e,
	0xd897bd42, 0x17b4f31e, 0x1edf9de6, 0xf90c3b43, 0xfec3b0ce, 0x2fdb376c,
	0x13f5fa51, 0xa85fb73b, 0xfafd00bc, 0xefd7e919, 0x2fdae386, 0xfd7c6a19,
	0xf1c1c536, 0x8caba0df, 0xec12f8f2, 0xa43a14bb, 0xb44ef3b8, 0xbfcf9cfe,
	0xf8364fc8, 0xdcebd0d4, 0x2a9560cf, 0xd99d03ed, 0x10a7bc10, 0x7cb52df7,
	0xd44dbbca, 0xff1588cf, 0x1afc40ee, 0x30e91b78, 0xe8f013e3, 0xa13e7076,
	0x6b1e0872, 0x13168f01, 0xce3ac71e, 0x657e0761, 0x3e655ebd, 0xf027d377,
	0xc55dfa0d, 0xff5f4ef1, 0x2bc63166, 0x98fc6fea, 0x1e57fbf4, 0xfd799e67,
	0x186efc30, 0x3ee07247, 0x157ff5cb, 0x8a1ed1f1, 0xbaecb5eb, 0x88e30528,
	0xf5073375, 0x83db9d86, 0x4effa4f9, 0x1179b6ef, 0x3c69d3ce, 0xf77a74be,
	0xbe318765, 0x91d37ef1, 0x5eca257c, 0xa3f3fd39, 0xefe856c5, 0xc5a3cef4,
	0x20efe90a, 0x5f78cbe1, 0x8befc5f7, 0x9ce45a7d, 0xd9bf20c0, 0xdeb3faf9,
	0x3f26e3c1, 0x89b6bcc1, 0xcc9f3d8c, 0x33c364e3, 0xf3e3f72d, 0xc0102916,
	0xd48b6838, 0xc7718a5d, 0x9d19b7c0, 0xbebac99b, 0xacd6cc92, 0x0f2e3602,
	0xdf3db3be, 0x527ac611, 0xdfe52777, 0xc3bac769, 0x067aba58, 0xa5edb8bc,
	0x63f7d49f, 0x0bfcd0e9, 0x0369ef11, 0x31e26f9e, 0x8a73f5ed, 0x94a44e29,
	0xb03bbd72, 0xf7882920, 0xbc5a6514, 0x39bd7147, 0x2a516473, 0xcc993fbe,
	0x66d71ff7, 0x0791d2bd, 0x4032e3e3, 0xad17a7f1, 0x1b2ef7e4, 0x0c5ecde9,
	0x949b2fdf, 0x3ecb7c4e, 0x9d47d983, 0x3d2fb963, 0x8ff14594, 0xc52f00cf,
	0xc8cdbfb8, 0x7e14d1ee, 0x0b2ad0af, 0x6a50eaf3, 0xddee6353, 0x70fbf611,
	0xddfb7fa1, 0xf0158096, 0xb7378ea2, 0xa77110cb, 0x98dfc810, 0xb57f1831,
	0xa4d5d953, 0x7a018c67, 0x8b29aafd, 0x6e4dbdca, 0xd35cfe7a, 0x4dc32a38,
	0x2dd32a1e, 0xd168a3dd, 0xddd71a55, 0x6df57e82, 0xb7be8b0a, 0xb7bcb623,
	0x63e3df89, 0xcf1c3fd4, 0xe1d00a02, 0x9a47a143, 0xfc429a5f, 0x8004d0f5,
	0xefd0e27a, 0xeff15e1f, 0x25b86505, 0x0523c3f5, 0x1f0fa065, 0x033e7892,
	0xbc526bd8, 0xf28c5e7b, 0x2a476b21, 0xc2fd89e6, 0x596502c1, 0xf0391798,
	0x1960729d, 0x51ffbdc7, 0xcc317656, 0xaffff71f, 0xe39f6c60, 0x873c56d5,
	0x45e07d9d, 0xed46f919, 0x4cf9f7e2, 0x98cd7c93, 0x646ec117, 0xf159df7c,
	0x673e6335, 0x8dcc4dff, 0x38c6fdfb, 0x3edc1cfb, 0x74e0e3d8, 0x7a71269f,
	0xc8aaf9b3, 0x8a28182b, 0xdb62375e, 0x29f83d4f, 0xde3007ad, 0xf1a611fe,
	0x987e2806, 0x03ecbbe8, 0x3ffdd29f, 0xff5dfa17, 0xf3c50a2b, 0x7bf0cb41,
	0x6e67e691, 0xf6f1235a, 0x57ec78d1, 0x2f69dbe3, 0xcda07589, 0x70f6e9ca,
	0xbc373f1e, 0x8515e841, 0xb3fffd71, 0xa02f99e4, 0x1a7f30dc, 0x88b603ed,
	0xb1f14238, 0x93817501, 0x02570bdf, 0x7c378cf5, 0x17d402d2, 0x12d99e82,
	0xe7c4edf3, 0x4cd27d67, 0xbe1d7ba8, 0xac9fb197, 0x33d91b45, 0xddbacf80,
	0x9db23736, 0xa396af81, 0xe1f31daa, 0x45bef633, 0x522d86fb, 0xe1268a8f,
	0x4a7cf787, 0x6b16caf1, 0x7faf3663, 0xccf186d4, 0x1f1b389f, 0x7c0b3ac6,
	0xf03cf65a, 0x0e7170c3, 0x1ea09f1f, 0x3d44390b, 0x17ab71f0, 0xe56421f8,
	0xf89ef875, 0x5c6d6423, 0xb1f8e780, 0x85fd0ade, 0x2c23bd52, 0x3f9ad750,
	0x15723d6c, 0x1ff68dd6, 0x873efb52, 0xcd46edce, 0x1ff4879f, 0x7750ebac,
	0x5e15d546, 0x1a5e7667, 0xf83babf3, 0xd70fe529, 0x88fce5ef, 0xe279c378,
	0x8eb879bd, 0xb98fd19d, 0x6f14dd9a, 0x3afae42e, 0xe333e26c, 0x8b16ea7c,
	0xe945259f, 0xf58ccfd9, 0xf45a634f, 0xb1c7bc79, 0x7f54465d, 0x8b9d7e22,
	0xa014def7, 0xa54037db, 0x67cd6f11, 0x6cc72a1e, 0x0720739b, 0x15bb2f9a,
	0xa4a616f4, 0x47dfa914, 0xe311983d, 0xe64cac37, 0x5c9cd3fc, 0x94325572,
	0x47ae25eb, 0x27214e03, 0x9bd90a3d, 0xbd5742bd, 0xe00961df, 0x615b23be,
	0xe2b5e7a5, 0xeef5b7fc, 0xdc65fbce, 0x4ac67e37, 0x7935c6fb, 0xd42b12be,
	0x79e4f66b, 0xff24599a, 0x33b526b9, 0x3916b273, 0x49f58987, 0xaeff645a,
	0x28dd6bbe, 0x6f783fcc, 0xef846bff, 0x08f292d7, 0x51d0babe, 0xfda4efd5,
	0xed0bd54c, 0xae0c73df, 0xb5deb47b, 0x78293c39, 0x77e067de, 0x2db11efc,
	0x89be671d, 0x4afefef2, 0x3bfee98b, 0xfa003ca3, 0xf18e0bcf, 0x90b04df3,
	0x041dcf01, 0xfd0b99f9, 0xba77afbc, 0x5e2dbe10, 0x8a6825df, 0x988d2597,
	0xda3e00e5, 0x2dd5ef9a, 0x6dbb1893, 0x3b36b8cd, 0x555bf518, 0xbbe462fd,
	0xb62692db, 0x38d75f21, 0x0577ca64, 0x7790f10b, 0x804fc88c, 0xda9ace7a,
	0xf7efb859, 0x0a82ed95, 0xb0d1fdb3, 0x806bef9e, 0xfc8a505d, 0x80f48f53,
	0x4ddec5ba, 0x4b6f7fe7, 0x322fc262, 0xa41c579f, 0xce3c8deb, 0x8b73be7b,
	0xe8936755, 0x7f51a27c, 0x7a4dc92d, 0xd0094aa4, 0x59d54f3e, 0xfc6b9d17,
	0x4dd8e3fa, 0x8e8723e7, 0xc61c11a3, 0x7191b538, 0xbed57f48, 0xe1fc8076,
	0xf6189703, 0x59e297ad, 0xbc8877cb, 0x38778713, 0x55f943f6, 0xb3d01f44,
	0x6f257780, 0x40501eb0, 0xd41c1cef, 0xcadb333b, 0x51be9172, 0x49ba687a,
	0xa015792f, 0x4324c1d3, 0x7e2b7d2f, 0xf698a4fb, 0x7afd46f9, 0xcf0b1f6a,
	0xba911c4f, 0x9f2bda1d, 0x08eb06db, 0x8fb39d1f, 0x18cd2fee, 0x9fd47bff,
	0x49397fc1, 0xa0028715, 0xfaa60e5f, 0x19fd704a, 0x51b991b8, 0x06571e1e,
	0x3a289e1c, 0x75f124e4, 0x25eceaa1, 0xf047fc26, 0xffa2645e, 0xd36e4dbb,
	0xed92f07e, 0x98f9d077, 0x2c5e831c, 0x6d7bcfc0, 0x03ed302c, 0xbe387fff,
	0x04de1c2a, 0x9dfd9470, 0x1a6718e1, 0x78c7022f, 0x155f7c13, 0x86f5390e,
	0xbf6879d9, 0x9ee85b35, 0xc04b4cc5, 0xd3768f9e, 0x9bb2169d, 0xf984b430,
	0x9358605b, 0x8091241e, 0xb6bdee76, 0xe45f9805, 0x2511d856, 0xebc9e50d,
	0xfe7b466e, 0x17f90a07, 0x9d6edcf0, 0xc3b0aa8c, 0xb141f78b, 0x730edc15,
	0xf8ebf857, 0x3fbe6fa1, 0xd5e84238, 0xe0959d02, 0x27f7a13d, 0x192ab82f,
	0xbbcf75e0, 0x6ddb01b3, 0x6a9fd2d2, 0x25792663, 0xba4da4bb, 0xf583017d,
	0x95a4d3e0, 0x4f0cc764, 0xc48c76e2, 0xb91db656, 0x2e7bde3c, 0xacd767af,
	0x8471859c, 0x12ecdde0, 0x8e82a7f4, 0xa401e760, 0x41e69b43, 0x1bdde43a,
	0xcbf9c76c, 0xdd6858f7, 0xdb835394, 0xbefd6336, 0x15da0f42, 0x5fae54c1,
	0x3a359a07, 0xc9aab467, 0x95f78b9d, 0x75f074b4, 0x0ceb7360, 0x9578c25d,
	0xf7c15806, 0x68f9c6d6, 0xf7bb4f6f, 0xe5fb3691, 0xed3cc7a8, 0xcf5e74c3,
	0x8d75c6ca, 0x8927dbe5, 0x05aeb0f7, 0x9e8e599b, 0x7c17a91a, 0xe908d60e,
	0xbcda4799, 0xdcefd8b9, 0x3fbfc66a, 0xad8b7184, 0xbf887a83, 0x3c09a777,
	0xe9f31d41, 0xfbc8e6e4, 0x13ef9832, 0x953d728f, 0x7207fd0d, 0xb2013e69,
	0x342ac61b, 0xed8c071f, 0xe2e3ba82, 0x0bf7da7c, 0xe07d783a, 0xd8defe62,
	0x5ac751af, 0x21c6bf68, 0xe6c8e1f0, 0x2ff055ed, 0x382fe8c3, 0x29c7ee35,
	0x57cc32de, 0xcff198d3, 0x6293e3cb, 0xef09233f, 0x47e28807, 0xda32eb7b,
	0x318fb6ac, 0xb9abd3ef, 0x3cc2bae6, 0x92dfd10b, 0xabf3f375, 0x3e3c4592,
	0xfee3658d, 0x4fc5814d, 0x2c45d8f6, 0x17f6c160, 0x979520b3, 0x9f3d30b2,
	0x3ea87ac0, 0x05a64311, 0xcdc9bc78, 0x8f31640f, 0xe663768c, 0xe4ae237c,
	0xd9f6859f, 0x571164cc, 0xa1fe86cb, 0xa99cfa5d, 0x357e1fb4, 0x9378c7be,
	0xb303cc6f, 0x8f17e4dc, 0x8cf7b68b, 0xe7b0d2f5, 0x3dcc042a, 0x7b5c52c9,
	0x2aefb0c1, 0x5fdebc1c, 0x0d9012a9, 0xfd8210b8, 0xb0b1dfd7, 0xc62ce31c,
	0xe2295efa, 0x4a1b959c, 0xab7ed132, 0xfc9f3fd8, 0xb992bba0, 0xfd78b6fd,
	0x013fd51c, 0x202d87cf, 0x8e22a0bf, 0xd4f976fd, 0xc896fd88, 0xdbb5885e,
	0xe88bae82, 0xaac02b1e, 0x3a45ef17, 0xf5af7568, 0x33dc7ca0, 0x9829e486,
	0xa15255e4, 0xf6e65c1e, 0x97dc30b4, 0xf1ba8770, 0xe8938ffd, 0xb8a0e4de,
	0x1f30695f, 0xd2affbc0, 0xc789c917, 0x3807cd8f, 0x2dfdca98, 0x9207fe63,
	0xf4851fde, 0xdaf02b98, 0x85dc96a3, 0xbd51e974, 0xd2acb173, 0x748cfffc,
	0xf0a73d5c, 0x422c5981, 0x867cd8bf, 0x1afb04f4, 0xaf7e8957, 0x86d3b6c2,
	0x73a0cdd2, 0x5cb5ddac, 0x13a0e7e2, 0xace1abcd, 0x23e7a4c5, 0xa4a854f7,
	0x3f84fbe7, 0xbfcb3872, 0xe9204afe, 0x215bacd5, 0x7bf717fe, 0xaa0148b4,
	0x73159d5f, 0xb3c88cbf, 0xfb7a1729, 0xe33f9877, 0x9e3befc2, 0xd73f42f7,
	0x7c82a0b0, 0xd9e4587f, 0x44a4bf80, 0x0946c9fb, 0xece49afd, 0xfd736e9b,
	0xfae6719a, 0xeff13db7, 0x49b7bbc3, 0xddd7ed37, 0xe327e78b, 0xf08f65e0,
	0xbdfabe8b, 0xcf362c46, 0xbdd20f71, 0x494bf30e, 0x639e79be, 0x879f83b2,
	0xf077ef08, 0xba9a16f3, 0x0d034309, 0x1fa257e0, 0xf784ec9e, 0x899fb9e3,
	0x5b24d4f7, 0xbdc8fb79, 0x9f6e3c44, 0x7112cbe1, 0x9cd64f03, 0x6e1e5f09,
	0x4f2857f4, 0x230f615a, 0x9af9227d, 0x4e31fbe6, 0x8c59bf27, 0x73e611fa,
	0x8c01c623, 0x9f31a878, 0x739f97bf, 0xc44f88af, 0x64aeedd2, 0x20b4b76e,
	0xd8e2a39d, 0x77ce82ad, 0xdc00dca1, 0xeefb8a1f, 0x947c921f, 0x016995e7,
	0x59882c6e, 0xf2eda3e7, 0x65ada7c0, 0x7870cf18, 0x42bc518e, 0xa92de5d8,
	0xf787fdfc, 0xe7e8e548, 0xffd60db5, 0x86f186da, 0xff518736, 0xf25bd50b,
	0x47c60e58, 0x1f7f0ebc, 0xe779efe2, 0x67bc6143, 0xcd9765b7, 0xe907f94d,
	0xf9e26fdd, 0x36ddcc95, 0x8cb5df8a, 0xacfb4f3c, 0x2c79f698, 0xb09a7284,
	0x4fb42e7d, 0x5d67b48f, 0xb473a649, 0x667e5f86, 0x35253b8c, 0x4a31fe8e,
	0x74c5836d, 0x255add6f, 0xb17d476c, 0xb3f3c3d6, 0x6832fa22, 0x1b6b278a,
	0xd9476940, 0x33df788d, 0xb1555906, 0xe29f7c8f, 0x94f5a3d1, 0xd8e9f566,
	0xb939d5af, 0xec61eddb, 0xca7ad69f, 0xc16b77d1, 0x2bb060bc, 0x55acb5f2,
	0xd5a75788, 0xe9e70473, 0x98dc5a74, 0x59acdb27, 0x745a9e48, 0xb6bde53b,
	0xc8ead74a, 0xcebf46b7, 0x30e0851e, 0xe689e5e2, 0xcb9f80a9, 0xdf35cfc8,
	0x37bff593, 0x1d78469e, 0xc1d72f72, 0xd1b88fcb, 0xa16a99ae, 0x4b252e7c,
	0xc9c4ef63, 0x6f1c1ccb, 0xee171283, 0xfe0676d8, 0xdad9d213, 0xf47a42e3,
	0xcdf7f169, 0xf5f49afd, 0x312de4f4, 0xc7f9c5fa, 0x61f030c2, 0x9df3d49d,
	0x7f923c82, 0xd7fd06bf, 0x2ae33a4f, 0xa19e9375, 0x9f4352fd, 0xdb2f68b7,
	0xf9b0be79, 0xfc44b63e, 0xfac5e067, 0xf3c622e2, 0xfb0cbd19, 0x9c1e1f3b,
	0xf947d852, 0xb8949331, 0x29e0a1fb, 0xf0a9f298, 0x7ce8ec7e, 0x6be4169b,
	0xcabe5380, 0xa17b476f, 0x1dae6b39, 0x14abebe3, 0xffb875f7, 0xd822f03d,
	0xcfdc6e3d, 0x518fcb35, 0x7bfb8bb6, 0x712cd3ef, 0x8bb575ef, 0x9f63e47b,
	0xda7d0487, 0xe74e5ff7, 0x0ff112e4, 0x5c3e6358, 0x8ac5ec47, 0xcb81f78e,
	0x23af0e56, 0xf4621d81, 0xf75f089b, 0xfbf077ec, 0x83d8c7bd, 0x8ec59eb8,
	0xf6e786d7, 0xc01b7de0, 0x2e7ac013, 0xaa6dbf1f, 0x8743f142, 0xa3d9893b,
	0xa6335bda, 0x68cffe12, 0x908678e9, 0xc63f21b5, 0x53c0cb81, 0xbd7cb340,
	0x0c7f3f7d, 0xb57c8e5f, 0x8a25f910, 0x4da17f2f, 0xb897ca1b, 0x105e2006,
	0x36fbe8fe, 0xe26319ad, 0x84385bde, 0xa6f8633f, 0xf3a30678, 0xdca1c379,
	0xc4877d04, 0xa8753a3d, 0xab9fc1cb, 0x3a6359bd, 0xae25fbe8, 0x4f088392,
	0x7e01f771, 0xc194264e, 0xdf1407ef, 0x71eb8ec7, 0xe3d275f2, 0x394ca9d4,
	0x7f1a7de6, 0x9dd421b7, 0x8a73c6e4, 0xbff8b4a1, 0x66a1f163, 0xe21d0bf8,
	0xc50f419c, 0xc5f68db7, 0x66ef30b7, 0xb1250f28, 0xd5d83b76, 0xcf22686f,
	0x888bfd81, 0xc2e083ab, 0xfafdd738, 0x308fca52, 0x68087fe6, 0x3333ed86,
	0xf9248a7b, 0x1b6dd06b, 0x568bdd33, 0xba21ef67, 0xdff8b7cd, 0x1c34fc43,
	0x7ac4c9eb, 0x6453e5e8, 0x70b467a7, 0x4f6069fb, 0x4397f932, 0xf04cd3e9,
	0x61cd9ed5, 0xe9436181, 0xc984ab56, 0x3b3dae4e, 0xd0a6058a, 0xb4f603bc,
	0x6cebfbc8, 0xff474d8c, 0x84f1cec2, 0x8f4789f8, 0x1b5c8497, 0x74bd00f4,
	0x03d053a9, 0x6f4834f1, 0xaf487f71, 0x6dee97b8, 0x9d337f61, 0xbdc675fb,
	0x0e176f44, 0x3dd3d3ee, 0xef0eb54d, 0x07df7803, 0x7e532a3b, 0x7e52a2df,
	0x9b22deef, 0x05e30537, 0x4b2f7e8b, 0xc62fb4cd, 0xc0b17ef9, 0xd0f32f5f,
	0x5ac0f5f9, 0x63efce87, 0x791bfb32, 0xf94c950f, 0x74a9e61d, 0x1657a4c9,
	0xec016a96, 0xe67bb8b7, 0xa45e78d3, 0xce993db2, 0x86fa2f2f, 0xf9fa04e7,
	0xb8701e8b, 0x964277f1, 0x925f96bf, 0x7f2efd0d, 0xf9474f30, 0xcbe15e4f,
	0xbb187bb2, 0x472c19d6, 0x5a4da93f, 0xc49a40b0, 0x6cff3740, 0x95d7c615,
	0x77df4bcf, 0xb3ae7d40, 0x25c6156b, 0x50f18d7e, 0x94f6d3b2, 0x14f93fa3,
	0x5fc469fe, 0x1d4f0701, 0xc3b888b1, 0x40caab0b, 0x11925fe5, 0xf30068b2,
	0xb0bdf703, 0x66c1cf0a, 0x592779a6, 0xbb7fbc60, 0xfb72a5ef, 0x03f70055,
	0x00de3e13, 0xdf737fef, 0x017d90ff, 0x1fdf1274, 0xef852f2f, 0xf518672b,
	0xa7ac54f7, 0x9d88b327, 0x3be41d38, 0xda3e323f, 0xb8c1a185, 0x32f2e9c8,
	0x99edf6f8, 0xf40aa58d, 0x0fbef27f, 0x44078d57, 0x44beb65d, 0xa7f8c2f7,
	0xe688fbef, 0xc7e2321b, 0xd1564f81, 0x1ff3173e, 0xc57bc2b4, 0x476d5d25,
	0x37cc3a55, 0x0ff98749, 0x3d5c2f6b, 0x90d7e47b, 0xce43718f, 0xcceb5d5f,
	0x8c393920, 0x82b51d28, 0x283777df, 0x6f9cb9df, 0x7ae3eb07, 0xa309f9f8,
	0xa1ebc59e, 0x0bebe3bb, 0xc3d70a57, 0xeff8a4a1, 0x043d0a97, 0x9c530ef8,
	0x38392bae, 0x3fa22f36, 0xd3ec7e40, 0x71d69e49, 0x847201fd, 0xb7206679,
	0xb2fbfb71, 0xf7121af2, 0x6f148761, 0x86cbfa32, 0x4bf9031e, 0x4edc71c6,
	0x2b9d69b7, 0xfa485eee, 0xce9703f5, 0xfc7371e1, 0xf59a9464, 0x1777b308,
	0xabb1fb46, 0xe66f5c9c, 0x53ec6a5d, 0xfde8d584, 0x4a3be589, 0xb63e79ce,
	0x51c1e316, 0x1e6476f6, 0x0f9fe465, 0x73fa17e9, 0xe33dfe8b, 0xfa5f042f,
	0x4e95f079, 0x3cdf3af8, 0xe399fd23, 0x53fb4309, 0x8751fec5, 0xe3511d79,
	0xc08cf9c3, 0x12dfe21f, 0x852b3fa5, 0xcff6353e, 0xbc5f76fb, 0xf45e4d79,
	0x25bcfcb8, 0xfc69f7d0, 0xe8009ebd, 0xc563d453, 0x6c1af78a, 0xa69ddc5f,
	0xfc0efda3, 0x4df82ad6, 0xe8337e41, 0x2c6b4a1c, 0x93aef9a1, 0xec71cdf4,
	0xbfc190be, 0xd65efc1d, 0xe5f8b7e1, 0x19f05105, 0x0ffa1efa, 0x72a7fe89,
	0x90747e7e, 0xf9456f9f, 0xf329fe11, 0xdcbdd0f4, 0x825ff0b1, 0x6a2d3732,
	0xa0e5dabd, 0x6f03173c, 0x0dff955f, 0xe136a17b, 0x3822e4ba, 0xbb0b1f87,
	0x08aed0dc, 0xd9f101e5, 0xafdd0ef9, 0x1992ea18, 0xf38f755e, 0x6c51bd46,
	0x795649e8, 0xb218e678, 0xd97a225b, 0xa18bf64d, 0x7b76c337, 0xad3efda4,
	0xf515bcb2, 0x3d9fb8aa, 0x3e2d065d, 0x3bc70239, 0x4e3ebe4e, 0xf7b8b3f7,
	0x39a87edf, 0x79887f39, 0x2662bc3c, 0x2c509bdd, 0x3de9d3d6, 0xbc9f8a01,
	0xbeb131ac, 0xeb187c72, 0x9eb675f5, 0x41f38b9f, 0xea347e26, 0x5bd49760,
	0xe3fd220a, 0x7c51b9fb, 0xcfe0b9ff, 0x5d7cfa58, 0x087804fd, 0x08661e20,
	0x1d4067bc, 0x0a60afef, 0x2f985fac, 0xacf34732, 0x5b828bc9, 0x4338fae3,
	0x763d70b6, 0x1f48b91e, 0x78efc4c6, 0x239e4938, 0x4b76e0f8, 0x7de38ba1,
	0x78a73893, 0x427202c8, 0x9e7c31fb, 0xa9b3bb7d, 0xeed15cdf, 0x3797a56f,
	0xc3177c89, 0xd5fbac5e, 0xf8664d88, 0x763f7f79, 0x1f14bc71, 0x3b424ef3,
	0xf34fac66, 0xdc507fa0, 0xe600f73d, 0xc5ee141f, 0x7c23e78b, 0xe5c9d85e,
	0xe04bb814, 0xd1edc5e5, 0x39734efd, 0x9bfb390d, 0x18f0a3cc, 0x3971e313,
	0xbb97da37, 0xcc0e3e34, 0x54f886cf, 0x28d47acc, 0xf87076ff, 0x9639e00e,
	0xaa07c05a, 0xa16f036d, 0x3b7705ce, 0x318f8e50, 0x5f71ca0f, 0x04cb02e7,
	0x10262ba4, 0xc3f4a3b9, 0xc30f3e7a, 0xecbe050e, 0xe79cbe44, 0x8cfd491a,
	0x1e4de63d, 0xa2c7ef0f, 0xef1534dd, 0xd10670ab, 0xf2e2588f, 0x7c85d8ff,
	0x2940c371, 0x93eb77c6, 0x511d9b1b, 0x77db07cf, 0x63e27b41, 0xe1013cbf,
	0xf7e33efc, 0x40f98b8d, 0xc60d80d3, 0x4e4153ab, 0x461ea80b, 0xde5485bc,
	0xfa56e07e, 0x2f560a85, 0x60ddfbf3, 0xf886befd, 0x1a4b65f3, 0x24fd17d2,
	0x656b93b4, 0x8fe52e5f, 0x7079b70d, 0x83bf001d, 0x8390fdf8, 0xffe80e29,
	0x4f512805, 0xa76f92cf, 0x0ab33f73, 0x3037da24, 0x5bd47bfc, 0xf75d27e8,
	0x47e2648d, 0x631dd9f6, 0x919ade30, 0xfd04e9cc, 0x763f45d8, 0xfc88e4fb,
	0x8ba8e7fd, 0xd631dfc9, 0x449243b7, 0xeaba1cfd, 0x512dcdd2, 0x87f6107e,
	0x3490fffa, 0xe476f727, 0x91c7e17f, 0x591e987d, 0x995ed177, 0x3dd345ac,
	0x19ebe020, 0x6d147c85, 0x3a7da28f, 0x59b2cf68, 0x3d06afab, 0xceecd97b,
	0xde8d5e30, 0xeafab81c, 0x59bfa0bb, 0x003acf60, 0x2f82ed0f, 0xdff1e50e,
	0x56343d0d, 0x0fc07ba2, 0x37c7f927, 0x3271916a, 0x5321bc45, 0x266727e4,
	0x853f32f1, 0xa29dc1eb, 0xf6c36e24, 0x89f1f8ae, 0x5ffef15c, 0xac7f5c2c,
	0xc79f8929, 0x6bebb4fc, 0x4bc699c6, 0x3f3cf7b1, 0xf710caed, 0x169e533c,
	0x109f5f8f, 0x21cec1ed, 0x2aec453a, 0xb0dcce7e, 0xe6f38d43, 0x07be4975,
	0x2af42e28, 0xfc7155f8, 0xb8b83fc7, 0x135ef07d, 0xefd673a3, 0x42f3b9e2,
	0x584c7bfe, 0x41f2ba5f, 0xcd5d6f3a, 0x5e3fb482, 0x9d3645bd, 0xd958aee7,
	0x59b7bf46, 0x5b989411, 0xc7ccbf42, 0xfc0b65cf, 0x551a512f, 0xfc2f3dfc,
	0xefe8a67d, 0x894e36aa, 0xeb95a7b9, 0x7f6eaf8b, 0xf7ed34ce, 0x394bf447,
	0xfdb179d9, 0x6b1cfc1a, 0xe4ddbe87, 0x5f379d36, 0x396c72b8, 0xede59cdf,
	0xcd0f3117, 0x817b516f, 0x1dfc7e19, 0xc313cba9, 0x2c8f7837, 0xb8819dd8,
	0x07a4aa70, 0x036fe78d, 0xe75103fe, 0x1c9e17ea, 0x776c7043, 0x2f91fbf9,
	0xb3247022, 0x364e2980, 0x9d8eff83, 0x8119c783, 0x5ae7024f, 0x5f29adef,
	0x24bfeed7, 0xf45fdd81, 0x8bfbb577, 0x967ae16f, 0x2c6c4875, 0x662de5f2,
	0x45332c3b, 0x929e72e3, 0x850f731c, 0xe0cc7b88, 0xdfe182f6, 0x2d67850d,
	0x19597f7d, 0x90ec17ef, 0x1e5ec2ed, 0x7fe5edcf, 0xbf97b41b, 0xa27fe517,
	0xa015265d, 0x19dfe33e, 0x77943bbf, 0x1fca65ea, 0xb70a7efc, 0xdeebe75f,
	0xfda0528b, 0x3eaf915a, 0x7bf17c64, 0x83ad6b44, 0x3f94d2fb, 0x3bf3e9b6,
	0x25f7f05a, 0xfd807606, 0xe4b07a0f, 0x1ee9e7d1, 0x6fbbe32e, 0x5d1ce8af,
	0x269bf801, 0xe1eb5ce8, 0x27ad61f6, 0x7e818eac, 0x5c396a72, 0x25fb9db9,
	0xdcbbea25, 0x1beede2a, 0xfc535629, 0x4bd44caf, 0x1efcdc52, 0x34b0aab0,
	0x6ce5da06, 0xd82922dc, 0x131efe1f, 0xc8d393c0, 0x43bfd182, 0xdb953394,
	0xba9edf35, 0x3e345a49, 0xcb768782, 0xd03af19c, 0xd9333dad, 0x13cceb83,
	0x885bffba, 0xc237da87, 0xd97f5f94, 0xda0add1b, 0xef74bbed, 0x11192935,
	0x3d65b83c, 0xe4d1d707, 0x1d9c3837, 0x5f317e83, 0x94e7685f, 0xdb99bce8,
	0xc23b327d, 0xeb485db8, 0xe3dde654, 0x976bbf4c, 0x89d62699, 0x7ca7e64c,
	0xd3b59962, 0x38ca3bbe, 0x5ddd5fee, 0xb1db99b8, 0x1566ff9c, 0xf3e0b6f8,
	0x9e2fc359, 0x1443f78c, 0xf82b0dac, 0xdabfd57b, 0xbbee3f18, 0xe61fe054,
	0x33f38151, 0x7d3e71e6, 0x26b3b461, 0x72184f88, 0xbe3b3c92, 0xfdd8c1df,
	0xa68f5e9c, 0x41ee977f, 0x77e9556c, 0xeffc0cc8, 0x21777dd2, 0x9b9d393c,
	0x188dc224, 0xe1db88cf, 0xb7d79473, 0xc039f355, 0xc560fa84, 0xd115d1ce,
	0x2555a0fa, 0xc98a6cfa, 0xfbec370f, 0x72fe2275, 0x23b5f75c, 0xd6bbeb7d,
	0xe9677c51, 0x317bfe16, 0x8173f109, 0xb8aa93f8, 0xb3ced75c, 0xc94e3e53,
	0xbfd10aa3, 0xaeff95a6, 0x1df6ed67, 0x92b3ae3c, 0xd46f5079, 0x2a90ee76,
	0x27efe3c6, 0x471690ee, 0x6d4473e1, 0x2fa7f290, 0xc7f21a72, 0xbf2c59f5,
	0xed189c63, 0x6e0ec394, 0x6896f5b7, 0xed1fdc01, 0xb16bfab5, 0xb2766f5d,
	0x0c80f307, 0xe3b0bffc, 0x7037ca6a, 0xb185b4ee, 0xce6cb76c, 0xf6bb43b2,
	0xf20f544b, 0xffdd2ed5, 0x4d25e20c, 0xfbf085f1, 0xa7a774d4, 0xdb75be19,
	0xbb5d64d8, 0x165c3c70, 0xad971fc3, 0x3ff372e4, 0x4e487fa8, 0x9b9464d8,
	0x7fb85217, 0xf913f601, 0x7cad8757, 0x87193b1e, 0xbbc53f37, 0x48f7f897,
	0x539b8d1a, 0x5e30961b, 0xa76a779d, 0x845a7ce9, 0xbe07bcbf, 0xdd83bf0c,
	0xd5bf22a7, 0xf253fd08, 0x9de916e8, 0xa68fb828, 0xce5f04c8, 0x8d4be076,
	0x66ffefde, 0xfba7b53a, 0x4bb6733c, 0xbc0d5df4, 0x67a51c5f, 0xd1c4798c,
	0xbf10c737, 0xcfdd1bda, 0xe6137d73, 0x6f0145f1, 0x0b8f3d2c, 0xcb0e57bd,
	0x03573d35, 0xf3df70e3, 0xf5127e70, 0xac7fc867, 0xe14f1ebc, 0x49ea23f6,
	0x59f1468b, 0xf80d23b2, 0xf5f3768c, 0x08532799, 0x8784dd0f, 0xcd0a8dba,
	0x1bea9667, 0x3c947b73, 0x3bfa2c7c, 0x749bf370, 0x5ffad35f, 0xac7e251e,
	0xeff890eb, 0x551c76e3, 0x40f8c46f, 0xed1949e0, 0x89b86bca, 0xf7121ec0,
	0xe2135da4, 0xb42eb8fa, 0x337bc143, 0x3bcd3e0d, 0x57ee8075, 0x31b4ebab,
	0xff8083f4, 0xc5fa433e, 0x1f81a9f2, 0xd2c6df43, 0xcf02fff3, 0x0085c0de,
	0x000085c0, 0x00088b1f, 0x00000000, 0x7dd5ff00, 0xd5947809, 0x677df0d5,
	0x2613324f, 0x930842fb, 0x840a2584, 0x10424849, 0x58424994, 0x28027164,
	0x0b61b641, 0xb4a9b201, 0xcff6ac7f, 0xbf229060, 0xdd6d1bfd, 0xad101dad,
	0xc1410bad, 0x08380c06, 0x236d5622, 0xda2b15a5, 0x27b22951, 0xfe2d7e8d,
	0x9cff95fa, 0xcccdef73, 0xc58666fb, 0x17cf3ed2, 0x7dcb9f1f, 0xb9ce7eef,
	0xce7b9ce7, 0xf31877b9, 0x58c49632, 0x58c664cc, 0x35effc21, 0x416706f9,
	0x33593cca, 0xc6b58c6d, 0x2b6e45b3, 0x74fdd963, 0xf9598f54, 0xcf3b34f7,
	0x6df02bd7, 0xec3b630c, 0x117b589e, 0xee391563, 0x454fd82d, 0x05b3944a,
	0x553ac9fa, 0x912586f0, 0xe2a73ab1, 0x89aa828c, 0x70dfd0e5, 0x343b47f8,
	0x0271c34e, 0x18239599, 0xe37f80bb, 0x6b632983, 0x92fe8319, 0xccf8f812,
	0x71c4c810, 0xeff1f319, 0x1581b67a, 0xd867db04, 0xf81f341d, 0x59dfe7ee,
	0x70447bb6, 0xb29e72fe, 0x8576c9ff, 0xaba0d9fa, 0xf9876e1c, 0x718e486d,
	0xa7a7c0b6, 0x76c19eed, 0xa8f6a7e8, 0x8dc38fdf, 0xf069da3e, 0x871d7158,
	0x6fe80e4c, 0xc9ba93d7, 0xf2ffc83e, 0xb2a50349, 0x89bb42bf, 0x1bb42bfa,
	0x970f1e68, 0x3f4abd5a, 0x68b88d48, 0x7c5ad748, 0x5bc7805e, 0x541e2773,
	0xddb318f2, 0xfa63f26a, 0x2d496ea6, 0xce99bf96, 0xd3a0dfc7, 0x0df98edd,
	0xe61958f7, 0x455dd877, 0xe637d708, 0x6a7e12c4, 0x333e4cab, 0x57b3f3f4,
	0x5af79e14, 0x59fe0c7d, 0x0cbd99eb, 0x28c4b1db, 0x3f8833e7, 0xcdd37ecf,
	0xafef00b8, 0xb1992cf4, 0x39ff8ca9, 0x726bde5e, 0x6da9f7c0, 0x8217cb8a,
	0x6db6da87, 0x1eb0a586, 0xb780b463, 0x9e106b80, 0x4d13ee1c, 0x1f151bcc,
	0x3f7647c4, 0xa00ba73b, 0xeaf78417, 0xc7eca2e7, 0x0bac7c2c, 0x5b5d7ff0,
	0xd0df2a9c, 0x963f669e, 0xc6afcc1b, 0x6c1d207f, 0x679c5661, 0x5ce798ad,
	0x5c16e79d, 0x70259d77, 0x2da808c0, 0xf26dd23e, 0x09d1c358, 0x4dd5dfa7,
	0x6c721dbf, 0x52ab6314, 0x189a520f, 0x98cce9c3, 0xeb23d7cd, 0xbf78152f,
	0xb7685311, 0xf206e90a, 0x4cdb0bab, 0x3eafea0c, 0x407268d6, 0x08cc9d6a,
	0x90a3d63e, 0xfbc7435a, 0xec67d531, 0x115f6a7e, 0x0f5136d3, 0x85f8af70,
	0x7d616f62, 0x15d327e7, 0x41b7730a, 0xb93c5f7f, 0xc231762f, 0x7a0bdbf7,
	0x8deb0c56, 0x0bbdebe2, 0x7bf413f7, 0x380039e6, 0x89a37bd1, 0xe5ef5985,
	0x87fcc7f6, 0x6ae78415, 0x2f33fb01, 0x2bf98f94, 0xb9f78bd0, 0xb0c1ce7e,
	0xcc2fd3e4, 0x30aff3ba, 0xc65b33ef, 0x3648f53b, 0x9fa26e2d, 0xe728a4ee,
	0x449fa066, 0x00ac9b3d, 0xedb6d7de, 0xed0b1d8b, 0xb23f3e4e, 0x1eed0cc0,
	0xd4fefb14, 0x8426fa2b, 0xdcbf3dcb, 0xaf96037a, 0x660929f6, 0x5fb9e71c,
	0xfa1d33fc, 0x80d2d9a9, 0xcf2d6610, 0x400a6ebf, 0x136f9d3d, 0x3f5cfeff,
	0xf93bd63b, 0x203703f4, 0x5ada5bbc, 0xd3d4fca8, 0xc6ff289b, 0xf9eeb72f,
	0xd6af507f, 0x7ac4eb1d, 0x4bd95ea7, 0x18f5a978, 0x48deb85c, 0xb6f0fd74,
	0x813fb4bd, 0xb1bf69ae, 0x24c7ce2a, 0x3dfa4b5d, 0x6345cbf9, 0xfc828e90,
	0x00df7f87, 0xba016d74, 0x18cd10de, 0xb169f7d2, 0x5997577f, 0xfa7a6037,
	0x5c2aa8c5, 0x3029bd6f, 0x33e70e24, 0x4f85d39c, 0xedb6ade0, 0x95bd6336,
	0x7f3f53da, 0xe98f7d82, 0xe3cfa008, 0x6b50ef40, 0x385185cb, 0x3f044bde,
	0x051257a8, 0xff339df0, 0x13e70553, 0xb8d1bc33, 0x3cf9e69a, 0x8755872f,
	0xe1af1796, 0x83a5a8f4, 0xa0ab765d, 0xd20fbe47, 0x386657b7, 0x9d980f88,
	0xf5f38f9c, 0x5a78d7a5, 0xc6fdf06c, 0x1ea71e35, 0xc4ebb8f0, 0x21fd89a1,
	0x655ccbff, 0xaf5fe114, 0xf7a97ed0, 0xba9c695a, 0x39f632a6, 0xb16df7cc,
	0xcced925f, 0x81f11d70, 0x0dee9c4d, 0xbcc560cc, 0x44f89ba1, 0xda4e86dd,
	0xf85b7537, 0x3ba5993c, 0xda8d9673, 0x0f8baf59, 0x59da03ce, 0xceef94ad,
	0xca0465bc, 0xc9156f1d, 0xe689871d, 0x03f24a7b, 0x305bcde6, 0x92dfb822,
	0xf883cc75, 0x6a41364f, 0x12a6fce5, 0x2f663ffa, 0x6bf20bfd, 0xf3472699,
	0xd29c2d72, 0xf4f978e2, 0xeca51738, 0x3c9504b9, 0xea57c488, 0x561ffe05,
	0x5748d502, 0xf6519dde, 0xf5240067, 0x84860437, 0x38a495f2, 0x8273a70e,
	0xe4edce6e, 0x4ea6f2f4, 0xbdf5c5e7, 0x26d879b9, 0xf95ae7e4, 0x09b8d4a6,
	0x2f80f55f, 0xfe979433, 0x29a1cd7c, 0x986b2f28, 0xfd5bf713, 0x8dcf4176,
	0xbeb9e88c, 0xf61972bd, 0x8a713fd7, 0x5ca0af53, 0x7f6264f8, 0xb2d7d7c8,
	0xe92fdc22, 0x44ed964f, 0x8576b2bc, 0x8d7cc60d, 0xbfb63b7b, 0xa9ceb131,
	0xb5b942cf, 0xf502d539, 0xa62dcc6f, 0x700f0ff6, 0xde7f6294, 0x7aeb460a,
	0x7921e8d8, 0x30da70f4, 0x7aabca27, 0xa25cbacf, 0x13b44727, 0x70c799cb,
	0xf7afd63b, 0x951b67ce, 0xa770fb30, 0x5f72a2e2, 0xda0a2f8c, 0x68576d4f,
	0xf3b7d49f, 0xc256787d, 0xcec6a647, 0xb9de3885, 0x55e6661d, 0xd6f27482,
	0x4e5c49ce, 0x39266abe, 0xc5d9ba79, 0x7ad1073e, 0x0979c84a, 0x642fd5c7,
	0xb33f68e9, 0xc79c6659, 0x568f3152, 0x71fbe723, 0xdce78f82, 0x2391e7cf,
	0xa71394f0, 0xc849a913, 0x8fbe56af, 0x943cdeec, 0x78c56763, 0x1648e7f8,
	0xae860a72, 0x3a27e65b, 0xf7817daf, 0xe5766897, 0x074211df, 0xd2d1bf52,
	0x971c5953, 0xee4fe937, 0xa4199057, 0xb553393f, 0x61ac6f4f, 0xe75806fe,
	0xfcea4f8d, 0xef48f3e3, 0xf1f895b9, 0xacdb135a, 0xa26fedf4, 0x82457f98,
	0xf9415f3b, 0xfa4ac733, 0x8b3eef43, 0x50a2e976, 0x9c502b0f, 0x770ab42d,
	0x9dea0ea1, 0x1139b648, 0x1ce3d36f, 0xdea5f561, 0x6e3d1af6, 0x8f37ab5a,
	0xdae94365, 0xe7842ae8, 0x2c9d209b, 0xed0eced8, 0xe6f25ea1, 0x246f4fb1,
	0xfd42d37e, 0xe5d9c496, 0x011b0afc, 0xee39493e, 0xd8be5c35, 0x73d6e19c,
	0x37d1f04c, 0xd7cc2ce6, 0xb6ccfd21, 0xd9f87ed2, 0x4e12ca6b, 0x70c8206f,
	0xfef879df, 0x9e3fb060, 0x923d1071, 0xe8df541e, 0x47a785f6, 0x41ea5fbe,
	0xfa528a2f, 0x64cc63d2, 0xdf91c7ce, 0x72a1ea84, 0x8ffdca7f, 0x3c39df7c,
	0xff72b748, 0x3f3eee5f, 0xf0fbe467, 0xe91fac1c, 0x77be97bc, 0xb8defa71,
	0x9421f616, 0xd87d846f, 0x0fb7c212, 0xffb4bc98, 0x1347640e, 0xc9b81d7e,
	0x3a78ef21, 0x48fd87c6, 0xddb4f97e, 0xf21c577d, 0xaf6fcdab, 0xfc15b227,
	0x7dd77ead, 0x37a62e43, 0x3fbc0c59, 0x50d7ec0b, 0xb800b1fa, 0x7a94056d,
	0x34c7cf91, 0x9920f5a9, 0xe5c7143e, 0xfbd677cf, 0xe9031572, 0xb55f022d,
	0xb843cf3a, 0x80fbd40e, 0x13665822, 0x5192fbd7, 0xd89ca066, 0xfd43e31c,
	0x79993936, 0x1f330e5e, 0x12dfd8af, 0x4fff52af, 0xb7f5e58e, 0x65fd71c5,
	0x4bb7a88b, 0x0ae721a4, 0x9d0e0fda, 0x8fa653e7, 0x3b644f2c, 0xcb951798,
	0x4b9ef4f9, 0xc9be7c2c, 0xbcd90cf7, 0xc19f0431, 0x014d757d, 0x7ee739e2,
	0x358961bf, 0x6b948e38, 0xf9c1fa5a, 0xf5c3fca3, 0x5c8f0e54, 0x38af75af,
	0xb9e8695f, 0x4d6de853, 0x33d78c71, 0xf68bfffa, 0x86366de3, 0x83901efa,
	0xd5e6012b, 0xdf2867b0, 0x43ddb947, 0x04a0fdb0, 0xb43c7c4f, 0xec413d1b,
	0x133ef813, 0xf3037cf5, 0xef11e39a, 0x04205f46, 0x4f109bcf, 0x66cbbf50,
	0x9f61eaf1, 0x3a782714, 0x6f3c60e3, 0x51fa7319, 0xf800fcce, 0xe65bee09,
	0xd37e422f, 0x08b102c0, 0x3d5a7fe7, 0xf57e8987, 0x0e58439d, 0x90255ff0,
	0x891fdf87, 0xee9ee7e1, 0xa1bef5b7, 0x4b1ecf30, 0x858effe0, 0xc9acf779,
	0x9fa17a71, 0xb47d778f, 0xede823e3, 0x85e61d93, 0x7ae0b04f, 0x8b3a2deb,
	0x3f982121, 0xb6aab0a7, 0xb8f97c30, 0xf9c363c0, 0xfa85e674, 0xdd32c0cc,
	0xe3e7d700, 0xa1bbfc1d, 0x562a84db, 0xe64cf9c3, 0x63e87d05, 0xd709ab1d,
	0xce78c4cf, 0xd1c3b6bf, 0xd4f95c32, 0xb7ffce78, 0xd6fdf367, 0x21f149bd,
	0x5a69ac1f, 0xec3d37fb, 0x36359aff, 0x8c50a53f, 0xdd8d567a, 0x21e5d7eb,
	0x33fe00df, 0xdb3bc092, 0x6f941c52, 0x0e30cf50, 0x0385ed61, 0x25bbf027,
	0x6d2d3e42, 0xe46beb7f, 0x66063527, 0x2cfd0719, 0xf40fb8b3, 0xac2fa287,
	0xbd9162cb, 0x8eef7f57, 0x293f9464, 0x5c4d5bf3, 0xa3b04e6e, 0xa6b8aa7e,
	0x5cc42fe9, 0x90321f4c, 0x06784b1e, 0x778d6cbc, 0x7ac3c747, 0x2463f7e7,
	0xc1dfe7ef, 0xffac91f9, 0x5a4f9096, 0x0224f8fa, 0x6509ec1e, 0x5bfe23af,
	0xd489dd62, 0x55671def, 0x129ceb7c, 0xa409f678, 0xce6cdb9f, 0x99777867,
	0xcefa10ee, 0x7d5ff017, 0xea78475e, 0xd21cefca, 0xda748594, 0xc001f99d,
	0xd987757b, 0xfab2f48e, 0x2cf089bc, 0x0cd67ddb, 0x30486e0c, 0xa0c4e4bf,
	0x5aee7889, 0x11eb9cca, 0xc4374bef, 0xdf086f30, 0xe9154542, 0xa33cfea3,
	0xbc74967e, 0x5de10475, 0x9d10086f, 0x0958b12c, 0x0de7f58f, 0xc1b60f34,
	0xdb202678, 0x889fee03, 0xf5c48d75, 0x2e347f79, 0xf830f8ee, 0x69df0298,
	0xfc229efd, 0x4aeef48e, 0x4777a50c, 0x578078bf, 0x0e97a983, 0x3d1096dc,
	0xd4d86587, 0x9b78eff8, 0xe2ccbff0, 0x5ebca131, 0xa47382ee, 0x2fe4f11e,
	0xc50f0fb2, 0x85fd38f7, 0xef8f9761, 0x3fafb174, 0x87fd0136, 0xe35387e1,
	0x5e797f39, 0xfbe74bd6, 0x564ce3e4, 0xd7a632f3, 0x3eed0a42, 0x02f916ce,
	0xea221f91, 0x47bcf325, 0xf38f93ec, 0x38ed3d78, 0xdb3c0b77, 0x08555c13,
	0x37e7682f, 0x89ec5d21, 0x5a7e91f2, 0xf90d7c08, 0x4803edd8, 0xe5fe053f,
	0xe305fe41, 0x9ea8e3f8, 0x6b07e499, 0x7806fe04, 0x10722aec, 0x0296367c,
	0xd99f209d, 0x766fb66d, 0xf12af104, 0x1ae3c5a9, 0x2cefcf31, 0x862b86f7,
	0xc8077b50, 0x5cf135bd, 0x7f7099ee, 0x5c4c4cc2, 0xf8441b1f, 0x5fd13a22,
	0x8a6ebe3e, 0x7d8078e2, 0x49e3bffa, 0x8447f9be, 0x085f97ee, 0xf67e497c,
	0xaf1ab471, 0x2f9cf1b1, 0x4bd448fe, 0x3973b78f, 0x7da6ece9, 0xaf3c71f7,
	0xe5c3989f, 0x1fb7d48d, 0x05e2ed11, 0xe52a647c, 0x6ac9e8c7, 0xf45e223d,
	0x4b1f1f1f, 0xa7f5e029, 0x77290708, 0xe3f8bf80, 0x7fcc3f60, 0x85fc4cdd,
	0x821eebad, 0x3dea0ffb, 0xdcc27c4a, 0xe40130bd, 0xc7a02dc5, 0x5da80a98,
	0x73ef7e3a, 0xe92e1eee, 0x1e50c6c2, 0x29eb966f, 0x0f7e26ec, 0xb5d68d72,
	0x50df0184, 0xb5ff8d2e, 0x680d2750, 0x0758f3fd, 0xc3d15bcd, 0xb9fb4880,
	0x01fd81cc, 0x4f8c5fdc, 0x3b5dc20a, 0x074151de, 0x0c5789bf, 0xf25e91c7,
	0x6de23e59, 0xda5ffbe1, 0x67974016, 0x0eaf16ed, 0x742fe7e4, 0x9fb0d79e,
	0x4dbe7733, 0x9351f7fa, 0x35ab487f, 0xffc9b94c, 0xb04a23d4, 0xf4afd17c,
	0x8bf0135e, 0x1e679ded, 0x5eeb039a, 0xe277a9d2, 0xfeee4b90, 0xa346f7af,
	0x7469dcfe, 0xe410f9e2, 0x9c06fdf8, 0x17d72377, 0x74d4ea8f, 0xeafbfa70,
	0x8111ccf3, 0x486fd02f, 0xe77c936f, 0x1e6c5468, 0x64acf983, 0xbf28c1fe,
	0x09973297, 0x5b6ecfd3, 0xfc018d31, 0x10d75b96, 0xfb793a3f, 0xab7bd214,
	0x97ca9799, 0x167e306e, 0xb7961f2a, 0x1e2bf3aa, 0xfa57e755, 0x3b5ef9d4,
	0xcedab971, 0x02735327, 0xc0d3bfa7, 0x588f49f6, 0xbea1f66b, 0x23d7ada3,
	0x780b36e8, 0x49f22762, 0x7768fb90, 0x4ae5135a, 0x66bebe41, 0xc5ca6977,
	0xe70d71ec, 0x51be65af, 0xbd5ef921, 0x12f98f21, 0x217bf6fa, 0xf60dd39e,
	0xe0e310eb, 0x5974e2f9, 0x137c75f8, 0x6894f52f, 0x5cb7afea, 0x2f1c13f4,
	0x70d1e696, 0x3e6112de, 0xba7f6a56, 0x5138fc3a, 0xbb1c7209, 0xdb064e4a,
	0x26b97227, 0x3e92cbce, 0xd2a7ce1a, 0xfa979977, 0x065db06e, 0x8658afd7,
	0x904c78fd, 0xb37b494f, 0x2b9f0fdc, 0xf64692cc, 0xb9c407a1, 0x768799dc,
	0x0f51cfe6, 0xc938fdc2, 0x530027b1, 0x98d77a5c, 0xe0ec8621, 0x03aed17e,
	0x2054eae8, 0x4c0eef84, 0xbc9225b0, 0x8e273275, 0xe17de92b, 0x3cfd159d,
	0xdcbfdf30, 0x09e29e5d, 0xfb5ef3a1, 0xff9f898f, 0xe4aab318, 0xe1c8d32c,
	0x7720eda5, 0x1adf4963, 0xafe74c82, 0x7a24efbb, 0x64ee66af, 0xddaef3a4,
	0xff3d3343, 0xf395fc82, 0x6c5de599, 0x4d879464, 0xa66ffb0c, 0x8eaccf98,
	0x9d7c68b7, 0x71a465c5, 0x4f61cc5c, 0x9f3323a6, 0x034f302f, 0x9defafe4,
	0x18d31a3f, 0xafe6271b, 0xf1bd7074, 0x25b2917a, 0xb79c549e, 0xf185c719,
	0x152f98a2, 0x4e3196d3, 0x15e3a607, 0x83cf81b7, 0x6b2279e3, 0x3afac0cc,
	0xd7cf404b, 0xc6483309, 0xa2f0bdf6, 0xd7e44dbc, 0xb859eecd, 0x6d5bbf1c,
	0x624c47c4, 0xe0049e1e, 0x5fc4b987, 0xb36eb82c, 0xd7127fd5, 0xb7a91365,
	0xd8fb41cc, 0xaec8cd9b, 0x18dacd11, 0x9eb56b8e, 0xed62e2f5, 0x3e60aecc,
	0xbfe3deca, 0xb49f218b, 0x8923757a, 0x404b2e4f, 0x5bbca93e, 0xbe01788d,
	0x913cedcc, 0x6e500dca, 0x2e7cbd63, 0x45afcc5e, 0xc634b9f0, 0x5cc090e1,
	0xb683de34, 0x450c69ea, 0x828d7598, 0x9d8b1fed, 0x9be7107c, 0xf287808c,
	0x1506c984, 0xab724adf, 0xea5529f3, 0x9d479a7c, 0x76a3b0b7, 0xefc55fa4,
	0x4090bd4e, 0xb45ca9e7, 0xbf0518ab, 0xe7cd1398, 0x098dd325, 0x3f4d7fba,
	0xe5cfaa71, 0x4626f1f5, 0x8b64baf6, 0x7d248d85, 0xd7026365, 0x62f13e57,
	0xf89bbeb9, 0xc778fe79, 0x67e0035a, 0xbce2a57d, 0xdebbf007, 0x8b579f66,
	0x3105d376, 0x70635edc, 0x7ca158b4, 0x739c7553, 0x768f8e23, 0xfacf5866,
	0x17eafb28, 0x6c0baf10, 0x5eeb1ebc, 0x4dc37e8f, 0x8df6ed1b, 0x75abb40e,
	0x5ea1344f, 0x37d99cbc, 0xfdf430b3, 0x981bec2d, 0x0798d3ef, 0x5e8228bc,
	0xf82df7e4, 0xc7e7873d, 0x93b9e317, 0xc474e5ff, 0xd97ce295, 0x22fc856c,
	0xfcdb1d0d, 0xa9cb2768, 0xf93b27ca, 0xc3dec207, 0xad1f7ec4, 0x83634fd9,
	0xf9e54df4, 0x5d69df22, 0xd215a6f7, 0x7ec21d41, 0x7e16689b, 0x817d90d5,
	0x87c3b793, 0xa02e6e62, 0x7ef9127e, 0xc7f93270, 0x2c75e9f7, 0x94e387f8,
	0xbe25c707, 0x8d944134, 0xe2f7f836, 0xd22b1dfe, 0xb9be917c, 0x63d11260,
	0x30eacea7, 0xb67ef8e9, 0xdad1e0e4, 0x14b847ad, 0xc16befdb, 0xf8af5cf9,
	0x3f74cd29, 0x5bf647a0, 0x803e0160, 0x55c4a1fb, 0x65aefb81, 0x5ea3b302,
	0xdf2cb31d, 0x1fef8769, 0x00e6fc2c, 0xb5479bda, 0xcc23f232, 0x71dae131,
	0x287eae56, 0x2957672f, 0xf846ffde, 0x06fbd04e, 0x26afbb43, 0x8677d394,
	0xbbcc19aa, 0xfca2d052, 0xeabe591e, 0x9d68f2d4, 0x490fe549, 0xbb72b44b,
	0xa3c4c270, 0x72efa409, 0x9267e47f, 0x5cb2e49f, 0xfb2127e4, 0xf7ed38fd,
	0xf12277d2, 0xe0b97503, 0x46bb3707, 0x173f4919, 0x5ff2417c, 0x683bee37,
	0x01b19737, 0x59b37f48, 0x43e9f123, 0x2f892ba5, 0x46bcc2dc, 0x6587f384,
	0xde720f1c, 0xf5ab26b3, 0xeadd9b99, 0xad2a9cfc, 0x26e1c3be, 0x51eb9dc7,
	0xfa94cf97, 0xbeb564ea, 0x7d7fff3a, 0x3772471b, 0x0bbad9e5, 0xc0efd103,
	0x550dedcf, 0x3bf71f16, 0xeb4e8818, 0x72ff71d7, 0x7be2fb43, 0x776f1093,
	0x6113d233, 0x86cb285f, 0x5954dd93, 0xfea7821e, 0xf9053eb5, 0xc49b50fd,
	0x3e6fd73b, 0xa2f6fa30, 0x9583e25f, 0x9e6055b0, 0xafdc4cfb, 0x798a3fb6,
	0xe92c6ed1, 0xdb90b6d1, 0xd417613f, 0xec327ce2, 0xcfd44e31, 0xc80ae837,
	0xd621ba5e, 0x6f6bb2a6, 0x50e9cb5c, 0x661d49da, 0xc5fa8056, 0x6c6b331c,
	0xfdb7f6e3, 0xdcadacc4, 0xf613e63e, 0x0f42a386, 0x6475f284, 0x81f0d39f,
	0x1fae04a4, 0x25cbcd26, 0x4755683b, 0xa1da217e, 0x7d913e41, 0x838268fe,
	0xf27957da, 0xa3777ec9, 0x4ff92e75, 0x19363a1a, 0x74835996, 0xfa144ce3,
	0x418b0c7c, 0x7bb5eb7a, 0xbb266cbd, 0xee742fd7, 0x17f444c2, 0xdf64fc9a,
	0xfa37a10a, 0xacfe491e, 0x9636f810, 0x072ee7b9, 0x67bd74b8, 0x9539e272,
	0x1f64632d, 0x1c67657b, 0x330cedd9, 0x75fff119, 0xd9f08ca5, 0x98267685,
	0x357117ff, 0x53af87a4, 0x9f4f895a, 0xf0489f8b, 0x4fdd655f, 0x279acde7,
	0xe4428e81, 0xea2daac0, 0x49d66afc, 0x17dae4e7, 0xf123d0fa, 0xeaf7c933,
	0xb1dbabb7, 0x967e6a41, 0x8172f82f, 0x02ab39db, 0xcce55ea7, 0x385de7e1,
	0x8a3ac030, 0x7b0935de, 0xf1fb7ce9, 0xcf916428, 0x93d3172a, 0xf4276cba,
	0xfe72ff7c, 0xd1c6245b, 0xa12287ca, 0x8060dd1f, 0xfa820a71, 0xf9e3114e,
	0x7d0ebafd, 0xdf382eaa, 0xea4ed142, 0x4aff9259, 0x0096957c, 0xbb3a044b,
	0x97f05133, 0xf88d966c, 0xce89fe86, 0x89a48c15, 0x78bdfea7, 0xc62b1abe,
	0x22f07a03, 0x1675795d, 0x7aefd21f, 0x92e491a5, 0x4869f505, 0xe21e2a37,
	0xf1a9bfbf, 0x63de11ea, 0x69ace358, 0xa59c6f50, 0x04e10633, 0xc4c3f274,
	0xb4fd20a4, 0x36e67f30, 0x54474545, 0x9dee267e, 0xe52474b0, 0xae43ff84,
	0x15854c27, 0xe8153f63, 0xbf748148, 0x936bcfc2, 0x60333fac, 0x537477fb,
	0x33264e88, 0x57e7019f, 0x7fe35761, 0x3f3aaa52, 0x3e87d1c5, 0x25c12e28,
	0x573539e0, 0xfc92ee5d, 0x55f9a98a, 0xf496fb16, 0x81df761d, 0x3df9e1ef,
	0x1ae589a6, 0x68b28e50, 0xfe30e0e7, 0xaf1367a3, 0xd9e21fba, 0x887e30c4,
	0x0f3f232e, 0xd502c75c, 0xe97d282f, 0x4d9bdcec, 0x7a10d4fa, 0x9762fb94,
	0x2803c791, 0x4fbf73af, 0xf70d8589, 0x72157d23, 0x1fdc9dfb, 0xc67d21d7,
	0x58aee907, 0xd24b7f7c, 0x103640d9, 0xf6faece9, 0xf01ebf28, 0xbbfa2f92,
	0x20aee90e, 0xfea5ff28, 0x87d252de, 0x1c94b2be, 0xdf7ceb94, 0x4a3ff949,
	0x64316b69, 0x51f91f21, 0x8437ce0b, 0x7ce1de9e, 0xf689e809, 0xa9391f69,
	0x9bd0d72e, 0x28e1fbc4, 0x594b1f2e, 0x6cd9d123, 0x7f52839d, 0x8f920ae5,
	0x06d9d6e5, 0x4cd6ff6c, 0x90136f4e, 0xbeb0731e, 0x2dca5e9a, 0x1e96bcea,
	0xe85d4461, 0x8cfa5ab8, 0x91036f44, 0x4c7ca4de, 0x7dbd34b8, 0xab8df425,
	0x215f6f48, 0x9bd1231c, 0xff24ce96, 0x2f6516da, 0x1b3cc2b7, 0x0792146a,
	0xd41bdea3, 0x75a1f982, 0x6ebfa459, 0xa3ee738b, 0x5e5e46f2, 0x63d2e9d8,
	0x1ace481c, 0x2ee59e51, 0x13437cc7, 0x45d74394, 0xc89c7987, 0x7979bba0,
	0xfb8d3dfe, 0x7827a86c, 0x275dfb79, 0xa163ebd7, 0xb45eb7dc, 0xc72d6d2f,
	0xde06c37c, 0xfbf40bfe, 0x2d78c48c, 0xbf7e0b5f, 0x272cfee6, 0x7d72be3f,
	0xef58bc79, 0x7de5e536, 0xb795aed4, 0x12c0715b, 0xe6cf48cd, 0x620deefa,
	0xe49fe39d, 0xfcfc4ceb, 0xa00ec9c6, 0x5edde58b, 0xeb8ebfd2, 0xbf898b6a,
	0x96a73845, 0x9819ad2a, 0x8bf6024e, 0xdce2cba9, 0x7ee6cfa0, 0x8430cdc1,
	0x39db8933, 0xfd0d3fa4, 0x7a2195f6, 0xdb89338d, 0xe4bd6599, 0xd200c078,
	0xb236e3c3, 0x9f7f4b33, 0xa0a611ff, 0x5235c7bc, 0xff04481c, 0x469ca4df,
	0x0d261bd2, 0x80bf7e94, 0x9b8c0961, 0x89cbe17f, 0xa330ece1, 0x72beb893,
	0xc821c442, 0x1e3e35ef, 0x890db0ef, 0xbae11d24, 0x4794b7f9, 0x52171ebf,
	0x7882565e, 0x878af9e5, 0x21b8da9e, 0x6babe003, 0xa8517834, 0xc7142a65,
	0xf993a331, 0x9df6c5fb, 0xf30324ff, 0x87ae289b, 0x05babfcf, 0x1d1131e4,
	0x0b3767e7, 0x8371b1fc, 0x0b677e89, 0x124ccd3c, 0x3628cf7a, 0xcdd3f90a,
	0x58b76f02, 0x7e260f40, 0xf0d46ad8, 0x90925b8d, 0x51163c6f, 0x6b9756ff,
	0x188d4af8, 0xdde85ab7, 0xe937592b, 0x1f15c727, 0xe31e27a5, 0xeb6af77a,
	0xba6fd261, 0x66fae71e, 0xfe900b2d, 0xae23b5a3, 0xaf9d4e7e, 0x1be7536b,
	0xaef9d5da, 0xa71a5e11, 0x62bab1eb, 0x3cd5dfb4, 0x8bd91efa, 0xf17f246b,
	0x280bf9a9, 0x3cbf9cd2, 0x7dd92d72, 0x78df33be, 0xc5494e01, 0xbbc938aa,
	0xec429293, 0x78f2af22, 0xcfc67a8f, 0xa6b65de3, 0x10475aba, 0x691e527f,
	0xe0be49f9, 0x207ed227, 0xe33e4bf9, 0x8dce08f2, 0xaeb0b9ef, 0x547b9f46,
	0xaf9c5de2, 0xfd0bdb7a, 0x1ff51f27, 0xc36ba7a4, 0x439053ef, 0x43b398ef,
	0x42dcd0e4, 0x6f5be10b, 0xaab1e11d, 0xa249e1e8, 0x35e7c887, 0x5e86b975,
	0x56e979e4, 0xd0b32f41, 0xffe30163, 0xb9d17159, 0x4e4ad0ec, 0xd75b372f,
	0xb87ebd10, 0x3c8bd38a, 0x39f95db7, 0x2effa5cd, 0x3a5eb4e7, 0x17bd0289,
	0xf29939d2, 0xf3a0e55c, 0xe9c28371, 0x87e16ea0, 0x8238554f, 0x3350e17c,
	0xf084324b, 0x66299689, 0x5b0bfa0b, 0x33fcfc8c, 0xc5c7ea73, 0x8cf8424b,
	0x8fd4aa2b, 0x491d62f0, 0x8bad0764, 0x3e69f691, 0xe75d1cce, 0x7e423ff7,
	0xf90c54f7, 0x651e7b5b, 0x3cf492a4, 0x98e29439, 0xb4bf0b4f, 0x038acf9c,
	0xe009edcf, 0x6dfa6c7e, 0x57ddfa14, 0xefbfbe2b, 0xd98a3f40, 0xcfa47bf3,
	0x89bf3ad5, 0xc93b0bdb, 0x8dc72a7f, 0x12f4ff6c, 0xc1bd33ff, 0x12b770e5,
	0xf0a9714d, 0x1fa8487d, 0x6e64c3eb, 0xf27292e7, 0xd73ec28f, 0xedaa9bd2,
	0xae09c511, 0xffbae0bf, 0x78f5f0a8, 0x3f1237df, 0xfa3bfb47, 0xb32a4159,
	0xe77df1fe, 0x5b04f183, 0xe09e232e, 0xb9dbe08c, 0xef4c7b80, 0xc59d738d,
	0x7e109ff5, 0xcfc213d3, 0xfb962276, 0xd6f7cedd, 0x5a2672e7, 0x5f8427a4,
	0xdabc44ee, 0x59eb231f, 0xd9ac7a45, 0x40675962, 0xacb3363f, 0xf6a4041b,
	0xe291b988, 0xf5f3e634, 0xdb8ced75, 0xdfc431b4, 0x9a5c9291, 0xf6ed0c9b,
	0xa60addda, 0x353f5acb, 0xbbbdda85, 0x77a45d70, 0x4575f5f0, 0x9b8e54f1,
	0x9b995c92, 0x1b9ef08c, 0xe6f67c20, 0x9bbcc8c7, 0x9ebaeffa, 0xfcded9f3,
	0x099e78f7, 0xa3b485fb, 0x69aff247, 0x702069fd, 0x8a2079f8, 0xfeb5c3db,
	0xaf9205f0, 0x7cf87f09, 0x74169fc1, 0x42fcbb70, 0x1fdf5b0b, 0xa47517ca,
	0xac6ef3f0, 0x1fca8877, 0xa2b98dee, 0x9f4907f8, 0x7b3a035d, 0x878fc7fd,
	0x84eb8ff8, 0xae4eb0ff, 0x7d7abb6f, 0xaf3c04e3, 0x5c78ffa2, 0xff5f5172,
	0xe0ce36b1, 0x0627d455, 0xbb70f105, 0x42adc39d, 0xf68e5b5f, 0x8c659ed5,
	0x7f6fb3e2, 0xda0b697b, 0x0fbf6f5f, 0xcfc4942d, 0x13aeaf48, 0xaeb48e70,
	0x398eb724, 0x68ed7654, 0x7f9908e6, 0x955e279a, 0x243d4d27, 0x4d7fb2be,
	0x80fdaaba, 0xfd556cc6, 0xaad74d81, 0x05bcb3ca, 0x86ce7caa, 0x07f554eb,
	0xf2a996b7, 0x51bd1f43, 0x659f3f55, 0xd83b23f7, 0x8ada3d41, 0x99be35d8,
	0xcf61f2aa, 0xff6aaadd, 0x787c6b05, 0x2edbd41c, 0xebcc33ce, 0xcc5e1cea,
	0xff3830cd, 0x544b6d11, 0xb6945bed, 0x1af23f62, 0xa057e2bf, 0xaf8172de,
	0x5fdc9d65, 0x957db230, 0xb1d3ffaa, 0xd6887efc, 0xeb9d0a0f, 0x576b1f49,
	0x5f4ae3d8, 0xc74d68bf, 0xce31eb03, 0x147fafa7, 0x5bb427f8, 0xd418e705,
	0xce7ab4e3, 0x44b6c93d, 0x2ce93792, 0x96b5d39d, 0x07a4ac2e, 0x27a93cf6,
	0x1b3e60bb, 0x8238c8f2, 0x1cf99197, 0xc3d7f17d, 0xe7abbdb8, 0x67c51b05,
	0x297b78ad, 0x5539a3d1, 0x0e51174d, 0xe4c45d35, 0xe6c2e9aa, 0xbf41d354,
	0x681d3512, 0x52e71ee1, 0xc00b05d3, 0x96f0217f, 0x4f709570, 0x1ba6ac98,
	0x580bbc2d, 0xab8a01f7, 0x3f4e29f6, 0x6e87e30b, 0xbaeb44df, 0x52f91e94,
	0x0a3bf0b2, 0xefda8ef8, 0xdc12b16a, 0xd4973c78, 0xff42ccc7, 0xa5ffdad1,
	0x5927b37e, 0x3f45ff9c, 0x5ebfaed2, 0xbeb9d2f1, 0xe2573fd7, 0xa167f4cf,
	0xb8c8d55e, 0x46fdc8bd, 0x7b585272, 0x648f7d23, 0x9d70946f, 0xd5b9f42d,
	0xed7645cc, 0xfc43cce5, 0x4ae558ee, 0xb0ad13b2, 0x9cfc8cfe, 0x7d7267a7,
	0x88f986a9, 0x1fb15fcf, 0x1651f41f, 0xc2d58f62, 0xfc50e951, 0x4237e436,
	0x0eb3a41e, 0x143c0f29, 0x686401df, 0x49f95629, 0xfa2efad4, 0x97f842e9,
	0x78e57fd4, 0xaf929e12, 0xacccf1c9, 0xfb8a9f51, 0x58e7c342, 0xa34fd6ae,
	0x7b48d7b6, 0xe2160d0f, 0x67dad1ef, 0x38197682, 0xfa38c29f, 0x0c2d5981,
	0xeeca37f0, 0x115ffb22, 0xdf879ceb, 0x2d6d2c4b, 0x53b08706, 0xed7ac35c,
	0xd5e51114, 0xb3bffc25, 0x89e04abc, 0x5f7ebeac, 0xe58647e9, 0x3411fe7f,
	0x0838a71e, 0x0d7733ef, 0xea7a424d, 0x1e74af6b, 0xd1fa0d79, 0x4213baeb,
	0x71bd88ed, 0xd6804afc, 0xdd730b73, 0x90f442cb, 0x7136d67a, 0x8bda165e,
	0x62c64e41, 0xac59edca, 0x1b0fab5d, 0x83ac9ec8, 0xafdd2095, 0xd17e2166,
	0xe53960ac, 0x32f37df5, 0xfa52e74e, 0xec53afc4, 0xc780de22, 0x07c13117,
	0xd23339e5, 0x2dc64eb9, 0x980269bc, 0x72e30414, 0x5ce2299c, 0xb0f2c794,
	0xa7efb47f, 0xf6011d90, 0x1fba12a7, 0xa878e37b, 0xd47ecfbc, 0x2dc65fac,
	0x64856de8, 0xba1a5a1f, 0x8780cbde, 0x04ee5bd4, 0xd8d3007d, 0xa9e10714,
	0x9fe8fa2e, 0xd85c585c, 0x6cab8aa9, 0x0641c130, 0x8aaf06ed, 0xb536b9b8,
	0x45373ede, 0xf38903c4, 0x15e0a5ce, 0xce221f19, 0x72e3e04d, 0xe71930f5,
	0xa8b8e126, 0xa697dc2f, 0xf7fbf584, 0x2e5d5dc2, 0x72e12ee0, 0x59f3a8b6,
	0x76de97c4, 0xdde11938, 0xc1aeeb12, 0x048e03fa, 0xe0ba2b8e, 0x67f42abc,
	0xa7b53e28, 0xd6f74f5d, 0xf1e7afea, 0xf53bf54d, 0x75ce1ac4, 0xf40a7d98,
	0x8fbed353, 0xcd33c2f4, 0x0f4168c0, 0x430cd53b, 0x37622e1a, 0xd23bc0d0,
	0xc7ae4939, 0x84e4229b, 0x8f8cbf58, 0xbbae7581, 0x85d61c04, 0x7e854383,
	0xf0c0bf78, 0x431eb890, 0x10cce677, 0xc3aed0fa, 0x66edc295, 0x3fdc1bb7,
	0xed3efec6, 0xfb1878cc, 0x1c77d0ab, 0xacf84748, 0xd35ee851, 0x47bf3378,
	0xefca969a, 0x1a049599, 0x370f789d, 0x7e4ac335, 0xfbdfa1b5, 0x482194e9,
	0xf919cb77, 0x735e3fe5, 0xe1d2fc47, 0x2a8671c1, 0xc8ffba3a, 0xfc9fcbd8,
	0x8ffd10a0, 0x609e29f3, 0x43c79981, 0xc63f7d64, 0xe4fc039f, 0xe0b31375,
	0x376634be, 0xee91bdd2, 0x31d93d38, 0x026cf513, 0xbf9c9fd2, 0xbf2a2fbc,
	0x8b7cfe97, 0xe512f782, 0xdd2df1f7, 0xb4876ea3, 0x2922e91a, 0xe5f1feb8,
	0xad1aa3dd, 0x27d43c41, 0x5ea3d699, 0xe5c2ce78, 0x638b8ca6, 0x93f10376,
	0x3fbe1635, 0xe7960e8e, 0xcf0dbf6d, 0xae51f5a5, 0xbd71a37e, 0x9e19ebef,
	0xbbb2bfb7, 0xfad1c5fa, 0xaf77a41c, 0xe776f3b1, 0x9af97c44, 0xbce8cb0f,
	0x3e12d49a, 0x14adeb8e, 0xd5a8be7e, 0x0d6bcdf8, 0xaac78a7e, 0x51e838c5,
	0x1a57efc1, 0xdce32d07, 0x2e50f4b5, 0x671f5ff0, 0x74918660, 0xb17ddaef,
	0x53fdaf7a, 0xd4bef61f, 0x527944df, 0xc353f739, 0xdc6c2ab9, 0x7e1489de,
	0xd7c60e7e, 0x6cdee805, 0xcededc6f, 0xa61614d2, 0x74395eff, 0xa78aa5de,
	0xf5dc7193, 0xfc5027e7, 0xa17e9f5c, 0x1835873f, 0xfe0917af, 0xf5fe02e5,
	0x2a374718, 0x2be73bf4, 0x451271c1, 0x16205c5c, 0xdbafe3f7, 0xfcaf74f5,
	0x937507d7, 0x77998737, 0xcb872a72, 0x370649b5, 0xf30c3fc6, 0x30a6d733,
	0xf27acbe3, 0xa7bc8a7e, 0xf6df9da9, 0x9c42c0b2, 0x86e7c63f, 0x952a2f1b,
	0x7bce57c3, 0x47c73c7b, 0xdd331efd, 0x297e805f, 0x7c7b7a8e, 0x83f89aa0,
	0x1ce78d5d, 0x37edc781, 0xbee93206, 0x4f6e14d4, 0x2b0f4488, 0x51e33d62,
	0x81ced60e, 0xc53f40ca, 0x1ec54686, 0x452ebfb2, 0xebb8410f, 0x0bed7854,
	0x57e11377, 0x39cf2bf6, 0x53d51f27, 0x43c9c43c, 0x9732df62, 0x8b6dcf15,
	0xc93b5c85, 0x64e43fb8, 0x9be742ab, 0x9ac61e25, 0xde2cbf80, 0xe1f49ab2,
	0xad4667ea, 0xdf867147, 0xb23e06ef, 0x1bb19538, 0x4eb25d20, 0x765f17ed,
	0x217b1f7f, 0xcb9f950b, 0x8fc92359, 0xdba99fea, 0xfffbb0d5, 0xd6927a86,
	0x5f368f5f, 0xa5c643d4, 0x3146f38a, 0x7ffe462b, 0x9a5f33fb, 0x12394430,
	0x7e009ffd, 0x7c80c83a, 0x99e942d5, 0xeea53b66, 0x5484d754, 0x54a2cb80,
	0xb454a4cf, 0xe1cfbcdf, 0xc3db53d1, 0xe25e03e5, 0xd664b905, 0xf326f8f3,
	0xfecfee3c, 0x000fbe11, 0xb99b30f0, 0x77efa43e, 0x3419ccf7, 0x7fc11f4b,
	0x30bec074, 0x338fe48e, 0xf13de915, 0x299349f9, 0x18f9ee6e, 0x636fc217,
	0xed1f2ba9, 0xf92b1b0e, 0x998b467d, 0xbf7dd3fb, 0xba06f31e, 0x3db5063b,
	0x5ce78650, 0x3f5ec77b, 0xe83673da, 0x47f146fe, 0xf1e06e1b, 0xc0bac980,
	0xc159fede, 0x7c6292f1, 0x4f6fe8a9, 0x7ba2661a, 0xd2fa898c, 0xf890c6fc,
	0x83817aa3, 0x13f1c52e, 0x7deec7bc, 0xf42ff81b, 0xf7e063db, 0x1c65ae2e,
	0x0c8e32bf, 0x63d50ec7, 0x30fc00cf, 0xafe65178, 0x46fc536d, 0xf6dd4f58,
	0xa9a7e46d, 0x3c9fc7bd, 0xafcee50f, 0x92e7e40c, 0x3d7c4af3, 0x59fd0cad,
	0x53ccde52, 0x263edcec, 0x4cb9f4f4, 0x587f71fe, 0xb98ba095, 0x179f3f42,
	0x84bce1c3, 0xddb13339, 0xab1616ad, 0xaf342d83, 0xd688adbc, 0x8718dab7,
	0xebf4807a, 0xc21fd644, 0x9feab5db, 0xb9fbf1b5, 0xec10f74a, 0x679c14e4,
	0x1eefb62e, 0x7ea27c12, 0xc6a7bf08, 0xfa173106, 0x0cf7eb11, 0x077684dd,
	0x4ff73473, 0x94b23f03, 0x6cbe9014, 0xcad1f3c1, 0x14fca2d7, 0xc2e027a7,
	0x8c7caeec, 0x99986bbf, 0x20714051, 0x9de9ba47, 0x40c67389, 0xe05bed26,
	0xc2c80a33, 0xd395a9ad, 0xf5ef400c, 0x4187a0e9, 0x45d4e3fe, 0xdf780cd3,
	0xad503b31, 0xed29bc83, 0x36bf9e4e, 0xf6f31c70, 0x5f3c75b4, 0x43d6a810,
	0x83da587e, 0x46078f3c, 0xb492ac20, 0xa179a6c7, 0x427153ff, 0xe80671cf,
	0xaefd725e, 0xfb50baa1, 0xce34a0e9, 0xf1454ea7, 0xd8b2a77a, 0xef0899a2,
	0x2df5f0dc, 0x6e3f5269, 0xbd7276a5, 0x0d4b3db2, 0x2a4f6edf, 0xdc52b76f,
	0xc31f1e27, 0xbf714436, 0xf016379c, 0x2863bfb0, 0xa73715f9, 0xedfef3c6,
	0xb0614fd0, 0xd94f091f, 0x15771c9f, 0xc3e463ca, 0x95e76e46, 0x72a4efe5,
	0xace309be, 0xb90671a3, 0x99dc3df8, 0x3f88f919, 0xe0419bc0, 0xb5cfc0cd,
	0xa0fcf89b, 0xe23cb8df, 0x4ed0a3fb, 0xa85bffbf, 0xb79c159f, 0x088e4e96,
	0xc2d9593a, 0x71dda9fd, 0xe34f4439, 0x22bbc463, 0x0c75ea85, 0x941ef013,
	0xd9d7c716, 0x8514978b, 0x701169c6, 0xbdd008cc, 0xf75d2bc4, 0xbad37fa9,
	0xc2e5f043, 0xb7f641f7, 0xaf99b35f, 0xe90be387, 0xbbf49e39, 0x9dfd5407,
	0x5f69ab5a, 0xd7121b02, 0xed439f1b, 0x2cc5147f, 0xee6d9df4, 0xc795976d,
	0x4fd450f5, 0xcc0dbbe5, 0xf50b037b, 0xcfbef613, 0x3fefc6d0, 0xad39d707,
	0x2ed3ac50, 0xebe769d6, 0x95e8a9f4, 0x9cceee1d, 0xc74beb6d, 0xedeff0bd,
	0xe881786f, 0xc3cfb54f, 0x3afb87f5, 0xa4065e12, 0xc8bc655d, 0xd9e06a79,
	0xfccd670b, 0x7f713c24, 0x6ae1bb53, 0xb4f394ba, 0x59dfda47, 0x52bc71df,
	0x4eeeaede, 0x1ccd171e, 0xdbaeba6a, 0xb8c3a59e, 0x16aed901, 0x4149fd6d,
	0x4d2b9ebb, 0x58337f9c, 0xc3f88446, 0x61456909, 0x5df481ed, 0x8aebfe7b,
	0x5adf71e3, 0x9257443b, 0x29ef13b3, 0x7bf2cf7a, 0x763563f8, 0xbd1ff419,
	0x0bb60d6c, 0xfe7517ca, 0xbebf0141, 0x4ceea576, 0xb9a15f9c, 0x138715ec,
	0x5b69b1ce, 0xf6175f89, 0x0b23bb2b, 0xdb1ecbf2, 0xb0bffc46, 0x5997d97f,
	0x1fabcfc0, 0x0f97997b, 0x1b32fb2b, 0xf0af69f3, 0x2bd778fc, 0x7b19efc8,
	0x3184da65, 0x45627d41, 0xd5c6839a, 0xd218eb97, 0xf31eaf51, 0x18f499ba,
	0x6948d709, 0x18d759a1, 0xd8d7ffce, 0x5fdc0f4b, 0x74ff8252, 0x9c4efda0,
	0xd50603ef, 0x962bbef9, 0xdaee93df, 0x37ba0ffd, 0xe79a5772, 0xbed0697b,
	0xc2cce621, 0x13dfc82c, 0xe7f909f3, 0x21e81714, 0xd8713768, 0xaf987cd9,
	0x1ba36672, 0xcab626f5, 0x5c103169, 0x600b3d85, 0xf7e00172, 0xdd5f9eda,
	0xe30f9fd5, 0x118c79c6, 0xcf61a07c, 0xbf477fd7, 0xab29c36e, 0x63fecd13,
	0x03bb1e3a, 0x1d31aef5, 0xe5cd7cef, 0x22e7bf30, 0xed063de7, 0xa4bdf095,
	0x1ff34cdd, 0x72cd71d3, 0x0ff63fac, 0x2748391d, 0xb7f51fd7, 0xdae85b20,
	0xaafe9bfd, 0x8bec2dfb, 0x466dc68b, 0x7849a7f4, 0xaa9415fc, 0x478f047e,
	0xa5be3c38, 0x4973b2f8, 0xc807d687, 0x47bea9a8, 0xf93bfa04, 0xb4587b89,
	0xf214fd13, 0x0ed6b9fe, 0xd612a47a, 0xefafdf07, 0xe8841986, 0x5bcfe3cf,
	0xf3049180, 0x954e2ca5, 0xa9a4b72f, 0xb3d857ea, 0x5293e554, 0x4f9551af,
	0xf2abe471, 0xa8c77353, 0x96774fea, 0x9537f2aa, 0xafd5514c, 0xf2aa5574,
	0x5536fef9, 0xdb0751fd, 0x9987e5d5, 0x7050f11e, 0xd30fb9c4, 0x322e63a2,
	0x689f16a7, 0x98e987dc, 0xb43838af, 0xceebe076, 0xefc3edb7, 0xbdac0ed2,
	0xc2ed2417, 0x9f56f473, 0x37fdbc29, 0xbc1390d5, 0xf1d7afaf, 0xb4ff417b,
	0x78877e7a, 0xc682f793, 0x90181da3, 0x2ce8b150, 0x9f3fbfbf, 0x208ec9db,
	0xcd3f9062, 0xf17d91b5, 0xc5f1b188, 0x7f9fb88f, 0xebbdf200, 0xeb54abbb,
	0xa3de7f1e, 0x5b29775a, 0x6dd3c1a9, 0xfd857caa, 0x49fd554e, 0xe5556ba9,
	0x69f71c53, 0x2a80f4f0, 0x98f9dd3f, 0x349b4f06, 0xaa95fa78, 0x8777d25c,
	0x41ed53b0, 0xe3a412fb, 0x88e59d02, 0x744e1b87, 0x3a4a3e13, 0x4f11cb5b,
	0x23691dd7, 0xddfa157c, 0x8b2ec8e5, 0xc3ee360f, 0x30e70fd4, 0x7346f76c,
	0x9bfba52a, 0x3aa7641d, 0xe94b9cd0, 0x7d2766c1, 0x09736dff, 0xbb36efa5,
	0xf35dfd28, 0x9b3b4a64, 0x35b694dd, 0x97fd51b7, 0x9db9db9b, 0x7df7a12b,
	0x0f680188, 0xd40ba738, 0x90d787a3, 0xfc8e986e, 0xe0745cf2, 0xf1efe61c,
	0xbf23a6ea, 0x01132134, 0xd22650b9, 0x0f5dfd21, 0x135e03a5, 0xc65e79d2,
	0x5ce9b45d, 0x0f87a8f9, 0x8fdfbc7c, 0xbb18030d, 0xd53bad77, 0x16f3c71e,
	0x29b213c8, 0x8fdfad5e, 0x2f5c405d, 0x8eb928a2, 0xdf31d3f2, 0x13cbc515,
	0x1d37ef1e, 0xeceff0f5, 0xf1f57717, 0xf9c40f8b, 0x2fe2fd6a, 0xd0d8709e,
	0xdbe8738e, 0xc78436a1, 0x72cf6121, 0x62e37cb1, 0xf90d4b48, 0x47b39446,
	0x4c897a34, 0xe695d41f, 0x3a6dbf62, 0xcf14cde7, 0x2191a37d, 0xf854cefd,
	0x33d657b9, 0x29f117f6, 0x9e74cdd3, 0x2d73ac3a, 0xa531b8a7, 0xf38429fb,
	0x0873c7a4, 0xeeb65dee, 0xc55f844c, 0x9f3cd9e3, 0xe294fdd4, 0x391bc90c,
	0x9e3f467c, 0x53e1b575, 0x933e0e1e, 0x3cfcedd3, 0x400d77e6, 0x0fe6403d,
	0x70eaba57, 0x752e1f3f, 0x2dfba60d, 0xbfdf336e, 0xefdd1b6e, 0xd1570661,
	0x9d7621cd, 0x6a46e9fd, 0xf82f1b37, 0x56f37da1, 0x2d73ed3d, 0xe74b3f3c,
	0x09d11efa, 0xc6e7339e, 0xb0e0b9d0, 0xa00bbf8e, 0xe7f4afad, 0xd1d382e7,
	0x3a6fede1, 0xab365e51, 0xd01dc5ee, 0x289ad75f, 0x3dcbbaea, 0xaeb1f494,
	0x03ae8046, 0x678d13d2, 0x29d9b979, 0xd97e4240, 0x282ff879, 0x8ee3b17f,
	0xd423faff, 0x8c4d64ff, 0xfd886493, 0xaddf825a, 0x0482f2a2, 0x0b4fe90b,
	0x43280e66, 0xf84f38b9, 0x0cda16f7, 0x33e6e4c9, 0xc9f099c4, 0xfcd665aa,
	0x564100f5, 0xc269589d, 0x326a97a7, 0xe98f5b6e, 0x980f41aa, 0xed6f0af0,
	0x51eb6df0, 0x2d83ad8d, 0x2ffc445c, 0xcc335ef0, 0xde93516b, 0xf273cfc1,
	0x2beae8de, 0xf491538a, 0x13c4587b, 0xbce81001, 0xa8afefaa, 0x417ad8ec,
	0x85d21ba7, 0x1b0460ff, 0x9fed4171, 0xe4e91fba, 0x86f782cc, 0xa81ff044,
	0xf8fe85cb, 0x571f1327, 0x1c880efb, 0xe39fd0d7, 0x2809b0fd, 0x5bc9f513,
	0xabc81cb9, 0x229ef2fa, 0x875e7f58, 0x0871475d, 0x2076ea8b, 0x05da7a1e,
	0x1dac8d1e, 0xef2cd3f7, 0x96284fe2, 0xf61f734b, 0xd9d2f252, 0x950f2f69,
	0x77018597, 0x2cbca879, 0x472d6ee9, 0xa3e528b9, 0x9bfa8bf4, 0x6e5f046b,
	0xbfba7e24, 0x07f289b9, 0x1e94bd9a, 0xf820de6c, 0xbf952b72, 0xe0a8fcdb,
	0x97c13ecb, 0x1defa39f, 0xee9455cd, 0xda50f669, 0x257eeb12, 0xc589f71d,
	0x6f87f143, 0xe866663e, 0x30e9eb77, 0xec05dc53, 0x489ea788, 0x3322b8c4,
	0xc6d487dd, 0x7cf96917, 0xef6c3d2f, 0xebc8fef3, 0xb8dea788, 0x0717d420,
	0x43a7a646, 0xbe4361cc, 0xcd7a41f4, 0x0fb7d474, 0xd4361c39, 0x5e3c8fa7,
	0x90e97c43, 0x423361cb, 0x95f4c3fe, 0xb0e3dcbc, 0xe7ff2199, 0x72f257c7,
	0x0516c3af, 0x57d28ff9, 0x918fbcf1, 0xde903e93, 0x7c8bdd30, 0x71fb2996,
	0xb25b947f, 0x00b88026, 0x1fba5d79, 0xd4a4c5f7, 0x5f7013c5, 0x10774f4c,
	0xac714c7d, 0xa9f98fdd, 0x780c9bb9, 0xcd65cb15, 0xcaed875f, 0xd80d2b12,
	0x6dc6426e, 0xc4ddb0eb, 0x42180f41, 0xbe1e4ddb, 0xa7e61d6d, 0x50193739,
	0xf82e9d3f, 0xe647ec98, 0xd3e4b965, 0x646dfe32, 0x41e49b87, 0xe49bbb5e,
	0xd94b8481, 0xd17bcaec, 0xaed0d55f, 0xc79c15d8, 0xf837a56c, 0xeb086300,
	0x74ce3df1, 0xa1fe3b8c, 0xb7ec2d6d, 0x475fcc06, 0x1daf1ff9, 0xf7f9557e,
	0xf7f8e137, 0xa3bf6207, 0xf6b8c7bc, 0x3dfc4c0f, 0x17089995, 0x163ba7d4,
	0x50dde8db, 0x9ea1b1e6, 0xf9e42555, 0xfca14c7c, 0x407f917e, 0x5cea0fa4,
	0xddf0fec6, 0x2f9c5fda, 0x7b07f2fb, 0xffda22ff, 0x11227b9a, 0x887f05ca,
	0xe7e76fef, 0x462ef125, 0xd3f7e31d, 0xa73f152e, 0xc6d7038d, 0x6d62ac93,
	0x7d595c07, 0xf16a48e3, 0xdf4e5b1e, 0x2f196ef8, 0xeef38dad, 0x7345573d,
	0xbc855a7e, 0x4478e806, 0x5fe43864, 0xe1f90e02, 0x3d67d0e0, 0xf7b1c78c,
	0xf1122f89, 0x3175daec, 0xc77f124f, 0x6bb7c457, 0xa2e927d7, 0xb95afaef,
	0xf870379c, 0x8e577e83, 0x6458ae78, 0x0ab76863, 0xbc7f3fe5, 0xf2d1ff08,
	0x27c5abb3, 0xcbaa2ce7, 0xfaaa77a4, 0x842ab1f2, 0xc98f96a3, 0x54daf17b,
	0xff78a9ea, 0xf11ce30e, 0xe73c20bd, 0x59ec937f, 0x9574fd8a, 0x875dff75,
	0x00c4d0e7, 0x38dee1c1, 0x41c2354f, 0x0578f131, 0x427c7719, 0xf5097de7,
	0xeffa3bb6, 0x0e777e22, 0x91ec0585, 0xbd479055, 0x5dddaf6c, 0xdcb1fd8b,
	0x4b39c500, 0xae29117e, 0xc3908d76, 0xefbe537d, 0xd7697c64, 0xc933afa6,
	0x7d89777e, 0x151e0911, 0xbc0171fa, 0x1253d1ff, 0x8cf3f243, 0xbef8fcc2,
	0x64d299ef, 0x0cce5bd2, 0xbd301930, 0x33e2e7da, 0xff508603, 0x99f1f3da,
	0x1f0b12b4, 0x4c64e277, 0xbc76977f, 0xefdee510, 0xbb655c45, 0x77ea3bc9,
	0x131e1f68, 0x9bfafe45, 0xc2214094, 0x3eae7b41, 0x32fcf6f3, 0xf3df5e47,
	0x026fac35, 0x53f6afae, 0xedf8bddd, 0xb5dbcf4a, 0x18677f4d, 0xe9b63ec7,
	0xf518665b, 0x9ddfce5d, 0xd40e79f1, 0x482d3c2b, 0x80cfa322, 0x4bf9013e,
	0x559d65c5, 0x159e9ce0, 0x792f2e72, 0x8967c787, 0xef3e7b54, 0x2adeaef3,
	0xb01e3aaf, 0x71445fd4, 0x2c40fa28, 0xf1d5fbdd, 0x9c642b77, 0x3ce25bd6,
	0xfdf5e70f, 0x95ebb748, 0x79d54cce, 0x2e1f07fd, 0x40f88bbc, 0xbc6dc514,
	0x1279fed8, 0x9d2ff5ce, 0xe6bd0f49, 0x8377d208, 0x2704effd, 0xea6daf99,
	0xaccfe551, 0x8513be0d, 0xff6aadf7, 0x04b927a9, 0xe1036c72, 0xba61bd89,
	0xb2be443d, 0xc2f5bfb6, 0xbbf0247b, 0x9d18044a, 0x70cce717, 0x714abd41,
	0xa3de621e, 0x8fce2f3c, 0x70cdb9a0, 0x4995bf41, 0xe36b3ea2, 0x7cb201f9,
	0x583faf1b, 0xe5e567f6, 0xfa2f3269, 0x4fe646bb, 0xd92cf2f0, 0xca26fa3e,
	0xc9f978db, 0x40cdeffe, 0xf7f2463d, 0x7f42feae, 0x0139ef16, 0xf912ffbf,
	0x6ee245c8, 0x1e42e5d4, 0x2a9bf7c8, 0xe625307e, 0x6db7dc3d, 0xd610c50a,
	0xfb246dde, 0xb6f8e9fd, 0x6777d0bc, 0xbb8e7c65, 0x5af146dc, 0xdd0eaf75,
	0x4b7117ac, 0x0ac4b7a8, 0xde857aff, 0x9e977e4a, 0x8f5f39fb, 0x3755f7a4,
	0xafe152ed, 0x2f78b94f, 0x30931c9a, 0xa71fd9de, 0x36033dd0, 0x01e293a8,
	0x191432e2, 0xa4f7407f, 0x625c7c65, 0x79e1730e, 0x5137f139, 0x63d1bdfc,
	0xab6fc49d, 0xd9edc37f, 0x23ed8f75, 0xef44b6f9, 0x2f927b20, 0x819293db,
	0x7f1b12fe, 0x69bab217, 0x52cbed0f, 0x0bf85d87, 0xc28787bb, 0xfa866073,
	0x6f802d3d, 0xe1c5c64e, 0x37ff2eaf, 0x476b5fc3, 0x57eff797, 0xdf1c615d,
	0xfbf71b39, 0x3e9e053a, 0x058a39d3, 0x80cfaebc, 0xef2ece71, 0xc7a7121c,
	0x8a4eec60, 0xbfd0ab5b, 0xabe7845b, 0x431b469e, 0x3a539fbc, 0x83083ef3,
	0xe239ed7f, 0x8aa64c89, 0xd19a9b2f, 0xba6fbe87, 0xfa6f7c04, 0xc537c24f,
	0xd1393010, 0xbf847c4f, 0xf9dc5733, 0xfe342999, 0x65d041a7, 0x07ee76bf,
	0xc16df193, 0x93c71b72, 0xcdd537f0, 0xfa1c777c, 0x187ee49b, 0xd0dac31f,
	0xed74007f, 0x44ed7414, 0x1bf496ba, 0xbb413bf4, 0xd20df030, 0xdfae1aaf,
	0x3fb74bef, 0x7f5c04b8, 0xeb849ff0, 0xc97fd076, 0x8a23bb5f, 0x385a32ec,
	0xeb833cff, 0x2fde122d, 0x38247c89, 0x4e7084bf, 0x7e70faba, 0xb2a1c329,
	0x4778486b, 0xfc5a4792, 0xd98779c8, 0x65df45a7, 0x299f5e9f, 0x402194f8,
	0xbc5ab571, 0xf78be8ef, 0xfbc0979d, 0xde24ffce, 0xa6d370b5, 0xab7fc2b5,
	0x4641fefd, 0x55777e44, 0xcd3ff8e0, 0x71a0b02f, 0x517caaaf, 0xf2aadbd3,
	0x2ff7dec5, 0xed208fcb, 0x7f29fffb, 0xcc23f482, 0x0e856578, 0xf95a8dfd,
	0x3ba64cf0, 0xe3d0007f, 0x7bfebb4d, 0xf93807f8, 0x5714219a, 0xcb588775,
	0xf1fee397, 0x5f405dc9, 0xfb72365f, 0x27bdd1ea, 0x7d118e8d, 0x79c165e9,
	0xd085731d, 0xf7a682d9, 0x2d67a88d, 0x9c398d00, 0x0078b59f, 0x5c5257b7,
	0x2a85f014, 0x0226330b, 0xe2aaa83f, 0xd0ab9ff7, 0xa94f18a1, 0x33e503df,
	0xef8fcc0c, 0x0d5a5755, 0x39f9337e, 0xcdd9f7d5, 0x966b3de2, 0xd7baa098,
	0x29e977ae, 0x12e6ef7e, 0xd5bd1fee, 0x81f746da, 0xe7bc1ee7, 0x97b85dec,
	0x788b79d7, 0x47bcbafc, 0x95dd67f8, 0x518b3df8, 0x9e73c52f, 0xb7e9fc22,
	0xae9fc919, 0xd62d176d, 0xf0af433b, 0x3c9d99b8, 0x4fee52fe, 0x7341df58,
	0x82cfbf01, 0xd951b7bf, 0xcd0ff468, 0x2f7abd43, 0x250dd5e9, 0x7f10f36b,
	0x4f94130d, 0xf3c179cd, 0x57d3434d, 0x9fcb5ed4, 0xdae5e9b5, 0x3e693f53,
	0xcf22f448, 0xfd9b4741, 0x57dad794, 0x3fff8fe7, 0xf31c8fe4, 0xd305af95,
	0x3ebadfb1, 0x0eeb0d18, 0x4bfe7734, 0x376903f6, 0xad047690, 0x11f2425d,
	0xd2e3eef9, 0x9ef17601, 0x39f92969, 0x92a78198, 0xd01caedf, 0x0dd73f87,
	0x7f28ba28, 0x9bff9756, 0xd2e5f3f9, 0x972a6d7f, 0x3fba5aab, 0x6497f332,
	0xadf4966f, 0x18f9ffa5, 0xcfe30283, 0xdee8506f, 0x568ad577, 0xbbe558e3,
	0xeb2afbd3, 0x370e4cb1, 0x62b85c8d, 0xf5a0e079, 0x74f5cbeb, 0x6feb30be,
	0x439da273, 0x17d7c1e2, 0x812e5b6f, 0x49ff2db7, 0x8b95f5bc, 0x377e16c7,
	0xfa54c8b9, 0xfa03ebc4, 0x06fbe7e8, 0x509f5c5c, 0xd79bff97, 0x68df721d,
	0xbc175ea1, 0xd7f18357, 0xe5d9f718, 0x6b4cf7e3, 0x77e95ab2, 0x77495801,
	0x95bbf22c, 0xf7fcf5bb, 0x432e0c66, 0x687bc85a, 0x4fff9867, 0xc62b8f48,
	0xb48477f1, 0x22f5d171, 0x75957a5e, 0xd453dd3b, 0xe3266bbe, 0x7f45ebae,
	0x64cdf7da, 0x816ef97b, 0x53b37df6, 0xd9fdc403, 0xe3c05602, 0x47ce2e50,
	0x0f3ca1cf, 0xfb9ccff1, 0x0aec99b6, 0x7fa2033d, 0xe208cde2, 0x3c5f7ce5,
	0x3c097b7e, 0xc49ffb7e, 0xf57e96a3, 0x1f742db6, 0xf7e94aed, 0x2e2b871d,
	0x97c82933, 0x6bcdf97b, 0xf237e266, 0xdbaef67d, 0x84f7a45e, 0xe466beba,
	0xfbd4bd87, 0xf0cfe3dc, 0x1fd784eb, 0x00d8b5f3, 0x7a8f63af, 0xe6373ec9,
	0xdfee87b0, 0x85d77e8e, 0x7f2cff11, 0xf38f5bbf, 0xd48cfa96, 0x4bfc826f,
	0x71134bdc, 0xe7cb9755, 0xf8bfd4ae, 0xca2bf2ef, 0x8ce771fb, 0x1dfc22fe,
	0x28ceef04, 0x3b43cf7a, 0xba99c9ff, 0xdc2fbe8b, 0x9c99eb12, 0x2599f809,
	0x677c84e4, 0xdfcf42b8, 0xd4e9ef17, 0xcd707d93, 0xd2f0ff0f, 0xdb4b8e13,
	0x3dec1a15, 0x3265cf61, 0x7bf1d06d, 0x0ee5052b, 0xf3c48b8a, 0xa50bda1a,
	0xff5b50fd, 0xadd9473e, 0x1adf6499, 0xf9c2e9d7, 0x13e7ca3c, 0x4d0d5f09,
	0xf7f42cdd, 0xdf8d2241, 0x1ec8bbb0, 0x13ca6efa, 0x7fa48a99, 0x104b71fb,
	0x174b97df, 0x2dced3ff, 0xabccf433, 0xa11d7c80, 0xcbdeb8f8, 0x9f3bfeb8,
	0x90ba5275, 0x61ea5375, 0x12c2fefc, 0x1974a4e6, 0xe49a5373, 0xf704fcf0,
	0x3bb19777, 0x5f4de299, 0xd23866fd, 0xc61bd9cd, 0xe24c62b6, 0x691bf2d5,
	0x7caebef5, 0x68ff7f07, 0x447f37c7, 0xa1faecfa, 0xc6f8b2f1, 0xa7aeb113,
	0xc7f8c333, 0xe7aa577f, 0xaff696f7, 0x69517921, 0x04d86de7, 0x4d8b77ee,
	0x13fda2c9, 0x9b299be4, 0xff44df24, 0x754f88f1, 0xa565fe3c, 0xb700ef42,
	0xc5b47407, 0xf2cf2c46, 0xb5b2efe1, 0x23e5e76f, 0x0a7ce2ea, 0x898c47e4,
	0xc5b7e5e2, 0xc9bef0f9, 0x7da01602, 0x9b6f08b9, 0x123ef1e8, 0x9df28be7,
	0x6411387d, 0x797ed02b, 0x9bdf8587, 0xc8418160, 0xfcf0f3ff, 0x7e7ce614,
	0x91f7ec41, 0x8fdf9cd9, 0x43db532c, 0x05e514de, 0x81acb28e, 0xe81b0e90,
	0x6bfb803a, 0xc6e77c64, 0x1da2169f, 0x2fd0c748, 0x3b98c5f3, 0xdb298fc9,
	0xbd9475cd, 0x2ab6f583, 0xbbdfbe3c, 0x661bdc5b, 0xfea1c9dd, 0xf94724b0,
	0x23e708fb, 0x4514bfa8, 0x4efe2b86, 0x79cc3ba0, 0x8e8bc651, 0xd91b33c4,
	0x7bbd19e5, 0xf9e155b6, 0x37f59993, 0xbe4e1bad, 0xc7ea2f03, 0xcf9e1d73,
	0x2691bc70, 0xe9fdf0c6, 0xfb8b9fee, 0x1331ac6b, 0x9e2ba2ed, 0xbf50eb32,
	0x31c410f8, 0x08f9e7de, 0x7e98dbce, 0x4c66e70c, 0x66e702ff, 0x73853f4c,
	0xc39fa633, 0xe5d319b9, 0x08f89de7, 0xd03f5b38, 0x5bae0df5, 0xf3b4f7fa,
	0xcb932afd, 0x77f1decd, 0x02fc689b, 0xdbe08787, 0x8c9def8b, 0x6b75cf7e,
	0xfc7a775c, 0x6bade845, 0x3d323ff7, 0x1bdaf061, 0x8f84ab47, 0xe6253b5b,
	0x40ddb791, 0x3daf3ff2, 0x521d5b10, 0x89a06a2f, 0x71d88fda, 0x3ffb162c,
	0xaf85ef67, 0xcf25814b, 0xd47cf1d0, 0xad3775c0, 0x70ecfe43, 0xa22c0d65,
	0x34c36e7d, 0x0f0ffdaf, 0xe82a3de2, 0xba22e29f, 0xe987ee94, 0x8759a0bc,
	0x5d720e16, 0x373ae35b, 0x3badfb62, 0xc02571b2, 0x37df1877, 0xb84a4748,
	0xf5a5aef5, 0x2eee64dc, 0x3741fbc4, 0x8d87d05d, 0x94702ecb, 0x843b9c12,
	0xf7ebdcbe, 0xf125f416, 0xb7f75df6, 0xdf263fb6, 0xea5e4151, 0x6df4b940,
	0x9585ea2c, 0x7da07e22, 0xd3dfa0fb, 0x7a83b37d, 0x479bf786, 0xdff7abc6,
	0xff7c81ec, 0x6ec474c9, 0xb5f11b93, 0x41f1f775, 0xe030def8, 0xa872d067,
	0x60e0613f, 0x11977dd5, 0xfc7ebe63, 0x9f5489a7, 0x2e757f7e, 0x718154db,
	0x7b2cf332, 0x2d25c4df, 0x815a7fb0, 0x528b3271, 0x2e980395, 0xc44d6476,
	0xbf7918f8, 0xe96e6960, 0xd352dc01, 0xcfa4959c, 0x09932295, 0x96e50f91,
	0xb958f118, 0xaa094794, 0xfed4a4fc, 0x1c53faaa, 0xa9f2aa39, 0xe554c3b9,
	0xce69dc72, 0x237aaa51, 0xf1b3bbe3, 0xe0eb073c, 0xc33fa7ef, 0xb11f0fdf,
	0xc38df0e3, 0xd9e33f20, 0xc95de99b, 0xc67ca2ad, 0xc43ee5cb, 0xd3c01747,
	0x89d50a04, 0xfe1efb92, 0x39a67629, 0x7eeed42f, 0x71cb80fa, 0x4b85e719,
	0xbd22139c, 0x6bdb2c87, 0x37c009cf, 0x39be441f, 0x76d9d5f2, 0x1d6ed3f4,
	0xc63a75f3, 0x503ede9f, 0x44887e7d, 0x43fbbd37, 0xf43efc71, 0x6e96a29e,
	0xd047bb18, 0x1c674f21, 0xaef1f7e2, 0x15fdaf94, 0x0bd91af9, 0x88bf62bc,
	0x1bdf6354, 0xfefe7269, 0xbd47b40e, 0x491bc7a7, 0xab24f7bd, 0x20fadff1,
	0x9b65b3bd, 0xa44b4dee, 0x87d45eef, 0xefbd85eb, 0xdec281c5, 0xdef7bb5e,
	0x3960c2b4, 0xaaa9f35b, 0x595bbb3e, 0xcbafcaaf, 0x2fefe752, 0x3eda1f5d,
	0xfd563e92, 0x679362e8, 0x55abde04, 0x6e9efec2, 0x05127cef, 0x82bdd85f,
	0xbdf1ecf8, 0xb377e92b, 0xa1ebf5b5, 0x5653b43f, 0x92b39047, 0xf3d5cd3f,
	0xe5b5c9f7, 0x54540daf, 0xb574abbf, 0x6010fbc6, 0xbf94f14f, 0xc3f7f2e1,
	0x28531e7e, 0xe3101c9d, 0x81ec7d9e, 0xe01dfe1f, 0x3f277676, 0xe38d9d57,
	0xfb6f2372, 0xa41d3a17, 0x7d39a323, 0x3a03d9e5, 0x355d4794, 0x3fbc5e31,
	0x46d2b0d1, 0xb323af71, 0xc964ffbb, 0xe068fd07, 0x00589fd9, 0x4bc67fcf,
	0xb8f221a8, 0x90590f0b, 0xce2ff3ff, 0xc3663c90, 0xd5d19c79, 0x419fe75a,
	0x5ab92337, 0x42c5f9c6, 0xaf213fa4, 0x86abec18, 0xfcaf597b, 0x7082fe42,
	0x477338a1, 0x867feff7, 0x39b7d176, 0xc23b40bf, 0x5c07d23c, 0xa17db556,
	0xe85bbf8d, 0xd513efe0, 0xf891ef88, 0xadfdaac7, 0x5e5f3c26, 0x8ff1fe6d,
	0x775ee281, 0x68713e64, 0x61b1e02a, 0xd157bf27, 0x1fb831d3, 0x5a1be10b,
	0xaa3c35f8, 0xfffdfda3, 0x8dc7d501, 0x00800021, 0x00000000, 0x00088b1f,
	0x00000000, 0x58b5ff00, 0xd554700d, 0xdf6f3e15, 0x926c85fe, 0x23640fcd,
	0xd5ddbc24, 0xaf242110, 0x12489bf9, 0xa942125d, 0x48a0dd5a, 0x513ea2c6,
	0x9adfc811, 0xcda28da0, 0x83bf2ba3, 0xf8aad535, 0x945a2e37, 0x234d6819,
	0xb824193a, 0x3ac15194, 0xd420feba, 0xd5359866, 0x4d924a18, 0x9d4e2b51,
	0xfbdce7a1, 0x042fbb1e, 0x861b4eab, 0xef7b9c9c, 0xef9cf7bb, 0xee73dcfc,
	0x73f83399, 0x3ed8c019, 0x10a85171, 0x79e3cc00, 0xce01730d, 0xeb00e368,
	0x3891ca00, 0x0d304df3, 0x7f89dda0, 0xbe6b484b, 0x48650c5e, 0x0200cdfb,
	0x0a982d8e, 0x4eff1390, 0x4c9b6da7, 0xf9c69520, 0x56dbf717, 0x2fb41c86,
	0x4e62fdb0, 0xf71437f6, 0xbf31957f, 0x2475d390, 0x73f37407, 0x8fcf3c61,
	0xc015ccf2, 0x41e78592, 0x40ef2083, 0xbb3fa472, 0x0a915216, 0xd84a9610,
	0x2bdad716, 0xdbe1ae00, 0x3203b8d1, 0x81570ff0, 0x0c59ce99, 0x2a6bee5c,
	0x808df2ff, 0x5fe92ddf, 0x004a1172, 0x7e59ed1f, 0xb35387c4, 0xaa002f25,
	0x0b5414b0, 0xba7df888, 0xe503b73f, 0x6e144abc, 0x3f1217f2, 0xf9e0223e,
	0x85926a47, 0xbff6c0a0, 0xf5d7f69f, 0xe7f1623a, 0x0b5e9806, 0x0805439c,
	0x78b66f89, 0x3c5cf926, 0x819ab8e2, 0x19cfd1d6, 0xecab7e91, 0xdef17afc,
	0x016457f9, 0x4e065a9c, 0xb57bca1b, 0x1e403e08, 0x7685b35e, 0xfc7d49b8,
	0x55c412fb, 0x9c906488, 0xd5c5a553, 0xdd94e212, 0x67301bf9, 0x7686e026,
	0xedc4a7f4, 0xae78e3a2, 0xd5b9fa1c, 0x77ea1f11, 0xdb20a76a, 0x9655b470,
	0x6b7fb4ac, 0x9647c9f5, 0x11adf9e2, 0x9e501651, 0x8e077de5, 0x5d3d7e11,
	0x10be603d, 0x8fabb7a0, 0x4776e5d1, 0x7a622c58, 0xc80b460d, 0x6bd302b8,
	0x3d33c6b5, 0xb8f9f1dd, 0x4df813de, 0xbcb39196, 0x54c9e007, 0xca1275ff,
	0x2fbee6b7, 0x69252c8e, 0x0fa75637, 0x6bee01cd, 0x17f2e333, 0x281c015b,
	0xe48ef8ff, 0x1cecb3d0, 0xb88ad7f4, 0x9fd89ebf, 0xe703b47f, 0x6165bc4f,
	0xe6b07aee, 0x91bbb1b1, 0x9923b35f, 0x03227ce1, 0x7f9a1cd4, 0xc5485676,
	0xc69bb705, 0xf7083a07, 0x077914de, 0xf4fe7fce, 0x91bb5dac, 0x22ebb55f,
	0xdb6cc499, 0x788d7e86, 0x0c8b9e7f, 0xc394bf8d, 0x3f1703be, 0x9f9d8577,
	0xf730be2b, 0x7f9a6ac1, 0x73a65321, 0x3f0dfb74, 0xc403e49d, 0x17082beb,
	0x4ef5d139, 0x0990ea0a, 0xed326e37, 0x5fa02e3e, 0xbf2ab42e, 0x7eaebb24,
	0x551f4fe2, 0x2f753ea1, 0x4bb1fcfc, 0x1f55be50, 0x27da054c, 0x471e576e,
	0xf579daed, 0x51a9b7e2, 0xfb53d7f4, 0x185069bc, 0x6769a7c7, 0xbb53f392,
	0x6ffe2b86, 0xf03749e9, 0xce397d6d, 0x7ce20b4f, 0xa18c7013, 0x3e933059,
	0x355c5acd, 0x48fb949b, 0x328816ae, 0xadc440ff, 0xa22557e4, 0x307ca3e0,
	0xe18d80fe, 0x1ecfd13f, 0x2fcc4c91, 0xf4a04d9b, 0x64949c60, 0x7145dd82,
	0x62fc70ab, 0x767acc0f, 0x07f3620b, 0xfb8f4329, 0x1373c5fc, 0xf5a073fd,
	0x6dcff255, 0x239fe636, 0x72e2c049, 0xa5db39e2, 0x0afdf674, 0x1e2c97fb,
	0xced6f1f4, 0x10be46d3, 0x4aef947c, 0x1de95282, 0xbb343b48, 0xdffe5d04,
	0xeeadbf93, 0x6f2bedf9, 0xba9f3c33, 0xf73a63eb, 0x0fd98390, 0xc7b8e6de,
	0x3d246804, 0xd856fdf4, 0x4a5cc1c7, 0xf2676ef2, 0x8f43e3ea, 0x70522d1f,
	0xe797a1ff, 0xf3fa0114, 0xf4323172, 0x9633e224, 0x16be3912, 0xf7a1ef69,
	0x738e29a7, 0x3cee6de5, 0xf9d3f6c5, 0xa1e78111, 0xc703d266, 0x5eff1e43,
	0xcf39c589, 0xe65b830f, 0xc5eafc32, 0x7fb234c2, 0xbe5184ec, 0xfbea7289,
	0xfbe9f2eb, 0x910eebeb, 0x518f50bd, 0x0328a46b, 0x93cfafc7, 0xa68d7a0c,
	0x1dd28a46, 0xebe4ee34, 0xf04f9032, 0x13fa46b7, 0xc768dbed, 0x35f28dbc,
	0x10720a36, 0x794ab8d8, 0xc1586913, 0x5ed766f9, 0xdbf0370d, 0x68978fd1,
	0x9959067e, 0x05aeefcc, 0xb44bd7ee, 0xf43d7dbc, 0xe5e30058, 0x9ddd6998,
	0x91bff456, 0x4a2d879e, 0x3f55de62, 0xf3999d36, 0x5aaef3c3, 0xbf94050b,
	0xd50e9d47, 0x40798c54, 0x1443cc12, 0x4b90b91f, 0x0e5e70eb, 0xbda81fa3,
	0xf2883936, 0x8ff2633c, 0xd6cdfe12, 0x81c51170, 0x2633ddfe, 0x088f8d85,
	0x7b20af6f, 0x445c3983, 0x6e963879, 0xe90d2105, 0x43e23954, 0x80afd43c,
	0x059895e5, 0xdcf17b1a, 0xa0533ab2, 0x87cf11d7, 0x9b2cfe7a, 0x6b88e383,
	0xf1eb8d0d, 0x56537e8a, 0xd71f5c6c, 0x716fc8c7, 0xcb2bb8f3, 0x267a0534,
	0xda999789, 0x447a107c, 0x1efccf1e, 0x0770d2ad, 0x5f9489f0, 0x55be355a,
	0x54b1f3cb, 0x3ea22abb, 0x2ed0fb55, 0xc39957c8, 0x16628807, 0xefb44e80,
	0xfdf3083c, 0x9cf98cfa, 0xec6590ee, 0xeec39e5e, 0xb99a79e5, 0x20010837,
	0xfee9dabb, 0x8845ba42, 0x852f4488, 0xe07d4671, 0x33451334, 0xfc00ba30,
	0x00842e8c, 0x9ba08ba3, 0x87a1cbd1, 0xc2212bd1, 0x070ecc28, 0xf707dd81,
	0x3ef0873a, 0x6edd9f86, 0x6cb97ba2, 0x8b260429, 0xf7375a8f, 0x81e3f3fb,
	0xc7e2be59, 0x1410b1e3, 0x7ceb9317, 0x6028ccb8, 0x62e3af7e, 0xefc4ff23,
	0x22e42092, 0xb651035a, 0xc8e465cf, 0x907ccfb8, 0x81d7c4cc, 0xdff5f18f,
	0xa8ca8f13, 0x270a5662, 0x726ea5c1, 0xc342b93f, 0x596118e5, 0xea97b71e,
	0xdbaf1896, 0x8b93330d, 0xed7383ee, 0x67247909, 0x17ed7259, 0x958ca612,
	0x337e5dee, 0xd2b2d1e6, 0xf22f0eda, 0x957f6f77, 0x2fb555f3, 0xeb5f9079,
	0x717ce7ee, 0xc645a96d, 0xefd8542a, 0x1dbc805f, 0xe2127f93, 0xa8457a24,
	0xa524aa44, 0x9dc60116, 0x33af744d, 0xd6d95c63, 0x4a33cb02, 0xd5844012,
	0x1465e8b3, 0x7ebc8d27, 0x76e4e35d, 0x96556adb, 0xb31ee9bb, 0xc4255387,
	0xfabacd7f, 0x372fba6c, 0x9ffef95a, 0xbce6954c, 0xf0daba8a, 0x5c497b3c,
	0x93579c4f, 0x520a8f90, 0x7e3ba747, 0x2f38f7fe, 0xb9e75df0, 0x6e9dca5d,
	0xf9ec17c4, 0xae9ff640, 0xbdbde7dd, 0xa26cb255, 0xfcec9df3, 0x477e4a68,
	0xe1dd4e27, 0x3eb4abf2, 0x4efdc296, 0x3d4cbb25, 0xf6e5dd3f, 0x9fce8afd,
	0xf75b1e38, 0xca612bf5, 0x20a19f43, 0xdcefcfb8, 0xd75a7aca, 0x95e68a66,
	0x9d7ebda2, 0x7e4adc7c, 0x80b1fba2, 0xfa865bc6, 0xb2107d07, 0x76a8f8b2,
	0xbcc7ad9e, 0xdd8838f1, 0x2e21fb86, 0x9d7f7e65, 0x1a2ba705, 0x56890703,
	0x3875dd2a, 0xc43ce743, 0x57c711ce, 0xa58c5f90, 0x8cfd607f, 0xee0ce9c5,
	0xeafe5a8f, 0xed787fdf, 0x21face74, 0xf6db0e21, 0xbfaff37f, 0x4edbbda1,
	0x5e5a6439, 0x0ef1efb5, 0xf8f407ea, 0x90d06ac3, 0x9c78f45f, 0x8b0b67d7,
	0xb7c5dd6c, 0x0f9afad1, 0xa794bc06, 0x06881b2f, 0xf58e5ca9, 0xe3ce9d1f,
	0xbfe3af42, 0x7dcc7e16, 0x52522f52, 0x65ecbac7, 0xbd436431, 0xd0bea9da,
	0x73fec278, 0x1a4dfa3b, 0x7239f7ad, 0x9a95af50, 0x5f872d5e, 0x825f52b7,
	0xefa4a8db, 0x95fe4d2a, 0x2572dd4f, 0x42ab8bd5, 0x803df896, 0x42069bff,
	0xa6ee481b, 0xca71c69d, 0x9b7fa498, 0xd5337df6, 0xfbaa5e6b, 0x60daeb8c,
	0x7f293feb, 0xc719f5b5, 0x64a7775f, 0xf76abb31, 0xe675681f, 0xd21adaed,
	0x3ffac1cf, 0xba86c86b, 0x21dd3fb5, 0x75cf893b, 0x9edf2cc8, 0x58fccf5e,
	0x654f0f5f, 0xe3d11f32, 0x6026d576, 0x638eb3f5, 0x1f36f3f1, 0xf9f8a3d9,
	0x6317566c, 0x11eacf3d, 0xefcc27cc, 0x0113118b, 0xf4c5eefd, 0xcf098f71,
	0x40bfb179, 0x6f7b7aa6, 0x7efe0f97, 0xbd3e5c61, 0x7717afde, 0x8fa959d7,
	0x28fb15ba, 0xfc3f6a1c, 0x7c8ed05c, 0x15a066fb, 0x1a415a28, 0x87e54dd5,
	0x3ed10844, 0x1ab87a10, 0xcb4538a9, 0xefac2e27, 0x9248f013, 0x509480a6,
	0xdaf8eb1f, 0x1725bb34, 0x53e61864, 0xdf0c0be4, 0x8c7a55a7, 0x48beabdf,
	0x73e50561, 0x6fba7dfe, 0x507d61b6, 0xf261c808, 0xc3fe2899, 0x8c1ad575,
	0x57958e35, 0x8b994e12, 0x37eb0c4a, 0x443c2ea6, 0xa5fd5dfe, 0x041f8279,
	0xaabbf244, 0x6813c028, 0xc6237997, 0xbb0ff2f9, 0x4fcf1521, 0x6ea130fa,
	0xa055bf60, 0x1926c5ba, 0xf41eedc7, 0x19b80a0b, 0x2fd12330, 0xbf73b8e2,
	0x626c353f, 0x1701517e, 0x465d563e, 0x24205b38, 0x29db8b9d, 0x61deb4a2,
	0xef317165, 0xf94c8770, 0x88dfaa68, 0x11a3767f, 0x88c51cff, 0x4695f4f7,
	0x460373bc, 0x1a7667bc, 0x46ab75f1, 0xe69bbcfc, 0xd45fd619, 0x67e06b5d,
	0xb0dcbb6d, 0x62d0e2fe, 0xe7673f03, 0x73f586f5, 0xe61b967b, 0x1b56fb8b,
	0x9b3f75e6, 0x093f07e8, 0x33f04fb7, 0xec129813, 0xf759dbaf, 0xf743d283,
	0x7ff9ce18, 0x47917fdb, 0xfd9a0bcb, 0x03d5aa7f, 0x6f0ea4ef, 0x2abd70a5,
	0xb3b5e799, 0x16d509ef, 0x2bbdafd6, 0xd0a5d665, 0xf37eed5a, 0x1c1bf76b,
	0x2779ccda, 0x7c88e5e7, 0xc959f290, 0xc91d7f31, 0x1c0d1655, 0x62a13544,
	0x8d2ebbb8, 0x7240fbd6, 0x4e4fe34e, 0x4aeafeb4, 0xb886cc01, 0x1c5a7e42,
	0x75d46bcf, 0xae2e1a62, 0x641436fa, 0xbe8296e9, 0x241efe22, 0xa2fbf254,
	0xe60497c1, 0x2a6a5c04, 0x90a47bf5, 0xbf8eabf9, 0xfd847efe, 0x1fa95800,
	0x4143d930, 0x8ef564f7, 0xf5644dbc, 0xb3eac298, 0xbd850537, 0x8f6b5d2b,
	0x777e51e4, 0x1eed2b67, 0x24cc6dc4, 0x139eac4b, 0x2a5241a2, 0x4bb18a46,
	0x1f06d2eb, 0xced871f5, 0x0f0005c2, 0xd41aaa99, 0x33be2642, 0x66dbc15a,
	0x28f2e9fa, 0xdf783d6b, 0x0dce0a0c, 0x3bedf8a5, 0xd1e64ef3, 0x111365fd,
	0x3f7a1289, 0xf347ddf1, 0xb24ddf67, 0xb7cc3f51, 0x12a49351, 0x023dea14,
	0xd24e43eb, 0xc4249766, 0xbb0b26ef, 0xcbeb40b7, 0xd2f0d06e, 0xda65b2fb,
	0xc5b883f9, 0x37e7cc4a, 0x70c9bdf4, 0x688d7269, 0xd90150ef, 0x32dffb89,
	0x7d4251c3, 0x654af829, 0x7debcfde, 0x87f174da, 0x5f7aabdc, 0x4df5be7b,
	0xbf4361ae, 0x2733bb0c, 0xf89c8f7d, 0x9bd715ee, 0x39b83fef, 0x8343dd99,
	0xfbd9739b, 0x31ff7c62, 0x810dffb6, 0x727e0cf7, 0x0d5fe753, 0xfab377fe,
	0x9a3e6189, 0x8e996e35, 0xc95f47fa, 0xc40bf859, 0x5b65f46f, 0x68abf505,
	0x424f5eb7, 0x607d1d3f, 0xef3a02d6, 0x0ff9ebbf, 0x5740ef86, 0xe9bbbd84,
	0x3aef1e7a, 0x5768f8c6, 0x7a89d194, 0x4eadfdea, 0x02867fad, 0x85c797aa,
	0xef64f229, 0x797a9735, 0x7f303fbd, 0xc7dd2d5a, 0x3356b903, 0xcf9cf9a7,
	0x7e73b4a9, 0x31a222e1, 0xf513638b, 0xf80203b7, 0x6587f404, 0x9bc7f482,
	0x4f7fdf71, 0x3f25de53, 0x5e3d5b6f, 0x6878c664, 0x28de8e2b, 0xa7d73da0,
	0xfe93ef2b, 0x39831602, 0x7cce4c19, 0x4d861bea, 0xb980916a, 0x4db9fd20,
	0x277a660d, 0xd18ea29b, 0xbde49d8d, 0x81fa81bf, 0x8f8f2b61, 0x83736f1c,
	0x701c7a8a, 0xffcc032a, 0xfc98624d, 0x842bdd56, 0x8b7f3076, 0xc4a7175a,
	0x6bdfd1f5, 0xfea6dfa8, 0xe9c49626, 0xe9811ea7, 0xf2d119f9, 0xc3d6fd38,
	0x978e5af3, 0x6b717ad3, 0xdec590be, 0x02e2809f, 0x1d51f3cf, 0xefe7eea2,
	0x0750d3b2, 0x7ab06baa, 0xc942fd63, 0xe530b66b, 0xe75dfd0f, 0xcecdc7b4,
	0xf7f2f2c9, 0x6d07ac9a, 0xdfbb20a1, 0x280d7923, 0xeb05b767, 0x3e1bea1d,
	0x368ef604, 0x0961ef4a, 0xe1ed3976, 0x0adc3a7d, 0xb7b3e7c0, 0xe1cb7cd3,
	0x4f94e3c1, 0xc3251e42, 0x2a9070cb, 0xa4b49f28, 0xdef5601e, 0xcfddf0ff,
	0xd8b7fb4e, 0xd53ebca3, 0x87cefdde, 0x916de8cf, 0x3bd90b47, 0x72479c97,
	0x72e972e8, 0x72e8b8ea, 0x6ef9f7c6, 0xafdfd7ff, 0xf1e87e74, 0x4f14f98d,
	0x577f3f88, 0x169b8514, 0xb97df24f, 0xe835db97, 0xfe744bf2, 0xdf7f00ea,
	0xf747fb8b, 0x3e531f5d, 0xf960ec3c, 0x4fdf7cf0, 0xff65b3d4, 0xea078661,
	0x97e92379, 0xa25167a0, 0x47fda39e, 0x7e942d1f, 0xdcb17ebc, 0x8d6f7b08,
	0x4f26ff6d, 0xf65befc2, 0xfc8c79bd, 0x777f45ab, 0x4f7c63df, 0x3ec14db0,
	0xf7b26335, 0x1265bc72, 0xfe9b2fea, 0xf1b30cfd, 0xde81547b, 0xae28fba3,
	0x7bc14ea9, 0xbf41fc97, 0xfd68f777, 0x837d108b, 0x8f3a7de5, 0xa0837efc,
	0x7f4ffbb2, 0x780a08af, 0x956d91bf, 0x881f760e, 0xf9321d33, 0xc1f41eed,
	0xd9bbf908, 0xa9decc97, 0xafcbf427, 0x08eb955b, 0xd5ef35bf, 0xdd3f5366,
	0x5ae5d6fb, 0xa3efc65f, 0xcb2fcd72, 0xbf927ce9, 0x6bf98d30, 0x855f2699,
	0x0f1eeb1d, 0xe45576a5, 0x3bda12ef, 0x0c37e6c7, 0x007fdcfd, 0x9e7336ce,
	0x00001b00
};

static const u32 usem_int_table_data_e1[] = {
	0x00088b1f, 0x00000000, 0x51fbff00, 0x03f0c0cf, 0x18140b8a, 0x18d57c18,
	0x19d57218, 0x23aa1e18, 0x0f8969c4, 0xdfa65173, 0xc181859c, 0x81ad8812,
	0xdf8816d8, 0xbc303231, 0x7f5e2467, 0xbd8208a3, 0xa181805f, 0x076fc809,
	0x0c4229d2, 0x7640e90c, 0x055f1033, 0xf1023ff2, 0x2d3e205f, 0x2a20c0cc,
	0x0c60c0c8, 0xdc4032c4, 0xfcdf8222, 0xa6f20256, 0x44fca8c2, 0x10afbe34,
	0x840bfd7e, 0x23afcbf1, 0xfb0d8f20, 0x1f1f926a, 0x3bd02893, 0x1e43b810,
	0x964b7f95, 0x1cb9e181, 0x02818303, 0x2489df84, 0xbb1404ef, 0x6f610b2d,
	0x38606714, 0x92eb9403, 0x26ee6ec7, 0xa059fca0, 0x1cd41f9c, 0xc9488100,
	0x00036836, 0x00000000
};

static const u32 usem_pram_data_e1[] = {
	0x00088b1f, 0x00000000, 0x7de5ff00, 0xd554780b, 0xb3dae8b9, 0x24999ef7,
	0x42499333, 0x49af0842, 0x701a8802, 0xb15e1008, 0x9441024c, 0x420a03a8,
	0x84089c45, 0xd112f210, 0x03b39f43, 0x4f6950f2, 0x0f52d62c, 0x89e0a0ea,
	0x0201b41e, 0x60e8188d, 0xda2d43c0, 0x3eb01160, 0xd5e4013a, 0xd1500c90,
	0xd77af4b6, 0x67b5afff, 0x4899def6, 0xedce78f4, 0xfcfc77bd, 0xf7af6b16,
	0xfaff5eff, 0x4e648ad7, 0x21226425, 0xa68fc25f, 0xc8424407, 0x59da68e8,
	0x8451d348, 0x81ac9728, 0xc121022d, 0x4d3f7fbd, 0xa172117a, 0x92cba671,
	0x25c14849, 0xe422706b, 0x0b010503, 0xf3b49f2d, 0xeb44877d, 0x2514ee57,
	0x8ded3728, 0x1b1df6c3, 0xabe40085, 0x9d3fad2d, 0x9de1f340, 0x76817922,
	0x1336824d, 0xb4e42349, 0xcb9fb095, 0x38d2f98e, 0xb4dcad96, 0x578c1e6f,
	0x712164d6, 0x46e9fdb4, 0xa5f903d1, 0xa100845b, 0xbebe55e3, 0xfb419cc6,
	0x1a10145b, 0xbf345ce2, 0xcbb349e5, 0xbd8ac84e, 0x36423a1f, 0xadfbce42,
	0x75c665c4, 0x10e43594, 0x36d81e52, 0x2fb68325, 0x4db82adf, 0x8df2ffb4,
	0x7e603b17, 0x60f28de5, 0xa4b7f691, 0x86b8813e, 0x24bfb1b2, 0x49cb5e30,
	0x3ca76f1c, 0xbb2bc608, 0x889990fa, 0x03d94eb0, 0x3ce92aed, 0xb8eadd60,
	0x701bfde7, 0x959e153c, 0x68f1d32f, 0x04d7aabd, 0xcab12c37, 0x8f307c44,
	0x66e3d78e, 0xf58368bf, 0xd8879ad5, 0xd928ebb5, 0x0f28eb05, 0xb14f326c,
	0x9936fcc1, 0xfda2734b, 0x37ffa92d, 0x6436fcfd, 0xca69f6f7, 0x3f79e98d,
	0x6890e905, 0x4f109cbe, 0x4897ed03, 0x61f4f301, 0x091fefd1, 0x25ef8849,
	0x597122f5, 0xcc53fda3, 0x44494213, 0x93fe9f79, 0x63d941c2, 0x8cc96c0f,
	0x13a96de2, 0xdbc51670, 0xa3c72725, 0xf6d3ce14, 0x053fa6af, 0xd4f9d07c,
	0xfe989df9, 0xe98e9fcc, 0xc2177e53, 0x50ff69ed, 0xddf8374c, 0xff19fdf8,
	0xfa374c58, 0xe73e983d, 0xc0698a9f, 0x2f7ac5ef, 0xba6367f8, 0xefc3efd9,
	0x30cbf92f, 0xe0d7f7ad, 0xcbfc57f7, 0x57eadd31, 0xfe6bfbf0, 0xf83698b5,
	0x0edd30eb, 0xa369a2f8, 0x76f5803f, 0x6d31ebf9, 0xf7e037f2, 0x4c26fedd,
	0x3a3871d7, 0x448149f2, 0x10f0e0e1, 0x493b4527, 0xc814f62e, 0x65ec9f34,
	0x4ab9b4f9, 0xd3e69981, 0xe14f347c, 0x2c115192, 0x467cd0b0, 0xf01f2b0d,
	0xa5685243, 0x2b0a01f9, 0x29e75acf, 0xacf9a38c, 0x643e563a, 0x4f1852a3,
	0xac0243f3, 0xc1ad86fc, 0xbf9a04c2, 0x0f9581a1, 0x6c93266f, 0xc83c3f34,
	0x3c87b9f2, 0x9f34ec93, 0x79f2cadb, 0x1c93291f, 0x62179f34, 0x07b7c7ed,
	0x2bad9744, 0xaecbb61e, 0x6ae284f9, 0x47ab72a3, 0x66f3471a, 0x4dc443d7,
	0xf0cca3e1, 0x3c287d48, 0x07960f64, 0xbcb17b95, 0xf2c1ecd1, 0x980594f7,
	0xb0fb25df, 0xc95294fc, 0x961f66f2, 0xc11e515f, 0x60ac937c, 0xcfd6b5b9,
	0xcb0566f2, 0x62d76a33, 0x00e5bbff, 0x3ed4e796, 0xcdbbe589, 0xd9ff2c01,
	0x2678cfa3, 0xc14afcd3, 0x23d034f7, 0x3648cb4d, 0xba4353d0, 0x6ad3d297,
	0xfa06cc81, 0x1d1031fd, 0x7dd5cba5, 0xdb87c8cc, 0x117bc9df, 0xbd7f17f8,
	0xd2fa5f20, 0xfed899e3, 0xa647ec79, 0xeed788fd, 0xb1ddf727, 0xdf727eba,
	0xa9fb532d, 0xe32b7a87, 0xf6cfd67a, 0xe7ebc777, 0xdab96ef3, 0x8f9c36cf,
	0xcaeb67bd, 0x7ebe7dfd, 0x50afbf3e, 0xf38dd9fb, 0x7cd9ea49, 0xc3d7df1a,
	0x08fdf1a7, 0x3e705a7c, 0xcf9b3da9, 0xf87aa3a8, 0x811a3a8c, 0xa7ec21cf,
	0x69facf4f, 0x4f87aa3c, 0x7c08d1e3, 0xf575c7de, 0x46bad9ef, 0x67c3d31d,
	0x7c08b1d4, 0x64f9c13e, 0x5d9facf6, 0xb3e1eb1f, 0x7c08e3eb, 0x833f60ce,
	0xbcaeb67b, 0xc9f0f44f, 0x9f0224fb, 0x7d73f630, 0xf5d9facf, 0xbb3e1e89,
	0xe7c0893e, 0xb0cfd8af, 0xef2bad9e, 0xe4f87a4f, 0x1f0229fd, 0x8cfd0093,
	0x9a7cd9e8, 0xa7c3d53e, 0x7c08d3e9, 0xd19fb012, 0xd8cf9b3d, 0x8cf87ad3,
	0x4f811d3d, 0x3ef0012f, 0x34fd67ae, 0xa7c3d69d, 0x3e0474e9, 0x9b9fb1fd,
	0xb1aeb67b, 0x19f0f467, 0x9f02267b, 0x02aeb821, 0x1f30f7ca, 0x77b1fb42,
	0x0beecfdf, 0xbeecf87a, 0x4dcf8110, 0xed114fd8, 0xfddafb27, 0xc3d0ef8c,
	0x04477c67, 0x9fb1633e, 0xcfd67b5b, 0x7c3d0eee, 0xe0447776, 0xb9f08053,
	0x1aeb67bd, 0xcf87a9df, 0x9f064ef8, 0x266a4791, 0xd5396839, 0x36916e85,
	0xf1eed099, 0x3a2f3408, 0xba745e59, 0xa225d809, 0x56906f6a, 0xdbdb488f,
	0x3ee526b6, 0x4776b44e, 0x975874e1, 0x5a635a9d, 0x6c7123bb, 0x49cecebc,
	0xf2eb24f2, 0x74335329, 0x59bd53f5, 0xb3def2ba, 0xf795d06f, 0xf2eae5f1,
	0xebc6cb7d, 0x29aff7ea, 0x2e07e5d4, 0x3f574dbf, 0xcba19953, 0xaefdaf67,
	0xbae0feae, 0xd7e57407, 0x95d7286d, 0xaa581f5f, 0xff58dfcb, 0x61fd5d7d,
	0xe5742b0d, 0xae3d3537, 0xfc111f2b, 0xf23f2e99, 0xfaba33e0, 0xd05f5ba3,
	0xfe398f95, 0x5c7cae8a, 0x3f2ebb68, 0x836eece1, 0x9e73679d, 0x45e791be,
	0xecc27ba0, 0xb4663efe, 0x337682f7, 0x3619cde6, 0xd9f7e3b4, 0x28a75d4b,
	0xce6fcd7e, 0xf8a2f577, 0xaa129c05, 0xca320bd7, 0xefd10bae, 0x5df78c8f,
	0x1fdfa4e7, 0x726efb31, 0x294fb0c6, 0x1d24083d, 0x52099752, 0x991af963,
	0xdf6163d1, 0x68da43ab, 0x78536afb, 0xf7cd1248, 0x00360b13, 0x98273efd,
	0x45e34e90, 0xe2f50352, 0x05f7042d, 0x5ef3326b, 0xbaf43454, 0x43e53fb6,
	0x5aefda21, 0x760e97d9, 0x87b50bc6, 0x5643b015, 0xcaeba7f7, 0xe145e420,
	0x44195070, 0x4d2ff7db, 0x2cfed1f7, 0x6ba76a66, 0xf1d337c7, 0x7afc7073,
	0x6eb5ff18, 0x8d64b7c6, 0x1d6f8dd5, 0xdf1ba650, 0x3be3a66a, 0xfb503da9,
	0x229f1f01, 0x3b213c61, 0x7c700f84, 0x1c3280cb, 0xee998d7f, 0xc7e3b457,
	0x026fc647, 0xe30bd97e, 0xfeb18e8f, 0xf5faf1ac, 0xafd7280f, 0xffd6ccdf,
	0x1f1b6d66, 0xdfd71e3f, 0xf5b1b422, 0xeb67280f, 0x237eb0b7, 0xf0223be3,
	0x7feb083f, 0x67f5bbb7, 0x3fd7ebe7, 0x7ebf42b0, 0xbdff1b0b, 0x7c7c73da,
	0x07ff8e1b, 0xff5b1ce1, 0xdf1c0ac0, 0x81b9f16c, 0xe37dcc7e, 0x7c74026b,
	0xa60a8fd2, 0x742e40de, 0x2687481c, 0xe426a253, 0xce164227, 0x467891e3,
	0x29e2576f, 0x51bca1bd, 0x50093bf0, 0xf74796c9, 0x97d69c5d, 0x83302d6c,
	0xba72c25c, 0xa7c8595f, 0x4449a0ba, 0x594f26fa, 0x7ce98302, 0x05449a3b,
	0xba9e0bf2, 0xaff20039, 0xf7ee42da, 0x04893b42, 0x3fa7fbe1, 0x7682f61f,
	0x6174c65d, 0xa43a7c9d, 0x3ec8b7e1, 0xad0c90aa, 0x022bf3a1, 0xcd1d1822,
	0x20fba09f, 0x1f17f742, 0xa1067dd1, 0x66527924, 0xf7427de3, 0xd10f904b,
	0x139412fd, 0x88ed8b52, 0x107f79e2, 0xa897bf9d, 0xf3ae0f3f, 0xda29641e,
	0xf7f8c49f, 0x00213ac4, 0x797fb8f8, 0x747e0502, 0x8a4a253e, 0x87d74f2e,
	0x0ab7c3f5, 0xec041781, 0x99f007c3, 0x3023fbce, 0xed9f9a5f, 0x518e6d64,
	0x28a1f7f4, 0x2fb6bf98, 0x9fb445c5, 0xee4788bb, 0x5ccfdb4d, 0x13132256,
	0x7fd0b970, 0x7ccfd029, 0x01196e99, 0xc92a4a7e, 0xe741c4e1, 0xeb275dfb,
	0x3e47ba7f, 0x67ccd215, 0x78f56cb6, 0x97667ce9, 0xbbff3888, 0xffcbeaa6,
	0x63c137b8, 0xb5d34e1a, 0x999c71eb, 0x3df97d5e, 0x39f9f5b3, 0xea9e7d3e,
	0xdef4193d, 0xefc665bd, 0x9d742c14, 0xa5702373, 0xbcf3a513, 0xbee1c38f,
	0xe1d1591a, 0x6aadb615, 0x7c143839, 0xed85d704, 0xeff5aec5, 0x97cfae5f,
	0xfcfcfa28, 0x39fe86b5, 0xf8e69cdd, 0x41f4013f, 0x1f4033d3, 0x38a79e14,
	0xaae5447d, 0x45663e9e, 0x43e8c196, 0x8969c75d, 0x46f4e0a1, 0xeb0b1f46,
	0x43d36212, 0x3c1e8449, 0xe952fa5a, 0x87a71e61, 0x2c3d398f, 0xaba7a0da,
	0x2ab02439, 0x77bfb69d, 0xd3c43edd, 0xd184a151, 0x7a540fc3, 0xc1e8e908,
	0x88c1e9c7, 0x1e9c79bf, 0xd18f7de6, 0x219f1183, 0x0da10f4e, 0xd5926597,
	0x0f14af15, 0x83c53cba, 0x334eef01, 0x47c503d0, 0x20787a4c, 0x70ba6eb2,
	0xcbcf9f9a, 0xd38be0ba, 0x01679603, 0x09c209d8, 0xad7767db, 0x2e84e54f,
	0x6c4368bf, 0x153757fc, 0xccd29ca4, 0xd6e1b2ab, 0x7a9a5394, 0xeba7ea4b,
	0x73038bf2, 0x6d17f574, 0x2f95d128, 0x2bac5bac, 0x41f6bf9f, 0xf944be5d,
	0xfdfeae9e, 0xe5756bcb, 0xa63cd5f7, 0xecb7bf2b, 0x8e7e5d49, 0xfaba97ef,
	0xa4deccf7, 0x7de99f2b, 0xd77e5759, 0xfcba6dd4, 0xbaebcf74, 0xd7bda6fa,
	0x98f409df, 0x6024547f, 0xbbf29c7f, 0xfb4fee90, 0xd67a6287, 0x38be46ef,
	0xe98b1fef, 0xf596a6a1, 0xcf956813, 0x0913b3c2, 0x24a59fd3, 0x2b2d9089,
	0xf36bb5bc, 0xd4139f41, 0x98af2fbb, 0xa3f4ab55, 0x42e4c0d2, 0x306f1738,
	0x4248e093, 0x7c4a5004, 0x2d18b0fc, 0xf2d10fcf, 0x8bcbee94, 0xcb314837,
	0xcc5243f3, 0x567fab7e, 0xc319d032, 0x67e5133f, 0xa3ec17d2, 0x1b9f6e4e,
	0xe2042bcb, 0x64277ed5, 0x45fff205, 0xcc2b9fae, 0x6c544e4c, 0x1c4853ef,
	0xa90e0f90, 0x1af1aaf9, 0x06f57328, 0xf1d6c8fa, 0x370da2f1, 0x013ce4ea,
	0xd02a6def, 0xf7dd48d9, 0x7413f525, 0x89f7daed, 0x902aef38, 0x7d40e321,
	0xa04d5b7a, 0x032d8397, 0xf3061aee, 0x81361cf4, 0x454a6abc, 0x3fddb1fb,
	0x0494e535, 0x7a62f478, 0xd31b3fd6, 0xa61f7ed3, 0x9865fca7, 0x60d7f09e,
	0xc72ff21a, 0x82bf13f4, 0xb5fe47e9, 0x5fd1fe98, 0xff71e987, 0xfa8f4c06,
	0xf11e9803, 0x9efa63d7, 0x56d301bf, 0x1da6137f, 0x2aa60f7e, 0x30f0a9bf,
	0xae59ddd2, 0xfd03cfa7, 0x5d9d057d, 0xed4bfd36, 0x3a517eda, 0x8fc57cfb,
	0x68fc956a, 0x2c1bc5bf, 0x74d24e9c, 0x40bff0f4, 0x7a068c87, 0x897a70b1,
	0x41bc5e5d, 0xfcf2cafe, 0xffb31c90, 0x7bfe17ea, 0x89b46de8, 0x94dfa3d9,
	0xd4f4a2de, 0xd94f40d7, 0x0ca7a2d7, 0x9e947471, 0x4c9c9b46, 0x7a7a71ff,
	0x6311d602, 0x180b71ff, 0xbb1aa975, 0xfcc093ce, 0x81dcfcd9, 0x9fccb45a,
	0x495ec7cd, 0xfda2b6eb, 0x780a1817, 0x6ff434be, 0x7f5fc043, 0x945538e9,
	0xcfafdd99, 0xc3dd2f48, 0xa0fb83dd, 0xa25500d2, 0xc796bb23, 0xc6b833c5,
	0x9254c899, 0x8363c84b, 0x903f725f, 0x24897983, 0x7b80fb43, 0xbf463dba,
	0xf806a6d4, 0x2bae0b5e, 0x438657ed, 0xf99fa77f, 0xa3a41e7b, 0x8eaecc4d,
	0xbed1116f, 0xdd17c127, 0x3e88df00, 0xc1d3b8b2, 0x6c1e1e0f, 0x107da276,
	0xa7e1e9b0, 0x145e7cd0, 0x18518f7e, 0xafbea2b5, 0x0df8474b, 0x4fa432ba,
	0x2d77e00f, 0x782d7f39, 0xf8c8103e, 0xb5e7816f, 0xe4b5e3e4, 0x5eb8f122,
	0xefeba26b, 0xf72c3bdc, 0xc1c81771, 0xeb9fb62c, 0xf9eade06, 0x2b3e7195,
	0xd16be944, 0x4a9a6771, 0x0803adc7, 0xf024e71d, 0xa97f6d0b, 0xbf263af1,
	0xa76fbb54, 0xbc13d025, 0xf7d4c85e, 0xbfa1b0f7, 0x745f074b, 0x696b7ec0,
	0x2a79c9ba, 0xb4d41e06, 0x69d321b2, 0x4d9fdad3, 0x3aa5fcfa, 0xda036a61,
	0xbbc4ae89, 0x709e8187, 0x020d4f3a, 0xa98e9db9, 0x74d2cfda, 0x9514f3b3,
	0xb3ebe77b, 0x2f3ed913, 0xd6c1e4c0, 0xe7179424, 0xffac56fd, 0xbba7cf6d,
	0x10f9d47e, 0x5a4e48d2, 0xb2d31e41, 0x77ebeeec, 0x5fd2cf4b, 0x24c7e0cc,
	0xb015f2cd, 0xfff4ad0f, 0x13d6412f, 0xbf6af309, 0x62a20dd5, 0x6fbe09b9,
	0xdb478dd5, 0xd633d4b9, 0x8abeb32f, 0x5a72246f, 0x2faa5ba5, 0x308f83f6,
	0xce37e815, 0x933fb7a9, 0xa6eaf974, 0x3d9d4e3e, 0xf2a0ff0a, 0x1208d497,
	0x27054fd0, 0xb6c94e9f, 0x7bf3a056, 0x40849c1e, 0x57ab02b7, 0x7d990d69,
	0x6657382e, 0x7e6eeb78, 0x25d37f14, 0xd665f24a, 0x2d873c3a, 0x327eb86b,
	0x8d0b99e8, 0x6fc0d32b, 0xf4bc44b0, 0xfb463788, 0x8fde414f, 0xc394be06,
	0xd39efb7a, 0xaafda107, 0x4a2fd1df, 0xf935a76c, 0xc7f31376, 0xc2bdfb18,
	0xe0b5c8f5, 0xf0f5b553, 0x8c13b014, 0xba6aaa70, 0x5ca1f668, 0x45e5ffa4,
	0xefc2a4e1, 0x057bd179, 0x7d795bf4, 0xce2dfa1b, 0x1f90caca, 0xecbc857c,
	0xfa5b3eba, 0xbacd04e9, 0xe30ad214, 0x0f96303c, 0x7cf75c44, 0xb9f8e548,
	0xe404c9df, 0x6b4ab910, 0x9b01e669, 0x745e535a, 0xe340f3bf, 0xf7806292,
	0x51efd839, 0x7880b9b9, 0x5207881d, 0x9bfb0797, 0x1534c40b, 0xbc8174e0,
	0xc1a918e7, 0x46648643, 0xcffdd338, 0xe8fced09, 0xa79747fe, 0xbe5d1ffb,
	0x8348cc94, 0xa7d28278, 0x70101264, 0x78f2ba7d, 0x2efd89c9, 0xc1ab3522,
	0x86fd51ae, 0xd489380f, 0xf2afce97, 0x95e6cfd7, 0x4a6479d0, 0xcf513ecc,
	0xb32717c3, 0x6c3797f9, 0xf9687b32, 0xb391c6c9, 0xeda684a8, 0x3e21ab03,
	0xb829d940, 0xc2bab8b7, 0xdfceebf7, 0x5ed55f38, 0xcf2e72ea, 0x2f5951e7,
	0xe8310278, 0xd18926ec, 0x260faa99, 0xfeab75f2, 0xfc8669a3, 0xf8d7903d,
	0xca1be69b, 0xf73f31bf, 0x7e7e3a22, 0x934df45e, 0xc2ff1952, 0xc29058fe,
	0xb8dfcf48, 0xfd2ef4ff, 0xfe8d23df, 0xa7effb16, 0xffda33e7, 0xfe756ffc,
	0xbfccba83, 0x95ff563a, 0x97757ebf, 0xf979e542, 0x20ee7eaf, 0x2738ced4,
	0x29b9a5d5, 0xacb62bfe, 0x9c1d0072, 0xd0071495, 0x3880b9f3, 0x9e431035,
	0x2e04916d, 0x01363cb7, 0x4ff09bfc, 0x57f9ffda, 0xf403b89e, 0xb22d95f7,
	0xf596fd13, 0xf285a096, 0xe2e3556b, 0xf31c3262, 0xe6bf2c6d, 0x26f908a2,
	0xff967d3d, 0x20d3cffb, 0x4a52858e, 0xe7fa135f, 0xa81fb883, 0x14e9fcda,
	0x24d5efd0, 0x6c667c8c, 0x917fe307, 0xc4a7fa8c, 0x1cb5d89c, 0xd069211d,
	0x1baafd9e, 0x3a28b89f, 0xf4215fe0, 0x97eb18bb, 0x69fefb71, 0xe50bdec9,
	0x063218d7, 0x0f0a97e4, 0xfdf66012, 0x317f97ca, 0xa7ce8dbc, 0x1ceff37d,
	0x2a4e0682, 0x986a5d9f, 0x576efcff, 0x83b2f2f7, 0x8ed6a1f2, 0xab81f554,
	0x9a4bef89, 0x07215a59, 0x5ca8131d, 0xbb24d8a8, 0xe2b9fa15, 0x7a5f17d5,
	0x1fc5fc06, 0x6983dc58, 0x3d5e4bff, 0xcd3c7470, 0xf726d92f, 0xb0cb662a,
	0xbc516909, 0x97ffd354, 0x50f146e7, 0xd980e3be, 0xff7d8c35, 0x1f147261,
	0x33edb64b, 0xe15d6193, 0x9f61a931, 0x818b6439, 0x29b68697, 0x7cad6760,
	0xb83373f9, 0x15edced0, 0x18ccef48, 0x0074dcf0, 0x138030ed, 0x29e391e2,
	0xfd433782, 0x90178a6a, 0x8c9e2ae7, 0x3cb9cbe5, 0x395cfe81, 0xedafcf48,
	0xfd97e3a6, 0xf586e2d1, 0x90f6bd97, 0x4671d603, 0xfd7461aa, 0x0f34aaec,
	0x564cb71d, 0xb2989cd2, 0x3dcf65ef, 0xe8b6f48c, 0xcc69c3f0, 0x63e9e80f,
	0xf4a4dd42, 0xdc2df581, 0x57d71338, 0x77487c4a, 0x5e8acf65, 0x499f8f90,
	0x18b6ea64, 0x6657d17c, 0x0bccf272, 0xeba590d4, 0x6ffb033b, 0x89efe790,
	0xc846bf18, 0x7c67e883, 0x5a85af98, 0xccff9868, 0x4974f0ca, 0x4b397132,
	0xbd2d75ad, 0x0ad35e6e, 0xdfdf39f8, 0xb3ce1bd3, 0x70a489aa, 0xd25f0878,
	0x45c3c57e, 0x887e19bd, 0xede3ca4b, 0x09359da8, 0x56fd43be, 0x5c3713d9,
	0x997c8ed7, 0x197f1d19, 0x3bce9f1f, 0x33a3ec1e, 0xfdedb169, 0x0f55645b,
	0xa1ae3d50, 0x337f0d2f, 0x18fcdf7e, 0xdf956fe3, 0x42a7d303, 0x308e5ff9,
	0xa07681fe, 0x82bce91f, 0xdf7cb1bd, 0x03ca02dd, 0xe2c6090b, 0xe732cdeb,
	0x4ab97d6b, 0x92de7427, 0x17a1a890, 0xe1193fe8, 0xe953768f, 0x469db453,
	0x78c3565e, 0xa9fdae8e, 0xf388bb7c, 0xe7ac9a7f, 0xf191b27f, 0xabf6f77d,
	0x725efcc2, 0x8067a5e0, 0x2a7f295f, 0xd957e02e, 0xf3feeb0b, 0xdfa396d6,
	0xe7fa7ca5, 0xf54f9506, 0xa7c8d3f2, 0x261fdb65, 0x3e469f40, 0x1abf73fd,
	0xe94f9312, 0xda7c98f7, 0x2a3ff42f, 0x7df8553f, 0x553f00c7, 0x4707761e,
	0x50fc3ca3, 0x8794c572, 0xe48477f4, 0x953fa575, 0x2b7a54ee, 0x81ca8fff,
	0x74227720, 0x845dd2a9, 0x33ba552e, 0x3f0f57ae, 0x2655b963, 0xebef6788,
	0x2b57ee32, 0x261c599a, 0xdf56f76d, 0x0f270851, 0xf75231aa, 0xda5edf56,
	0x6f90c07c, 0x18f7d430, 0x7d435ef2, 0xa35f219f, 0xd4d15fab, 0xff882662,
	0xb89eaea0, 0x327219fc, 0x06bd1625, 0x8dd5be10, 0xd00acd17, 0xed8c2d85,
	0x814415e5, 0x1ef0beb8, 0x9de1f711, 0xc1abc614, 0x3335b05f, 0xb1b950a0,
	0xf7ed8e2a, 0xd5e6a9c3, 0x9d3ae720, 0xe4324761, 0xdbfd98e3, 0x923b0de9,
	0x5b647634, 0x3a7288b3, 0x63532014, 0x06a863ed, 0x48867841, 0x5cece577,
	0x0db448a9, 0x9b7e0e58, 0xae0dd13a, 0xf7b50582, 0xa75ce038, 0xcefb39b3,
	0xc2fbf4d9, 0x56188adf, 0x18ef19d2, 0x8a22f30e, 0xd9a3ea47, 0xca259c3f,
	0x3d74f9d3, 0x3ed99bf3, 0x833ac162, 0x21d641fd, 0x96da94fd, 0x527e4199,
	0xfe84ffbb, 0x41f1843c, 0x6cafef39, 0x6d5cbea3, 0xfb8ef14f, 0xfacdf2e5,
	0x6fdf1f72, 0x62f9526e, 0xf7c11904, 0xc1cfcc7b, 0x989170e5, 0x0a6ce773,
	0x2283ceff, 0xa5fcd0b1, 0x7fe11166, 0x0010ab69, 0x5251157f, 0x48aabf91,
	0x0a9fe518, 0x1fe076a7, 0xa9f2f773, 0x79c7e77d, 0xd93a003f, 0x7ff0e1f5,
	0xaefb69a3, 0x01bc860f, 0x1b1f5ff9, 0x5ae921f0, 0x38ded27f, 0xdcef573c,
	0xeefa476b, 0x80cef3dc, 0x75fe401f, 0xd9e61b8b, 0xe1f3f7b9, 0x2b9d2f40,
	0xdf20652c, 0x7f33fb3a, 0x9f3dcae7, 0x3ea10f0f, 0x76f1147d, 0xaffb6648,
	0xff7fcd4b, 0x2905e844, 0x09d8155d, 0x7f90137b, 0x61c777aa, 0x9ee7753c,
	0xb67cf3cf, 0x553d6f6f, 0xd3a28e3c, 0x876f664e, 0x38b125f9, 0xc637ea81,
	0xc74b58bd, 0x67dc6caf, 0x27cb4f9e, 0xc31fe6fd, 0x6e766e41, 0x874ff667,
	0xe20e7a1c, 0x1fc98e04, 0xbe2990ac, 0x3289803a, 0x9cc87908, 0xa4f80931,
	0x81fe5c2b, 0xc29ea7fe, 0x1affe3a3, 0x261e0878, 0xab01ecdf, 0xebfeeb00,
	0xdfa21f27, 0xa97482d0, 0x0dcff7ae, 0x5c9f68b5, 0xb376dd6b, 0xfee7f999,
	0x10b7599f, 0x73bac9ec, 0xbdd7c9fe, 0xfce1765d, 0x95d07c8c, 0x823cf7ce,
	0x6eed57f9, 0xe90f6f9c, 0x7c9ff8bd, 0xef1b5ffd, 0x1dde29db, 0x92f75ed7,
	0x7775f27f, 0xcedff78f, 0xe27778e3, 0xfcdf99bd, 0x75f7e703, 0xe613dce5,
	0xd7396e7f, 0x3b55fadd, 0xb6f262de, 0xcdf9d016, 0x30767526, 0x5ea4e62c,
	0x89a1043a, 0xe97ffe96, 0x0d95f305, 0xda6a91e7, 0x11fe666c, 0xe9c1ce19,
	0xc0a664b8, 0xdf6c7ff7, 0x1fb70774, 0x8a57e8ee, 0x1e1deb76, 0xc913d766,
	0x05182deb, 0xdc0b7871, 0xb9250fe8, 0x9f907dc7, 0xebcf3379, 0x0aef8ff7,
	0xbb5023c4, 0x53018efd, 0x7b1d820f, 0x68293f67, 0xa41b6961, 0xf7f83bef,
	0xce7dfab1, 0x7f3e9f1c, 0x7e7d6ccf, 0x166fef26, 0xfc745718, 0x00215e59,
	0xffb94ffe, 0x0fe0a953, 0x44ca1795, 0xa71e2010, 0x27ec1566, 0xedf57a66,
	0x57bec037, 0x67ec2fe3, 0x0ba010f3, 0x93a1db99, 0xef966e6d, 0x6e7825e7,
	0xa950edc4, 0x39288797, 0xc5ddf8d1, 0x3834df56, 0x150eb0bf, 0xae778e10,
	0x590e5113, 0x979c0473, 0xf18cac77, 0xbc9a9fa0, 0xe29f8079, 0xbeaa6391,
	0x06e1a6cf, 0x70e62d38, 0x6835252e, 0x5fab9127, 0x079f997e, 0x768262fe,
	0x210f62d6, 0x40fdd3b7, 0x8c10be69, 0x48bcfca7, 0x2e624a22, 0x720551f8,
	0xd547e742, 0x9df7e1e7, 0xd73f68b4, 0x1d1ddfaa, 0x9fe9db7f, 0x189cdf28,
	0x3f6ded44, 0xcc23c18f, 0xdbeea81f, 0x70666fee, 0x0210aeac, 0x418f4859,
	0x3f39abd9, 0xfb61631a, 0x70fd3ffb, 0xc163f224, 0x644b0ebf, 0x6841c9fb,
	0x7eab569f, 0x0895c50a, 0xcd4b93fe, 0x6d9cfcd9, 0x8317c392, 0xfdf30e0f,
	0x4e201fdc, 0x939da68c, 0xf6113a85, 0x7e8c240b, 0x1c726542, 0x8e2312d9,
	0xc4c5b7b1, 0xb8358bfd, 0x989f84bf, 0xbf647807, 0x6269b445, 0xeb6f06b2,
	0x0d273f6e, 0xf8078aef, 0x279cd09d, 0x0be157fd, 0xeb8047fb, 0x14d0b8e1,
	0x5ef58c6f, 0xfc57e1cf, 0x3ef15fe6, 0x4ce68cde, 0x6332e019, 0x7f3ba8b2,
	0xfb70b4cd, 0x0919247f, 0xf37e2af3, 0xc038c756, 0x0dd141cb, 0x9baaeff7,
	0x317d9a2f, 0xf08cf5ce, 0xfcf1fe84, 0x02977640, 0x24fe4f3c, 0xecfec08e,
	0x945e7e1d, 0x39eff103, 0x80f02ae8, 0xc2d72abf, 0x2c6b4bfc, 0x5def844e,
	0x2a7205c5, 0xd1a7371d, 0xc48e0239, 0x35fd7832, 0x4346eca0, 0xa76b0630,
	0x60a8cbd6, 0xceccdaf5, 0xdfeb58aa, 0x79f8156b, 0xb191fb88, 0xde1f3fc2,
	0x1ed5fe0a, 0x343d042c, 0x1bafdd59, 0x7f209ae9, 0x042a9a5c, 0xbec04f40,
	0xecc5f30b, 0x263be7be, 0x60ccae56, 0x7ba55cf2, 0xe7ef9c23, 0xef8eabf4,
	0xc05f70e7, 0xb38543e9, 0x7ce35f0a, 0x5e54fad5, 0x39fad44d, 0xf11a6cee,
	0xaad1e81a, 0xa269c166, 0x2149555d, 0x7561f033, 0xf83293d3, 0x58b8e7f1,
	0x0c8f54bf, 0xaf0b9ed7, 0x9f3848b1, 0xf309dc96, 0xaf2e4e80, 0x6d0cf6a3,
	0xd17059ef, 0x1df87201, 0x70f7fb93, 0x5779562f, 0x42be5b24, 0x77e87d5e,
	0xd25936de, 0xf3899bf6, 0x40a2abbc, 0xbdccb706, 0xdee4fb15, 0x635a7a1a,
	0xf572c649, 0x2b85467b, 0xf1d3be17, 0x4fca1e70, 0xfbe2042d, 0xf15a1a73,
	0x35bde19e, 0xcb0e8c49, 0x3199f61a, 0xd5f5899f, 0x8c71d4f1, 0xb17774fc,
	0xfe747e3e, 0x803f50a4, 0xb825b14b, 0x4e831dcc, 0xfc46b06f, 0x4f4f5f98,
	0x0edd2878, 0x4f48ffff, 0x44f5532c, 0xd595e308, 0xeaba97f6, 0xf4b1de89,
	0x575ad2c4, 0xd2c3c06f, 0x81bdd93d, 0xb6fe9649, 0x9e962d28, 0xcecfdf78,
	0xfbf18f23, 0x53779db9, 0x4693713d, 0x871ddc4f, 0xf76c6274, 0xd727ca91,
	0xde2a13d2, 0xcde587fe, 0x6227a0fb, 0x41a777f0, 0x2e6acc4f, 0xeb313d41,
	0xbf7f516e, 0xdc04f41a, 0x4f56e98b, 0xc1cda414, 0x884eecbc, 0x73ef3f41,
	0x8f18fa3b, 0x407186d3, 0x3ab60c5f, 0xdea37c71, 0xbfae4ee8, 0xfeb953dd,
	0xaace087f, 0x933a5f5c, 0x4aeff3dd, 0x79e90487, 0xd72a1ce9, 0x2647a005,
	0xc7de97d7, 0x390669fd, 0x3b3905eb, 0x59672b4a, 0xd31f2afb, 0x994dd50b,
	0xcb4b98bf, 0xbb275bbf, 0x77feb4ad, 0x4f3772a3, 0x5b07772b, 0x17547c59,
	0xe4c65bb9, 0x91e6e5ee, 0xb7753f68, 0xbcb98fbe, 0x906cf2a5, 0xcc7d063b,
	0xbba09b9e, 0xc4727547, 0x00ece67f, 0xc447797e, 0xb94fc173, 0xc468701d,
	0x7b028e7f, 0xe995857a, 0x3e383b81, 0xb6e4fc3b, 0x4c0e54c9, 0xe9ecc05a,
	0xc222adca, 0xf191aaaf, 0xf8a0d57f, 0xa7e68b80, 0xcf15fee4, 0x61ec96f7,
	0x05747be7, 0xfc1a05c5, 0xb427792f, 0x4bcdfc1a, 0x3e780936, 0x00e87109,
	0x9e1c45cf, 0xb825eea5, 0x27c631cf, 0x4ad4fea8, 0xf3716f5e, 0x1abbf426,
	0x072a16e3, 0xf60e76dd, 0x8616c523, 0x421de287, 0x9c265360, 0xb9ea1b93,
	0x8973c31f, 0x79c306ca, 0x42ef5f22, 0x03b39831, 0x17bf63f6, 0x5cf4b1dd,
	0x652e11b5, 0x1cb845ff, 0xf51970a6, 0xee970fdf, 0x7bed40e0, 0xe11b43f4,
	0xdb95a0f1, 0x1464b99f, 0x26a7e1f0, 0xe515ca0f, 0x4ee3116d, 0x58393c16,
	0x9f83aef7, 0x4c77cbeb, 0xa07dd5be, 0x4f8b155e, 0xdb71b459, 0x9f9a3481,
	0x804640db, 0x06d17b1b, 0xe88e1ebd, 0xea1746fd, 0xdb35b9f5, 0x5c738804,
	0x956defc8, 0xf7c49e05, 0x4e5bee30, 0x3fad3cf5, 0x83e2d73f, 0x71c3d5f3,
	0x2a9b9461, 0xf9c6bedd, 0xcfc72b68, 0x64f08cc9, 0x824d4fd4, 0x1831f913,
	0xc515f4c7, 0xd1d3bc13, 0x29f3ee32, 0x7fcc2f1c, 0x58f0c4d1, 0xfc06f14d,
	0xe799a53c, 0x781d99eb, 0x106f9aaf, 0xe4012e02, 0xbd993eea, 0x149021fb,
	0xa3412381, 0xaedce11f, 0xe7834d20, 0xfe8c6d3d, 0xfc6e08b7, 0x7dffa010,
	0x4b773c13, 0xe98eccf7, 0x70abbd29, 0xf5cacd7a, 0xe1f3c707, 0x91e2d6b8,
	0xb823ae78, 0xe693fdf1, 0x388f3c24, 0xf1dec755, 0x3678e668, 0x3bec05f2,
	0x4c8aefb4, 0x9c438987, 0x8c38d4ea, 0xb371c3f3, 0x95a65d98, 0x707b914f,
	0x71bafd3c, 0x15a4d52d, 0x3c68b1ed, 0x05826f9a, 0x055385f6, 0x16271f49,
	0x16ff3a46, 0x4962bffa, 0x927fbeed, 0xd3f8c4ee, 0x77ea9c87, 0xc35fbb27,
	0xf3fd2df3, 0xf0a5cd8e, 0x7456bcbd, 0x1eea16c3, 0x3e68eb93, 0x65c79bc8,
	0xf972fc02, 0x7a61ec90, 0x4ef50120, 0xf1273bc9, 0x8b09525e, 0x3f25226d,
	0x24e5fa62, 0xa91fcf9f, 0x2f80f6de, 0x868c3485, 0x76ee4cf7, 0x81722bef,
	0xe1d465bf, 0x769e7055, 0xd1e724d7, 0xc7cf80a3, 0x27367bd8, 0x7dc24ed6,
	0x0a0f43da, 0x29c76fc8, 0xccfda0de, 0x1e8f33bb, 0xb7dee3a5, 0xc7cf1536,
	0x67527ae6, 0xdcd979c1, 0x45dba243, 0xd3bfcdeb, 0xb2f3836e, 0xe2454369,
	0x3ee7c0d3, 0x9dfe8ad2, 0xce0f35b9, 0x51977984, 0x4266287d, 0x37a8b87a,
	0xd80a37e4, 0x99f15abe, 0xeb5ddee1, 0x51e68b86, 0x5a52fc74, 0xbd5ec00f,
	0xdeabd591, 0x8421b82c, 0x49f9b4b7, 0x9ba59794, 0xa4307c05, 0x56bfda95,
	0x4ac06fd6, 0x48dd6dfb, 0x22fcd3db, 0x6efd0f68, 0xe7059a4e, 0x9e74d560,
	0x2d6c7ed8, 0xd296779e, 0xb498b476, 0xfb107e6e, 0x2051bc5b, 0x6cabcf70,
	0xc74fe66c, 0x64877f42, 0xdb1f9437, 0xcc334bf7, 0xaf1d1e7b, 0xbe7fed0f,
	0x7f422a18, 0x27040fdc, 0x1b6323be, 0x84ebf88c, 0x23834305, 0x05cf8cd9,
	0x92b7dea2, 0xb30e71b4, 0x749c58e2, 0xd5daf2e9, 0x9290aeb0, 0xba42699a,
	0x3d0668ba, 0xdbc28a7e, 0x93d7ed47, 0xd13f1666, 0x87349ca2, 0xa1f47234,
	0xbf6c6cb8, 0xcf00a9a0, 0x2f1217e3, 0x6afbc79e, 0xb6d23d99, 0x80202e2a,
	0x073b261d, 0x5596f7c0, 0xf1defc16, 0x1d3fd32a, 0x47e843fd, 0x2651b33d,
	0xe56d0f70, 0x01a7ecc6, 0xcab6678f, 0xb3e26f48, 0xd17a3cec, 0xd64fccab,
	0x7bf591b2, 0xbd999966, 0x34e5048f, 0x7565e8bf, 0x6397abff, 0x9472aea5,
	0xd4b94653, 0xa9f0ae25, 0x6c90335a, 0x6cb57917, 0x72abca0a, 0xd08077aa,
	0x7eabc8ba, 0xd9cfd1ab, 0x9b133f45, 0x21728faa, 0xb2a4a52e, 0x400dbcff,
	0xc0b1f7c7, 0xebe0d6ef, 0xf41cfd9f, 0xc09d856e, 0xf9c92a97, 0x82e8c0b4,
	0x6dccbf00, 0xf019f6de, 0x38dcd941, 0x34e9577c, 0x66f801e0, 0x939e0a5d,
	0x104a0696, 0xe69c6ade, 0x3a7a0da2, 0x738ffd57, 0x68f1227c, 0x025957f5,
	0x1dea68f1, 0x57a511fb, 0x4dfdce3a, 0x804e2042, 0x0f5bdb7c, 0x13bcc28f,
	0xdb9cb5e7, 0x48eceb07, 0x77bec7cf, 0xebd01571, 0x040a1fbc, 0xf8a275ec,
	0xac3e8356, 0xc0b820da, 0x87e8bb9f, 0xda22fdac, 0xec7de61e, 0x28ae8c97,
	0xfe80bb7d, 0xf93e36ab, 0x2cdfd616, 0x63ffa0b8, 0x9ed04a9b, 0x82445328,
	0x70db9be5, 0x14f540ff, 0x28b52fc6, 0x7fd01a62, 0x2716a3d5, 0x1d2a4a98,
	0xc6d974a9, 0xd58953e3, 0xda2efc3d, 0x9526132e, 0xc51e95da, 0x9f4442d9,
	0x2b549d02, 0x5edace8c, 0x3640dd95, 0x764ba6d7, 0xd70cf99f, 0x33b3e2af,
	0x8b7dc0a7, 0x023f5445, 0x9c6cb69d, 0xe23b0664, 0x73c0404c, 0x4974aefc,
	0x4a3b5a6c, 0x0567cba5, 0x15afaf26, 0xee85dae7, 0xf4aa5d38, 0xf71a8947,
	0x64871595, 0x8da8f702, 0x1b93e8f4, 0x419c4166, 0x3d746bc9, 0x5693be74,
	0x75ed0f7f, 0x9f348e15, 0x8952f906, 0xfca893c5, 0xb8b12950, 0x3f3dafa3,
	0xe293f8c3, 0x107e51ec, 0x904c5c59, 0x5b9ffb8e, 0xbc38c45f, 0xddb4af0b,
	0x1bcdf681, 0xfe000e94, 0x8824ed5b, 0xca008ffb, 0xd146f2a1, 0x528a7183,
	0xcd2eef30, 0xb38d5dbe, 0x3b2bf258, 0xbb7cbbc2, 0xdb4c5025, 0x393aef97,
	0x57bdcf1c, 0x446e3184, 0xfb404579, 0xe1a12898, 0x5ca40f70, 0x461ef162,
	0x1c6f60bb, 0xbfb77fdb, 0xec1b309e, 0xbd9ea136, 0x70de5697, 0xf8d16c8f,
	0xc9c67775, 0x873c3d6a, 0xe19e2851, 0x4fcc3b9e, 0x1a974efb, 0x32fed1e7,
	0x26f2bfa3, 0xf2b9ed19, 0x101d6dfa, 0xdc7e57df, 0xeadcfb82, 0xaf188bfa,
	0xaf57e93c, 0xd56b3be2, 0xbe2ea24d, 0x555c4bab, 0x22e788bd, 0x18958d55,
	0x78f341f7, 0x10d5523e, 0x5af0be3b, 0x7e4b3ff1, 0x429767b5, 0xc764b841,
	0xddf03bbf, 0x0e2dd6b5, 0xff52bfbc, 0x5d8d71d5, 0x1e1aa8e2, 0xaa38cafb,
	0x4a0ff0f3, 0xb8e26758, 0xa1c6a71d, 0x46b933d5, 0x8de797e7, 0xd88e27e1,
	0xf67eaf5b, 0xb6f9c41c, 0x73f3ff6f, 0xff8adf30, 0x8839f975, 0x7388a0df,
	0xfd523d82, 0x2718fbca, 0xe213b6a9, 0xe5e7fef9, 0xd2f8c77f, 0x6e2c0f8e,
	0xcf63ade8, 0x6f600199, 0x6bfb6c74, 0x2e8dc41a, 0xfe8453db, 0x273b659c,
	0xfc3126f5, 0x740a6a05, 0x7c41e81b, 0x2d5f11ab, 0x67182d8d, 0x1be28172,
	0x2e2443e4, 0xc592a1ae, 0x3c78ba19, 0x71d8d6dc, 0xdfe25dc4, 0xf3baef1a,
	0x8d8b9066, 0x66b82ecc, 0x8a11dc1c, 0x807a9bc7, 0x718fadbf, 0x7f1b1279,
	0x141fe017, 0xf5e3034f, 0x359f7071, 0x19fe7c2e, 0xe94c6b28, 0xd82e0e36,
	0x71a9b803, 0x9e71edca, 0xbf81e21b, 0xc607ffb6, 0x8ade021d, 0x3f9f205d,
	0xe17e001b, 0xfd1872b3, 0x163de10f, 0xbe572fbc, 0x4ff218e7, 0x18c3cec7,
	0xbc784c07, 0xfc890770, 0xf7277c58, 0xb66f54f5, 0x0e39f8b3, 0x73af887f,
	0x8f3bf039, 0xac7463a3, 0x1775d7c6, 0x9f125757, 0x60c5dfc5, 0x9b957ff1,
	0x6af1e43f, 0x63097c51, 0x5f6d4f01, 0xc2a8af19, 0x187009c1, 0x8d138da3,
	0x8918bf1d, 0x02f8e627, 0x8e9c81fc, 0x7cd281c4, 0x0c0b883f, 0x0c48c708,
	0x89b1d079, 0xc87697c5, 0xaaa5efb1, 0xe373a371, 0xe81a7c0d, 0xb5e8bc59,
	0xe175ffe6, 0x0bbc7b73, 0xa9c235fb, 0x396c6afd, 0xff7ce7ee, 0x541def8d,
	0x0d7bc608, 0x7b878e3f, 0x666d8d13, 0xdd42977c, 0xb6f5f13f, 0xfb5a7f73,
	0x13c6222b, 0x41686eae, 0x17946e39, 0xc49cfc55, 0xf927df38, 0x989aab7c,
	0x6edf689e, 0x3f68d80f, 0x8ebe6fed, 0xb5b55cf4, 0xdf19e30d, 0x0e61dfaa,
	0x4197ce69, 0xf334044f, 0xdf6d7f6f, 0xfcdb9470, 0x38e3289d, 0xfdb3c7cf,
	0xec737570, 0x5eb7aa71, 0x44b38dd4, 0x6d3b3069, 0xbcef1ed7, 0xfa07b9e4,
	0xeccadf3b, 0xe20df3a5, 0x6ef758d4, 0xfccbc456, 0xa58eb41c, 0x7be25f54,
	0x3ef67659, 0x4788e896, 0x7d996bfb, 0x5ec4f1ec, 0xbe319a90, 0x8f2d6562,
	0x3b91f8c7, 0xd2bdf01d, 0xf9811b7e, 0x6af802ae, 0xd3b2f1f6, 0x936ec047,
	0xb4a3bdd3, 0xfcea2ce7, 0x244cbdcd, 0x32ffc1a0, 0xb0ded4fb, 0xd29224ff,
	0x4771e60f, 0xe812e7d6, 0xf33f56bf, 0x27ab93df, 0x56f7c107, 0x852079c9,
	0x593adbf6, 0xb5eb8370, 0x7407dd2b, 0x3dd363e7, 0x213f77fa, 0x77d61f56,
	0x7b426dc9, 0x3a0a6ed0, 0x8f621569, 0x0dc74d6b, 0xa4b88bac, 0xc7b10c34,
	0xfdc7f738, 0x41a4bbd6, 0x352eb284, 0x5b9ea14f, 0x9163bdd2, 0xbc325638,
	0x0c8e416b, 0xe36af4a2, 0xe5faaaf4, 0xb4dfecec, 0x97be10df, 0x6a439491,
	0xd9d77c81, 0xac37687d, 0xd08cefe7, 0x838850df, 0x6ef12648, 0x743c3bed,
	0x1dfbdd5c, 0x3e5d5c74, 0xa7cfa3c9, 0xc54e954c, 0x7c292fd2, 0x1b44531e,
	0xc8a921c2, 0x8ad7eea4, 0xe745a707, 0xdc4a949d, 0xddbf2841, 0x94e67186,
	0x3aed14bd, 0xbcfd366c, 0x7274fce9, 0xa4273122, 0x753cd898, 0x25c49ddf,
	0xfa3dfae0, 0xbabe74ef, 0x7954dffc, 0xe4091127, 0x4adacd9d, 0xe92ffc38,
	0x74a8fde0, 0xe01a7fa8, 0xb57df087, 0x429ee042, 0x1d075f22, 0x09df575f,
	0xbe3601de, 0xcfd21fbe, 0x784fbda9, 0x2d7fd713, 0x0484de09, 0x0379a7ca,
	0x3800306b, 0xe0e49d3f, 0x5ee6d7bd, 0x96b29f28, 0x89dc6217, 0x6ae8c750,
	0x7c823ad0, 0xe2cc2833, 0xf1a3c85b, 0xac5a8f68, 0x85cb8944, 0x9144527b,
	0x00946173, 0x0ad73fe7, 0x5a4aed13, 0xb68d694b, 0x9a170e6b, 0x34245216,
	0xdfed1140, 0x80c9e09a, 0xf74f57f1, 0xc0469ba5, 0xed56a7c7, 0x7b5c87ef,
	0x4d04783d, 0x0703fac2, 0x40a1666f, 0xc5031ef0, 0xbfd001c8, 0x093c9175,
	0xbaed7dc2, 0x63de48f8, 0x2ebef2a5, 0x2687e58b, 0xef055fac, 0x7a24b486,
	0xc438c287, 0xcf01bcea, 0xb8c982bb, 0x17e96bfe, 0x37439e75, 0x8fc4a687,
	0x78537e62, 0x3db0759f, 0xf51a7f72, 0x9a9b16f0, 0xc23ee20f, 0xe51878db,
	0x61c3655a, 0x9e41372c, 0x425303a6, 0x1126fa53, 0x2f13cb72, 0x0f5fa516,
	0xe925e3f1, 0xef4eba26, 0x901e2f13, 0xd7a87074, 0xbd3241c1, 0x4bc38064,
	0xde0e0b5f, 0x0e109784, 0xa5375d3d, 0x5e013b8b, 0xf84c0ad3, 0xe398d66e,
	0xd0aff436, 0x23ea1c5f, 0x6ea6cfde, 0xfbaad7ee, 0x3dcfda11, 0xdb52fa5a,
	0x1dd574a9, 0xe71364dd, 0x44bdec0d, 0x4dacfd3d, 0xbfa0f8f0, 0xdd8f0492,
	0xc7eb8a9e, 0x7cd3dcfb, 0x91e4f73e, 0x3626ba51, 0x7619c8df, 0xc581ff18,
	0xecbf1a09, 0x62a582b4, 0x396f9d16, 0x746a42f0, 0x95cba93d, 0x9d7421b8,
	0xc6131ea9, 0xf824b767, 0x3ce813aa, 0x41c3b31c, 0x8630b2b8, 0x620a46f8,
	0xf1d42f94, 0xfb61ef56, 0xa625d5f5, 0xde760ac0, 0x517f402b, 0xe81908fa,
	0xa3e8cc23, 0xa3e90da9, 0xd18db9aa, 0x216d5347, 0x9b9c17d0, 0x8ebf3ec1,
	0xde004784, 0x66f13d57, 0xd29fd491, 0x7578424d, 0x32174a5f, 0xc7151609,
	0xc6575c21, 0x9f9f0fc4, 0xf0eeaeba, 0xeb30775b, 0x4fd81c89, 0x79e1321e,
	0xb5370a97, 0x2c092bde, 0xdd8e72fe, 0xa8700757, 0x0b7a1b1e, 0xe0fdbf96,
	0xe1b7187b, 0x1f633438, 0x4ddc77b4, 0x8e8ae431, 0x0568775b, 0x475c83be,
	0x265d01d7, 0x7a02b092, 0x30787bbd, 0x03c089fe, 0x801c9eec, 0xcbf21b47,
	0x121efc2b, 0x5fbc3be5, 0xbd81303b, 0x0262f0ff, 0x75f9138b, 0xfcf38882,
	0x6bb30275, 0x325d0f52, 0xfaab7ec3, 0x4fd61351, 0xbb473485, 0x3b7947fe,
	0x0627cb89, 0x2a9f150f, 0x9a49513d, 0xfc48ef00, 0x90d7c938, 0x3f4b5a30,
	0x9a5909c9, 0x3f76d4fe, 0x02f713f5, 0xecc747aa, 0xd021e07f, 0x7e7e94ab,
	0x4c376ba2, 0xa9b8038e, 0x633e81f5, 0xdbb687e1, 0x1c60ed0b, 0xedb617b0,
	0x7be22a5f, 0x6bc43d08, 0x47ffbc1e, 0x9025e7eb, 0x7db4ed9a, 0x214d225e,
	0xbdf3c29f, 0x4b2fbe79, 0x9b723fb3, 0x137dfa04, 0x4d1ebbf7, 0x920171e0,
	0xc31986f3, 0xb8eccf20, 0xd478f4fc, 0xc2df2a0b, 0xb7387e5d, 0x75f9f896,
	0x04cb3856, 0x58f95378, 0x76829b0a, 0x24b2b4aa, 0x18e20997, 0x75d3f6de,
	0x9dcbdd4b, 0xf767aedb, 0xcfdf8d03, 0x637cf9f3, 0x5d2ffafb, 0x079f0dee,
	0x435a56f8, 0xf3419d3f, 0xc65fd755, 0x0915c1f3, 0xeabe1355, 0xfce302fd,
	0xc67abedf, 0xc761f601, 0xb1a99617, 0x3681ecec, 0xfd078f46, 0x1e5db1b3,
	0xf4839f7f, 0x3559e356, 0x8ca110f7, 0xca8865db, 0x768efc2c, 0x045077d6,
	0x29153e02, 0x6427da19, 0x44e1f9e2, 0xefc47dc3, 0x2f9f9904, 0x50030c0f,
	0xc0ddd712, 0xd982f9c6, 0x1ffa5649, 0xf115339c, 0x25b7b173, 0xed3b4adf,
	0xcec26def, 0x6a52f357, 0x2c4f205a, 0xa202ffac, 0xaf2d4f7f, 0x64e4dd77,
	0x133137e8, 0xac935bfd, 0x456cf286, 0xb24d3902, 0xb12e3133, 0x33ec6888,
	0xeed037a6, 0x02f3a38e, 0x686d3e39, 0x2f327b89, 0x1fff4cbf, 0x4ff72168,
	0x6e37ecd7, 0x4f71cd75, 0x752fd9d6, 0xefcbaef8, 0x1fde21fe, 0x5fe2ce2b,
	0x0f4e8c6c, 0x386ebdfa, 0xb3c2367f, 0x6a3c25d0, 0xbb857577, 0xb8468e11,
	0xc23570ab, 0xf723e0b1, 0x7018e4e4, 0x88a5c232, 0x3d050dd4, 0x08ddc2a6,
	0x8cadb797, 0xb1cede2e, 0x6f78fbe0, 0x6f8e0c4b, 0xbd923353, 0xbb41e9c7,
	0x03a548b6, 0x495bb30b, 0x49e23b6f, 0xd92773b5, 0x08d9bf99, 0xf470aed7,
	0x45a51714, 0xc016f7d7, 0xc133e80b, 0xfd0cc47d, 0xfc460e26, 0xa244e091,
	0xd3a0eb8d, 0x270477c0, 0xd2baaeb2, 0xe0866fdb, 0xbf13b37b, 0x45b9dbd0,
	0x81ce53cd, 0x7e96e09f, 0x7f828f25, 0x6dd080b4, 0x11e50b86, 0x4c8487e3,
	0xc70a53a4, 0xe37a7a13, 0x72b0a6fd, 0x797d570a, 0xe968f136, 0xdc69c8bc,
	0x41b9d7f7, 0xafd71bff, 0xe0afd9d2, 0xf0aeb8c3, 0xcaace952, 0x194efdc6,
	0xcbd81fa4, 0x951f5fc3, 0x349bf208, 0x4bf4c727, 0x8dee398c, 0x47c7c3f4,
	0x2f88163a, 0xfd99ddf2, 0x8763905f, 0xc8d496a8, 0x6fa275b1, 0x1c862da5,
	0x66e5e953, 0x899bb78e, 0x4bfc0fb2, 0x2fe91337, 0x6640fd91, 0xd84ffd74,
	0x2fa43ef8, 0xfceb0be9, 0xe98b8273, 0xc8cebe45, 0x0979a9ba, 0xf1f3e7e3,
	0xbc36adf3, 0x52c241c7, 0x59ee047b, 0x628d6ef8, 0x43ce8e4e, 0x80c9f5e6,
	0xb9ecc21a, 0x315ef8b9, 0x32f90b85, 0x808f3a21, 0xddf0904d, 0x0b8f3e16,
	0xe20556f5, 0x7d13ded8, 0xf7e06d9b, 0xc70d0e10, 0x21c149f5, 0xe58cffa0,
	0x57f69b97, 0x57ad3941, 0xfcf8f58a, 0xffcc8897, 0x0963de10, 0xbdd990bc,
	0x1ad94a9d, 0x17ca84f5, 0xf20f70f9, 0x60bbe026, 0x44f7985f, 0xdd347550,
	0xf70cb17b, 0xb94d0585, 0xe0738c12, 0xf78c14d2, 0x091e242f, 0xfd235bec,
	0x48dae91b, 0x96e831c7, 0x03c22bfb, 0x75f29f60, 0xe3b545e9, 0x44737422,
	0xbd2a374f, 0x1df9fa50, 0xa8e74fd0, 0xb3069f4f, 0x97519dfb, 0xa9ff40d3,
	0x1ed47a76, 0xf00bbcf1, 0x575eceed, 0x6d0ff4ed, 0x9ea1f7be, 0xa0f3c244,
	0x9750d67d, 0xc7dbee09, 0xe1473dd9, 0x5cbf6abb, 0xf641df6b, 0xa5310dd3,
	0x0f1c799b, 0xef82260d, 0x054b2af9, 0x91f72f94, 0xdde30cb0, 0xf6eb2357,
	0xc2e2f3b7, 0xce00fc9f, 0x43af6b0b, 0x2883e67d, 0xb3db1136, 0x5cd5e3b8,
	0x0f0d0eef, 0xbfdeb801, 0xd89edf5c, 0xa2ef74d2, 0x7db0227e, 0x50b8bcff,
	0x2dcfdc2a, 0x8df5f451, 0x30ebabe3, 0x576c6bf6, 0x6bf7626d, 0xb76a5de0,
	0xdcf86ec6, 0xc8d9ecc6, 0xefe6df7c, 0x9b78501e, 0x7cd39fc0, 0xeecdea3d,
	0x66b3e7e0, 0x779a48e4, 0x2c7b42b1, 0x3fbd63b3, 0xc2a38ea2, 0x55692e7b,
	0x8337f9e1, 0x7dd994df, 0x300fe63e, 0x9dd4153d, 0xa0e9abc7, 0xfbb464f0,
	0x68083506, 0x14345767, 0xecebe698, 0xee1fb67d, 0xbbc3ef62, 0x71bf5018,
	0x1bf7b31f, 0x50df716a, 0x3ff6c8d1, 0x3a0ce09b, 0x07244f83, 0x7d9101f7,
	0x5549c42d, 0xac83fbc2, 0xdd57083c, 0xfd58ebb3, 0xe60df609, 0xbec106c7,
	0xbb2e97d4, 0xcf27fe69, 0xfdd2b6ae, 0x124cead3, 0x69fee847, 0x9d9e4fdc,
	0xe52c6eb2, 0x008f64b2, 0xfcd23def, 0x9eb8db6a, 0xfc27a3ef, 0xf46ae364,
	0x73782427, 0x6d7d9aed, 0x0831fc77, 0xd8af8e8c, 0x7a24b6cf, 0xfe51d827,
	0x1184bf30, 0xaeac97ff, 0xc7bfa044, 0xb6fb3ef8, 0xfee00fe5, 0xabbaee21,
	0x2c1e2003, 0x16fde39f, 0xab37b33b, 0xedfdd813, 0x2ddf4587, 0x9be76fd0,
	0x1f808757, 0x27a1edf9, 0xccd6df71, 0xe43c87df, 0x493b432f, 0x3b0ce3c5,
	0xbb6fb3b3, 0xfb01c5be, 0xff47db8e, 0x5f9def01, 0x697bd890, 0x3acd63ed,
	0xad8f773b, 0x5fac0668, 0x44d8294d, 0xa3f9cb90, 0x7d071ff6, 0x887e9ddf,
	0x008f7fca, 0x3d5c9ff2, 0x3fe7869c, 0xe01c078d, 0xf7e76cbb, 0xb6342fd8,
	0xd3403da4, 0x707f6dca, 0x3e6b7ec0, 0xa905df5f, 0xa9d7df15, 0xbbe229d8,
	0xb4dc7410, 0xdcbfc17b, 0x71ef3f38, 0xab558c36, 0xd1ff72ff, 0x9ccbd7d2,
	0x87bef87e, 0x6cde0f6a, 0xbf300255, 0xfd115ae6, 0x889337bd, 0x05df139f,
	0x7a28d899, 0xed5d1ce2, 0x55d9efc3, 0xc61a72bf, 0xb2732d33, 0xcbe3ba71,
	0x49922ffc, 0x407ef340, 0x611414be, 0xa45ff9fe, 0xf06a7811, 0xf5acc1c2,
	0x226f80c5, 0xb74307bb, 0xf68fd912, 0xa23f3f27, 0x1ef0fdbf, 0xf99e5ef4,
	0xbbe5e34d, 0x3a912026, 0x0051bd1f, 0x8bd7cc3b, 0x9c990739, 0x89c4ed57,
	0xa3fde85f, 0xb0b53b46, 0x7da3c479, 0xfd9bc209, 0x59b080bd, 0xf6f4b3b5,
	0x4c4a786b, 0x279095bb, 0x77725e91, 0xf7834f66, 0x6b7f7275, 0x73b8c272,
	0x3757bd38, 0x5ff7c65e, 0x167048aa, 0x8a355794, 0x788120ce, 0x023751a1,
	0x5f7aa8bf, 0xd5d34b85, 0xf070eb16, 0x3a2ebdaf, 0xe6bd4057, 0x470e90cf,
	0xea2afefe, 0x19668ea5, 0xdea93fdf, 0xbe63a9f3, 0x68effec6, 0x74a2ef66,
	0x7fd49f36, 0x11b94a6f, 0xb1336dda, 0xb7feed7d, 0xf20096fe, 0x2f5737e6,
	0x5a7ee0a5, 0xfb06fbd5, 0x1b4f68da, 0xe62265ed, 0xabb8811f, 0x889944a2,
	0xee0ed442, 0x223ff7a2, 0x5749da8f, 0xf6085ffd, 0x0ec31884, 0xe3a670e0,
	0x4647c049, 0xe76820bb, 0x927f68f6, 0x3602ef0b, 0x82594d5d, 0x139b4cf7,
	0xefd02b9c, 0xce9decc3, 0x367fe7fd, 0x121fbe0d, 0x57033bd9, 0x37a7e445,
	0x18192ef7, 0x4a87c0d2, 0x95dfc444, 0xde3b173e, 0x1caff5a0, 0x707e6788,
	0xf6a37dc9, 0x7eb442be, 0x982bc380, 0x94d3cec1, 0xe7ef780c, 0xedb3db1b,
	0x1fe5f65d, 0xb4a91c83, 0x5880a786, 0xcdb1b21f, 0x639ff80c, 0xc989fef7,
	0x80048697, 0xfb0a428b, 0x596e3a12, 0xba04293c, 0x2712d70a, 0x3cedefc4,
	0x5e013268, 0xc4c96d46, 0xf8579b38, 0x86e2e379, 0x46a6733a, 0xe7e62d6e,
	0x65656755, 0xfbe6b240, 0x2f930742, 0x3f940f67, 0x03f7f28f, 0x431c190b,
	0x983916df, 0x5661dc9c, 0x7a856da6, 0xef784c27, 0xbb5bff67, 0x657782df,
	0x8d771f17, 0xd035fd00, 0x4d7ac2e1, 0x77c15e87, 0x223e9ae9, 0xdbcdd5e8,
	0xe89a225c, 0x17106fb8, 0x311dbff3, 0xe23a7ee1, 0x149e24b7, 0x073f6758,
	0x71becfdb, 0xdf3ba4d0, 0x7fbf837a, 0x3930776a, 0xff983a24, 0xc2c1fb6b,
	0x7307d014, 0x03b33eec, 0x6854eff8, 0xf5414c35, 0xd7f6a9d7, 0xa7db23b8,
	0x1cffa30d, 0x02726ed7, 0x5e475dba, 0xaebd6110, 0x092484b3, 0x463d8ba4,
	0x523a73fb, 0xd1bdfda3, 0xf3a3face, 0x55f81378, 0xb0783f85, 0x8dfe6873,
	0xe2192956, 0xabf854b3, 0x77c750eb, 0x26cf1035, 0x6792b21b, 0x8df857fb,
	0x91d0f8d5, 0x5bbea24e, 0x0bf9748f, 0x40e5c7bb, 0x3ed0507a, 0x1e207b3e,
	0x5c1d9ced, 0x92f4923f, 0x1c3fc881, 0x660e054f, 0xe9f3a8ef, 0x8e7cfc6e,
	0xbafd357f, 0xec8afd74, 0xf86e9052, 0x252e83fb, 0x3886cd68, 0xfc6ca6b0,
	0x389a3abb, 0xff9c7cd9, 0x737bfd59, 0x0993214d, 0xed5571ee, 0x59f09211,
	0xcbda1e93, 0x1a933a11, 0x8e9afe90, 0xf2e3e413, 0xdf9907fa, 0xfe1bca90,
	0x839e172e, 0xf3f0ff03, 0x4d023ef0, 0x5a6f35c7, 0x1be117d9, 0x455f0074,
	0x06f944e1, 0x333a9ad2, 0x65e2ebd0, 0xcfc45d2c, 0xf06f1795, 0x6e967f21,
	0xb381f164, 0x8f38991c, 0x895e9c0b, 0xe2033e29, 0x4ddb0e47, 0x8fcaf3ba,
	0xe99e2ced, 0x16fae35c, 0xd7d29718, 0xf1d7a05c, 0x0d3e4f4d, 0xf5e955d3,
	0xfb1966dc, 0x9fd78b29, 0xbc7097bb, 0xe8c23cee, 0xb966dc7d, 0x1a85de10,
	0xf82710a7, 0xbcd8dfa1, 0xfdf90445, 0x2673d006, 0xb7d073e3, 0x9e3c0f67,
	0x73d07df0, 0xfe02266d, 0x52661dee, 0x17c34db6, 0x5afd37fb, 0xf5e5bfc7,
	0xafd0d3b5, 0x40164a1e, 0xab7cabce, 0xd9877dc2, 0xfff22b7d, 0x9ffe061d,
	0x0d3fdacc, 0x5aeba178, 0xfd7ff9cf, 0xf4ffca54, 0x24e6d253, 0x61d9fa01,
	0xd84efd8e, 0x7f486fda, 0xea1ab911, 0x3ad75722, 0x1c86ae50, 0xaafc74d9,
	0x9fa12fdb, 0x4e3f3220, 0xab27eb37, 0x00299374, 0x0628ebfc, 0x28bc0107,
	0xa99e815c, 0x8cff7c3d, 0x83cae41c, 0xf0d39e12, 0xbf1e2073, 0xabf9c6a1,
	0x67951afc, 0x7efadf2a, 0x9bc8f309, 0xec12b35c, 0x056294f5, 0xe09cf3e9,
	0xf54c981b, 0xe3e039d9, 0x3960f218, 0xd915c787, 0xcff7ad77, 0xcb9e8033,
	0xd60fcee8, 0x4e0a3643, 0xee5a8bc0, 0x27f6c8da, 0x523cb8bb, 0x6ff9abbf,
	0x9770ef0c, 0x39772377, 0x36132fd0, 0x90e99c43, 0x4463d300, 0x207e4428,
	0x8032dba6, 0xfd5316cf, 0xfe8d5df5, 0x21d7273a, 0x0870aa9d, 0x2575b972,
	0x86bbad89, 0xb039f3cf, 0xe06b46f5, 0xc092482f, 0x181459f8, 0xffd08b9f,
	0x6fe303b9, 0x3dbf7a45, 0x613bbd36, 0x7f0c94df, 0xd2136757, 0x2754d267,
	0x2f5943de, 0x7492e3b9, 0xd30051f6, 0x817e5bfd, 0x5fa035fb, 0xe8eef7e0,
	0x9fe80cbf, 0x00fba0c4, 0xfe0d7ba5, 0x74a03a54, 0x234391f1, 0xa1748c1f,
	0x70aa179e, 0x6f3861d9, 0xc9912ebc, 0xb970bf83, 0xee26eae0, 0x37cf5d45,
	0x2ed9f3c6, 0xe46cbe78, 0x2ab7c02b, 0x835f8e1f, 0x3a2566bf, 0xfb6bdfd9,
	0x99c63e78, 0xa773f1d4, 0x3a9e3e06, 0xd051396f, 0xcf194f9d, 0x7c125a8d,
	0x7ceea252, 0xcae8a96a, 0x1147d289, 0x6e9767b7, 0xfdb9e0b1, 0xbc012836,
	0x680f8fed, 0x253a85ef, 0x5052786a, 0xc4cc4af7, 0xe1f4ab79, 0x83266e5a,
	0x4ae5fee8, 0x887ec966, 0x55a5b9df, 0xd7461e29, 0xdcaccdb1, 0x03ee3b7d,
	0xff42b7dc, 0x9c9b16b7, 0xe491cf10, 0xd7e00a71, 0x7c0d1540, 0x338d8878,
	0x237ddb32, 0xee5d7fee, 0x060f2091, 0xf8a9bc70, 0x9dd0e155, 0xaf0eeb9e,
	0x527c38b3, 0x8e51b979, 0xa6f9c17c, 0x96d7a795, 0xfc088a23, 0x15be20e4,
	0x9f3fcc22, 0x1c88bfc9, 0xae7827c9, 0x2f513138, 0xb7fcd447, 0x26264728,
	0xd8c8e56a, 0x42394c50, 0x3ff9317f, 0xb442f375, 0xd8f1c963, 0x899dec76,
	0x82a70f4c, 0x52f5a4fe, 0x6e77fe15, 0x791c5d13, 0x58f71875, 0x7182d9b7,
	0x721caade, 0xe10a4ddc, 0x403ae6ef, 0xbbad42df, 0x866fc77d, 0xb374def3,
	0xcf9fce0b, 0xfbc461c9, 0xaf01ba39, 0x0af0fa43, 0xf218ef80, 0x441f8088,
	0xe63f63f9, 0x919b17bf, 0x1116964f, 0xb7fb9fd4, 0x2aba418c, 0x8012ce2b,
	0x93ebcb6e, 0x9e4f2804, 0x9c8134ec, 0x6631d752, 0x1a0c89b9, 0x30b07c89,
	0x318f8351, 0xfdfe0d4a, 0xbe2981dc, 0xee893974, 0xdf7713d3, 0x3d03f5a2,
	0xd2ebf348, 0x9a207ea3, 0xd3eb635f, 0xb2d03f73, 0x035a6d7f, 0x9d64277f,
	0xc614b3c3, 0x2ef0496d, 0x77af3483, 0x7234488d, 0xdbf65aeb, 0x6a97a537,
	0xad226fee, 0xe9a71a54, 0xeaf3bbfc, 0x5ddfe85d, 0xcaa9f303, 0x7434fd38,
	0xc462ef87, 0x3cd9b7b4, 0x40b9717a, 0x8f88223e, 0x111ade5e, 0xdcaa2ffc,
	0xbc870f59, 0xc02cbf6c, 0x6fca8ab9, 0x8ec0b720, 0xc02ae356, 0xff4765ff,
	0x43eb007f, 0x2f63513e, 0xc5362bac, 0xe5f9177c, 0x2ab7db44, 0xdff3499f,
	0x8f3f7d77, 0xc88b1bc7, 0x7e332f4f, 0x7d7af262, 0x763489f1, 0x0fdec1ae,
	0xf18f887c, 0xeff70afc, 0x7d15ebaf, 0xc58461cf, 0x2afc40ac, 0x539710f1,
	0x342cbf13, 0xc43b410b, 0x760dfec3, 0xfd9f746c, 0xcfa61337, 0x353bd8ff,
	0x26f8ec13, 0x18fc1b93, 0xa47efc55, 0x7bc1207b, 0x7dfc0d2d, 0x9b1682c5,
	0x7f051e47, 0xefcac5af, 0xe7f47b5d, 0x03c36325, 0x95f2d2b6, 0x1bfc16cd,
	0xea059d8d, 0xe370e1df, 0xbe1567bd, 0x3f59dfc3, 0xa544e314, 0xd9f0373a,
	0xffac710b, 0xfad4e217, 0xd7d044ae, 0xe7db9ddd, 0xff42cf2f, 0xccafeaa1,
	0x8045070f, 0x65d8564b, 0x6c72c162, 0x704c291c, 0x7e79eabd, 0x8efb8703,
	0xd045db83, 0xeb9379e3, 0xe73ec256, 0x28efbb0b, 0x7cf8ddd0, 0x4a379dbd,
	0x778169a8, 0x04adc931, 0x7f2a47f7, 0x3ec884a4, 0x8e926930, 0x32a03c87,
	0xecf59fc7, 0xa2647d83, 0x9fd00897, 0x0da88e26, 0x3cbd25fa, 0xe0bdedc2,
	0xbff2e1ef, 0xd9fbc95d, 0x0050b071, 0x3ad5ef7e, 0x74e57059, 0xb00defa5,
	0xe2c51edf, 0xeaaf005d, 0x7fe0703e, 0x877f80dc, 0xc9df5220, 0x3e09cdec,
	0x397024df, 0x8184f5d3, 0x0ecdc66e, 0x5793c0b4, 0x1694ca63, 0x9eb34bb3,
	0xebfb04c5, 0x1d70521b, 0x0afb8e7d, 0x93dbb520, 0x67f19fb0, 0xd3271883,
	0xf86086bb, 0x23d6ff50, 0xaff53f68, 0x8f001569, 0x89be0e3b, 0xbad7edf3,
	0xaf9ca59f, 0x407b73b6, 0xfb9d979d, 0xa676ed67, 0x7737fe67, 0x006a4c28,
	0x00006a4c, 0x00088b1f, 0x00000000, 0x7dd5ff00, 0xd5547c09, 0xf37df8d5,
	0x9932cb66, 0x93b264c9, 0x01476130, 0x5bb09027, 0x0a300427, 0xa02901c1,
	0x48049c46, 0xd881b258, 0x0cd7eb62, 0xa4623004, 0x054552b1, 0x51f8281d,
	0x8d361a8a, 0x9004e835, 0x558d0506, 0x2f96ac5b, 0x225d8608, 0x62d8bf58,
	0xf739cef9, 0x97bcccbe, 0xffe97004, 0x1f87fbf7, 0xeef39bbf, 0x7b9df77d,
	0x92ee7bf6, 0x2567e795, 0xa6300678, 0x962d79b7, 0xffbac64c, 0x2cb186e1,
	0x5995b18a, 0x48f284de, 0xf636d6c6, 0x06407478, 0x3a43be63, 0x63276f57,
	0xb18c4937, 0xc15d8c11, 0x8b185b9f, 0x831919b1, 0x78b2eef7, 0x96506d23,
	0x603e68cd, 0x1a3b2680, 0x85e51cff, 0x83bd59f7, 0xe2c644b1, 0x80d67d0e,
	0x612dc4fd, 0x6b61ba0c, 0x18922d0f, 0x63cdad54, 0xf60a5a2c, 0x2c625f07,
	0x5e09b196, 0x10ec6baf, 0xa72c67a8, 0xb661fb16, 0xc616c988, 0x4ded157e,
	0xed28efc4, 0x23dbe427, 0xc086447a, 0x2b27bde2, 0x2f766b98, 0x2fed86c6,
	0x307ac9d8, 0x1bc22fb6, 0xe06f7aa6, 0x8c2f308a, 0x7748e9fb, 0x20bf3e1a,
	0x9df819b1, 0xf3c258ad, 0x5b0e06ad, 0x67c23a2c, 0x52a24d81, 0xb16c9b6f,
	0xd93a72c4, 0x30bb4106, 0x57e94ede, 0xe9b3ef29, 0xe64e2e88, 0x26b1fa24,
	0xe3336b9d, 0x0c0cf0e3, 0xfa2f1bb6, 0x66f6e51d, 0xcdb6a1eb, 0x01b4cde2,
	0x7fb8623c, 0x1a840c9f, 0xa7dbe396, 0x95853287, 0xbd00b3ef, 0x7ea30e58,
	0x03599a62, 0x1f4589b0, 0x41477669, 0x9d9b54fd, 0x54f237be, 0x67ba432b,
	0xe383cc48, 0x2395e2d0, 0x8d3472f0, 0xd2245891, 0xc70633c5, 0x5cb9343f,
	0x0e2a0036, 0x7ac09b66, 0xcd8f7632, 0x190d7849, 0x2327deee, 0x8c8f6ed6,
	0x6117defd, 0xa657f7a3, 0xf780f971, 0xccfbe027, 0x017296e1, 0xc3ffa1bf,
	0x77002ad8, 0x9c918e35, 0x633bf003, 0x1b98c979, 0xf903b4e9, 0xdb978219,
	0x8f7be9c6, 0xfec743a0, 0x1e9033bd, 0x5b9d268e, 0x1d864e82, 0x6833f489,
	0xb9716c3a, 0x583bf88c, 0x4100c493, 0x165b5cfb, 0x2e4b2248, 0xd7c84976,
	0x4ccf08fc, 0x0f03f51b, 0x759e5033, 0xef784afe, 0x926e519f, 0xc25b05f3,
	0xc4cc276c, 0xfe057610, 0xab46d497, 0x44bab2e0, 0x417e89db, 0x02fe0178,
	0x33f6cc72, 0x58ca1b33, 0xcf62af31, 0xf805decb, 0xf373129d, 0x4b807cea,
	0x91b5ff7f, 0xddc648e9, 0x8d1dce38, 0x420a2383, 0x8e3963e4, 0xefc55333,
	0x2d7df1fb, 0xc12433bf, 0xdf80dbef, 0xb6fc8ece, 0xbf05a258, 0x5657a4dd,
	0x7df0930f, 0x717fd7a0, 0xa087787e, 0x169a399c, 0xd8f00ccb, 0xbc88fc89,
	0x79143f36, 0x3f3858b7, 0x45543e14, 0xbf6257b8, 0xfc41d016, 0xeb0c6fae,
	0x27abcf87, 0x9dfc72ea, 0xb633d9c8, 0xdf37ae48, 0x98a7ce97, 0xe905c59e,
	0xf5ffeacc, 0xee802fca, 0x4cbbf865, 0xe5067f74, 0xd51ee802, 0xc4fdc613,
	0x50e2cfc4, 0xd6e6753e, 0xa3d01283, 0xca765ea4, 0x87ca8430, 0xffe46eec,
	0xcb92b5f3, 0x97a9f484, 0x5f9e1e49, 0xa537ee19, 0x62fdf105, 0xbb1075b7,
	0xffa14a09, 0x2197d02c, 0xc5a2cb9f, 0x03007df7, 0x1c6c173e, 0xddeaca7c,
	0x9e4f6a1a, 0x1847ffaf, 0x04c6f9d2, 0x0c44e036, 0x7b5370b6, 0xb1ff6b03,
	0x099fd049, 0xae90937f, 0x2a3255e9, 0x4eef34d6, 0xdb7c4c93, 0x630dfd85,
	0x0d1e7fcd, 0xdb61fd78, 0x44379d18, 0x7dd52e6e, 0xe02f7335, 0x3511165f,
	0x8f015988, 0xa0fb97bd, 0xb7f5299c, 0xbb20292f, 0xddec80f7, 0xdbd78a13,
	0x3b738efd, 0x2d6cf2cc, 0xdda7e237, 0x200895d2, 0x9fb99461, 0x92e0e81e,
	0x7c325dc3, 0xf79c36af, 0x948fb59b, 0x06f6558a, 0x1afd20fa, 0x957e89c2,
	0xd2ef41bd, 0xb1b7cf08, 0x2316fdff, 0x97e7844b, 0x9db11f40, 0xc0f7f782,
	0x63e403f7, 0xd9bb7c47, 0x5c84225a, 0xdafc41c8, 0x807c82f9, 0x9e8b65fe,
	0x858171c6, 0xb59f90bb, 0xfe433746, 0xbd728efb, 0x2a56f851, 0x7d42ee64,
	0x8c2f11e6, 0xdd23f9ef, 0x85fef85c, 0x3a614bba, 0xadefdef8, 0x878813de,
	0x851ad29c, 0xfd5f70fe, 0x03cdfea5, 0xe0b5bec8, 0x8e874bf3, 0xbe03bddb,
	0x5c2ef8d7, 0xf4caf8cf, 0x95925591, 0x8b69c6c4, 0x8ee11123, 0x52472352,
	0xd237c37d, 0x863fd220, 0xca97d0f6, 0xee3095fc, 0x3c850395, 0xd44e654d,
	0x9fbf2d7b, 0xd8ae7ab2, 0x9576f442, 0x674523d5, 0x0f24eff2, 0xd1ca71a6,
	0xc3a0e780, 0x741886b3, 0x0cb1be38, 0x258f66fd, 0x9071d863, 0xf9999367,
	0xa49da0c2, 0xe0c33e67, 0xc7daf8e0, 0xa0f2fbdf, 0x1bc68c43, 0xf202fd85,
	0x5f8074cb, 0x55833819, 0x0ee3a169, 0xc44aff10, 0x91cc4af8, 0xc3c61901,
	0x35ce1976, 0x47a0762b, 0x3f81fc47, 0x6f9f8889, 0x1788eb8c, 0x48b7fbf9,
	0x47d22557, 0x58f364df, 0x58c93c68, 0x27e786cf, 0x45f7f8e0, 0x9da147b8,
	0x9194badf, 0x91785f3c, 0x60c237f9, 0x91d7efb7, 0x37606cbc, 0xa0dfdc90,
	0x13d338bb, 0x1bdcfa49, 0xaa68cef1, 0xeddda1d1, 0xd0ea77ed, 0xaa6ff69e,
	0x0e48e9d5, 0x7d04fdbc, 0xbf01e92e, 0xcb95b71b, 0xd21e53df, 0x3f43afa3,
	0x7c995f81, 0x0a5f9cbc, 0x390b46dd, 0x43748d18, 0x3faad087, 0xd20e6cd7,
	0x92c3f80d, 0x63fb1ded, 0xe91539ac, 0xc9daf0d4, 0x5fd0cd3e, 0x67271be9,
	0xff4a5d22, 0x18212268, 0x56fec7fb, 0xb22ff794, 0xce678f3a, 0xf4bb9455,
	0x24fd4f10, 0xf5d907ba, 0xc464d662, 0x76a4a138, 0x621f4ba1, 0xedf895cf,
	0x2269a190, 0x53287ff6, 0xce814b66, 0xe2c35c97, 0x427e2759, 0x78c5df29,
	0x418f700d, 0xafce91dc, 0xfc795865, 0xa07f2768, 0x62a87f6d, 0xaf6c6bae,
	0x943bfbae, 0x0fc3361e, 0xc4d44fef, 0xdcd16541, 0xcd123daf, 0x641830fd,
	0xfe79e237, 0x07df8b15, 0xfe0fce8f, 0x9d018a28, 0x60faefce, 0xe8e40f88,
	0xffba6b3c, 0xafb3d475, 0x5dc61922, 0x1a3fd313, 0xd412d4b2, 0xf3879bcb,
	0xeafcdfb1, 0xb42728e1, 0x9f7db89f, 0xbf4217c3, 0xabfe999b, 0xc34eb976,
	0x31f1f2ef, 0xe41f737d, 0x74fd7b07, 0x89ca139c, 0xe0e5bdaf, 0x43a71072,
	0xf6162f3e, 0x147c65ed, 0x5c4f6f12, 0xa4724a52, 0x666d25c0, 0x81098fe6,
	0x74464df5, 0x916d25bd, 0xeeed0fcc, 0x5038b68c, 0x4b12580e, 0x25d33b42,
	0x9e93aebd, 0x3d0ae7da, 0x4e9fa50f, 0x8be2b8c5, 0x3ae1e22e, 0xee5daed1,
	0xd74e202b, 0xbe77e107, 0x74f3ef95, 0xf13adef2, 0x88d725de, 0x26f78c78,
	0x6cbd031a, 0xcc63b49d, 0xd2d4fc4f, 0x45cbede9, 0x2befd811, 0xce9ca66d,
	0xb46dfaf0, 0x29c587ee, 0x90ab0087, 0xf65ab078, 0xe22d18be, 0x970029c1,
	0x1e34bff6, 0xbcbb40ed, 0x3377bb08, 0xfea035f3, 0xe143e56a, 0x1be46ef7,
	0x4b326dea, 0x2afdbe46, 0x46e5c9da, 0x1fa283e8, 0xcb6a3a5a, 0xede64609,
	0xbab01e6c, 0xcc61ae9d, 0xfef0f607, 0xeff2060d, 0x75ff2f87, 0xf79010ea,
	0xb60ceb93, 0xb9c9f065, 0x7b75f7eb, 0xa6e7ea02, 0xc0126c9b, 0x5e819d27,
	0xeb45f7a8, 0xc3ca0f65, 0xc7f775c9, 0x2cf282cd, 0xe0316fe8, 0x40c1b451,
	0x786ee7cf, 0x169f9e80, 0x3eb45d7a, 0x97b446f6, 0x8aaff787, 0xfdce3e43,
	0xc869e1f6, 0xdb46ed97, 0x1650e98d, 0x635c936f, 0x7f3de843, 0xde0a9853,
	0x717363ae, 0x995f0a1c, 0x77af6de4, 0xd12d3e02, 0xbdf35e7c, 0xc75018f9,
	0xb65f109b, 0x72f8f344, 0xee309dd2, 0x144bccd2, 0x103befd7, 0xcde4fe4e,
	0xc7e29948, 0xbefffa40, 0xd9c01373, 0x145deadf, 0x8f3e09db, 0x2c667c13,
	0xa176ec81, 0xafd9c399, 0xccfe29e9, 0x6f44c8b6, 0x0e391f68, 0xda227fea,
	0xa2cec007, 0xf479321e, 0x6ed0119a, 0xd0c0d59c, 0x3024fd0f, 0x3f03227f,
	0xfe9b4b79, 0xf190e6b3, 0xfd35618c, 0x62ce1e30, 0xb773cd06, 0x9b679f1e,
	0xf5c7cfd5, 0xc634fdba, 0xea6ce30f, 0xe9dc8ae7, 0x84ee42ed, 0xe077d8bd,
	0xc0266fcc, 0xc90f0af8, 0xcb5f3f14, 0xf88bbf1e, 0x6fcf91eb, 0xf7836de7,
	0x1caa0b0e, 0x79727cbe, 0x70d5ca22, 0xf8032d89, 0xf5cee5e4, 0x4b908271,
	0xfdbf80c6, 0x75cdfc82, 0x51876bcd, 0xbe18efdd, 0xfc461db0, 0x5d8edfaf,
	0xa2054edd, 0xeb433e79, 0xf37ab437, 0x131bf29f, 0xf54adfd3, 0x017ca859,
	0xb9db73cb, 0x09dad5dd, 0xad589fad, 0xff41afb1, 0x87f953a0, 0x048ec2d5,
	0xfc9184fd, 0x1f388fc4, 0x3277b5ce, 0x8638861f, 0xaa1be5e8, 0xc43879a7,
	0xddb0535b, 0x4c674880, 0xc5e71396, 0x9ed0223d, 0xfde91d3d, 0x0f243da9,
	0x1ab6e375, 0xf68dda1d, 0x9d418cfc, 0xabe651a7, 0xfe3e7679, 0x61873b2c,
	0xfcf34abe, 0xa557e2ae, 0xb5ef257f, 0x3cf18b32, 0xa78f3441, 0xea73f47b,
	0xec0f386c, 0x7e43a097, 0xf1682fdd, 0x80c24548, 0x8fdf2013, 0xc4a93856,
	0xf3df1c38, 0x71a70ded, 0x06792e7d, 0x223ddea1, 0x1b5f2e75, 0x60ee22ed,
	0xcafff21e, 0xba6339f3, 0x3d76d3b0, 0x7793d71f, 0xf67c62a5, 0xa9ddc379,
	0x073f3f68, 0x5e309b7c, 0x57acbbd0, 0x171eab8b, 0xf098f8fa, 0xde62d113,
	0x13d46bff, 0xdd9b4180, 0xb8e007db, 0x8f37a43c, 0xf2a0cc56, 0x54258a89,
	0xa34f6e5f, 0xfeb2dbef, 0xfc09e9ec, 0x932d513b, 0xf463981f, 0xf78689f4,
	0x9475984e, 0x1e5e383f, 0x122bb399, 0x2f9a339f, 0xc27279ce, 0x5e485f66,
	0x91c71caf, 0x3738f5d9, 0xfd9fbfda, 0x51cd612e, 0xe5da8fe8, 0x7f0748f1,
	0x163dbcfc, 0x71cd87e7, 0x6a4caed8, 0x268db3ea, 0xa1a9ad57, 0x224fb879,
	0xee511bdd, 0x46ec8d6a, 0x70da8bd4, 0x78b46fee, 0xf672156e, 0x213f4548,
	0x2701ae07, 0x440b5e80, 0xfa39fadc, 0xfef84ea9, 0xcc2f78b2, 0x4ed97ee2,
	0xf8a48ffc, 0xf201c69c, 0xdee51d52, 0x3cc27881, 0x4396176c, 0xce3e79e3,
	0x7b09b162, 0xbcf896e8, 0xbd9af3c6, 0x575b7c93, 0x1e2d1df9, 0x3a70c677,
	0x4a3ef36b, 0xf67de4a9, 0x63dcf18b, 0x71f2a9b7, 0xeee65ace, 0x1693df2c,
	0x09f6a463, 0xe11cb76e, 0x32ef5aec, 0x64f99fbc, 0x60cd6bcc, 0xc450deae,
	0xc06dae8f, 0x58e2577c, 0x87cc52ff, 0xead68cad, 0xe70c2fa1, 0xbabc3d63,
	0x8bb41f38, 0x1966f26b, 0x6b168f01, 0xcf15e11c, 0xbf2297ca, 0x1a3abc32,
	0x70fec674, 0x9e4ca4bf, 0x6110c9a1, 0xc343411f, 0xb29edf50, 0xfd218f78,
	0xaf2ece86, 0x5f313a34, 0xdc79a3e8, 0xdddbc969, 0xfa71f20e, 0xe34ef0ad,
	0xde8a8bdc, 0xd092634a, 0x326c67a5, 0x36321d10, 0xe22676fd, 0x56e9b19b,
	0xff9214bd, 0x50318a88, 0xcd6fd3fb, 0x88f94eef, 0x77ac4d8f, 0x8d7ec75a,
	0x16dfbc31, 0xc69def41, 0x174ee5ce, 0x38b0fd23, 0x1be219b5, 0xc5d69db5,
	0x67f30664, 0xc91725a5, 0x73b51f4e, 0xbeacf0ff, 0xd01240f6, 0xccd9d9f3,
	0xbf9f7485, 0x55e50365, 0x6f6b1a77, 0x29e386db, 0xafcc31d5, 0xc7f03fec,
	0x1f184903, 0x63a676ce, 0xfefed07c, 0xf12bada1, 0x5973b3f9, 0xd13fd23a,
	0x7984b8ff, 0x6ac3af96, 0x6f5f5e88, 0x30a5b136, 0xd7ef79a4, 0x800bf6de,
	0x18eb16d7, 0xb8ed15da, 0x5d064be1, 0x83019602, 0x3fe7386e, 0xef853fda,
	0xe4465820, 0xa437c287, 0xf72876df, 0xf0957e6f, 0xb16af057, 0xf3ce893a,
	0x0dbf6cb7, 0xd8a924e5, 0x5ffce12e, 0xfa87ebc1, 0x7fd11f89, 0x5ec4c666,
	0x191cff97, 0xd4ff89d3, 0x23a7cdfa, 0x7f6337dd, 0x079ff2d7, 0x1fea7d84,
	0x75f6e1c3, 0xca3a438b, 0xb2f969a3, 0x8f21dedf, 0x7be6313d, 0xb15fb1e4,
	0xda7be9db, 0x2356f63c, 0x7635a3b7, 0x4ee4df76, 0xc0bb61f4, 0xd5a6b757,
	0x51d17e88, 0x976a752f, 0xcf1e162c, 0x2fbcdd81, 0x439d6426, 0xa13b576b,
	0xefb6216f, 0x17b02dbf, 0xee8e0d5b, 0xd7618115, 0x9e60570d, 0x4a77c9da,
	0x173a7e85, 0x4ed0b703, 0x47b23396, 0x3279fb00, 0xfda1202f, 0x61947e01,
	0x6f5ad7bf, 0xd166b26a, 0xbeb2933a, 0x549562d4, 0x3135dbf3, 0x83f73b4a,
	0x174a5fd8, 0xb0a97ef6, 0x1f7e302f, 0x316381ca, 0x28a3ad53, 0x728e27eb,
	0x40cc649f, 0x2f28c2b7, 0xbbc63dda, 0x5aed00d4, 0x46d73047, 0xb679ad80,
	0xf697b42c, 0x5c06aeb9, 0x9e795967, 0x2e57d1e7, 0xd465fe64, 0xf32f1f0f,
	0x4e6ff0f6, 0x9d0b7ce3, 0x457e2bcf, 0xbbf81f19, 0xd78e189a, 0xe2ae626f,
	0xbd447eef, 0x5ea75ff2, 0x7c2efe6d, 0xf93af17f, 0x896184ee, 0xf7ed1375,
	0xda5e2276, 0xec9c81ef, 0x59391eba, 0x25d75df1, 0x361fa423, 0xd748ee4f,
	0x893a6277, 0xea27abf7, 0x9c71e9fa, 0x99d5dc2c, 0x131a3bdf, 0x1f5e9ff9,
	0xadf82a3a, 0x1f821f5a, 0xfcff3c55, 0x7d7bd732, 0x6577cf11, 0xff3da79a,
	0xf22366ab, 0x506f5959, 0x27fb2df0, 0x87f82448, 0x51d4ff0b, 0xf5f7aed9,
	0xf79c10d2, 0x4cbbed65, 0x8685f9f1, 0x7e7c527f, 0x2b9f1341, 0x72845ddf,
	0x938cf800, 0x2e7f4923, 0x0479e3ae, 0x1a9f3999, 0x46f2f98d, 0x493bf303,
	0xa17e29fe, 0x117c02f1, 0xc5bf6c4b, 0xa2cdf348, 0x06873b83, 0xb87591e0,
	0xe843398e, 0x670eed15, 0xc57a10ce, 0x7055d8e4, 0xd54927ac, 0x0f467e3e,
	0xf7a27d55, 0xf27d5506, 0x382ac1dc, 0xaaa47ca5, 0x9bf0777d, 0xef9a70a1,
	0x9efb5576, 0x70545355, 0x55bb9aef, 0xddcf99ed, 0x39c60bd4, 0xefb38c5b,
	0x7b5502da, 0xae009f50, 0x6c11cd9b, 0x7c75bb3e, 0x640e04a3, 0xf487c8b6,
	0xf557cff7, 0x9d46a737, 0x023a20d7, 0x24eb0add, 0x6dd20cf6, 0x6e7ebaad,
	0x932be3fd, 0x57e79ca1, 0xeb8f9f3f, 0xa7ca1259, 0x9d6ef9fa, 0x479c7ee7,
	0xf3a877f4, 0xafe4d724, 0xf8b5efaf, 0xfb600aeb, 0xb78a166d, 0x22ce0e8a,
	0xa825323d, 0x0ce61bf9, 0x22fd2abf, 0xf535d9fa, 0xf42aeff0, 0xf2d4b8b3,
	0x9e9fa5a0, 0x06481eb5, 0x92fd4abc, 0xd23ac02b, 0x06dd5e6f, 0x3f4b53c2,
	0xd0eedd2d, 0x845f6bd0, 0x13238a77, 0xcb164dd7, 0x72c4ceb8, 0xa5f57af8,
	0x1d06afba, 0x95d6aa72, 0xb9475aba, 0xbac9d1db, 0x475c05da, 0xc75d89bb,
	0x6fbeda3a, 0xf0260e90, 0x27e00658, 0xb732ee1b, 0x05859baf, 0x76b44dd7,
	0x6ec1294b, 0x3d90702f, 0x5637ae0f, 0xad43dbc2, 0x9e50f17f, 0x293fac50,
	0x7d9451fb, 0x8f922c33, 0xe807e953, 0x33f63f70, 0x811ecb21, 0xfbedb7f3,
	0x447cd117, 0x2c8337d9, 0x121f6d0f, 0xacfd9317, 0xc9135fc5, 0xc1c2fe9f,
	0x5843e9fd, 0x0594fe2a, 0xc2bbfcec, 0x8fd5769f, 0x55d4ceb2, 0x6995ed29,
	0x0a55acdd, 0xc4ec6d77, 0xf8e93f9e, 0x5393f381, 0x4faff21d, 0x27e7423a,
	0x803a5c0f, 0xfee81d76, 0x08e283b4, 0xd05297f0, 0x11153e5f, 0x7ad6fa45,
	0x85f7f650, 0x4ecd1707, 0x70407dab, 0xef8b4c3d, 0x00d27368, 0x4a3ac87d,
	0xb35f26bd, 0x5f8f3072, 0x5ae3105e, 0xedfdc91d, 0x6997011e, 0x55650be6,
	0xda0c5e7c, 0x243eb730, 0xb0e3d84e, 0x447179f0, 0x7bc41ed6, 0xac2bc883,
	0x7be8934c, 0xfc89252b, 0x31d683fa, 0xc8ec5f54, 0xb772c7aa, 0x3de9fb83,
	0x59415318, 0xe3e383d3, 0x944afb14, 0xf68897fe, 0xa8631c4b, 0x89b0e3dc,
	0x0376c9f8, 0xe11cdbf2, 0x728d7ea6, 0x7b2bebe7, 0xd01f3c1d, 0xb193730b,
	0xf2513d41, 0x1d85e3d7, 0x89b57cc3, 0x713dc994, 0x5f305c5c, 0x1fd1e4cd,
	0x4f221d1a, 0x6eebd12d, 0x08b737b4, 0xb795763e, 0xedb3f776, 0x8e9165c7,
	0x4240eb79, 0xd76b79a7, 0xc35bca78, 0x971c7a9b, 0x7c8d7f36, 0xf507b088,
	0xf68eefe1, 0x686eaf75, 0xde8cea6f, 0xb4879c4a, 0x167886ee, 0x37f3f71e,
	0xe07b5e53, 0x9c2e9ea1, 0x634cac6f, 0x3f282d7b, 0x78c3194b, 0xb759aeb7,
	0xabea0c2c, 0xf586cc7d, 0x79f1d623, 0xa75ad14c, 0x8069870b, 0x7065a1f9,
	0xedffbf50, 0xd5fa2688, 0xc0694f35, 0x54f5773c, 0x50b74766, 0xa3b26ac3,
	0xc758be30, 0x7d479d3a, 0x4269e423, 0xf5195ed6, 0xe415b63f, 0x7d3e13a8,
	0x07f2e0e3, 0x7a86ddfa, 0x7bd5ac31, 0x712baf89, 0x0e2640fb, 0x75fb6be7,
	0xdf6b7f14, 0xf65467ff, 0x060e51bf, 0xdfcf3bfa, 0x7970b2f4, 0xd1e1181b,
	0x5dbb62c7, 0x43b446cd, 0x9d3d8a45, 0xe07a63ad, 0xaf829dfb, 0xfbe3ae77,
	0x2be5d810, 0xee256457, 0x433fd462, 0xd534513b, 0x487cc7e2, 0x8f9a7d51,
	0x9448f2f0, 0x7fab29ef, 0x517083df, 0xe70d8646, 0x31bfeedf, 0x851fa5a9,
	0x23db8c6c, 0xec516b3d, 0x0755f903, 0x114c9fad, 0xe2cbd6f2, 0x6ec13c24,
	0xfd004757, 0xdd2dd68b, 0x3e50fb8b, 0x75a31dfa, 0xeb722392, 0xa7ecec50,
	0x83259c40, 0xbcb3d4b1, 0x5f32f8c1, 0xfa2a9987, 0xbe13fdf1, 0xf77e0e6b,
	0x6907f5a7, 0xcc0c473c, 0xba390667, 0x13ba67b0, 0xb195d7e3, 0xb5c91766,
	0x2a3c5f58, 0x5390577b, 0x2296b7d1, 0x47d5776a, 0xc37f70d8, 0x7bb908ff,
	0x303bd634, 0x9779da16, 0x7e8a56dd, 0x29a979ad, 0x7792fd15, 0x00eca259,
	0x25abbd3c, 0x6598f71a, 0x875c4689, 0x7d3cb59f, 0x838bc63c, 0xe6257b99,
	0x618dee33, 0x4fe9ea9d, 0x169eb963, 0xd1981b94, 0xe230834a, 0x55f38afe,
	0xc0afed12, 0xe05ca475, 0xbe315ccf, 0x8fde4792, 0x8980f922, 0x9e7b8e3c,
	0xf2dccfe0, 0xad47d222, 0xb5662ebf, 0x67e844c6, 0xef4c357e, 0xdff4747a,
	0xf8505d8a, 0xaeab525c, 0x5fd5632f, 0x060e3ed2, 0xed05b3f1, 0xc7ffc6bc,
	0x31747d0a, 0xfbd5f217, 0xf7198b33, 0x74118cbb, 0x6c96afc9, 0x2d665f68,
	0x0e9d886f, 0xd946acf0, 0xd0ad3285, 0xaf887585, 0x857ed006, 0x29bd8d8b,
	0x74e8bebe, 0x6f3b63c6, 0x25bb8f14, 0x3e1877bd, 0x3bc637bf, 0xadb5e70c,
	0xee185b1f, 0x06d638ff, 0xcfee14f1, 0xb441b332, 0x83636efe, 0xc5f88726,
	0x0e2d837c, 0xb63edaf3, 0x35f18128, 0xb8e8731a, 0x4dd5cccb, 0xc65b6eb8,
	0x3e313ef4, 0x7c448ae9, 0x7d6d5123, 0x267da24d, 0xc3e0ceac, 0x33331af5,
	0x197dc52f, 0x71359da7, 0xcf328210, 0x69e9030a, 0x8a68b6c1, 0x67960b0b,
	0x0b7e511b, 0x1d934576, 0xc3ee7882, 0x7c83435e, 0xc87cb63c, 0xb7e80481,
	0x25cd36a0, 0x4277f9ab, 0x1d56af15, 0xe276f853, 0xd13b7c1a, 0x5f80df19,
	0x342be7aa, 0xc50f62fc, 0xb7911c50, 0x66deadf0, 0x7962e7c0, 0xe99fed18,
	0xdd609e2a, 0xa53eb41c, 0x9272b3cc, 0xb443e7da, 0x3aa97bfe, 0xe5a6f893,
	0x67bfce57, 0xc27f430d, 0x686166fe, 0xc9edeec7, 0xcf029bee, 0x7eb893ef,
	0x5b795bdd, 0x73e9ea0e, 0xbe6edcb1, 0x34230157, 0x857ef632, 0x30fbb999,
	0x8d8541f6, 0x122a8fe0, 0x856bfe08, 0x2b8fca93, 0x427951fa, 0x3d1495e4,
	0x79200103, 0xedcb14dd, 0x6558a6eb, 0x027171fd, 0x7f9c8c9a, 0xb3a9907f,
	0x6e0fa3e1, 0x7202971f, 0x846206ec, 0xa6332fc4, 0xdb932046, 0x6d8366e1,
	0x83c6027c, 0xef64488f, 0x54a33c0b, 0x69de99ed, 0xaccc7dc4, 0x73e090df,
	0x34e4efda, 0xbc39014e, 0xaa8c626b, 0x64aab4fd, 0xeb1f5c15, 0xe726fc24,
	0xbf3d54f4, 0x1546ef3b, 0x4406df9c, 0xb37275c0, 0x8a13af9d, 0xecc667f5,
	0xe36bfe7c, 0x1f2abf6d, 0xc073ff16, 0x0643abf7, 0x43f2d7aa, 0xb5ecebe1,
	0xd405e63a, 0xb185ad66, 0x6a27bf41, 0x9d5e9166, 0xbf21623d, 0x90db72bf,
	0x7c038777, 0xd6819b6c, 0x8f2d8f89, 0xa0eb8d59, 0x46c5b6c7, 0x2bbd2831,
	0xb8c01665, 0xb2336f56, 0xbd96fb10, 0x43ed297c, 0x5c9bf7ca, 0xfbf9ffa8,
	0xb029cf7d, 0x443be313, 0x43e3f512, 0x88901fd9, 0xefa26e7f, 0x66ff30d6,
	0xbd814f80, 0xb3cfadc6, 0xa75e399a, 0xe11cb624, 0xf69f61d3, 0x71e039f9,
	0x50a6b73e, 0x7cbdf187, 0xe5ec9628, 0xdca1990e, 0xd0342de6, 0x8fbcd53a,
	0x33080de4, 0xe7327069, 0xeafb4cb7, 0xf51356d8, 0x42415acf, 0xdfe2dda0,
	0x92ae369b, 0xde08cd38, 0x4abfd03d, 0xd1ca27c8, 0x8ee668a9, 0xc2256426,
	0xb1fbccf7, 0x483eb01b, 0x1c20ff4f, 0xa7bd41f7, 0x99c3fd15, 0xb220ff42,
	0x92c50f6b, 0x7ee9695e, 0x96edc8c2, 0x0a40f50f, 0x9ea0cbda, 0x307f232d,
	0x738ae0cb, 0x48cabd91, 0xa2757b44, 0x71fb40da, 0x351dde99, 0x3b33e699,
	0xef958e48, 0xc73bd09c, 0xaa277e23, 0x11e618d2, 0x8a65aa0a, 0x78fe5007,
	0xe75f3f7b, 0xb2f65c78, 0x956fd061, 0x1df165e4, 0x85fee6e5, 0xce3f68c3,
	0xd1af314c, 0x402f81da, 0x827dbd57, 0x7c3dfcf0, 0x68cb08bf, 0x181d4fd6,
	0xfce58e3a, 0x7fbc097b, 0xb8bb3d65, 0x628e9fc7, 0xb1b17dc8, 0xf0fd15a7,
	0x92650fe9, 0x6a3dd3b3, 0x3f002686, 0x0ef6e9cf, 0x67c039fd, 0x7a2d7d73,
	0x6f708554, 0x3fce1c4a, 0x52a9d574, 0x79e7dc0f, 0x7828f57c, 0x068bccef,
	0x92f9a917, 0xf31fb258, 0x1eebceb7, 0xa3af6fba, 0xf1240afd, 0xa27706f5,
	0xe05cf404, 0xf98f1dac, 0x23cc39fd, 0x8fa710fc, 0x81111713, 0x1235b62e,
	0xc7657e6e, 0x70ab2d33, 0x502cf0ff, 0xc479d093, 0xdbcf0371, 0x7c78e2b9,
	0x0f09c4a5, 0x333b71c4, 0x9be5c74b, 0xdc5124bd, 0xfb2a3f06, 0xd9f6265f,
	0xb15f7629, 0x86acc5d7, 0xc4c73dd6, 0xf378fdf1, 0x2bb53f24, 0x304c15c5,
	0x9e368551, 0x62de2d94, 0xa8d3fbf2, 0x1c685b2f, 0xc9ce3cb0, 0x2f8c43d7,
	0x5b62893e, 0xf8f89ac4, 0x18ceed34, 0x694d85fc, 0xa14dfd1d, 0x3b72c36d,
	0x61706ff5, 0xe848a33e, 0xe48d4969, 0x9071f00f, 0x0ef254df, 0xd4df8473,
	0xfe0ea7fa, 0xe687e348, 0xab2cfc68, 0xc055fb51, 0xa3bf1237, 0xd3c5abe0,
	0x3a216113, 0xd0bc07cc, 0xfd7a16df, 0xde112607, 0xd9380b92, 0xe6229f01,
	0xe38d1b19, 0xb380fa80, 0x71da7e23, 0x8c57c075, 0xa1778b53, 0x9c80cbeb,
	0x5139f7c1, 0x0e3347fe, 0x78da1f85, 0xa14be14d, 0xb0b7d38f, 0x7e7e225e,
	0x32071ede, 0xf228ffca, 0x5aa01302, 0x499efbf5, 0xd68acf68, 0x0b4dfd80,
	0x4f228fca, 0x146d59f3, 0x0b294bca, 0xfd444cac, 0x1b4ed40a, 0xbafb7181,
	0xcffe29f7, 0xeb7a07b3, 0xd98491a2, 0x1cdce68f, 0x9d2d6b94, 0xefd7c5af,
	0x951c374b, 0x015fc95e, 0x926ce69d, 0x548361dd, 0x187ec4ed, 0x5cc1e91f,
	0xf988cf9f, 0xde62b98a, 0xcb3c2d7f, 0xf3ff7cf4, 0x22edf135, 0x78a1fa4e,
	0x791388ef, 0x56710eb1, 0x76676b6f, 0xa7e7194a, 0xd35caec2, 0xd35debbf,
	0x58f7f919, 0xb5d697c9, 0x7e142ebd, 0x79fa0e7d, 0xeed65b28, 0xe7da7ca4,
	0xde52766b, 0x9ce2f8dc, 0x5bb78c28, 0x8d5aced6, 0xb65a92fb, 0x5ebf22cd,
	0xd7e28cf4, 0x78d0c6bd, 0xfe6d7b21, 0xf285fff3, 0x768c25ba, 0xf7ee1580,
	0xd80e798a, 0x5ce76851, 0x5b26edcb, 0x1168edc3, 0xd7ca3ffa, 0xbb62fb78,
	0xfb7a159f, 0x3c87dca2, 0xb3f8bf27, 0xf797de59, 0xfb3fbf40, 0x47cb8443,
	0x7405b643, 0x02dba714, 0x164affe8, 0xee28f5fd, 0xff7f06cf, 0xbf8a83d1,
	0x9b7b3e27, 0x7e283fd1, 0x90de44be, 0x40b8c36a, 0xd7ff85f8, 0x7a402ef4,
	0xe9c53c53, 0xa71559fd, 0x4e6af1f3, 0x7adb95f7, 0xf0fce146, 0x149eaab3,
	0xadb67d47, 0xf67bd137, 0xc537a02a, 0x1c754ed1, 0xc6f40555, 0x1bd20279,
	0xefd82af0, 0x7176f414, 0x3a71577a, 0xce5e6ab3, 0x1f5740ee, 0xecffcbad,
	0xc6172677, 0x02c2a705, 0xda9d2f14, 0x90cab32e, 0x73894b38, 0x9e6ac1fe,
	0xa14c78c3, 0x4d3ebcf7, 0xe4bed083, 0x28a7fe3d, 0xedbcfba4, 0x81de293c,
	0x8f1dccde, 0xfbf076f1, 0x4c5171ed, 0x745c687c, 0x65297c9d, 0xaf7e461e,
	0x70474ffe, 0xe1b9205e, 0xf79e3b55, 0xea0ae710, 0x700ae7d4, 0x1d9e418f,
	0xb32e07f3, 0xa6e9f119, 0x65e12f3d, 0xbafdf798, 0x173397f7, 0xaab71e91,
	0x624d69f6, 0xc63c4301, 0x9d12b587, 0x9c592bc3, 0x30c59515, 0x784e5caf,
	0xaa4bc6e4, 0xb225787d, 0x62c3e28e, 0x95138f23, 0x788cbcf5, 0xc4640f1e,
	0x667d79f3, 0xbbde8dbc, 0xcec8c610, 0xfd18b05f, 0xe61e6fb8, 0x7df8094b,
	0xf1131edf, 0x04e228ed, 0x228d97f4, 0x0e2e032f, 0xc61ef1e5, 0xc89ef1e5,
	0xc36bca46, 0xfa3d644c, 0x98977bbd, 0x3ab7145c, 0xbd5f94ac, 0x7bb3d85b,
	0xd07a5722, 0x691bdffe, 0xfd096374, 0x983370fa, 0x1e7c0c61, 0x32486fbe,
	0x3c86fed2, 0x388bf373, 0xe12fbdb5, 0x406603f8, 0xaf0826f5, 0xbf026f31,
	0xd312baee, 0xfe412f91, 0x6538f3a8, 0x35e79de1, 0x497a09a6, 0x6be5376e,
	0x3877d04c, 0xbc5771e0, 0xda773f93, 0x1d66fe78, 0xe412c9f0, 0xf339f6af,
	0x317dfcf1, 0xc91bc7ee, 0x270c80b8, 0x62e0abfa, 0x8f2faf23, 0xa6b09daf,
	0x667f631b, 0xb7c881ce, 0x3819b462, 0xfab7cf7f, 0x077dbf31, 0x58ec8fe6,
	0xa65e49ea, 0xc74f99e8, 0xdc48aacb, 0x49f223ab, 0x7f3d0493, 0xac059c3a,
	0x41c0f740, 0x7a6b3e75, 0x0be81740, 0x1f43bdf4, 0xd4f94068, 0x1b069d99,
	0x2393c77c, 0x4779c60d, 0xc3ebb2f1, 0xf5fe32b7, 0x03466b09, 0x9cfbe3ac,
	0x79e41f5a, 0x59407b86, 0xf5336e91, 0x983cbf6c, 0xa5d201cb, 0x51f4eecc,
	0xe51285bb, 0x9a3c953b, 0xe874ffc2, 0xf78f943e, 0x9fa0fc08, 0xdf7c28aa,
	0x7ebf39d8, 0x7716e42d, 0x17dd21ca, 0xa05bbd08, 0xb536dbe8, 0xf0acbdbe,
	0xa05ce311, 0xeca23ddb, 0x09b62f4a, 0xcf16d879, 0xc4cfe3e7, 0xebf1f32b,
	0xe48b1efb, 0x7d14fafb, 0xfef13129, 0x21dfef95, 0x76f1adca, 0x0f82871a,
	0xd867ebc8, 0x002c0e8f, 0x9a89ebca, 0xe67f8a4a, 0x75bc90b2, 0x229db05a,
	0x76e11dd7, 0x82bba23b, 0x3675b1a5, 0x49fa5e92, 0xe8ed0b98, 0xdedac63d,
	0xba8f3cfc, 0x92ceb29d, 0x8c0c9ac7, 0x77c8a4ec, 0x4e333f09, 0xf4f5a48e,
	0x739f893c, 0xf16590bb, 0x8798ace9, 0xf36b1031, 0x6fda25a2, 0x5f1869f0,
	0xfad7bb37, 0xd7a849b3, 0x3d465179, 0x2b593396, 0x5b77fbf5, 0x8674eb0f,
	0xcc6498fb, 0xcf87c38d, 0x77c3704e, 0x70eed12b, 0x68f751f8, 0xb8091aca,
	0xd0371df5, 0xe065ea61, 0x4e5fc13f, 0xb9dd8370, 0x67a896f0, 0x0bfde917,
	0xfb1c842b, 0x6ff0e6be, 0x717ffa95, 0xfea511f8, 0x531f870a, 0xe3f017fa,
	0x9aa5fa9a, 0xfc39a7fa, 0x265753e9, 0x1d2e30f8, 0x6f3a45c3, 0xaa7644a4,
	0xf019ca27, 0x80596f33, 0xdba79be8, 0x2c31cbcb, 0x76b8cba0, 0xa782733b,
	0xd91ffa27, 0xfe82c272, 0xeee491d7, 0x67720f19, 0xc49ef388, 0xc964fe72,
	0xfb7b4467, 0xc1fc9fa1, 0xdbf62ea4, 0xdcf614f4, 0xf7a1e89c, 0xfd05ff15,
	0x7e9f7eb4, 0xd0e84c9e, 0xa7df37cf, 0xf11dd99f, 0x7e6425d1, 0x4ede7ef7,
	0xfa5274e4, 0xa29be251, 0xf60a7764, 0x54384ec7, 0xfc162bfb, 0xfcc565ca,
	0x15fdc312, 0xcb05fa40, 0x4087536a, 0x7a5e0bff, 0xe310b52d, 0x4be7e129,
	0x8dcc74db, 0x18db09e7, 0x3e1b6795, 0xa8b9e236, 0xc60d5dd2, 0x0caed0f1,
	0xbc10ecca, 0xe09e058a, 0x4253f4e7, 0x048f73fc, 0x8f17b09d, 0x97c8f5f3,
	0x9f91eb4e, 0x2db5740b, 0x1edfa0cf, 0x0eba7529, 0x3bde2e13, 0xd8bec5da,
	0x0edc097e, 0xf77148cd, 0x618671c5, 0xecca008e, 0xd5d7ceca, 0xf2fe8a16,
	0x359bdf84, 0x027662d4, 0xe43f339d, 0xeb8550eb, 0xf9d306d2, 0xe931b8c2,
	0x97cd5709, 0x697cf2b6, 0xe697cf3d, 0x83169bd9, 0x09c566f1, 0x30cdabdd,
	0x94f09b1f, 0xb2a067a2, 0x498e6ef0, 0x1c4e8781, 0xb3e78ddb, 0xed63be10,
	0x37a8d54d, 0xe60f888d, 0x0c0d87c5, 0x9cd0bb47, 0x81b3a116, 0x9b1fe8bd,
	0xdc788c5f, 0xf1e6ec3b, 0x64cb3cf8, 0xf3cf93e9, 0xfd1724ee, 0xe2b73d63,
	0xe63db1b8, 0x40c6bc39, 0x871874ec, 0xf6996df7, 0x4507782b, 0x575b3b78,
	0xe5c0971a, 0x46c138a6, 0x360468f4, 0xe0a2fc63, 0xe21f7ca1, 0xd04dc5f7,
	0x896589df, 0xb89cabe9, 0x80b5928e, 0xff7c49e4, 0x8cef58d1, 0xd09fefd0,
	0x85383eb1, 0x7e3c5eb8, 0x00b1f82a, 0x67a506f9, 0x21dcccb4, 0x6329b8f3,
	0xd4f05423, 0x1dcc3189, 0x9a9d879a, 0xe46782ac, 0xbfb554f5, 0xaa8df67b,
	0x53535cfa, 0x1c487946, 0xe49c75db, 0x16c9ebe3, 0x73c6384b, 0xc7ffaf7f,
	0xf8c1ee5f, 0xc2ec936f, 0x9ede7558, 0xc5197fcd, 0x3b887f68, 0x4e8bf286,
	0x699d87ca, 0x75c51994, 0x743eb77a, 0x6b3ce7dd, 0xadf7127a, 0xa3ceb574,
	0xd81763cc, 0x8dbed3f6, 0xa79d7b1f, 0x67cc413a, 0xe8c1b307, 0x7f962f0f,
	0xd2b8f944, 0xf3be3e48, 0xe2331daf, 0x1bae273a, 0xbf79015e, 0xf8c45f15,
	0xf947cdb0, 0x63baecea, 0x20362eb4, 0xd2e9db81, 0x78f50b6e, 0x4a0ca63e,
	0xc1e343f4, 0x5e41595e, 0xc0d81a9a, 0x9aaeb85d, 0x7871e166, 0x62c614db,
	0xfe78ae50, 0x9a2e31a6, 0xa82f07ce, 0xa5e7a1ca, 0xffd4e16d, 0x78d3727b,
	0xaaf77fda, 0xb90beb44, 0xc32ef7c9, 0xe18db2fd, 0xc3f701be, 0xbe5f7377,
	0x56e90735, 0x27ef8bba, 0x9cff95cd, 0xe2ca10b1, 0x3f7a1c9a, 0x128d6657,
	0xb2130bc4, 0x45cdffb9, 0x3cb00f9f, 0xfd0ab2d4, 0xf40c6cae, 0x8ced1679,
	0xc67642d1, 0x7d3776da, 0x4ccdacbf, 0xe04eefef, 0x99a193f1, 0xcdae35e3,
	0x7915cf43, 0x87a13d78, 0x21a79f6a, 0xef1e9376, 0x3334308f, 0xdb7b7f6a,
	0xe32a540d, 0xefdfbb7d, 0x21a8dce8, 0xb8f1abf6, 0x876de74f, 0x4430a364,
	0x952f8763, 0x4eb2b30f, 0x77fb54ec, 0x36bef8da, 0xe7df1b53, 0xfdc937b6,
	0x4983da3e, 0x71eb350f, 0x9a4587bd, 0x49af486d, 0x859dd3c3, 0xef25fa21,
	0xfc88cbbd, 0xdf79ac31, 0x04da7e88, 0x7d487665, 0xa0afd889, 0x6d7fd3b5,
	0x694bd3b7, 0x61df8abc, 0x7f2479d5, 0x00426d33, 0x17ecfe85, 0xbf794476,
	0xc034e689, 0x4f3cddc7, 0xf79249ff, 0xa687da0c, 0x0763362c, 0x54a6cdd9,
	0xb1f9675c, 0x9b3e07f0, 0x9b138a25, 0xa4e6ff69, 0xe61d4ee1, 0xbc082ff7,
	0xd6be3d14, 0xed153e38, 0x12d993df, 0x5bbdf7ec, 0x4372696e, 0x1cbf0d7f,
	0x41fd0432, 0xe4485dbb, 0xad9829e7, 0x07ce32f5, 0x7088decb, 0xe2e7bea2,
	0x33d70c64, 0x9e6898f7, 0xbd69cf02, 0xd30deca2, 0x50f73c46, 0x55f30516,
	0x9bf67ef8, 0xe3940161, 0xf4c33786, 0x4d1e37e8, 0x58c4b2f1, 0x2c77de7c,
	0xf5dd0fce, 0xb8a33d26, 0x66252dc7, 0xb5ef8d76, 0xce5696ec, 0x56f4fd14,
	0x17c97d71, 0xf4205a72, 0xe8f42bcf, 0xe93c7952, 0x0087a5e1, 0x7d075c69,
	0x0bb81a48, 0x85a704e3, 0xf45219ee, 0x43e71732, 0xc6f73cf0, 0xab2fda68,
	0x3d5a1bc4, 0x51b36e2c, 0x4e6d25bf, 0x8276efa1, 0x102bbd15, 0x7112637a,
	0xe7216cc6, 0x74dec9c9, 0x256e7f1c, 0xad147de8, 0x3ea067d3, 0x68c6e505,
	0xb902f943, 0xd10c2849, 0xbb86ca9f, 0x2627c618, 0x66e48787, 0xf1a19436,
	0xf8f69cc9, 0x0e3e36c4, 0x3cb49ff0, 0x74e7874d, 0x89a1fa94, 0x9f5cdc8a,
	0xe44cf7fc, 0x191052fa, 0xacf18de8, 0x85cc3ca1, 0x3a2faefb, 0xa2ce7af8,
	0x171d3847, 0x18d93c19, 0x5a7a2c5f, 0xc618fca2, 0x8697681d, 0x8637291e,
	0x6aee51e6, 0x409cc41b, 0x7adb3b87, 0xce3fd951, 0x23e5163b, 0xa09a6dbf,
	0xb5efa0d7, 0xe6e9987e, 0xdf832479, 0x8690dae4, 0x8caf2479, 0xc2953e7c,
	0xae844f6c, 0x51d5add7, 0x57594bfe, 0x264af254, 0xe212e7dc, 0xafa1ff47,
	0x067ba549, 0x2ca679b4, 0x6dcff7ee, 0x2fdf9032, 0x50f3f86e, 0x919fd41b,
	0x9fd1e2b2, 0x677bd41c, 0x4fe678e2, 0x0064bff1, 0x3b63c178, 0x833846a3,
	0x07d5acf4, 0xad1fa37a, 0xbe623a05, 0xce5ab6ab, 0x2778f3f1, 0x7183af82,
	0x59e456f9, 0xdbf3e72b, 0x5d3c907a, 0x1f91372a, 0xcb7204ba, 0xe290fc42,
	0xaf3b1477, 0xae451ff8, 0x7edcf44b, 0xfd5a4495, 0xfa0c2798, 0x2c9ec99d,
	0x7c7ebb94, 0xefd04cbf, 0x123d5c6c, 0x8382e0f5, 0x7e2a19f6, 0xaf07ab43,
	0xd3804056, 0x51dfa3a7, 0xe762baec, 0xe635bf15, 0xf9daff0f, 0x924efc37,
	0xaf4837f7, 0x7fdcf5db, 0x90b7aedd, 0x4c738cfc, 0x5cdca3d6, 0x263d1dbf,
	0x9531e8ec, 0xc2ed2d1d, 0xf8953c0f, 0x0ac0fcdd, 0xc4c73ed1, 0xf3b447e3,
	0x927dfda1, 0xea2b6634, 0xdc89cbf3, 0x7858fecf, 0x5fff6577, 0xf66efc4e,
	0xf5e25d7f, 0x89bdffd9, 0xd68adcfc, 0xbf1b33de, 0x9ec2e5f7, 0x07f47efe,
	0x07f81947, 0x11f583f4, 0x1fc2cdce, 0xb708bf90, 0x0fe6affa, 0xdacca466,
	0xd83f85db, 0xafbfcf87, 0x50e4503f, 0x4f451bd1, 0xead0bd14, 0x1317a291,
	0x2279851e, 0xbe3de9f2, 0xef44bf0f, 0x89eb46db, 0xd47488ce, 0x6e38f6cf,
	0xd6fa4497, 0xfd084fc1, 0xda8bea09, 0xa17a286f, 0x3fa28be8, 0xe62f4225,
	0x9f62f468, 0x48c4fb5c, 0x248eef78, 0x4f2857ef, 0x43b27aed, 0x94ba1feb,
	0xb22ccc2b, 0x86728e39, 0x65025572, 0xba995ca8, 0xbe6f87d0, 0x79385fa3,
	0x9914f29d, 0xff89e3c4, 0x26453ca0, 0x4f2a7665, 0x311fa496, 0xfe54b8be,
	0xe0270cd7, 0xec032973, 0xde505a6d, 0x78c3bc26, 0xcf93d0fc, 0x497e6007,
	0x531a3778, 0xe133ef28, 0x3a472b0a, 0xf0a9722a, 0xe6078959, 0xa4c3bc88,
	0xe23a4f64, 0x8581f38b, 0x88f767d7, 0x934726cf, 0x7327e711, 0x038d0ca0,
	0x877f8aba, 0x3e377d26, 0x3eba4af7, 0xf49adf3e, 0xb78dc7a3, 0x276e7526,
	0x807e9272, 0x66cdc89d, 0xcae7bf22, 0x84e37cc5, 0x65980b5f, 0x4cbea2e4,
	0xa7d4ae1b, 0xa3d6e63f, 0x5e4a607d, 0xef1cf29c, 0x0df602c9, 0xf0163c3e,
	0x0b04f09c, 0x7ea1cde6, 0x7b6b68dc, 0xc162445e, 0xdccf45f6, 0xfc9ab874,
	0xbfa70d7c, 0xd7cf59b7, 0x019c047f, 0x1e0425b0, 0xf1d781ae, 0x66fa51f6,
	0x041fba16, 0xcc1a49e5, 0x8909ecf9, 0xfbf3e01f, 0xb0bfa12f, 0x1af30c49,
	0x6f0d8e65, 0x56bb425d, 0x545ad127, 0x28d81d3b, 0xbd6943a2, 0x0e5be024,
	0x76317bbb, 0xaf0e2ef7, 0xcc7eca4e, 0x86fd17a7, 0xd43793ec, 0x57da6e4a,
	0xf7f25c30, 0xef48eb48, 0xff6a49d5, 0xf57a3f84, 0xdbf70cfb, 0xdbf7977d,
	0xa0f57fcf, 0xefa603f7, 0xa3e9fdf0, 0xbcdfdf3b, 0xf5fb8929, 0x4ed619b1,
	0xc925b7eb, 0x6f22fbfc, 0x4787df40, 0x7e76d677, 0xf89773ee, 0x97ae136e,
	0x7bef3d10, 0xe18dddcc, 0xcf011a6e, 0x3de90c7c, 0xfe55318e, 0xf04fbe0c,
	0x7333499b, 0xb87cf4ab, 0xaebd0d6e, 0x24dfde36, 0x904cf129, 0xbf0d3e5e,
	0xf7a1574c, 0xdbd09d93, 0x703f7ea9, 0xebad7e35, 0xdb90bef0, 0xbb1c8ab9,
	0xd56ef255, 0xad3e487b, 0x7186c90e, 0xac27a974, 0x410be71a, 0x72479cfd,
	0x0faca4d9, 0xf9bfd074, 0xa57fa8b9, 0xc57d1d0a, 0x7afea18f, 0xb9eded74,
	0x35cbb63e, 0xba03f773, 0xde0fca52, 0x0599f8ff, 0x125e618f, 0x09ea82e4,
	0xade087d6, 0x0d5ac7d5, 0xbfa35a3c, 0x7ec8ff42, 0x3a003fa0, 0xe6fb46f5,
	0x86746638, 0xe09b49c8, 0xae7179d3, 0x8f0c69b2, 0xf07a9b27, 0xac592132,
	0x76f3253b, 0x4f2164e6, 0xe87421e1, 0x009f92a6, 0xc6425bce, 0xcbba744d,
	0x3abb8ca1, 0x73e82277, 0xdbd79d93, 0xf31eab93, 0xdac20b75, 0xd5c91cfe,
	0xd0c8beb9, 0x461d57fe, 0xa09772ff, 0xa3f2425b, 0x82917d87, 0xfbc171cf,
	0x7c3e40f4, 0x504a0f68, 0xf28ea43e, 0x3e51dcd1, 0xddf79a7d, 0xdfbcab86,
	0xb77df1d2, 0xe7867de6, 0x7dffaf86, 0x1a89b7c1, 0xf868e6be, 0xe703563a,
	0x655fb029, 0x5cbb157f, 0x8af8f750, 0x37e60738, 0x1faeda25, 0x4867e794,
	0x14d8179e, 0x30f67df9, 0x9e506bca, 0xa79d11d7, 0xf9be0ad4, 0x99ff93d6,
	0x6478768c, 0xed13be10, 0xe5cfc110, 0xd0587ae2, 0x18ff3d5f, 0x55e9edda,
	0xc13f7b4a, 0xfa572f77, 0x2bef40db, 0x8dbe647c, 0x6157c4b9, 0x77ef9877,
	0x7e7eb187, 0xc27f7f3d, 0xfb0e9bb3, 0x1f455d7a, 0x5974346a, 0x9a7d81a7,
	0xe1ae6bf6, 0xde6b96df, 0x5f53487f, 0x6ad781ad, 0xfbf52ae0, 0xd225b3f9,
	0x7ce1fcc3, 0x97ab527d, 0x27b8f95a, 0x69ce3db9, 0x2452e7f7, 0xbd2a77c5,
	0xe1c9509a, 0xcf6ecf39, 0x02101aad, 0xe5ccef27, 0x0b5f017a, 0x3607ef39,
	0x311dee97, 0xef376174, 0x2e42ee4c, 0x3dfd69fb, 0xfc1fffaf, 0x8bd69135,
	0x3ec97154, 0xc8370d59, 0x870dde0a, 0xac864717, 0x2e40b2ab, 0x5eba23ce,
	0x772379bf, 0xe45c686c, 0x917143db, 0xfda54e32, 0xc8af6ff8, 0x265fbdf8,
	0x34ddc9ef, 0xc53bd700, 0x979da6ba, 0xba652fe0, 0x6fe4552f, 0x5c3ee3c6,
	0xe81e176c, 0xc84068bd, 0x1f6d5938, 0x2fc3671c, 0x519f7e65, 0xe807f025,
	0xb49ccf94, 0xee16749f, 0xf509efaa, 0x1792eb56, 0xbf7dbde0, 0x9fa09794,
	0x8624ba3e, 0x2dfd2df6, 0xfb9dc799, 0xe6e3ddac, 0x7110dc00, 0x86dbd91f,
	0xb951c787, 0x6caf7657, 0x4cf631b5, 0xc8dce1f2, 0x256f58fe, 0x6cf93d3a,
	0x9052ee63, 0x9d93a7ef, 0x6ed7bef4, 0x78c3ab8b, 0xd681957b, 0x3d73190b,
	0x98f3f247, 0xdbe71d29, 0xa46f4bf9, 0xdf82b0f5, 0xe78f1e4e, 0x18560aac,
	0x59a49d68, 0x913ca367, 0xda38d577, 0xb97b3517, 0x52b77d28, 0x7fbfe6f9,
	0xb0e78957, 0x744bd75a, 0x5fcdc19f, 0x0833bed5, 0x9eaaa2e0, 0x0de2ae74,
	0xbee00798, 0xf6d6cfee, 0xe33ee3f5, 0xb4e561e3, 0xd3da144f, 0xcba2b079,
	0x652777ce, 0xb6d97b60, 0xc0b7da0c, 0x5b9f8c73, 0xe237911e, 0x28fca739,
	0xcfee384b, 0x5196f96e, 0x8565a75e, 0xf845ee89, 0x733bd22c, 0xcdce83ad,
	0x5acfa462, 0x04946724, 0xd9f57874, 0x1213724f, 0xf049b9f1, 0x3e4b13f7,
	0xaebe7de8, 0x9fc87e5d, 0xf8734614, 0x724fe4d5, 0x5a38c337, 0xfb4bee9e,
	0xe6ea6ec3, 0x7a064bae, 0xfb9babfd, 0xc44ce4b5, 0x37adfb97, 0x23d7cdff,
	0x10573f5f, 0x7d9b7987, 0x68dfae42, 0xbd0b882b, 0xbcf0ba87, 0x4de0e49e,
	0xdd3173a3, 0x229e1767, 0xe41b3ce1, 0xe6f30620, 0x05bcc5b3, 0xcec979e4,
	0xf5abe24e, 0x6b1e3cc9, 0x34763478, 0xd72837f2, 0xd27ec867, 0x0fe0037c,
	0x3f216d9f, 0x84b4c277, 0x263b471d, 0x7db237f6, 0xc3274461, 0x587f30b6,
	0xdd4fe61a, 0x59be51e3, 0x299f6d42, 0x143d1096, 0xe3eeffed, 0x0eff78fb,
	0xf7de71ed, 0xe857a077, 0xbed2867a, 0xc3e2ca28, 0xc5a4e2e0, 0x1c7e47a2,
	0xe0b457d5, 0xf5c2b47e, 0x8503f206, 0x6a1f63eb, 0x7203fb45, 0xed35f983,
	0x19bad2b8, 0x2ba31e78, 0xaffdf4bd, 0xffd92f5a, 0xbf2f555e, 0xdcebf678,
	0xeb5d914d, 0xdb8d9165, 0xf9ebf1a7, 0x994589bd, 0x6fae3d16, 0xd6ff598e,
	0xb7273a66, 0x9e306c30, 0x6f5a288b, 0x5b357e22, 0x4ddb3e2c, 0xa2c05e78,
	0xb2f2868f, 0x376a6fe0, 0x968f5f27, 0x983cde99, 0xa1073a4a, 0x5e9e1bac,
	0xb893c4f2, 0xf30cf2dd, 0xf4061b4f, 0x72e6e8bb, 0x4c97717a, 0x3aed47f9,
	0x9dc1c962, 0x1d762cc6, 0x58d788eb, 0xcd662c3f, 0xced89ee2, 0x1faed7df,
	0xd769ba3a, 0xfe740d0f, 0x1fac48bb, 0x0893af66, 0xfc25a2ef, 0x0c767d5c,
	0xa89f1bcf, 0x691bfe00, 0x60db3edc, 0xfdccefdc, 0xfc93114e, 0xd6f5f866,
	0x8f290b75, 0x33b0a8f9, 0xbf7ee2f9, 0x54ae61e3, 0xae17e79c, 0x16fa230f,
	0x2fef373d, 0xb9e0674f, 0xe8475cbd, 0x9406fabc, 0x865f4e0b, 0x7e9503e7,
	0x2ffd2e4e, 0xfb304fba, 0xc31f9879, 0xd9a28a78, 0x21a5774b, 0x715312bf,
	0x5769539d, 0x7d97ecb4, 0x5f983b78, 0xff3a3cc3, 0x97df9911, 0x7e44dbb2,
	0x813d7410, 0x9ca39c85, 0xd1a0fcbd, 0x9eff8038, 0xd7c45430, 0xb3f9e0ce,
	0x8f1ea0cf, 0x738996e6, 0x94fd0a66, 0x3af95273, 0x9e5acf7e, 0x53f3a24e,
	0xdce8c960, 0x3c6ef4d1, 0xca289dae, 0x9d1754fc, 0x6d5929bf, 0xe34b2d72,
	0xe79fb4fd, 0x895df984, 0xd690a9ae, 0x51315f33, 0x796ca55e, 0x8a2c3b98,
	0x31d8bfef, 0xeb4ff680, 0x97ec768d, 0xc9d8b38f, 0x3f3c06ed, 0x25e787a2,
	0x4b176e16, 0xdcde81a2, 0x4375bb2f, 0x46363ef1, 0xbfb125fb, 0xdf2141c4,
	0xe773c495, 0x519d5be4, 0x751b7ec1, 0x35f30aac, 0x20ffbed8, 0xb4cc5fa4,
	0x8bd78819, 0x1031e932, 0x8c70f567, 0x87945ef7, 0xff3b3ce0, 0xd1e37d91,
	0x9ed82eee, 0x5821278e, 0x901f4bfe, 0xf82058df, 0x9bf62cde, 0xf78c0015,
	0xe3779545, 0x7995e47a, 0xd05ca89e, 0x52bfe147, 0x8188f25f, 0xbec1ede7,
	0x592941a3, 0xb7ea57fa, 0x8714d2c4, 0xb764b776, 0xe7da2861, 0x05de05fb,
	0x1f46534b, 0x302a7901, 0xbcdee958, 0x11ae5f62, 0x891ae2e1, 0xb17be0e0,
	0x679f28a9, 0x851abf97, 0x2c3c7372, 0x51fd1bd0, 0x1730c2eb, 0xf1b4279d,
	0xe5d9dd3c, 0xd21ce9bd, 0x05935b6c, 0xbd981def, 0xed1da7b8, 0xc05b51f6,
	0x6b47f588, 0xbb0874d3, 0x08d1b66d, 0x1137f5bb, 0x6bec567c, 0x27941fa1,
	0x78b7f389, 0xfe233edb, 0xc4a78cfd, 0xf8bfcf78, 0xfbcc1f41, 0xf536a494,
	0xfc027f41, 0x748c93ef, 0x3f912ade, 0xf7c6dd2e, 0x2ffc2bb1, 0xbe83fe45,
	0x2f7c17cd, 0xcfeaf5dd, 0x914a0f51, 0xca3b83ff, 0x7ef1c80f, 0xc363be7a,
	0xdfdfc678, 0xf8a2728f, 0x1b97802f, 0xe3b798ec, 0x47415af0, 0x3f963e78,
	0xfbe00df7, 0x1ff7dae7, 0x2bbfe4a8, 0xfc16eefe, 0x226a582b, 0x8c5bbb3b,
	0xdd91f9b7, 0xf3bfc851, 0x803bee2f, 0x3b252beb, 0x3b3b3bc0, 0x8f4103d1,
	0x147f1c32, 0x45714fe1, 0x2a378e19, 0xb976fe38, 0xc657fa17, 0xf194f8f8,
	0xf8c5e996, 0xfef17a95, 0x30fe8a2b, 0x7d5daf41, 0xfd09beb9, 0xfba5fd42,
	0xbcf8c490, 0x8a3df576, 0xbdf18a9f, 0xffcc4dd5, 0x4851b56d, 0xda2fe41f,
	0x22c7861d, 0x4d023b15, 0x40df6fce, 0x7e15f5fb, 0x0f9ff829, 0xb47711fa,
	0xe6c7c83d, 0xfc35ee2e, 0xd8f1d048, 0x3ad4f88a, 0x2dd9dfa0, 0xc9149d74,
	0x7be43eab, 0xdf28dc8a, 0xe4c3fecb, 0xd0dc71db, 0x57fb007f, 0x17d47bbe,
	0x8e7ec7a1, 0x0a1fae32, 0x665e8afe, 0x7b7bde57, 0x3bb6147a, 0x0039e96f,
	0xb6e42dc7, 0x77de8d9b, 0xef009c63, 0xca24ebbb, 0xf3131f57, 0x5e2b63fb,
	0x10182a8d, 0xddb3f794, 0xf2f71124, 0x4f16987c, 0x7c14fe45, 0x1f3ced1b,
	0xfd9be0ac, 0xf1dbf4f0, 0xae3782b9, 0xa7ca8513, 0x4e453f42, 0x5a77f395,
	0x53592579, 0xb5dca5fc, 0x3b75975c, 0x3a75fb46, 0x27f6d73c, 0x62e3a0e2,
	0x2c6b791f, 0xe5fe79e3, 0xe755fb09, 0x0c8b1884, 0xdf8a37f5, 0x7d6a9f80,
	0x3f69bf88, 0x9f70e677, 0x52797e46, 0xcf78d07a, 0x16635ab0, 0xaa7c5bf4,
	0xe3de3c69, 0x379dc4a6, 0xad90157f, 0xc5da9f98, 0x7229b7f7, 0x3f6e7c52,
	0x38897fc9, 0xc8ff94cf, 0x50c3b907, 0xa06f7fce, 0x15fc9c75, 0xcf188ce3,
	0x6b3cdbcf, 0xcf019228, 0x3f3da03d, 0x087329bd, 0x8b60493f, 0x1fe7869b,
	0xed313d36, 0xbb3e786e, 0x187ba64e, 0xdbd41fb0, 0x508607fc, 0x5878f53e,
	0x8c48ee73, 0x6d941fdb, 0xda8fb718, 0xb610f99c, 0x1ee9651f, 0x6c67974d,
	0xadd8218a, 0x505f92b7, 0xdf655ce2, 0xf381a55f, 0xd70a647d, 0xae14f4a7,
	0x9229e94f, 0xd957efd8, 0x5bdfd707, 0x3dd18437, 0x67467928, 0xb7bf006d,
	0x15e69e27, 0xca3c4665, 0x2950e748, 0x646b9b0e, 0xf4c1c4e6, 0xcf089cdc,
	0x1e9a1a0f, 0xf071ff40, 0xde3a4b01, 0xcbe4c87f, 0xfc780b43, 0x6319d7cc,
	0x319eea98, 0x29118f05, 0xfdb5ce5c, 0xe237ef29, 0xe74ec1bc, 0xd3fde90d,
	0x0d3f7fcb, 0x2de9dffd, 0xee38edbd, 0xe8c27b93, 0x8349c0bc, 0xef939efa,
	0x7b4b8e7a, 0x873949fe, 0x9c45213a, 0x9b711717, 0x3ad7ef22, 0x553ec1bf,
	0xd6bc7bef, 0x1573a53e, 0x5b71ce8c, 0x777d1853, 0x3bb7c46c, 0x6160df71,
	0xe786c98d, 0xdca04e5e, 0x6ed5fae3, 0x34a79f99, 0xb1383d73, 0xd79d087b,
	0xc394fc2d, 0x1f92b585, 0x7fef17cf, 0x9fda61fc, 0x4ae20730, 0x1ede6adc,
	0x7c79af2f, 0x45c3aa1a, 0x9e257797, 0x85b8bfcf, 0x70e8a7ef, 0x9dc1c2cf,
	0x5d9d1207, 0x763fc9c7, 0x1de4ac7c, 0x9f514c1e, 0xace8531b, 0x04de97cc,
	0x383e1879, 0x2a2fb748, 0x7c7c52e6, 0xe54bc2ae, 0xead8e905, 0x16c72851,
	0x780f9d2b, 0x1909eebd, 0xd92ac1ef, 0xe7197e95, 0xad2323bd, 0x17c9ef74,
	0xdd684b15, 0x39455cf4, 0x95bf0a95, 0xbbcddbbc, 0x2fbde81a, 0xe3d486ea,
	0x2237db79, 0xdbfec2ad, 0x576be53b, 0x719588e7, 0xf390799d, 0xccfbc157,
	0x38515996, 0x636786ae, 0x5f2047ea, 0x8c36ac23, 0xbec48af7, 0x3cb59691,
	0xb6653e8e, 0xf81130be, 0x9ddd6a7b, 0xdb1f7871, 0xd3a9869c, 0x1ee179f0,
	0xbff186c9, 0x28e4cf6b, 0xae7e979c, 0xf3c28e6f, 0x55af9f50, 0xe9f951ce,
	0xcc8d23ef, 0xfb627761, 0x733d0191, 0x6aa5f1a6, 0xe7119394, 0xf59e74f4,
	0xbca73c2c, 0xca70e5c8, 0x0c4fc08b, 0xf39913ee, 0xb4a7cf1a, 0xbcc56bcf,
	0xf718946e, 0x657629c7, 0x679e82dd, 0x4fcfe70f, 0x0939dbae, 0xc9bd3bfb,
	0xbfbc4360, 0xfea064d8, 0x4c7cc3e7, 0xda9ef807, 0x0839e7c2, 0xf4f8fce3,
	0x999f3e16, 0x33e7cb5f, 0x6e0d0b25, 0x2d53fe7e, 0xed21d98f, 0x2e9ebee8,
	0xef98ffee, 0x0f9be3e6, 0xabc7127e, 0x5668db95, 0xbec6e74b, 0xad50feef,
	0xb1a7bedc, 0xdaf2ed0f, 0x7a089c95, 0xbca3bea2, 0x7f30f22a, 0xb7a75f2d,
	0xa167a6d7, 0xa1f229dc, 0xd2aac7bd, 0x83fdf8c8, 0xda1770ba, 0x4e91c981,
	0x3b87fa03, 0x9163cd1d, 0xb953232c, 0x75b3953d, 0xc6e73c6e, 0xde9d4d2a,
	0xd84a739b, 0xc654d2df, 0xb54c59ef, 0xe29bfdf1, 0xc25297bc, 0x6fd05240,
	0xffb08e4f, 0xfc7aef03, 0x9337ca47, 0x93cf20f4, 0xe81fd947, 0xdbec62e9,
	0xf4932b94, 0x43c99e30, 0x007bbbec, 0xb7fd657c, 0x7b26febc, 0xf06001a6,
	0x858c7705, 0xeea96efa, 0xc199294b, 0x1cde9cef, 0x83e3829f, 0xf3e35fe7,
	0x37ef58a4, 0xf3899658, 0xd6a4175f, 0x82d24b41, 0x63dfdfed, 0x33bafa39,
	0x581b3708, 0xa00fde2a, 0xf3bfc76f, 0xadd53b32, 0x79e4ed4b, 0x682b6301,
	0x9f8f9e7f, 0x8f1f81bb, 0x45cf0e39, 0x502b7971, 0x6954e1ce, 0xf8b8e1ce,
	0x7ce53379, 0xa9fe7294, 0xd8fcf07f, 0x7e72efba, 0xff8182ec, 0xadc9247d,
	0xd525ff3e, 0xedee89ff, 0xe6b1f4a9, 0xfa83e230, 0xde094d5c, 0x72740723,
	0x44096abf, 0xbd179f02, 0x317a4118, 0xd077894f, 0xde0d0f59, 0xf812c03b,
	0x8407837e, 0x60ac9e3c, 0x71e97abd, 0x2fdef55f, 0xe6c780f4, 0x480def30,
	0xa1dd62a7, 0xd44e45d4, 0x8c28cae3, 0x24bfce37, 0xfb4226bb, 0xb2a71162,
	0x1ec2b14d, 0xa05b81c8, 0xffad31be, 0x193ff446, 0x389e3ca9, 0xfd481697,
	0x3493da25, 0x76822f3e, 0x672e6fb4, 0xd8b1add9, 0x87f6dcee, 0xbe01cd7b,
	0x78dbe099, 0xe836eb1e, 0xee9db873, 0xad32629d, 0x3df9fb33, 0x8be67a48,
	0x55fde3b2, 0x738aa44f, 0x501e7443, 0xf7428fe1, 0x4f80fc0e, 0x33ab1c63,
	0x57ce0333, 0xf475b3fb, 0xbe14a8f7, 0x2e17f728, 0x2cf3cdda, 0xc0521674,
	0x693a2f98, 0xab8f7f16, 0x8b7c3f83, 0x475054e2, 0xaceeca9f, 0x7fb9d59b,
	0x88c1be1c, 0x7ed8ff5d, 0xe154def2, 0x7a59d31f, 0x458cfde8, 0x3938cda2,
	0x54f789cf, 0xd3358a2d, 0xd68b23bd, 0xc43f24f7, 0x68584bcc, 0x862eb63b,
	0x9a6564e4, 0x579ff44c, 0xa0fee8c7, 0xda24badc, 0xceb13937, 0x5b54654e,
	0xfd3f3d02, 0xdc193bc2, 0xe4fe711e, 0x18fc77fe, 0xdff49fda, 0x5d64a97d,
	0x11e913dd, 0xfdc83e74, 0x918b22d9, 0x5f7a0bf2, 0xa7ed2b7f, 0x1f99946c,
	0xef07a9e0, 0xe57d2034, 0xdad72e70, 0xba1521fb, 0xba3f0499, 0xba722fba,
	0xbeeaefa8, 0xf86269c8, 0x4ee723d3, 0xf7b5bc44, 0x351c3e44, 0x4ae491be,
	0x7c47a73e, 0x0c48b74d, 0x969dc2af, 0xd4c3e6a7, 0x30d86aa9, 0xbfb24bfa,
	0x7e5ad186, 0x6fce0333, 0xf3f56e4d, 0xdf855327, 0x5ffacfe8, 0x48cd9ef5,
	0x1eb5e933, 0x780551ef, 0x1367b89a, 0xd78c39e3, 0x244dba2f, 0x09870fb7,
	0x091949ba, 0xfff97e78, 0xb553fbf7, 0xef6aa5f7, 0xcb71bd43, 0xb03c1522,
	0xf6aa17f6, 0x532dd537, 0x5607a7d5, 0x3487eaa9, 0x670546fe, 0x6aa33d36,
	0x46c8ec3f, 0xe688fd55, 0x51faaaad, 0xe0a876a7, 0xa8ff5b9b, 0xdb4b7f6a,
	0xc59c155e, 0xcfb551de, 0x82a07f36, 0x513ed9c7, 0xe135bfb5, 0x36feaab8,
	0xfd5559e7, 0x54977e84, 0xf7a31af0, 0xa5ea2a78, 0xf7aa5feb, 0xafe73126,
	0xe9d67ef1, 0x002b9d0e, 0xfd8ae7f0, 0x92d77210, 0x6f71e362, 0x4be7462f,
	0x03a3c9c7, 0xfc757724, 0xfd6a4aef, 0xc7acfe93, 0xf639f98d, 0x666f3f2a,
	0x1f4fb885, 0xb768bdf2, 0xddfe8599, 0x9b1c98b4, 0x24f58e0a, 0xcfc7daa8,
	0x13eaaa70, 0xf554fdbd, 0x2a5d73c9, 0xb87ca538, 0x25f77daa, 0xe69c156e,
	0xefb551cb, 0xc151e559, 0xa8666bbd, 0xeb5df7da, 0xf7f7d555, 0xdfd555cf,
	0x055ca5b8, 0xa25dac0f, 0x9d537f6a, 0x1e9f554f, 0x0fd552a8, 0xc151ac69,
	0x556b4d99, 0xf11d87ed, 0x3447eaab, 0x8fd5516f, 0x82ab553a, 0x53ad6e6f,
	0x2da5bfb5, 0xd8b382a0, 0x6cfb5541, 0x782afbf3, 0x5563ed9c, 0x8e135bfb,
	0x736feaa9, 0x2bd5569e, 0x7e84c8f1, 0x8b9faa5f, 0xf5d724f8, 0xf6fdea8d,
	0x4877637b, 0xbb294e74, 0x5ee50f7b, 0x1930e6c3, 0xe50f19e3, 0x41b8ec83,
	0x1596ec10, 0xf9db79cf, 0xca3c99be, 0x6e28392b, 0xc4e29721, 0xe7e03c7d,
	0x957670a3, 0x6ff18696, 0xeace3044, 0xf5c86576, 0xbb9359c7, 0x4963c233,
	0xeef8ef77, 0xd88f38b1, 0x47ee9e3e, 0x8895be66, 0xdeef7287, 0xd3ac61bb,
	0x336fd0fb, 0x90fa629f, 0x5860eeb8, 0x57c1b74d, 0x66dfcf99, 0x1ef0c73e,
	0x457ef6d6, 0x38ff02fe, 0xfe90a2f4, 0x003cc357, 0x4d60feff, 0xc40de805,
	0xb0a9bf40, 0x22a6bc11, 0x2b27e081, 0xadae549c, 0x33e547e8, 0x5faa2e15,
	0xe09c3157, 0x04dc2ae7, 0xa8722bfb, 0xa1e158dc, 0x662a9be7, 0xcc02fc10,
	0x02dcb18b, 0xb72c64f3, 0xeb177cc2, 0x17fcc1b7, 0x7c2a97e1, 0x5456d654,
	0x151df3d1, 0xaaef0435, 0x2bf04b58, 0xeb2a7e15, 0xf950b62a, 0xaa5a8ac7,
	0x23a8afaf, 0x008a8df8, 0x468a81c1, 0x3456f782, 0xe2bfbc11, 0x2a07c108,
	0xac6ca99a, 0xdbe54538, 0x7f54ad15, 0xe08da2a8, 0xf1d4bf20, 0x5ef1132d,
	0xe5039091, 0xce42879e, 0xe4467652, 0x1c848b6d, 0xe877ef06, 0xc5f711b3,
	0xf49ca266, 0xf4393923, 0xed71e25d, 0xe9294b7c, 0xf5ca395c, 0xacfbf6c2,
	0xa9d8e7b4, 0x3e01ef3e, 0xe217bd3f, 0x503f5c57, 0x2c5fadce, 0xc33dd037,
	0xe31dce78, 0x9fe58b9f, 0x70c3bc53, 0xfe441c3d, 0xdd137abe, 0x95e0a6ab,
	0xc032f787, 0x69f109fb, 0x6b375cfc, 0xab3ad034, 0x3b65b99e, 0xbe7e739d,
	0x9f9f3c3b, 0x7cd1f3a2, 0x739f9239, 0xdde71fee, 0x962fcf88, 0x9d8039cf,
	0xb45cd917, 0x0a6b98ce, 0xad93fdd0, 0xe7ca6507, 0x328f4575, 0xcbbccfb1,
	0x774e37fa, 0xe73ab8c3, 0x07dd32df, 0x32c1aef6, 0xbb04f303, 0xe779f3bb,
	0x553aeeee, 0x779c6af9, 0xb5f3e217, 0x0ea67ca5, 0x4ff5f848, 0x7f70be16,
	0x7c9e705a, 0x21354e07, 0x9ccc9dfe, 0xc8f7da06, 0x49a56fdc, 0x97a9bf78,
	0x47cce9e0, 0xef58ff65, 0xbbdbd41e, 0xef609f98, 0x676a5348, 0xd5e2d2e3,
	0x146af028, 0xe7e528f8, 0x713fde71, 0xd784dcbc, 0xed6e23bb, 0xf052e383,
	0xd3ce2dea, 0xcfad624f, 0xef5f7e21, 0xea45b2f9, 0xfe3e51d9, 0x89117203,
	0xc7681569, 0x12a47d70, 0x7d40fa37, 0x9cfc83e5, 0x791722bf, 0xf7c40098,
	0x1ce8921e, 0x404e5040, 0xe51e703e, 0x8273a568, 0x48272720, 0x74c8464e,
	0x9d5dfe1e, 0xeb448fbf, 0x988c73cf, 0x80722837, 0x5ae8f47c, 0xf9c54a0e,
	0xc839e504, 0x87c817d7, 0xd61b5e2f, 0xf655e90f, 0xd22708c6, 0xcfc752ab,
	0x96def92d, 0x1627dff9, 0xc51e5ca6, 0x7a6413ef, 0x4af30b97, 0x4b7ce2b9,
	0x6c96cc83, 0x5acec4ef, 0xfd1f3c9d, 0xefbf026e, 0x3eb352af, 0xfe727263,
	0xaf9c9c99, 0x2c9e168b, 0x77ff0196, 0xf3a69ef7, 0xffbb4a2e, 0x9f947d03,
	0x008000f2, 0x00000000, 0x00088b1f, 0x00000000, 0x7dedff00, 0xd554780b,
	0x333ef0b5, 0x4c991e67, 0x3335e4c2, 0x4c933279, 0x49309e42, 0x3ac40680,
	0xd3c30109, 0x248255e1, 0x51a0d832, 0x5a403302, 0x99deaf63, 0xd2091e10,
	0x042d60db, 0x7c509d45, 0x37bdaf5c, 0x46c1a45a, 0xc140826f, 0x1f50314b,
	0x80dadbd8, 0x10ab6ad6, 0x2da7f684, 0x6b5affad, 0x99cc939f, 0xedad404c,
	0xfdfffdff, 0x9b7c7df3, 0xfb3ef67d, 0xaf7af6b1, 0xfa7ccfb5, 0xc4ddfc29,
	0xd5e9b798, 0x6302473c, 0xeef5ca9f, 0xc65d33b3, 0xe65cbae1, 0x92c604db,
	0xabfaab18, 0xed05d3da, 0xa78c6d6a, 0x18dfa433, 0x49b18a9b, 0xecc8fd8c,
	0xbf41b589, 0x6ef9c43f, 0xf9416553, 0x07ef75d5, 0x3af9d5e0, 0x50a598db,
	0xbe76300e, 0xe3cf4a17, 0xf6832d26, 0xca9399db, 0xf2a6e63a, 0x32d0164e,
	0xc0ee6335, 0x64cb2d0e, 0x45d66eec, 0x7d96d7cf, 0x8a60ccdd, 0x0c9e543b,
	0x7eb037ac, 0x8365ee7a, 0x633b5695, 0x8f9b5a4b, 0x8b631958, 0x48cc77da,
	0x30b631b6, 0x9608f2b8, 0xef09f60b, 0x4bcca007, 0x5d71d8f2, 0x736f8203,
	0xeb7fcc0a, 0x539be5b3, 0x757cf9e1, 0x44d2d26f, 0xd4bff178, 0x5ea027ce,
	0x3a973223, 0x7fbee47e, 0xd9e4f66d, 0x5cbee126, 0x6c752fb4, 0xf6078e55,
	0x7b2eb35f, 0xca10a78c, 0xc025cc8d, 0xe92f8338, 0x3d617b82, 0xc11b16d9,
	0xead97e63, 0xbac2a55f, 0x1b783899, 0xcbef7683, 0x766df8ba, 0xe19b97dc,
	0x6317053e, 0x809f304d, 0x7f094373, 0xc644e2b9, 0x13833356, 0x0356fdfb,
	0xdbfea04f, 0xc16c1674, 0xac5cc0ba, 0x1a0bb184, 0x0630ab63, 0xd63c32da,
	0x5dcf5812, 0x4185b02c, 0xecf557bb, 0xd3538478, 0xf70b8f58, 0x5dbbf77b,
	0xb9e18a5b, 0x219822a6, 0x679a38c0, 0x071c4e74, 0x5fbd3366, 0x0f32f300,
	0x9e1a34fb, 0x78431f33, 0x3b8e0bfe, 0x84bae461, 0x147fa3b2, 0x69d31962,
	0xf30f4059, 0x9b182a07, 0x5205e30c, 0x0016c1b4, 0x36820b51, 0xdb71e70b,
	0xe391c67c, 0x7bd6949f, 0x69b02fec, 0xf6004380, 0x691084f3, 0x51fc9f9e,
	0x18f30f18, 0xfdc1e786, 0xe68ccc07, 0xd3b36159, 0x31f3c879, 0xbb9a40e3,
	0xe0cef008, 0x87cf0db9, 0xcc551359, 0x137ad8cc, 0x3cc61ffc, 0x038dff66,
	0xd4fe67cf, 0x2f3c34b6, 0x8f1a5fc0, 0x3e08557d, 0xd975c761, 0x593f5802,
	0xe006776e, 0xd36602f1, 0x52dcb9e0, 0xb83393f6, 0xc6f45b8e, 0x6c94355e,
	0x81a3e69a, 0xf61f3a5c, 0x6e152669, 0x19da1936, 0x1b4d879f, 0xf3bce223,
	0x8b761779, 0xef87dbd8, 0xe0d4e633, 0x2fd8f2fa, 0xf9ec7864, 0x95f68134,
	0x67408beb, 0x847eb1b8, 0x30b3689f, 0x7c0bd728, 0x0dd3ebff, 0xb623a441,
	0xa7f68f3d, 0xc379f3d5, 0x3354b7df, 0xeb4bd0e6, 0x1ec97f84, 0x0ee4733d,
	0x4deb53d7, 0xcfba7a8a, 0xb63fe8aa, 0xb768a6c9, 0xed157207, 0x454ead59,
	0x4cbdbb3d, 0x875c7fd1, 0x0bcf514b, 0x17fa2956, 0xd456ed3c, 0x15aaba8b,
	0x7b7427fd, 0xbdc5ed14, 0xd2f68af5, 0x7d453e63, 0xa2937f52, 0x04ce57ff,
	0x0653ed14, 0x37ed155a, 0xa8aed07c, 0xa1d838df, 0x95d37fe8, 0x9cbda2a0,
	0x7da2abfd, 0x4539feba, 0xa0e9867d, 0x51e3ffa2, 0xd019e3b1, 0x3ed6cdcf,
	0xb659f3c5, 0xe6f78ae3, 0xd4529ee4, 0x39ce971f, 0x7440ccb0, 0x1d4ab3b1,
	0xf338c2d0, 0xc62b6f9c, 0xfcf93d61, 0xb3f8a3fc, 0xbafd8ec7, 0x63e4f918,
	0xe23b41aa, 0x4a6d4dad, 0x94763a41, 0x6804382d, 0xeb5c72c6, 0xe5bd902a,
	0x8438ed56, 0xb9fbbe65, 0x561f200a, 0x10ea7d58, 0x173de396, 0xe638602b,
	0x057b8fac, 0xf15f12cb, 0xa52e0b74, 0x582bc169, 0x9bac0e4e, 0xf1f57c8e,
	0x48f9b5fb, 0x32f1b147, 0x3f08ba7e, 0x4455931b, 0x8ccb8dcf, 0xe63fe441,
	0x03228c1b, 0xaefe613e, 0x8f1b1379, 0x962b4965, 0x0b3d7ead, 0xe2db196a,
	0xf36e5467, 0x0730589b, 0xa56fd9d0, 0x55a9e37a, 0xce309955, 0x04d15ad8,
	0x71a660db, 0x60db25f7, 0xda0fcb7c, 0x1939f773, 0x97eda5fb, 0xe7b0350b,
	0xb2df2cd8, 0x33ac38ce, 0x8b8062d7, 0xa6c46019, 0x7edfb632, 0x38503b8f,
	0xe1d73eb2, 0x41f215fe, 0xb9e57626, 0x6dc78663, 0x53adf8ab, 0x36084265,
	0xdc030fba, 0xe8192577, 0x3b97ac3d, 0xaeb8cb3e, 0xc0df910f, 0x04575f73,
	0x728f3e3a, 0x57f61263, 0x2dc2bf11, 0xf859b9e1, 0xc88b31b1, 0x96006302,
	0x9d34a6bb, 0x679713bd, 0x9fc8080a, 0x1f7855d8, 0x760a4af8, 0x4dfaa2ca,
	0x6327a806, 0x2198c6dd, 0xe71573db, 0x3b1878b5, 0xc93f8217, 0x2efacaf5,
	0xc739f380, 0x2b347af0, 0xf6110154, 0xdbbef9a0, 0xf67984e9, 0xa17ec2d4,
	0x56cb4bbe, 0xfb870bb8, 0x9231538d, 0xb9d8b7ef, 0x1757673c, 0x60c41739,
	0x61e7ef9d, 0xf7d2e0ff, 0xff0edc60, 0xea532a15, 0xf807827d, 0xedc6a59b,
	0x4d3f400c, 0x70a3c00b, 0xed123c24, 0xf341c122, 0x0d82bdca, 0x36ecb9fa,
	0x26a52f1a, 0xad4efb48, 0xd6437187, 0x8203156f, 0xef5b9e09, 0x3eb8080b,
	0x64edc9ab, 0x9bd31ef0, 0x4837ff09, 0xfa6d6134, 0x4af7d2eb, 0xdbbf5c61,
	0x7334fd89, 0x110b3f00, 0x83133ea0, 0xc4da52f2, 0xf9c22c31, 0x406ea5c8,
	0xa3a55cc5, 0x7c66c7b7, 0xe2f247cb, 0x1b2da356, 0x65f1fbf0, 0x08ceeac6,
	0xf824b9e3, 0xce578d6c, 0x7873566f, 0x92fb7cc8, 0x4ca39f89, 0x98e21bc7,
	0x486f8f82, 0xd6b9689f, 0x7a1d2d7a, 0xef5909e6, 0x04c7982e, 0xb2feebe3,
	0xd7fb84ce, 0xf34dcc09, 0x749f9c89, 0x89db9a3e, 0x39f8447a, 0x6047c08e,
	0x104a633d, 0x2d82063f, 0x5aba8740, 0x26f513ad, 0x116f3fcb, 0xb0a73650,
	0x8bf90176, 0x98f2bd25, 0xf44d7288, 0x1b5ca1e4, 0xe0ebbeb1, 0xb27e7ca5,
	0x2f3f0e7c, 0x6f59a7cd, 0xffbc2395, 0x1f50c34b, 0x293c7f5b, 0x4f8213de,
	0x2cbc25ab, 0xa46aed63, 0x8baca98f, 0x9fac69ca, 0x41b2afca, 0x24cc5d2a,
	0x9cc15962, 0x37325654, 0x8f993395, 0x4ed62aca, 0x45d66ce5, 0x4fd65ce5,
	0x48367ce5, 0x34999ba5, 0xf9042e58, 0xe662e58d, 0xcc6bf2a6, 0x88fde547,
	0xd5cf80bf, 0xb7ea9dac, 0xbb2a2eb2, 0xc06cee81, 0x7e045ecf, 0xf00f6587,
	0x065f2c39, 0xaf65873e, 0xc06cc6df, 0x73f90ef7, 0x77ec3ca9, 0x5fd47952,
	0xbf31e546, 0xeabdfa8b, 0x84f2a2af, 0x49e54ddf, 0xfd95357f, 0x3bf50f7e,
	0xf2a7afed, 0xca8fbf75, 0x544dfd37, 0xa807f19e, 0x95bfb9fc, 0xa05a71ca,
	0xee6f8467, 0x3842f140, 0xb5778cff, 0xe7f01b2e, 0x7a5f12e3, 0x5efaa5c5,
	0x373c44de, 0x1e21d315, 0x10106e54, 0x2ab92cff, 0x6dca1057, 0xaf85ebb9,
	0x24f5b943, 0x9674dfd7, 0x2d0fd218, 0x0d828d1d, 0x0616edc6, 0x9670d1d4,
	0xeabe778f, 0x2e7f03d6, 0xa29b61ef, 0xad7f589d, 0xd7780f5d, 0x760df1a9,
	0xf6c3fb42, 0xd4fb529f, 0x7bbfd398, 0x7da9d786, 0x62d661ca, 0x9d13fa82,
	0x0513dba7, 0x7e640ebe, 0xc37f61ff, 0x3ae22cdd, 0xb29f9c39, 0x99ca00b3,
	0xa48d7bc1, 0x9c77175f, 0x7d41562b, 0x04b1934a, 0x7ed0aa94, 0xa3f788bd,
	0x976f0bf5, 0xceb3dbdf, 0xd87082dc, 0xe5a83efa, 0x6b2328f0, 0xa17d78a0,
	0x67d55c72, 0xafa99f9b, 0x3f687f31, 0x19e31ae1, 0xd82f5db2, 0xe3cffe93,
	0x6b7e3879, 0x39f77d3e, 0x47d89a95, 0x7dd3ca3c, 0x0ccf9c71, 0x17ba7e82,
	0x5e2fbdd6, 0x6839b7aa, 0xf10fc85f, 0xcb6eb6dc, 0xbea0060c, 0xfebdca2f,
	0x5b7fb638, 0x4d0bdce5, 0x6d9e0cfb, 0x38775479, 0xbfb0daf7, 0xe01e372f,
	0xe5cd119e, 0x6fb4ced2, 0xe842d945, 0xdb9dacff, 0x5da6bb63, 0x3b44efee,
	0xb2c555a2, 0xadbdbde1, 0xc2e5b7b7, 0x0edfdf38, 0xc7d403fa, 0x96d758dc,
	0x6d99ed0d, 0x896ac9aa, 0xbe3ae1c7, 0xc9eebdbf, 0xa55fa86d, 0xc0e7c7e5,
	0xbf1259b8, 0x281848cc, 0xbe7800de, 0x23eacb53, 0x240ff3c9, 0x6183a97a,
	0x665e01ce, 0x3afaf8e8, 0x543aac35, 0x3933e9de, 0xe6c9cd7f, 0x04dcd4eb,
	0x74fc86f8, 0x11b821ac, 0xd63e5ff6, 0x6f31f048, 0x578107d2, 0x9fda7333,
	0xed0cdd4e, 0x272a3de6, 0xa5a274aa, 0xfa8359a1, 0x85d632fe, 0xf029d8f4,
	0x5ce903f7, 0x2145042f, 0x10f8f913, 0x599ff7ff, 0xeb8710ea, 0x8080ead6,
	0xd8f97bf6, 0xe5006106, 0x82ddda4f, 0xb9b4f80d, 0x627823da, 0x51f03ed0,
	0x47b6457b, 0x5a7584cc, 0x50fde06b, 0x927992fd, 0xde615cf1, 0xf3d22eea,
	0x7ce84958, 0x0e1cd9c5, 0x264ec19b, 0x9693757d, 0xaf0e15d6, 0x988a9ce8,
	0x73e1a4cc, 0x97ef6f0c, 0x236fb4e0, 0x3074814c, 0x27cddb85, 0xfd21489f,
	0x834efe71, 0x93a7ed0b, 0xa92bf23b, 0x1754e0fe, 0x9f2791ea, 0xcb133a98,
	0xa6ce0ff9, 0x7605277e, 0xf9e1ed0c, 0xe22ade0f, 0x582c8cf3, 0x56778e17,
	0xff38f84b, 0xf7a5bbc1, 0xed8955bf, 0xbfc0aa65, 0xd6591da1, 0xda344cf2,
	0x9e6353c9, 0xa4f2c54f, 0x0fb1a06a, 0xc4c5bfe6, 0xd9e28a7e, 0xedf896dd,
	0x82cff82a, 0xd41a991d, 0x33334baf, 0x988bbd69, 0x7a00e88b, 0xed375d90,
	0x4057fee9, 0xed5f6293, 0x660e9c1a, 0x9b75732e, 0xd159630e, 0xf044aceb,
	0x1f731e55, 0xbf6672c6, 0x97d512af, 0x87ed33aa, 0xd7287cb1, 0x79f08a53,
	0xf6bf9fea, 0x1f5053fc, 0x09a37f7b, 0xc6c720f5, 0x917b5981, 0x186b8e1e,
	0x32eec3d2, 0x111abb5f, 0x851edf58, 0x957921fc, 0x5cf2854a, 0xc38f6f67,
	0x43956eba, 0xbee17685, 0xda7af6b8, 0x2181b677, 0x39055f1c, 0xdbb17884,
	0xf4851ed4, 0xe7497404, 0xf1c99e50, 0x33e71752, 0x28f3e1c5, 0x9fa87cfe,
	0x1e6fd781, 0x271ed7ea, 0x02893cd0, 0x36a09fd9, 0xc920de90, 0x2f805def,
	0x639817a8, 0xd7e89d3c, 0xf4e2edd9, 0xbc72301f, 0x405beec0, 0x021b457f,
	0xf76d68e1, 0xa0fb21cd, 0x840c0c46, 0x062005ea, 0x41b45c71, 0xcea03cf0,
	0x29debed0, 0x19f03af0, 0xa1fe175a, 0x346ac31f, 0xcb1d2277, 0x947b37eb,
	0x163ee1e3, 0x93df871a, 0xda41aef1, 0x7f84bd57, 0x3c7c3dbb, 0x326bbd79,
	0x023f5c6d, 0x9332adb1, 0x03d7c6fe, 0xac8550fb, 0xed1fa427, 0xccdd686f,
	0x00bc4569, 0x8e90123a, 0xe8624a10, 0x5744ebfe, 0xffae2c54, 0xdf883dc0,
	0x6047c8b1, 0x9be9df9d, 0x0d3a27a2, 0xa67347db, 0x1169e69d, 0xedea027d,
	0x823c6bb3, 0x02d3f60b, 0x8c768cf4, 0xd39baa59, 0x66d79244, 0x2682ede3,
	0xb4e6bf64, 0xb3d3923a, 0x1acd3dab, 0x65d9c738, 0xefc44ed1, 0x936bac39,
	0x61f7d389, 0x1c6fac07, 0x3233fa1b, 0x71d03f79, 0xe9c55d5f, 0x3a6ff872,
	0x43cf2deb, 0x1dff79f9, 0x768e9173, 0x31f66b7e, 0x6e6a7f5c, 0x78b21f67,
	0xee7e45f7, 0x75fb96ac, 0xf7c47b1c, 0xd691f742, 0x3e10f508, 0xaca0d293,
	0xea283e03, 0x84595e32, 0xb7f438fa, 0x670ba2a9, 0x8cdf20e7, 0x3f389955,
	0x638b080f, 0x1195f246, 0x5fc12578, 0x33a79f3e, 0x66fe741d, 0x81ce8aa3,
	0x4bf53a0d, 0xcb9da462, 0xb41304e7, 0x018f9900, 0xaa54b578, 0xcf1d8283,
	0xdea3fa0b, 0xf092c83b, 0xa9cfc35c, 0x9d9b6353, 0x877a7c83, 0x1b04f4ca,
	0x33905709, 0xbb5e906f, 0xe1da9123, 0x7f27a8b9, 0xef238c1f, 0xaea91d5b,
	0xf5eb8f3c, 0x2ff5947f, 0x7c8fb1c8, 0x78b69a9e, 0x2fac1e76, 0xfce8c7d5,
	0xddc7dbc3, 0xb2573ca7, 0x7da2273f, 0x5fbd82c6, 0xa7673ce0, 0xfb24abed,
	0x655cec27, 0x8848cbbc, 0xb36a172c, 0x44667d38, 0x91574f3b, 0x9e92215e,
	0x93174ee0, 0x81a2ed42, 0xdc076e4c, 0xc92323f4, 0x3eaef621, 0xd9d72288,
	0xee00ffdb, 0x0ab2e2b3, 0x391d918f, 0xb3bbe871, 0xd3f19ca1, 0x17ffd7d7,
	0x17f19bf4, 0x7f3e2963, 0x42cc0d91, 0x18e04887, 0x6f5019d8, 0x76c9f8fe,
	0xd4b49474, 0xddca2730, 0x726575a1, 0x4d63f779, 0x35fc4dd0, 0x897b644f,
	0x2e65820f, 0xd3b70b9f, 0xbc4e74d5, 0xda6bb98d, 0x38b46ec9, 0xa357810a,
	0x396baf5b, 0xb48fc5f1, 0x0b8efd0c, 0x729a6dab, 0x1ac2ffd8, 0xd225669b,
	0x50aac8b3, 0xed54588f, 0x6a8be7a4, 0x9eb9fc9c, 0xed5c5f3f, 0x6b8be7a2,
	0x11b9fc5c, 0x963c039e, 0xfdfb0754, 0x6312ee30, 0x7e854dbc, 0x6f371af0,
	0xf6a3a2bf, 0x380f6013, 0x510de500, 0xedf7e241, 0x5ce8a81f, 0x840c1a5b,
	0x9298bad7, 0xdf843663, 0xf513954a, 0xc8ba5d28, 0xa8ef504c, 0xd0d50776,
	0x4f6b30fe, 0xe8bdfdc6, 0xfa426f59, 0x344d317b, 0x745efee1, 0xf08cdd81,
	0xd98317ab, 0xa1c90976, 0x5a5d62fe, 0xfde91b70, 0xab027f1c, 0x0567e4f4,
	0xacfc875d, 0xa48a556c, 0xfd3970c7, 0x4189edc8, 0x3ab1e3e4, 0x08b9abe7,
	0x79f827df, 0x8a2fa77f, 0xcbef33c6, 0xd1d9460c, 0x57c10c8e, 0x7b77f486,
	0x1ab3b639, 0xe7f9c266, 0xa367b8d6, 0x87b2d91e, 0x030d9139, 0x70fbd37d,
	0x0ecfb49e, 0x04cae9cf, 0x9d3bb7ac, 0x0a004e6a, 0xd9e2d0be, 0xfb86dc78,
	0xb2995069, 0xde97f619, 0x87d8a86f, 0x39e99070, 0x9943a25f, 0x37e48c7f,
	0x8e3863ce, 0x73855975, 0x07cbf41b, 0xec7e8c19, 0x824eb447, 0xd156e073,
	0xef96f889, 0xb14d7b11, 0x269df4c3, 0x748f9b8d, 0xad3ee388, 0xfb71b7a4,
	0x47b47494, 0x5847d3a2, 0xe38098af, 0xd71a3076, 0x07eca1d1, 0xf280969a,
	0xa75e9c28, 0x01f90f66, 0x01187014, 0xfbc886e7, 0xd757de1c, 0x97da1cf1,
	0xf90bef8a, 0x31cf3c1a, 0xf91c7f3e, 0x48b54e61, 0xdac1c6fc, 0x1dfee34f,
	0x685044fb, 0x253cbce1, 0xee6f7c06, 0xb5b11576, 0xf89fac79, 0x2df6f5c2,
	0xf7c237fb, 0x81bfbe19, 0x23e7354c, 0x59b83eb2, 0xcee0fa4f, 0xc631017b,
	0x4065be90, 0x764542bf, 0x00b3d7c5, 0xdf12f50e, 0xe6aa7cd1, 0x48c5a4fc,
	0xdcb1aa78, 0x7fea1b97, 0x51579a98, 0x12fd459f, 0xdc515616, 0xa3714348,
	0x43b63e70, 0x00ca6f1a, 0x7fe14fec, 0xc85b3036, 0x8c1c6efe, 0xba6fd457,
	0x5fe8a292, 0xda17c40e, 0xa05f5d3e, 0x2a619f68, 0xb66fd455, 0x3fe8a0de,
	0x515d36cb, 0x473b939f, 0x739e7fd1, 0x4b7ea291, 0xff4572d9, 0x2bafae05,
	0xad5517da, 0x712fb456, 0x97d4506f, 0xa293ff56, 0x8b4f32ff, 0xfd797da2,
	0x70f68a03, 0x1f2e49fb, 0x777ce2c9, 0xca77d597, 0xeb953c45, 0xfde41153,
	0xc7b9e860, 0x2a7d7346, 0xa42fdfbc, 0xe05c78f3, 0x18c1b1f3, 0xec9dd215,
	0x315d637f, 0xef5cff0a, 0x01faa9d4, 0x9c72fa23, 0xb33d216f, 0xc51fdc93,
	0xd93dfc82, 0x11b7d57f, 0xeb78c1fa, 0x282d3263, 0xeaefd0ef, 0x04fa02d1,
	0xb7bfe455, 0xf80a36b4, 0x91bdb2dc, 0x68ae55fb, 0x64212799, 0xe7c0cc1d,
	0xf239e295, 0x9a2b993a, 0xf8a307fb, 0x5f923df3, 0x2bf461e9, 0x2ff630e5,
	0xef0fd966, 0xcb9371a1, 0xcff401b4, 0x413e7508, 0xc3cb7c8b, 0xd71b3a4c,
	0x5a0fc907, 0x22c31ced, 0x772e59c0, 0x05ccadfa, 0x031b5be3, 0xdbd85acd,
	0xebffbe4f, 0x7de1bb1d, 0x32918fab, 0xffefb3f0, 0xc8334766, 0x6cb2b791,
	0x459237c4, 0xd647e70e, 0x93e1f8be, 0x5acedf30, 0xd5f20973, 0x6f54f6f0,
	0xd7a3c5cf, 0xcd647f68, 0xb8efb781, 0xbb6bfbd6, 0x69096ecf, 0x5a2fd51f,
	0x215cc29d, 0x45d36078, 0x26ffcbf6, 0xde0deb8b, 0x63f25aa9, 0x79ed437d,
	0xc2ffe90f, 0x7e4d3fd4, 0xfedfa19a, 0x07c86df2, 0xb26ff9e1, 0xeb823f78,
	0x1927c779, 0x00a33cf8, 0xb7187bf4, 0xde322a25, 0x7c7c1d9a, 0x883352d1,
	0x31f5a07e, 0xf9da1b5a, 0xc80ffaa9, 0xe1addd4f, 0xfdb87576, 0xbd90c8fe,
	0xb7f645dd, 0xfff1c1c1, 0xa81d12af, 0xa67dfc4d, 0x2cd1300f, 0xe01167e9,
	0x10ed8ea1, 0xd4a55f90, 0xd287ef89, 0x968c5f45, 0xa36608fc, 0xd63077e4,
	0xb202fc2b, 0xe62fa0df, 0xdef1010e, 0xf9177bdc, 0x805fd1e9, 0xfc1d99e3,
	0x05fdc25c, 0x968ffaa9, 0xad7097be, 0xf3d0d9f1, 0x3cc22168, 0xfd90eb61,
	0x04f3e113, 0xf9409f51, 0xfa40c6bc, 0xe7bef844, 0x1d53ca3a, 0x83234849,
	0xfe466ea7, 0xf2435a7d, 0x897c3468, 0x305819b2, 0x473cfc64, 0x3a39c126,
	0x3cf15e37, 0x82c299c6, 0x669ef90a, 0xaa5a3f7a, 0xab198883, 0x871b681d,
	0xe7cabdf3, 0x5a71a93b, 0xb1041f49, 0x82777287, 0x3fd9cb83, 0x909318e1,
	0xde5db8ce, 0xe58c7401, 0xe9137ec3, 0xfe807b67, 0xdf98feb0, 0x9fd06546,
	0xbf5ee54b, 0xf9f7da93, 0xa4fea8cb, 0xa7f545df, 0x3e5455fd, 0xf3d377e3,
	0x54d5fd67, 0x87bf77ff, 0x3d7f2eca, 0xefde7f3d, 0x7f7efaa3, 0xa00fd513,
	0x9fa2283e, 0x17ca95ba, 0xded4edfd, 0xfaa0efe3, 0x9520fecb, 0xe9a7febd,
	0x177f21f9, 0xbbfb0fd5, 0xdfd47ea9, 0xfe63f54b, 0xeabe5463, 0x27e7a7ef,
	0x1ea867fc, 0x78a4c795, 0x3fbf6b57, 0xd16bed11, 0x6eddfa86, 0xf5099d4f,
	0x954aeb6b, 0xe839d909, 0x9fa17757, 0x8f0d4f63, 0xa9d759f7, 0x56c40fc8,
	0xb49f48a9, 0xf8e87cae, 0x4c5f6a0c, 0xc870bbed, 0x758fc064, 0x6b657f5c,
	0x52cfd4b4, 0xec5e122b, 0x7d21a869, 0x40c73db5, 0x227596ed, 0xa88f7de9,
	0x9764717c, 0xff1226dd, 0xfeb868b6, 0x9d41e320, 0xb8753e74, 0xcc5f2878,
	0x9b14e7e6, 0xdc8e5915, 0xa6f590e7, 0x3fb863d6, 0x0fec2d6b, 0xa8db5bd7,
	0x65a5f8c7, 0xe60fec15, 0x5aa75dd9, 0x91d60877, 0xabdb92b6, 0x0bf21eb0,
	0xd92295b3, 0x4dda9629, 0x95b4aeb4, 0x6778e50b, 0x1de9da1c, 0xb405c6be,
	0xfc911ade, 0x439e1d9a, 0x4f90ab71, 0xd25fb8aa, 0x07706492, 0xe7ae470b,
	0xeff5b0be, 0x486edc61, 0xb9e97d03, 0x8b00fb08, 0xfdc7ee47, 0x23e9f778,
	0xebbef1fa, 0x4d28f2e0, 0xbec7f4e0, 0x3dfd1221, 0x10a37ac6, 0x11ae1fef,
	0xb5226f29, 0xe87599e2, 0xc399faaf, 0x8c071df3, 0xe26da8fb, 0xf1ea1121,
	0xccfc7c55, 0xb549f146, 0xe1fde740, 0x76de7816, 0xda3776f7, 0x6ddb09c6,
	0x1d6e48cd, 0xa3240f2b, 0x504d2bff, 0x765c8f9e, 0xcc7cfb4a, 0xb87bc7c5,
	0xb27f2451, 0xfb7edd65, 0xa3ef3e61, 0xb8ca6f38, 0x7a61445f, 0x9b62d646,
	0x5a46590a, 0xe71178ad, 0xbdbd5a8b, 0xda4be70a, 0x2be792ee, 0x2b3ef9c6,
	0x5fdec69c, 0x5844f169, 0xe4fc68d7, 0x79e47c7a, 0xe6224c47, 0x9654b083,
	0x11e47c8a, 0x815be70d, 0xa49f5c53, 0x23299864, 0xe7e391e7, 0x3c3d3c72,
	0xc127de8e, 0x39175529, 0x74aafb0e, 0x9513309e, 0xb9b6b98f, 0xe304bf29,
	0x5eb4d0b3, 0x73c2eec3, 0x306e5f5e, 0x07c04735, 0xf9107cb9, 0x070df218,
	0x5ed9c693, 0xf151c7c5, 0xeb646e71, 0x346e5ea8, 0x6bf02205, 0x1a487cb9,
	0xf1c1d7a7, 0x67eef536, 0xf9e28edb, 0x9ca1aabe, 0xc15587a0, 0x4e2fb236,
	0xa6bf89aa, 0x9f3abba8, 0x59d7590c, 0x6b0f3f69, 0xa44e7983, 0x10af181f,
	0x4bd22af9, 0x80bfe621, 0xbb81086c, 0x25cfdefc, 0xd5e8fd39, 0x5f1471ad,
	0x8514ddae, 0xd30751fa, 0x34583e13, 0x10e2b8be, 0x5e20b07c, 0x750fc046,
	0xef8e56b6, 0x6327cb1b, 0xe5cb865c, 0x6097c8e9, 0xc5d52fdd, 0xbe9c3c92,
	0x1339f5f2, 0xb2ed3ea0, 0xecbd44e8, 0xb53d06e1, 0x8ab5f94f, 0xbe5e26f2,
	0x5f7ddb9f, 0xd92566fd, 0xb952c975, 0xa6f3b25b, 0x2f6732b5, 0x3ab4cb9c,
	0x3753d923, 0x85cf115e, 0x92e449da, 0x05f6889e, 0x30dcd7f7, 0xf821ed08,
	0x6503e537, 0x1aa8807f, 0x01e48cf5, 0xed6b73e5, 0x6033b3fe, 0xfe068e9e,
	0xb7d5c772, 0xd03d638e, 0x093f22a8, 0xffc49f60, 0xe7e4c902, 0x0bc90314,
	0x33d36ca0, 0x9596e7e2, 0x83f2137a, 0xf881b33e, 0x2332c75f, 0x1d5ba1e9,
	0x4f50a3eb, 0xc636d5d6, 0x1b563961, 0x69df44e8, 0x85f6f64a, 0x6fc429d6,
	0x400bfca5, 0x07d032cc, 0x9495aebe, 0x383f6f9c, 0x52fc81c3, 0xd969ed45,
	0x880c1fdb, 0xd69dbcf8, 0x14b15361, 0xfaa1f9be, 0xc86fdcad, 0xcce805e5,
	0xcb8f5829, 0x51b3d8f3, 0xf40c4caf, 0xe32ed361, 0xd7f21ab9, 0x9d1224d6,
	0x4c7cea69, 0x4a6bcf8b, 0x2e74a1f4, 0xa5e7c9d3, 0x38a58fff, 0xc0f8f5df,
	0x1ebdc6f5, 0x3933ebbd, 0x4f668dfd, 0xa7e146eb, 0x9b5c7db2, 0xc90ee9c5,
	0x39eae496, 0xaafd446d, 0x95678a43, 0xc87e7969, 0x5599eafc, 0x0c098714,
	0xd6c79888, 0xa9e9cd9c, 0x71431cc3, 0xd64c8ee2, 0xc083718b, 0xefee2aed,
	0x3affe449, 0x3fc9326a, 0xc5f053b4, 0xbfd0b205, 0xf9e3b1ee, 0x628c0075,
	0x199dfe60, 0xa0b3af9c, 0x6af184cf, 0x743ea718, 0xbbfc11fd, 0x1e530fa4,
	0xcf689a83, 0x67f10da6, 0x88c4d258, 0x071b8bfe, 0xae9bf595, 0x4ce5eb28,
	0xd74fa8a3, 0x4c33eb2b, 0xda57baca, 0xe556cdff, 0x653659f3, 0x70fd2d3d,
	0x04e28a94, 0xf65d7ee1, 0xd297fa3a, 0x556d3da5, 0x97080975, 0xee0681f4,
	0x3e00cd97, 0xefc11b10, 0xe39bdaca, 0x57fe9185, 0x413ae16b, 0xd35c378a,
	0x67839ecf, 0x51e28533, 0x1e31b39b, 0x3c763e35, 0xd5b247fa, 0x3c3cfebe,
	0xa2448e87, 0x1794bb23, 0x3e3e5234, 0x8f217848, 0x08107483, 0x7fe22fd9,
	0xcf3f3d68, 0x079c5df3, 0x2a1020e9, 0x34070b2f, 0x7cf20748, 0x4c83d1a3,
	0xdc52658f, 0xb9abce44, 0xe7258d2c, 0xf94a34d5, 0xf961dd71, 0x2ad39738,
	0x72e81f29, 0x244306ff, 0x0b3a43ba, 0xc3ba70e4, 0xafca4db2, 0x680bba41,
	0x73e1dd39, 0xb9d65fdd, 0x3787e923, 0xfab0784b, 0x7bd328e9, 0xd35bfb21,
	0x7ba8a715, 0xa14d93bb, 0xf1ab4ef9, 0xd5e4983f, 0xb48f28ca, 0xc7ceda41,
	0x64fe7f67, 0xab8f940b, 0x7f91073d, 0x473ec9ad, 0x0d8cd179, 0xdeff916a,
	0xc01efa8c, 0x647a7623, 0xec84f57d, 0x558debe7, 0xff642df8, 0x361dfac3,
	0x37bc3c4b, 0xc9c320c6, 0x53bca7a9, 0xda319fc9, 0x18aee839, 0x6f242d98,
	0x18fa275c, 0xb12b9bf1, 0x99fa56cc, 0x10a7c3e2, 0xfff3460f, 0x338a56fc,
	0xfafab56f, 0x61a3ffd1, 0x1c515760, 0x1933e014, 0xa7fe26d5, 0x4b7cf036,
	0x0fd29a4d, 0xa24161a4, 0xea62479f, 0x59927e89, 0x6657e280, 0x9be7a3e6,
	0x3d126763, 0xeb9ba08d, 0x3e630bd0, 0xe6137286, 0x7f5f3c53, 0x2d27972f,
	0xeb83d382, 0xffcfdf0c, 0x154fbb14, 0xf49fb133, 0x4d8374c7, 0x6fbd0d77,
	0x8693dfa7, 0xf8356fef, 0x9bd631ea, 0x6121a4f5, 0xadfdc833, 0x58d4c4b1,
	0x176393f1, 0x4ee59e61, 0x27374f09, 0xcc9f08aa, 0xd53b9ab7, 0xd664f821,
	0xf7a8ec7a, 0x9e525599, 0xbfa1fe13, 0xef79b368, 0xcbf308b6, 0x5e90cbfa,
	0x08eb0d57, 0x929dc3a1, 0xdf3438de, 0x754e94f2, 0x9d6638c8, 0x93e698a7,
	0xf9e4faf3, 0xf9b17cb6, 0x1f7e4976, 0x6dcb3e79, 0xb459fdca, 0x459fda3e,
	0x7cf2bfe2, 0x117f70bb, 0xf3baeae8, 0xd0e47649, 0xfb942b7c, 0xb47ce8b3,
	0xfb9a8b3f, 0xdbe686cf, 0xdbe6c5f2, 0x89e5c51c, 0xd1d3a246, 0x865bdef2,
	0x26dd8af2, 0x659b3fe4, 0xdfc4987f, 0xefe3093f, 0x2efe25eb, 0xa249ffbf,
	0x9f9bfc83, 0x8a645b1c, 0x9f91d7c4, 0x628f4933, 0x24c51e92, 0xf3eb0a3d,
	0x4c6d9fa7, 0x3bbc3c02, 0x1122d267, 0xd5fcd8e4, 0x40662767, 0xb7ce637d,
	0xb3a9fd79, 0x95e153fb, 0xf36673f7, 0x5ecf77fa, 0x10a2734e, 0x12a8b0df,
	0x026c76f8, 0xbaf2bfe7, 0xc9ef79e5, 0xdbd7fce1, 0xbfee5bf4, 0x7c893e03,
	0xc7c325bb, 0x2176bfd0, 0x2576306d, 0x0fa6f7f4, 0x008f6f9a, 0x36f4b917,
	0x1b3f279d, 0x7fe43cb2, 0xe3e7190b, 0x09fbe50b, 0x09fbca55, 0x48dbb1b1,
	0x416289ff, 0x68bbf213, 0xf5834bbd, 0xa236392b, 0x59cc25d3, 0x5b66f5cd,
	0xe057cf36, 0x951619f7, 0xa69ae349, 0x4bed80bd, 0x68cdae54, 0xa531bdcf,
	0x43d50936, 0x80ac2f39, 0x9fbd326d, 0x3e3353cb, 0x2cfe46bd, 0x97dece06,
	0x717c05d7, 0xd702bbfe, 0x7f70c705, 0xf9729fc3, 0x66fd427a, 0x068df7a8,
	0xc04627cf, 0x19e1c5d3, 0x34f0e2ef, 0xc336c60d, 0x06e37bf9, 0x3e891bcd,
	0x6bc2237b, 0xe0c35c04, 0x0dc003f7, 0x2351cec9, 0xde0f5dbe, 0xfce55c32,
	0x96c116b9, 0xa3eaf24d, 0x65dc8502, 0x148b69cc, 0xe7ead8c7, 0x7921fdfe,
	0xe861e69a, 0x9d5ad09f, 0xdd5798b9, 0xc47557f2, 0x2477b4bc, 0x1ac73478,
	0x25b1af28, 0x66f64b56, 0x866cec5f, 0x38d155fe, 0x1952e093, 0x86f9455b,
	0x85d604ea, 0x1e7858f6, 0xddcc7ab5, 0x4ea30794, 0xca1a0d45, 0x975cbca1,
	0xa607e29e, 0x51e66b92, 0xa3cbd78b, 0xf3cd9f8e, 0x36b563a8, 0xc7364954,
	0x51e62368, 0xe5c390bf, 0x27ee1f7e, 0xfb0fd711, 0x43ef0fb1, 0x3238f134,
	0xb8c68f3e, 0xc8c7c9b2, 0xf7ed2c9f, 0xe41ce905, 0x228d68fe, 0x9d6b503f,
	0xd44fd436, 0xf4272e06, 0x1b962a69, 0xf9e5bf22, 0xdc3472bb, 0xe26793df,
	0xf5cf4cf2, 0x09aff9d2, 0x1729fd11, 0x4a7f6472, 0x0d1b3c64, 0x78aa164f,
	0x874c991e, 0xca5a8d8b, 0xb46c5b6f, 0x601fa056, 0x07de2031, 0xbffd21f1,
	0x17e894ba, 0xf88ac3e8, 0x6e1bb3f3, 0x0c67e17a, 0x3f9cdcdd, 0xa1a59e9f,
	0x05a761fb, 0x8fc672e6, 0xbb74dfcc, 0x32e066e3, 0x767b996f, 0x53df9213,
	0xe095afe6, 0xd3e3ba78, 0xe91b6635, 0xc8719aff, 0x9becea17, 0xb4bea093,
	0xf88358a6, 0xbc49c727, 0x7f8f9cd1, 0x6031ed43, 0x7f530bbf, 0x78815b1b,
	0xe0660e24, 0x4938e47a, 0x5231bf48, 0xbafcf9bf, 0x422bf414, 0x2fdefd3e,
	0xc3ce8c3c, 0x424f491a, 0x9c8581fb, 0xd01fcc8b, 0x8e7d088e, 0x910b03f6,
	0xccb98233, 0x5f811032, 0x7ad9a5c8, 0xd01d6c7a, 0x9fb939b9, 0x4ef9f94a,
	0x182aba97, 0xc78b5ce1, 0x1e9b7f09, 0x9dab01df, 0x83c7ac3c, 0xf08c5efe,
	0xb4fab8f8, 0x696c2279, 0xd245e56d, 0x995a35e3, 0x5f446cce, 0xbc6575c3,
	0x77bf976e, 0xfda0e8ac, 0xaf508fb1, 0x7c79124e, 0x84db877a, 0xbfd83bfa,
	0x8777dc2e, 0x4ad8ccff, 0x15bdf871, 0x44fc24e3, 0xa3d605a3, 0x9ad3f093,
	0x9ecb69e6, 0x524d7948, 0x22ae503e, 0x65417f2f, 0xd4448cdc, 0x4e636e6b,
	0xd4b70da3, 0xb3f48cde, 0xea10f913, 0x25ee8765, 0xf9a4b2fa, 0x64318084,
	0x6809141e, 0xccf1497f, 0xb49589cb, 0xf6439d8f, 0xfd918f85, 0x47eee695,
	0x21f9747e, 0xb3b4bd0d, 0x4d6ed942, 0x619a7b73, 0xe7ec777d, 0x9a966af9,
	0x7ee90176, 0xf90263e7, 0x141d61a2, 0x70640fd7, 0x61dd42fb, 0x3fe00164,
	0x6e7b557f, 0x6cbb3826, 0x89c954df, 0xcd6fd0bf, 0x67e92d58, 0x2ccf059b,
	0xc54acf7e, 0xee39f922, 0xcff9c718, 0x744ce39d, 0x9beb66fe, 0xb14aeb63,
	0xe6f09d7c, 0x46f9d2b3, 0xbf681f94, 0xe960f98c, 0xdeb0e27b, 0x8c89aad3,
	0x938c6f9f, 0xf2c8dbee, 0x145f8242, 0x7e91e8f3, 0x3b9b82d5, 0xe67e9ef9,
	0x04cc6799, 0xdc27ca22, 0xf235e926, 0x5db9d138, 0x74ed18d4, 0x140bcc31,
	0x072e2e4c, 0x006b014c, 0x2ff5afe8, 0xd6f688ea, 0x6bf3a5f7, 0x62b16fb6,
	0xd3874aff, 0xf0ba7e8a, 0xf62d1afb, 0xcf3c56c9, 0x7b4a5996, 0xcfa71e51,
	0xe616f39e, 0x698f1879, 0x2a8f2298, 0x5e62d4ac, 0xda35c244, 0x2deafca5,
	0xe45e7887, 0x3f496316, 0x18b7e1c6, 0x58e84b13, 0x52cf3c8d, 0x1e346fee,
	0x3a347c25, 0x88d1bc79, 0xe5c041f2, 0xd9f43871, 0xe41c128f, 0x8e3cff7e,
	0xb3a315f3, 0x25fde197, 0xfd483383, 0x407744a2, 0x4a8feb05, 0x25ff7464,
	0x55740f4a, 0x31557088, 0x7179047d, 0x2f2e38cf, 0xf495a4b6, 0x44fad397,
	0xb6cd09bc, 0x24ac4b58, 0x30de11b7, 0xac9c4b6f, 0x3eba72df, 0x7917f120,
	0xff29169c, 0xdca6b6f3, 0xe8099545, 0x3b3f7127, 0xde35c70e, 0x52fa47ae,
	0xe6bc4cc7, 0xf9d2bd78, 0x75af1c8d, 0x01de3489, 0x4c750ba4, 0xd3c70989,
	0x1c22fc48, 0x75a527ee, 0x66f1adfd, 0x77dd2c80, 0x581d3aa5, 0xef491ac0,
	0xc63d4b91, 0xbe474b91, 0xeff985f7, 0x051fa526, 0x8459eff8, 0x73b49ae7,
	0x09e9cb47, 0x263c9ff7, 0x9db227d9, 0x06c69661, 0xb0f74336, 0x89c18203,
	0x3bb6427c, 0x384a51cc, 0xe487df0c, 0x9aa970e7, 0x4a5d8de7, 0x0fd7e464,
	0x274be7a7, 0xb50b8dde, 0x712ed04f, 0x04bb70e5, 0x5c4bb44b, 0xeb099f92,
	0x3b4037e8, 0x21fba645, 0xedb566bf, 0x7d60d33b, 0x2adfe03a, 0xf3485718,
	0xd2eb7e11, 0xe748ec06, 0xfd3dd219, 0xe4573870, 0xbe113c72, 0xe91d81f5,
	0x307132bb, 0xa70bdf19, 0xbdefc7f3, 0x79fb8c92, 0x9e50d67c, 0xd647c509,
	0xf7e4cb2f, 0x3eff8f92, 0xfc6113ce, 0x8a7fddeb, 0x036db73d, 0x73b781e9,
	0x7d1ff03d, 0x95b1ea1f, 0x16ecef5c, 0x69a77e94, 0x7fef9cb9, 0xbfe39725,
	0xed300ae5, 0x9127ba52, 0x7e849b9b, 0xc8edd308, 0xe5ee337f, 0xefeb6379,
	0xcee0fc6f, 0x3530f408, 0x373e33cf, 0x5acb0e84, 0x6b0fe4b5, 0xb98e6631,
	0xf47f9f96, 0x3e71f673, 0xf96f9d2e, 0x9f3cf4b7, 0x62f5c3c2, 0xca0ee7b3,
	0x9fcf08d3, 0x9fdfad18, 0x1a4def91, 0xe6abafee, 0x718b73fa, 0x3e03f921,
	0xf5011b41, 0x85ef890a, 0xc8f7f3af, 0x7c389244, 0x6257c0f4, 0x8515dd0f,
	0x7b246ae3, 0x9fd931ec, 0x77a25d51, 0x59afbc85, 0x08afa256, 0xc61697c1,
	0xc7c357f3, 0xa43b94df, 0xa2be934f, 0x8357e891, 0x437d1672, 0x4347e289,
	0x4b14867c, 0x918ec283, 0x9fcf0fe7, 0x8a97c90a, 0xedca74e2, 0x37989d99,
	0x736dfa05, 0x1163edf5, 0xcf453bbe, 0xc38016e3, 0xca3adbe0, 0xa2477df3,
	0x2e8901cb, 0x00bf3b47, 0xe3c9443b, 0xbc61d91b, 0x327805b4, 0x47d20c71,
	0x1555438b, 0x66cfb08c, 0xf4119f69, 0x4ee66feb, 0xf5fa4cfa, 0xd046e53f,
	0x767f51af, 0x43dff985, 0xbb37a8eb, 0x27d7e822, 0x201fc905, 0xd49cade5,
	0x0007bad8, 0x1c6f270e, 0xd1b16ce3, 0xb3971b3d, 0xa787ec04, 0x6f503ace,
	0xeff02f9f, 0x61f7c824, 0xa951e096, 0x17f88ec9, 0xe602d75c, 0x814ee67b,
	0x37ed08e2, 0x013a69db, 0xe77ae3cf, 0x93ca4cb9, 0x42738369, 0xabcefbbf,
	0xf245672b, 0xc21d1f6b, 0xc35d6413, 0x9e1958f7, 0x655c4842, 0x2c28bc44,
	0x04e1843e, 0xe3957fcc, 0x6ffde147, 0x6fc65329, 0xff72aeda, 0x162eee85,
	0x7e6028dc, 0x517db2a4, 0x3e3c2695, 0x2ceb88a5, 0xd7c26b71, 0xffcd0813,
	0x3773df4d, 0xa46781c5, 0x359e7c8b, 0xf0f9ec8c, 0xb8ae8fb8, 0x50c6a5df,
	0xda733549, 0xd8fd236c, 0xfe492f98, 0x1ec66abd, 0x9d77bf46, 0xf2d6af32,
	0xf90fdcd0, 0xabda29f7, 0x43ab1e70, 0xb63f50c5, 0xe4fd9478, 0x89a60b78,
	0x9e17de84, 0x7bf236a1, 0xb454cb6c, 0x89b8163e, 0x3cbf65da, 0x9b9637f4,
	0x5e6df787, 0xd3fa86c7, 0xe440a23d, 0x39daef7d, 0x983fdf97, 0x85ee2be8,
	0x232754a6, 0xb1d6a438, 0x03fa7e20, 0x6b88a0e0, 0xd1f7d2eb, 0x67a93f3e,
	0xc1c7812c, 0x20c9ed14, 0x613f11c1, 0x37388aff, 0x0f5153ec, 0x67af3bb7,
	0x1dd2ea6f, 0xd7e7e4d7, 0xa4ea37f3, 0x5ca5d978, 0x88a40f29, 0x63bea115,
	0x9d10f65e, 0x1e7027c7, 0x169e7794, 0x1db61e39, 0x450117c6, 0xd2f44b76,
	0xe558c522, 0x9730aaef, 0x84a9f748, 0x2166be32, 0xa3e3cdc1, 0x5be88c85,
	0x0b950067, 0xaa9859e8, 0x75dc2173, 0x96c3a83a, 0x27d32d05, 0xe4b573c3,
	0x98166e6f, 0x72667588, 0x509fb9ea, 0x904baefe, 0xda32ebbe, 0x0ffba03c,
	0x017ce144, 0x4f3c9efe, 0x546177c8, 0xfb5c169f, 0x23f7bc7d, 0x7efc3bcf,
	0xe51df925, 0x7f8347f9, 0xc651dfb8, 0x7f4e5fe3, 0x7bf7127d, 0xd6be11a6,
	0xd52be30c, 0x88f84a57, 0xf85f23ef, 0xed6cdcba, 0x76fbc22f, 0xed11bee7,
	0xd0f83f44, 0xd473023e, 0x39cf8fb4, 0xac3ad0de, 0x4f7e0cb6, 0x3497da4c,
	0x17dde7de, 0xb5f085fd, 0x028978ad, 0x186a2ff3, 0x9ecdd3c5, 0x8a450f8a,
	0x141ec383, 0x7ee4227c, 0xf5b78c3e, 0xdcfbcf10, 0x0879df85, 0x5ea023f1,
	0xb5837681, 0xb0479e06, 0x8eb2e483, 0xf2b1fbf1, 0xa0b45aba, 0xaa5e2347,
	0xcf3d1eb8, 0x5e622038, 0x5071268f, 0xcb69fa44, 0x087c7ce3, 0xe518937f,
	0xa553a81f, 0x36b1bf3c, 0x970733aa, 0x6b3cf26f, 0xbed254f3, 0x3ffbe9fb,
	0x374fa2f3, 0x7f309cda, 0xd18bf3de, 0xcc6f3f3f, 0xd43b46e9, 0xe1fbccef,
	0x67e81162, 0xcbe9ea5e, 0x77631376, 0xf5e7ede5, 0x3397d382, 0xef3abea1,
	0x81bf5e05, 0x26b39191, 0x8c62c0ef, 0xfc95ad3b, 0x8ff8f27f, 0x7d27ac23,
	0x53ad52f1, 0xbe47cc45, 0x27ce4f27, 0xd49f7464, 0x3393f3dd, 0xcb749718,
	0x09a5d1f2, 0xc9a077d3, 0xa4a8f78c, 0x8a58c4bf, 0xf096ce87, 0x777e0e6c,
	0x96fd1628, 0x71df04bd, 0x87fa7ec3, 0x5e9f8f3e, 0x65dfc970, 0xa01ab132,
	0xe62696ff, 0xc10aca89, 0x7d52e67b, 0x2960f3ca, 0x47af206e, 0xbac47f9e,
	0xf8c568e0, 0xa1ed75d0, 0x5d75e471, 0x1e91d628, 0xba1f1e16, 0x863e0c20,
	0xe3954279, 0xb9e29733, 0xcc19885e, 0xfd3ea010, 0xaa12fb19, 0x263e0d27,
	0x1aea4338, 0xe68f8e7e, 0xf118b6bd, 0xf5da88f5, 0x7e125e68, 0xbf7f8ab7,
	0x438a55a0, 0x09e4903d, 0x78067da0, 0x81557947, 0xdde52d74, 0x5c144e55,
	0xa7c0fea1, 0xc82b3c24, 0x1999fee7, 0x29df76ba, 0x7eef4bc0, 0x7f433581,
	0x5a4bd5ef, 0xf5e64fd4, 0x1ea2d59c, 0x59ff76bd, 0x5ccbde2d, 0xa3c4758b,
	0x24575a3d, 0xf92beffd, 0x15dcf96a, 0xf491d776, 0x77e8cd9c, 0xd0275b5b,
	0x07f5b43d, 0xfd6e1fb9, 0x6325dc4a, 0x8e7b4eb7, 0xeeb5b8fc, 0xae58cdbe,
	0xf0470360, 0x3ccb09bb, 0x8abdc56a, 0x8ad1f5e5, 0xbeb5177b, 0x457d4504,
	0xc80e9c3b, 0xa94d15d9, 0x4a18f78a, 0x32cf583d, 0xf687fc36, 0x8e74b57f,
	0xfbdbaccb, 0xccb5dfd1, 0xe663d4a3, 0xf18b34f5, 0x409f6eb8, 0xfc80aff7,
	0x72def86d, 0x432843be, 0xfb802af4, 0x47ae6e8c, 0x93d6adad, 0x7583527d,
	0x834d6b80, 0xce9f883a, 0xa5ae9239, 0x40b76f76, 0xdda95eed, 0xbb702f5b,
	0x2bafe25a, 0x7f2e35a4, 0xba0cd4e9, 0xf570194e, 0xbbd6423b, 0x43eabaa2,
	0xdf4947c2, 0x6d55f790, 0xd6c6fae3, 0x383537f4, 0x047b8aee, 0x7da76096,
	0xe5a8f429, 0xad7acaf5, 0x67a6134f, 0x7f90680d, 0x3e5268af, 0x72079f3f,
	0x80a3e91d, 0x5d3d2015, 0xa24413ca, 0x51fea92f, 0x7b279bfa, 0xd5a77d61,
	0x7e203fee, 0xc77b6836, 0xad3bdca3, 0x6e5d50f6, 0xb96be787, 0x8afae2bc,
	0xdf0f280a, 0x4cb8d16f, 0xb0349f78, 0x5dbc2046, 0x1ef442ce, 0xaa7f70fb,
	0xf3d647ab, 0x1bbe25f2, 0x7f246ee5, 0x09824be8, 0xd14a86f5, 0xf03de225,
	0xe8fc5196, 0x1e9cf9f9, 0x4281b24e, 0x220e575c, 0xce539c29, 0x672431a2,
	0x6573fe72, 0x3948e300, 0x25f902a5, 0x9b8ac0e6, 0x8914b04a, 0x5cc7cc8f,
	0xa61fbc01, 0xfe26aaee, 0x226b413e, 0x53c68efe, 0xfd70bf08, 0xd7de132b,
	0xe7059573, 0x8c76939d, 0xbf373fbe, 0xe445fb63, 0x572c8e8b, 0xdf580ec9,
	0xfe7c5103, 0xc10a0e07, 0x6d671866, 0x9fe251e1, 0x9c0f4016, 0xe255ad77,
	0xff4adda3, 0x1af905ac, 0x42dccc22, 0x8e59379a, 0x915e032f, 0x20adee1c,
	0xcd22c4fd, 0xd0bd1a7b, 0xddf36fb0, 0x0b165e52, 0x797e6334, 0x9c085e32,
	0x617e5c34, 0x20a5557f, 0x9e0bc586, 0x957f43ca, 0xef914075, 0xff8e25f3,
	0xf859e21c, 0x457db0f8, 0xfa8672bc, 0x6fdd2c6a, 0x9aeb297a, 0xbd6a40f9,
	0xc69b9ef2, 0x77bb0864, 0xf33fe4a6, 0xf761a99c, 0xeec2b2ce, 0xdd84159d,
	0x73de533b, 0x21bee25b, 0xf299deec, 0x3ace9b9e, 0xca3fd15b, 0x8f5150b6,
	0xd155bdce, 0xbb79c63f, 0xfc775da2, 0x13216a85, 0x1817b3bf, 0x5a1c00f0,
	0xe2ca3681, 0x4148e587, 0xd286742c, 0xc4651a50, 0xd758b5b2, 0x9ad2788b,
	0xdd73edc2, 0x7b586ff1, 0x98fd1c61, 0x6fe8f567, 0x582137fc, 0x5e89f681,
	0xbfc953ca, 0xcce4298f, 0x2ba71160, 0xdf27bcb9, 0xce00a5b3, 0x5b69f0bf,
	0x40aeff2a, 0x8f9e3e7f, 0x81363f1e, 0xdf807374, 0xd9209dab, 0xaf38f211,
	0xcbefcb3b, 0x73eef7c7, 0x7b38a2cd, 0xbb1fbf37, 0xbc78cb57, 0xefcf00e4,
	0x501eec2c, 0xdbe842b9, 0xc1f9c050, 0x1415dcf7, 0x03db591f, 0xa9e91652,
	0xef169ce3, 0xe9edac25, 0x3679458b, 0x8b4e7dde, 0xe7e1937e, 0x07139c92,
	0xffaf680d, 0x78e45747, 0x5af98bda, 0x12a38fa2, 0x86fdaf5f, 0xcc8ddb9a,
	0xa6f31735, 0xfb5d7e65, 0xed5fdf1c, 0x03cf2d12, 0x047468c5, 0xfa7c0dbe,
	0xbb0f929c, 0x5a60f294, 0x0ef23370, 0x7e8adfe0, 0x24cf162b, 0xf806b7bb,
	0xf031d236, 0xda7b6573, 0xc02fe216, 0x9fcf15cf, 0xb4ec97ce, 0x29f85602,
	0xadc677bc, 0xabcfb88a, 0xf1c12245, 0xc13a678c, 0x47007bff, 0x6f7da7f4,
	0x3c38dc04, 0x1faf07af, 0x9c87d9e0, 0xfd3f785b, 0xfe3fae78, 0x6d7e1460,
	0x7bede02a, 0x6412fe85, 0x81b75ea6, 0xdeb976f0, 0x75fd0733, 0xb0ffd347,
	0xb570e305, 0x4f74082f, 0x8efbbffd, 0xd7ff519b, 0x8cc4773e, 0xd76f30fe,
	0xa6d83311, 0x6b6341ac, 0xf01e3d46, 0xcf7a89c2, 0x5a5eeeda, 0xd2ae9aff,
	0xa6be7c3e, 0xd7efa05b, 0x9c5ff778, 0x0364fb49, 0xb85e305b, 0xbd759477,
	0xb391c929, 0xcf9e36f9, 0x513981e1, 0x05d7efde, 0x01e20283, 0xd75c25f0,
	0x3cbf0141, 0xe9b6f6c6, 0x51e923ab, 0xbc39e389, 0x1969b70f, 0xe01bebfa,
	0xd1c7dc7d, 0x3d5aa3f4, 0x0273d1e2, 0xaededad9, 0x71a24b53, 0x430d46fc,
	0xdf5e42fd, 0xeffde9c7, 0xaedffee0, 0x80a7a0d3, 0x09a9d4b5, 0xaa376fde,
	0x2af51c69, 0xdd97d50d, 0x5e2af3c5, 0x4b777ba9, 0x76fb8c2a, 0xfc794083,
	0xfefd57d3, 0xdd97d628, 0x70b5f5c5, 0x35f1967c, 0xf1c33f1c, 0xd69e0477,
	0xfd3c317f, 0x8e9e30cb, 0xe70f3947, 0xf882c33e, 0x1fbf2f73, 0x15f57d5e,
	0x3337fa0d, 0x1b9c98b7, 0x0ea45ea1, 0x9f23366e, 0x17b78578, 0x9c0a7437,
	0x456ed8df, 0xd56d4c3a, 0x4d77b432, 0x35ff5c05, 0xb2f3f015, 0xe30141b1,
	0xcfec4c6b, 0x9764be44, 0x6bcf49e2, 0x1473f558, 0xa6fce417, 0xced647e8,
	0xffb8bcd0, 0x990ef494, 0x9968160f, 0xcbf239e7, 0x3de0a576, 0xf9481f82,
	0x78d219a0, 0x338359d9, 0x2c594017, 0x95229fcd, 0xc250bd72, 0x9678167f,
	0x8a4f3be0, 0xea6eccb3, 0xc3cc7ca5, 0xf90d8f5a, 0x378cdce8, 0xb5ce501b,
	0x485abe66, 0x5378c679, 0x3f7e3260, 0x32bdff98, 0x367b37e5, 0xcf2fdc60,
	0xf518e740, 0x43ca0ed2, 0x689eca8b, 0x90e71489, 0x1b15ef4b, 0xed6f8f7d,
	0xe52a4c95, 0x1f4382fa, 0x0ec8076a, 0xe89338b8, 0xf1558ae4, 0xb49b3edd,
	0xfbf922ee, 0xcfdc3d6c, 0x2c5a7c03, 0x27ee192b, 0xcb3d01c3, 0x7b2a3fd8,
	0x86d79d1f, 0x8798ac75, 0x3c1077b7, 0x129c3797, 0x4b0fbbf0, 0x118d2e35,
	0x98e6fde0, 0x7df839ea, 0x900efc46, 0x26e30727, 0x7c97ba7a, 0x7aa26fd2,
	0xf54adfbf, 0x951b7ed3, 0x95ddea6f, 0x8725a708, 0xb708d97d, 0xba77d257,
	0x85debef1, 0xaf091a13, 0xb4befc4d, 0x7a976b84, 0x718f4cd4, 0x8fa0fdae,
	0xbfebc30b, 0xdd0a4aed, 0xce39fe6f, 0x69acf307, 0x3bf119fa, 0x99c5fd67,
	0x37151768, 0x7582dd9c, 0x67efd36f, 0x0ef13ea2, 0xebd20fc8, 0x0ab7bf41,
	0x694e47c8, 0x73596e31, 0xf9c69e25, 0x26706a81, 0x65e057d2, 0xbc9fee81,
	0x6b517dd3, 0xdc89f2e1, 0x1a2f7873, 0x0b9bf2fd, 0xbd3fb8e2, 0xcfc558a7,
	0x2aedc1d7, 0xf2fa1f09, 0xe78b14ff, 0xbdb26fa1, 0x7fbe0376, 0x7e90cd4c,
	0xc60c55b7, 0xdff0229a, 0xcbbfe833, 0x32c0fbe1, 0x1b5abdbc, 0xc93cc6c8,
	0xc38f096a, 0x860b9bdb, 0xe91a13fc, 0x084c403b, 0x32d50ff1, 0xb04ffdfe,
	0x400d7a7b, 0xd33db5c7, 0xeb533fc9, 0x9fe9ae13, 0x3f0f0d19, 0x7196b96b,
	0x475c8cff, 0xafd431bb, 0x53237689, 0xdfe01fcc, 0x5c774a81, 0x778a9ef3,
	0xf9e28520, 0xc5195b6b, 0xc95cd6bb, 0xc1fcf2a7, 0x1fa436ad, 0x277061bd,
	0x51ccefdd, 0x26b19d91, 0x1a7fd4a0, 0x685f388b, 0xdd9ff494, 0xe92f6005,
	0x04bd90d9, 0xc41ed176, 0x628bb04f, 0xbd85310f, 0xec9cfe14, 0x4f74bd25,
	0xf3c18e05, 0x0775847c, 0xf13a2a8a, 0x4ed60cbd, 0xf04ece78, 0xfbe1bbfb,
	0x8bd2567c, 0x865eba64, 0xdbf88d74, 0x7c3ae9cd, 0xca8a07dc, 0xdb71c59f,
	0x356f8946, 0xd35cfb4b, 0xde5e08c1, 0xd382788e, 0x5dc3acc7, 0x31f97801,
	0x51ef03ac, 0xa3bb705e, 0x0bfde0e3, 0xe634771e, 0x607cc8f7, 0xbbcf076d,
	0x4c2c736f, 0x3ed1bcc0, 0x77cfef09, 0x9c23d74f, 0xf4e0eb6f, 0x4ef7cf27,
	0xa404b2ef, 0x419a49a7, 0xd3da13ad, 0xa2c6ce7a, 0xe0e937de, 0xc3a404a2,
	0xbfb9d6d1, 0x35a7f390, 0x48e7eb4d, 0x3d4ca779, 0x6027b259, 0xbd8dde7d,
	0xd5f69df4, 0xb7f08c4d, 0xaf7fc0ef, 0xdf3e3a45, 0xb9426d13, 0xd14bf1f9,
	0x0bc6bdf4, 0x2a82eb2f, 0xfa0eec81, 0x9ac7e8be, 0x5fa4f981, 0xbdd3541e,
	0xbfcbef40, 0xe8f489db, 0xbca3a03d, 0x5b3dd5c3, 0x6bdca22f, 0x21f599e8,
	0xe1b4677e, 0x3d2c7fd9, 0x26fa69ac, 0xfd7245e9, 0x1bbd7e77, 0x9179e8f9,
	0xddd589f3, 0x777d243f, 0xe34bd5f5, 0xe3e53f31, 0x193cfe97, 0x3ff79af9,
	0x7e464d2f, 0xa5f1fde6, 0xfdeed8c9, 0x922fb451, 0x5e3652be, 0xcb25e74d,
	0xa2ebfb4b, 0xb7b43fc2, 0xbeddc388, 0x87be9da9, 0x62d4e93c, 0x0f77e867,
	0xdcab6526, 0x1bd27fd8, 0x42ab0995, 0x2fd4dbde, 0xe2719c52, 0xbae8caa9,
	0x55dcbc10, 0xc3fd91a4, 0xc3afc85f, 0x0cc3efa4, 0xf9fa71f9, 0xfadab077,
	0x9f7dfe45, 0x61ee817a, 0xe232fe83, 0xff9d165e, 0x7df4095d, 0xe7ba261f,
	0x7ac44d14, 0x87177d36, 0x1c47f405, 0xb2d27a21, 0x0eaf557e, 0x47baa8f0,
	0x7dfa4bd7, 0xea9678bf, 0xdb74fe92, 0xd8c4dfc5, 0x99fe0885, 0x9033d3dc,
	0x69fb878f, 0xd7062fe0, 0x355beb2d, 0xae3a4f3e, 0xb37fdc3f, 0xf266faa2,
	0x6ffb850f, 0x6aa2fdec, 0xfefc44de, 0x85675d39, 0x47a43efd, 0x50f5917a,
	0x11fdbf3c, 0x8959ffe8, 0xdaba646e, 0xbfe3cfd4, 0xf42bfa9b, 0x909f280e,
	0x3883f7da, 0x9bf8c00d, 0x813d167a, 0x574d847e, 0x01174697, 0xbebd36bc,
	0xfa446d90, 0xb3e85537, 0x37abbdf1, 0x0e1497eb, 0x7cf84be3, 0x0f5c858d,
	0x2213d61a, 0xd255bdcb, 0xf928ffbc, 0xfff0b2b7, 0x7607f90d, 0x12617d78,
	0xb9cbe1d9, 0xe1db849f, 0xe64372e1, 0xbbb8f2c7, 0xe48f7825, 0x7e921fc7,
	0xf132f603, 0x3685dde3, 0xb3d697ea, 0xe8ec8120, 0xd82717d7, 0xcfc7238c,
	0xf8aa9d12, 0xcbe391c2, 0xe0379c7a, 0x3b47a23a, 0x7ee6a5c7, 0x5042c5d2,
	0x3ef58610, 0x7d205baf, 0x09a35bdc, 0x5d793f62, 0x5fb98bfd, 0x134b8975,
	0xf586128c, 0x1c7f5943, 0xd40a776a, 0xb293eb2e, 0xe6efd8de, 0x13c5dc7e,
	0x7a9bfb79, 0xebc23b4f, 0xfdfe5e9d, 0xf85349ae, 0x47dcc673, 0xf4bea152,
	0xfa23026b, 0x1949f497, 0xcdf5c34f, 0xaeb27a4f, 0x3d9abdf9, 0x74ca7e12,
	0x1f461196, 0x93eafcb2, 0x28b5dfec, 0x7e5013bf, 0x97a151ff, 0xf20b8f87,
	0xbd215f7b, 0x277f08c7, 0x23ba21be, 0x6593e7d9, 0xafcf963a, 0xae3970ff,
	0x53f59d37, 0x7268ec9e, 0x9522a9f5, 0xb7843f82, 0x367c15f7, 0xa155fe7a,
	0x83fd4764, 0x25bff9e8, 0x3b7ff33e, 0x85e90f3d, 0x0cfbc8da, 0x87bf9514,
	0xfb506fe7, 0xb4739f28, 0x50fd7bef, 0xe760d392, 0x48f8f02a, 0x768556ba,
	0xfb9eb791, 0x6ce35a07, 0x72fd91af, 0x1fdf4d5c, 0x20760d59, 0x5f776fea,
	0x80d95131, 0xcb94327a, 0xdf453e9f, 0xaf5e5d99, 0xfa2b7f5c, 0x75fdf16e,
	0xd7eb8a76, 0x2bf24ab2, 0x99c4f6d5, 0x35bfdf30, 0xd228eba9, 0xb509e055,
	0xfed089ed, 0x7f52f96d, 0xd5b7f73d, 0xa7efd1c7, 0xa03d30b0, 0xefae17d6,
	0x1b82f52b, 0x68d13f24, 0xfb8fc1fa, 0x395f38a2, 0x5f3a26a6, 0x2bbfe6eb,
	0x7ce1eda0, 0x4514dbc1, 0xd7b4137e, 0x341f5d70, 0xeefc4109, 0xdfa91af7,
	0xf93f6207, 0x069e289f, 0xd9ec3e5d, 0x64ba4661, 0x68fc652e, 0x8837becd,
	0x91c7866f, 0x714bf7e2, 0xd1b8a1a1, 0x5907ca64, 0x05a4f603, 0xed9b4bf5,
	0xac3f8416, 0xef89058f, 0x987e14b8, 0x4bbd8e4f, 0x83f2e7f6, 0x2233fe3c,
	0x9b3ad47e, 0xbbf08fc7, 0x90fc1123, 0x3d1ec62b, 0x7423bf82, 0xdad1b8bd,
	0x8f7453ee, 0x11fe8464, 0x2a4c77a6, 0xc719fa52, 0x3b8fdc8a, 0xa13047b6,
	0x04ac6a7f, 0x19b4afc7, 0xf99eaf48, 0xe404bacb, 0x9d39f207, 0x7ae1c05f,
	0xf4cbedfe, 0xbfc9c47d, 0xfdf84d14, 0xddbf1fc4, 0x5e54b3f8, 0xf86de9b7,
	0xda34635e, 0xb97fe731, 0xfae11a3e, 0xf7f12863, 0x46747e15, 0xec8fe88c,
	0xcf4bf61e, 0xb2ff222e, 0x411697e4, 0xfb0cc61e, 0x7bdfc273, 0x15af7a4b,
	0x63f214cc, 0xfdf1e41e, 0x6ccf64d6, 0x64ceefaa, 0x2e907bfc, 0x10ff3bf2,
	0x45fd1af0, 0x8c59b005, 0x81bbff3f, 0x5178c26d, 0x55e7926b, 0x2adda3a2,
	0xbc11d21b, 0xc0a6714f, 0x8f923673, 0xe78c3208, 0xeff2d78c, 0x9364d212,
	0x98d7bf87, 0xda2c760c, 0xc59ab093, 0x902e6f18, 0x0de33ae2, 0x1ff1c44c,
	0xe1b678d0, 0xe81f4377, 0x44cd9d13, 0xfc04ce04, 0x7c7875ee, 0xb8f17049,
	0x92671cb8, 0xc5a3e3e3, 0x679c0499, 0x9e3bc73c, 0x3012e2b7, 0x93c72e6e,
	0xfcdcd7d8, 0x3e65b37b, 0xe93fefca, 0x4bfcf464, 0x543cf38c, 0xd3ce2110,
	0xf0b7c929, 0xdcb6e2b8, 0x3f4f09e7, 0x57f13c6f, 0x6a5fb348, 0x27c38bfc,
	0xe313dd7c, 0xbd93313e, 0x15ff97f5, 0xe7b6724b, 0x0bc3c912, 0x3ee93a83,
	0xb3f700c2, 0xbfc868f7, 0xb6ec0170, 0xfb3910a4, 0x797fc957, 0xe13a67a8,
	0xcafefeff, 0x4e3fec68, 0xaf6de392, 0x0f345e2f, 0x745fb2f1, 0xb84ad366,
	0x5fbfb61d, 0xcb7a849c, 0x5d2e7897, 0x7be21185, 0xefe4437a, 0xe892ac2c,
	0x87115568, 0xb9b7f4f3, 0xe46de5fd, 0xc4931471, 0x5a55bc17, 0xd34783e2,
	0x3fec82cd, 0xb38a44b7, 0xb9241c1c, 0x40977b51, 0x70be1cf7, 0x4fbba59c,
	0xfe615b92, 0xc499aae9, 0x5bf34737, 0x15cdc487, 0x49146fed, 0xee22f371,
	0xc8b9bebf, 0xf78efb44, 0xee639715, 0x2fffbca1, 0x8d361cf1, 0x59c6fbff,
	0x01109c9f, 0xf1c4bf8f, 0xbefff31b, 0x77fb3fe3, 0xfcc5ff1e, 0x7ffc2fbf,
	0xbf1e77fe, 0xfd7f1238, 0xf94fc712, 0x583f8f3b, 0xff3e0110, 0xc200f353,
	0x79e1fce3, 0x7ef1e101, 0x0155f1dd, 0x6c2adb6c, 0x5285ec1f, 0x5aa07b1f,
	0xc62d5600, 0x48efa3ed, 0xe3c29dcd, 0xfa956d60, 0x9c30a760, 0xabc3201f,
	0x08edc9c3, 0x40c5e153, 0xc339c002, 0xdf895fd5, 0x8530be73, 0x82fc877f,
	0x26519df4, 0x5b3be89a, 0xef1933d0, 0x4546b7c7, 0x3856ab8e, 0x1470bb25,
	0xb3baf239, 0x893e303c, 0xe220b67e, 0x92338efd, 0xcdd4da7f, 0x44c92fc8,
	0x9a42f25b, 0xfa8c96d7, 0xfcc398d0, 0x732f6c79, 0x6cbad275, 0x0f6485f6,
	0xbeb8ecda, 0x6f78a507, 0x3b1cecfc, 0x41e3a3fa, 0xe078c42f, 0x920b8c0e,
	0x7ea26b3d, 0x13f17cf2, 0xd41ffef8, 0x5bee8130, 0x267cf1e5, 0x22a2f0d6,
	0xd342779e, 0x814adefb, 0x208f79e2, 0xaaa9febf, 0x5daf70b7, 0x6f806242,
	0xc5137ee1, 0x794e4f19, 0xf343d72a, 0x06def8f0, 0x0af2ef13, 0x8eb0cdda,
	0x12952f0d, 0x343f2efe, 0xf4fc2de5, 0x3a21d797, 0x9453dd23, 0x246705fd,
	0x2fec877f, 0xbf5ae390, 0xef24fc90, 0xee85ffa0, 0xeca8d887, 0xb2faaf1e,
	0x48eeb7f5, 0x8141e9f2, 0x3f0287fb, 0x52a1fee5, 0x342b33ad, 0x78c8f26f,
	0x7b2b8e7e, 0xf642dc79, 0xed233cf7, 0x755ef4a7, 0xd2f40eaf, 0x5a452dd2,
	0x5ba5f394, 0x8e580dd2, 0x78550577, 0xdd597c1f, 0xfcf92a73, 0x6bd1e122,
	0x8edb3ed2, 0xef5c520d, 0xfe716187, 0x6a5a09f8, 0xc7c2407f, 0xb049b078,
	0xb62d90dc, 0x6638faa0, 0x291d499a, 0x760b549e, 0x6573ae31, 0x0cb75f2b,
	0xdb5edaef, 0xece79c74, 0x582dc191, 0xa7dbd496, 0xe1bdbf93, 0xdfd416e2,
	0x1d2f57bc, 0x65fc89bd, 0x13da1b5a, 0xfd280db7, 0x7938cf6e, 0x050fe5be,
	0x81ad3bfe, 0x74fefc59, 0xf0912ce9, 0x8a36be27, 0x0d78d7ec, 0xbeb11b53,
	0x2545eb80, 0xb1d38955, 0x91c716ce, 0xcc72583e, 0x70aab716, 0x3f160fd8,
	0xe10931ab, 0xaaf8dd74, 0x537b4fe4, 0xfa441aef, 0xd5f1bcfb, 0xa75e2735,
	0x5f7952bc, 0x38e45c32, 0x55f168e9, 0x5bc1cf39, 0x97915975, 0x670715e1,
	0xf4b1ffa2, 0x295ab3a5, 0xbf84d2cf, 0x5fc72ba3, 0xa45e0f4b, 0x671cabb8,
	0x922efaf5, 0x69ef0d5e, 0x3852fdf1, 0xfc78e4fe, 0xbf8f10be, 0x527bc01e,
	0x67ffbc5a, 0x2f52fba2, 0x7b17f74a, 0xfcf8ff60, 0x952e7f65, 0x95277ebd,
	0x5465fc87, 0x522e7b7a, 0x6132d6bc, 0xc5247e44, 0xddab4ef3, 0x29261329,
	0x0f547de2, 0x0da9f78f, 0x3de35fdc, 0x0fdfa1a6, 0x13d09ef0, 0x59ef2eff,
	0xfebaf749, 0x1633ca70, 0xe316bdd7, 0x7178216d, 0xc28ce5de, 0xef3845df,
	0x9c614676, 0x43efb4ad, 0xacbfe62d, 0xe8b5fb15, 0xa715830f, 0x77a26a62,
	0xdf9e45ff, 0xbf4e53db, 0xb8dd7547, 0x8ffff758, 0xb89e7d8b, 0x8f2701d8,
	0xa47cc98b, 0xe172adc4, 0x6392cd3d, 0x2155a8ae, 0xcdcda27c, 0x8e6d29e3,
	0x87c3a24c, 0x757199dc, 0xaa6de321, 0xf88bfee2, 0xd0a88e59, 0x3cc551e7,
	0xca3f160e, 0x13bd3c77, 0x5db65f54, 0xf7a48de1, 0x9ea9ff9f, 0x1df5fbee,
	0xdd2c73bc, 0xc7f30faf, 0x8dd555b5, 0x74fe418d, 0xb9b2c746, 0x8fe14ebf,
	0xb8f16163, 0xcb72fcd1, 0xb7dfa4ab, 0x28198361, 0x66fdc3b7, 0xcb90af78,
	0xcaaa5775, 0x1520658a, 0xc7862def, 0x82ce7ee5, 0xffa0386f, 0xc9152ab2,
	0x573e390b, 0xfc322552, 0x269291dd, 0x72e2904d, 0x6a59e255, 0x4dc6ec97,
	0xc45492a6, 0x684e77f3, 0xaaf2914d, 0x5afb559d, 0x677de133, 0x77df4083,
	0xaefc5eb8, 0x466fbbb6, 0xa4dfed2a, 0x47647ba6, 0x91b6bdf9, 0xef9e3cf1,
	0x5bdac25d, 0x731fa12b, 0x09e3dff0, 0x9e21b3f7, 0xee125ea1, 0xc2527f87,
	0xbd252783, 0xdec93de4, 0x25f4912c, 0xfc70bdf9, 0x2e04f3f9, 0xebf346e7,
	0x6f1a4eff, 0x9b495553, 0xae77cf03, 0xd93ca18a, 0x77a15554, 0x70778c84,
	0x7b67cf02, 0x8983e310, 0x1e41f1a1, 0x0b8f0c07, 0xb4ae7cca, 0x11338fef,
	0xbf010fde, 0xb5e63946, 0xe941f8f2, 0x9f74e5cb, 0x5c9d786e, 0x1d643f6e,
	0xc71eb7ba, 0xe618bef8, 0xe25e05cb, 0x325d8bbf, 0x68a1f2f7, 0x8e3b9f84,
	0x7bc6177e, 0x4462d1c2, 0x9c57347e, 0xbc77f784, 0xce28616e, 0x45a4f184,
	0xc6cfd5af, 0x4ba504fb, 0xdc214f8a, 0x2868d497, 0x6bd1701f, 0x6d7bf4d5,
	0x5d2bfcb2, 0x80d1b9d2, 0x3382b9ed, 0x55ed86ca, 0xe73ed815, 0xa4f45ed9,
	0x3ab879b3, 0x27fde7e0, 0x6e9113de, 0xde7bd4de, 0xba5f7e46, 0xd5338a40,
	0xa4bd3970, 0x71868167, 0x3721527d, 0x03ff495f, 0xf52e83f9, 0x28fc5294,
	0x0a1ef301, 0xe955e587, 0x62c7204b, 0xdfd8e586, 0x3cfebf2a, 0x9cf044c1,
	0xd70c7200, 0xc780bf13, 0xffcfc3e7, 0xa31f84a0, 0xf8d1a5c9, 0x551fca30,
	0xc14fa719, 0xdb8e523a, 0x15f3efd0, 0xba05d7d4, 0xfe1a399c, 0x1d784ae5,
	0xff73e927, 0x2340861b, 0x008000b6, 0x00000000, 0x00088b1f, 0x00000000,
	0x55b5ff00, 0x655b685f, 0xb97dff14, 0xb649b7b9, 0x76dabbc6, 0xa6f06bad,
	0x34d7529d, 0xe2accbbd, 0xc6dd2c86, 0xd4687590, 0x366e8c97, 0x4d714be2,
	0x1f486452, 0x25a8a584, 0x28226f6e, 0x95979882, 0x0f6516f9, 0x15918419,
	0xd68bea5a, 0x8bd9683e, 0x70e28e31, 0x3fe0a8b0, 0x77ce78d0, 0x6db935ef,
	0xe179845e, 0xfbefee72, 0xf9ce77ce, 0x6bf73f9d, 0x0a39e834, 0x31196c34,
	0x7a0e3005, 0x0bd07bf6, 0x4fa3e6bc, 0xe079b803, 0x377560cf, 0x5f192be0,
	0xc81c791e, 0xa0e829ac, 0xeac74bf5, 0x3cd23d41, 0x8bcdc8ef, 0xe051ee74,
	0x949f45d6, 0x5a93f7db, 0xce9311ee, 0x15483d25, 0x361f9cdb, 0xc70f403d,
	0x3a26aeb1, 0xf1411f21, 0x713eb59c, 0xd03dc80e, 0x2a24b845, 0xf2e12081,
	0x965e3bf1, 0x9f350273, 0x75b0d3a5, 0x5636c36b, 0xaff9fa76, 0xbcf6c332,
	0x45267c4d, 0xfe9b8746, 0x517666a6, 0x17d89a92, 0x379c7e20, 0x3f7992cd,
	0xb6df2c92, 0x45c8ecf3, 0xd3f65e5b, 0xd7926ea1, 0x4c216145, 0x9bab22fe,
	0x8ded7882, 0xc231f303, 0x0a2bbb7d, 0xbbd49461, 0x20efc755, 0xce3a1bed,
	0xa7103e52, 0xf4013e64, 0x02d031db, 0x544f48b6, 0x118d3cba, 0xfb581bd2,
	0x986ded83, 0xef6fcc86, 0xa201454b, 0x416e4210, 0x0d15bf90, 0xff929f13,
	0x0b026bd9, 0x242d92a4, 0xeb483c60, 0xfc5ade1f, 0xd733d684, 0x22914e84,
	0x634afc5d, 0xbaef6957, 0x4c9f13a6, 0x2c0d47f9, 0xeb59df8b, 0xb42f1125,
	0xa9b2eba9, 0x8827bf48, 0xd28fa80f, 0x07429417, 0xfe493df9, 0xae367798,
	0xabc20c15, 0x8cbdd7a1, 0xd8175dcf, 0x63595b4b, 0xef1767bd, 0x0851505f,
	0x27a75e4b, 0x56126788, 0x306bd27f, 0xeb3633ef, 0x69eaf1a4, 0xf55eb904,
	0xafdc7dd5, 0x18acc233, 0x56b52f5c, 0x0507f575, 0x6d357d42, 0xdd2a9b9f,
	0x75c83154, 0xc74deb74, 0x5111de4f, 0xeb6dafee, 0xc93f8b03, 0xfb2aa07a,
	0xbdde7a74, 0xbb3b319f, 0x3025a8b7, 0x08634882, 0xcbaa2378, 0x4253273a,
	0x3e3f28a4, 0x7996624f, 0xafd086e2, 0xebe67784, 0x260e7b2d, 0x54f30273,
	0xeacd25df, 0xa2c3a58f, 0x49fd2390, 0xa5f75c82, 0x04e72f1b, 0x098a5cf1,
	0x60f9c3d3, 0x29c7ca25, 0x218f3f3b, 0x8b8a2d87, 0x38d7bdac, 0x3d4b3c04,
	0x9a7ea7ec, 0x2801fbb4, 0xff9eb8c8, 0x88515020, 0xd8b565e7, 0x6349f3c7,
	0x4cc7fd26, 0xc0e81948, 0x9d79bb5c, 0xe6622733, 0xa479eb38, 0xfd57f39d,
	0x3c96edfa, 0x5c7b8ba4, 0xd7ea5b38, 0xcdccb76f, 0xa7e8fe79, 0x72f084f7,
	0x3d76b3dc, 0xef52563e, 0xdd37e49b, 0x2eb8d557, 0x8c4b5d40, 0xad445f02,
	0x85323e78, 0xf29bfb97, 0x7df3c23b, 0x7075f437, 0x9286e099, 0xb33c7028,
	0xfdca255a, 0x24a4a1bd, 0x3d69f676, 0xe7b62183, 0x791cf1ad, 0xe1ffe420,
	0x2a67f0d2, 0xd78a65d7, 0x4dc3789d, 0x9d95893d, 0x73f39478, 0x1b7f797f,
	0x3efbc36d, 0xec717fda, 0x5cffb5ff, 0xc9bdbabb, 0xfd36bfff, 0xb9d07dd3,
	0x39740677, 0x19e6ff2f, 0x43a43dd6, 0xe84af1f6, 0xe50f7957, 0xdf0df185,
	0x55cfb943, 0xff9a315c, 0x65a77cd5, 0x7ffb7bff, 0x6dbfc8ea, 0xbd2d5799,
	0xb6fdfeed, 0x5e2515ff, 0xae47b8e3, 0xf0b4607a, 0x60062d1e, 0x2b1ef0b4,
	0xc1f0b975, 0xfd2e43ca, 0xae836b43, 0x03f5f1fd, 0x3727fdae, 0x54fc2e63,
	0xff4bb0f5, 0x5cc70fc8, 0x29fae9f8, 0xdfd1fe97, 0x6761705f, 0x73a8277e,
	0xf71dcf5b, 0xdbd2e2bd, 0x15e6e337, 0x7af3739a, 0xcbcdde78, 0xb9ce1bb1,
	0xdde50df9, 0xfcf6bafc, 0xde506bdc, 0x16fd7fb3, 0x9de0fbe4, 0x4eb22ff2,
	0x581deaf7, 0xb788ffe7, 0x650fdd6a, 0xf70bde55, 0x4f60f5bc, 0xc7a61d4b,
	0xb967e90c, 0x73e7e43c, 0xdfb33eef, 0x11f7088f, 0xf7a3bae4, 0xadd07b0f,
	0x0008b02f, 0x00000000
};

static const u32 csem_int_table_data_e1[] = {
	0x00088b1f, 0x00000000, 0xe3e3ff00, 0x51f86066, 0xb8d3c10f, 0x72361818,
	0x0143f821, 0x684333b7, 0x0606163e, 0xc77e2001, 0x9ef0c0c8, 0x38330491,
	0x207eec10, 0x27880abb, 0x7dcf5071, 0xe62f1143, 0x9f5d9fa1, 0x163d76a0,
	0x837f7818, 0x03109db0, 0x03308b83, 0x84089883, 0x55045abf, 0xc1085ede,
	0x9941243e, 0xfa80e75d, 0xa5c3d401, 0x0003804b, 0x00000000
};

static const u32 csem_pram_data_e1[] = {
	0x00088b1f, 0x00000000, 0x7de5ff00, 0xd5547c0b, 0x733ef7b5, 0x9993331e,
	0xf20f264c, 0x04278020, 0x21842a28, 0x38880840, 0x8d069009, 0x8808889a,
	0x420100ca, 0xb9113248, 0x9db57a5e, 0x5688a189, 0x8db4b46d, 0x04076c5e,
	0xc075168d, 0x740d0340, 0x6af10530, 0xad282a35, 0xf0c5068f, 0xd0f09210,
	0x77adad8b, 0x49f7b5af, 0x90999ce6, 0xbf77eda8, 0x9fc5f7ef, 0xfb3ecdbf,
	0x5ed7bd9c, 0x5ed6bfeb, 0x48c7ed7b, 0xba6200ca, 0xe1af908c, 0x0e421aef,
	0x0190848a, 0x3e67693d, 0xe213c74d, 0xb60736cf, 0xf6848408, 0x249dadfe,
	0x71a67211, 0x20ce6ab6, 0x7358df64, 0x7e5a1ae8, 0x30179026, 0x3b69f2d3,
	0x9a243b0e, 0x4a21dcaf, 0x6bda6e50, 0x363befc5, 0x7bc80108, 0x5c8fadcd,
	0x3b5df345, 0x5689b244, 0x1376424d, 0xdda42649, 0x1a9fd842, 0x56a5f98b,
	0xb8dcad96, 0xaf680eef, 0xac4cc9ac, 0x46f6fbf4, 0x95f90dd1, 0xa100845b,
	0xbaee55ed, 0xeb48195f, 0x8210165b, 0xb7e69556, 0xb1a8aa3c, 0xf7b7dc84,
	0x9d9b477d, 0x0b3e5390, 0x47ec1551, 0x21147059, 0x056d81e5, 0xe5f7e903,
	0x8997055b, 0xe1be5fd6, 0x57d0076c, 0x170f28de, 0x1a2b7d69, 0xc91d446c,
	0x409afeda, 0x601f2d7b, 0x61e43b7b, 0x57d95ed0, 0x84442977, 0xf86eca7e,
	0x01d292ae, 0x3ddad6fd, 0xf6c7abe5, 0x3e567e34, 0xefa3db4b, 0xb820bd55,
	0x26558ba0, 0x3a3a01e2, 0x3ee75976, 0xd5fe8765, 0xc3622328, 0x2770b1fb,
	0xb03ca3f4, 0x03b02951, 0xa5951b7d, 0x5bea7aa3, 0x7a9ff0d1, 0x5333eafa,
	0xc6e5613c, 0xb28f94f4, 0xbe4f4474, 0x9077109c, 0x80a44bd6, 0xe7ba3252,
	0x3c4207f9, 0x7ea01321, 0x9e96a891, 0x11e4a9fa, 0xf4c3fe07, 0xfe0f949f,
	0x2d81b13d, 0x5b723d19, 0xf59904e9, 0x939cedc8, 0xcaea51cb, 0x4b5faf09,
	0x5079011f, 0x4e7cea7a, 0xa5f31f4c, 0xa7deba62, 0xe17edf22, 0xbd69891b,
	0x9fcf85cf, 0xba62e5f0, 0xf4c6e7c1, 0x4c42be57, 0x7c62be03, 0x2e6f936f,
	0x1e7d9ba6, 0xafb4fe7c, 0x5f06d30c, 0xce7f3e35, 0xadd31ab7, 0x7f3e3f3e,
	0xd30eb7c1, 0xd30eafa0, 0x9a2f20ed, 0xf802fa36, 0x035f4ede, 0x20be4da6,
	0x6beddf3e, 0xce21f4c2, 0x9214c747, 0x383e5127, 0xc549c4dc, 0xdc8a124e,
	0x27cd3279, 0xf27cb314, 0x853cfe6d, 0x343d93e6, 0xb032f94f, 0xa6679422,
	0xacd581f9, 0x24bdc87c, 0x43f342df, 0xe87cacfc, 0x2b7cee43, 0x63ad0fcd,
	0xf83623e5, 0x7e6863f3, 0x5f958044, 0x6f9435b1, 0x822bf9a3, 0x99ab3cac,
	0x7cd3b34c, 0xb3e58856, 0x8b4f775f, 0x56ecf9a5, 0xc0f9cf96, 0xf341cd3f,
	0xfbec6d39, 0xa203a7c9, 0xc3948f6a, 0x4c5d5976, 0xf836aca8, 0x49a5ba67,
	0x77a8af34, 0x8fe51711, 0x94b726ff, 0xbb21f946, 0x9fe43cb1, 0x8a8de58f,
	0xf6dfcb1b, 0xa77e6297, 0x63f2c1ec, 0x57964afe, 0x85fe583c, 0x37cc6eff,
	0xb72c7ec9, 0x5e58f8d4, 0xc0f963f1, 0xff58759a, 0xe580396e, 0xc51e6aa3,
	0x004addf2, 0xf35b1fcb, 0xcd3a7b84, 0x5f9e0ad7, 0x5a691e00, 0x4f013246,
	0x8a62d4c1, 0x9902b5a7, 0x11fdf80b, 0x72e28e80, 0x7a829a6d, 0x398ffdb8,
	0xe2fe814f, 0x97e4125f, 0x0660fd3e, 0xac6bff7e, 0x88f5a647, 0xfd93d77d,
	0x9eaeae46, 0xb4ca37ec, 0xbde01a7a, 0xeaff6b5a, 0x64c6fed9, 0x946f3d3d,
	0x436cf56b, 0xd7fb627a, 0xa737ecaf, 0xb379e9e8, 0x3767ab42, 0x3fdf13d2,
	0xeb0f1a7a, 0xb878d3f9, 0x482d3f9b, 0xd1fe80cf, 0x3d5dfe33, 0xdbbfc67f,
	0xb1d79fcd, 0xd5feb49e, 0x9eaef8d3, 0x76ef8d3f, 0xf630e7f3, 0xfaff706b,
	0x3d3dfe35, 0xd7bfc67f, 0x908f9fcd, 0xd5fe8c9e, 0x3d43f3b3, 0xd87e767f,
	0x58e39fcd, 0xf5fef0cf, 0x3d23e72b, 0xea3e727f, 0xd6174fe6, 0xeaff7973,
	0x9e91f9d9, 0xea3f3b3f, 0x5897cfe6, 0xf5fee8cf, 0x7a2fe72b, 0xa5fce4fe,
	0x01263f9b, 0x3fdb19ea, 0xd53e9a7a, 0xd3e9a7f3, 0xb0d8fe6e, 0xa3fd099e,
	0xcf5db727, 0x6ef6dc9f, 0x200924fe, 0xabfd49f7, 0xcf5da9a7, 0x6ef6a69f,
	0x7ac60cfe, 0xbf5feeae, 0xf9eb8f72, 0x9bbc7b93, 0x5fb0233f, 0x81ef5479,
	0x89eb421e, 0xdd9ebded, 0xd9fcf467, 0x3f9ba67d, 0x199eb063, 0xbecc9eb4,
	0xa1dc99eb, 0x8ee4cfe7, 0x62e4fe6e, 0x57fb333d, 0x3d0eeecf, 0x7477767f,
	0xf90f27f3, 0xfaff7d73, 0xcf53b935, 0x8c9dc99f, 0x550ee33f, 0x72d0734f,
	0x44ba163a, 0xa755c9fa, 0xe6816edd, 0x8bcb2745, 0xbf01174e, 0x0dfcd444,
	0xe916ead2, 0xf1adf6f7, 0x70920fd9, 0x04bf23bf, 0xbd4b15fa, 0x23bf70b1,
	0xe746372e, 0x13bbc4e7, 0xc2c4f974, 0x07f7ba81, 0x95d50f14, 0x42bdcca7,
	0xc9e69e57, 0xcbd3e5d6, 0x1fdeeb26, 0xcbaf9d5c, 0x5afab65f, 0xfe19fbdd,
	0xccf9749b, 0xdeeab775, 0x48b75e1f, 0xfabdfe57, 0xe5f95d72, 0xfcba9581,
	0xa1ff0d95, 0xf0747f7b, 0x98f95d3e, 0xe57507a6, 0xe98f4363, 0x3e0ee3f2,
	0x427f7ba1, 0xf95d26eb, 0xe9cf23c4, 0x6db527ca, 0x3aafe5d7, 0xe7e0dbb1,
	0x57ed9dd9, 0xb808bcf2, 0x4fefcc27, 0x0bdfd053, 0x57982ac5, 0x8fd1da06,
	0x54bb17df, 0xabe5463d, 0x4d58bcbc, 0x9905f2a2, 0xe7ae3a12, 0x5efb2c0d,
	0xf77e7d1b, 0x9cf7cf64, 0x8addf9f4, 0x8a338c67, 0x20f14a7f, 0x55485490,
	0xf2c6a413, 0xc78665fb, 0x46aff4fc, 0x7bdfa51c, 0xe2235d4d, 0xcc453e69,
	0xfcbc07ab, 0x4e21304a, 0x0d524463, 0x0998c5ef, 0xcfee0bce, 0x1fca79c8,
	0x8375d786, 0x3d0a1ea9, 0x3d93aef5, 0x6c67e0a9, 0x0fcb79aa, 0xc1dac87e,
	0x09035fb4, 0x2b784a79, 0xbf461fe4, 0xd534bc1f, 0x2b33eb43, 0x6f0f4fd4,
	0x8feda15f, 0xa01bf6c2, 0x697a17fd, 0x57343cdf, 0x4865bed7, 0x8b7dae99,
	0x5277db42, 0x4fe6a07f, 0x842a7dbc, 0x24bc84c9, 0x37db09fc, 0xf6c3290f,
	0x7ce857ef, 0x98fdbc25, 0x409bf6ee, 0xfb42f77f, 0x7ff4a213, 0xff7d64e8,
	0xfbeb9487, 0xbffeb0af, 0xb794735c, 0x6ffd831f, 0xfeb28e11, 0xfd67290f,
	0xbb7ab337, 0xf37477db, 0xfff420ff, 0x9ffade8d, 0xffdf4539, 0xfdf42acb,
	0xdff6b337, 0xdbc939ae, 0xeffb63b7, 0xff592708, 0xf6c0ab2f, 0x05c7b315,
	0x63d251f8, 0x7db403aa, 0xa61a8832, 0x6d0b8014, 0x0991d207, 0x3c84d414,
	0x3a450c2c, 0x78618eee, 0xe28622fb, 0x1f8ded0d, 0xb500939f, 0xde74396c,
	0x62beb1c5, 0x76029e6b, 0x7ce9cb09, 0xb5270965, 0x7c4449b4, 0xc0e6f593,
	0x476f4a70, 0x7c87e893, 0x03abfae9, 0x66bcff60, 0xbe18a0b2, 0x9e084893,
	0xd1f3fa7f, 0x65fbc29b, 0xc9d4974c, 0xfa616ded, 0xca8f3dd6, 0x29ab2327,
	0x0400337d, 0x1ff27a13, 0xa11079d3, 0xe80f8bf3, 0x4850833c, 0xf6b3227e,
	0x25f3a23e, 0xf9d1b7c8, 0x52139412, 0xead1df83, 0xfa52a50e, 0x1ffd398b,
	0x3f5f4c4b, 0xf8084dbe, 0xf17e7ea9, 0x4f38b183, 0x46dab05d, 0xc743de99,
	0x2ea27f42, 0x07e5fb4f, 0x32ed7539, 0xc8093607, 0x55f8155f, 0xc849aa82,
	0x94e975e2, 0xbfef3dd7, 0x469ec547, 0x710b7f59, 0xfdf429cb, 0x830957db,
	0xd9ddb49d, 0x1b36736e, 0x26e9dc27, 0x6e926bd4, 0xa6e425ca, 0xad32b1c6,
	0xe5b89481, 0xdac2db8f, 0xcfa8559d, 0xe7d62ecf, 0x6cb7643b, 0x947574a2,
	0xad236408, 0x7d5cce77, 0xdd8ed6b9, 0xcce4c094, 0x664e2bdb, 0x3481cdf4,
	0x513b1e1b, 0xec9d73ce, 0xef1e8d5b, 0x614e9962, 0x01fe9e41, 0x4feae404,
	0x756ef7c2, 0xe91b7eb2, 0xdc5b2b9d, 0x739fb4c5, 0xc0018a17, 0x3ffe91b7,
	0x4db9b5ef, 0xf75d3459, 0x22989933, 0x7fa463fb, 0x9fd8c79e, 0xf0e30ca0,
	0x73e332fc, 0x2e769b86, 0x1f018fff, 0xf80e3d34, 0xe31ff4a0, 0xabb1e8f8,
	0xb35e1f0c, 0x43c006e7, 0x4122e3d7, 0xdcbc72b9, 0xa4b2f1c2, 0x420b8f4e,
	0x71c8323c, 0xfb215cd9, 0xcc1c30c1, 0x565838e1, 0xedcdc7af, 0x45a72fc4,
	0xf5bccb91, 0xaa9c7f1b, 0x43eff646, 0x0ff99b8e, 0x44fe43ed, 0xe9c993f6,
	0xdba72e0e, 0xb7e5f5ab, 0xcedeb970, 0xfeb73ae5, 0x7cd4fdd1, 0x80d55b90,
	0xbdeefa0c, 0x9b679347, 0x2e1e9e4e, 0x779d234f, 0xf1de7970, 0x234f2603,
	0x9e5c6dbd, 0x65e7f56d, 0x5e923432, 0x560b7d23, 0x0147f447, 0x47f42e79,
	0x29b7a797, 0xd858f12f, 0xcce0caf3, 0x7a6163c4, 0x44a1a2b6, 0x981e5f97,
	0x597f7ba7, 0xf95d42fd, 0xbae5ba92, 0xeeebc5f2, 0xfa17e5d4, 0x7f7ba07f,
	0x5d1aeac1, 0x0fd5edf9, 0x97e7cae8, 0xcfcbaa3d, 0x7bae3cf3, 0x8ddcce7f,
	0xc5d9f2ba, 0x67caeacf, 0xe5d36e15, 0x74bbdc4b, 0x5ef69bef, 0xf3e0237e,
	0x0122c3f5, 0xd773e27f, 0x7e0b8c71, 0xf05d92ee, 0x8a9f31ce, 0x8df76eb8,
	0xcf84f4c4, 0xe53fb885, 0xa3b4c5cb, 0xe30ec5a9, 0x97171d04, 0xe66a7892,
	0xacd4374d, 0x34e3041b, 0xb374f1c1, 0xff1ae6e9, 0x637e4214, 0x45df9152,
	0x8d090af5, 0xc1804423, 0x25d1d386, 0xf5b79586, 0x0d4f5e51, 0x7964627f,
	0xe7f45b51, 0x5e16c7de, 0x77128ce6, 0x9253d1e9, 0x274f7e0e, 0xe58dbbf7,
	0x0e290215, 0x7dc84e7f, 0xf967d7a8, 0x30a15bb8, 0x9ed8affd, 0x901c4f96,
	0xbea88d0f, 0x0a417b54, 0x49c014f2, 0x978f4ea6, 0xb3a95fd5, 0xb2a204ef,
	0xe36f0003, 0x3457cf74, 0xeefba55c, 0xe9113ef4, 0x315b02ae, 0xe2c58609,
	0x87604cd7, 0x66432d43, 0xdd3a068d, 0x9c609baf, 0x7e801a6a, 0x615f69e1,
	0xe40931e2, 0x09e98c57, 0xdb4c5cdf, 0x8f4c1e7d, 0xfd30caf9, 0x698d57d8,
	0xa6356f9b, 0x98fcf91f, 0x875be07e, 0x757d9fe9, 0xd5f11e98, 0x2faefa63,
	0x5f21e980, 0xfb6fa603, 0xfab69882, 0xf0ed309a, 0xf4d531b9, 0x9ddc2fae,
	0x29f0e3e0, 0x9c145fc0, 0xaab7dc75, 0x1e94dd66, 0xdd339d9c, 0xd41fe353,
	0x7aa2e7c3, 0xb243c733, 0x425f0f0e, 0xd67119b0, 0xccbd7947, 0xf7dbd871,
	0x9bbdcbd1, 0x9b7835fe, 0xe67e6260, 0x0f5bc5b7, 0x780dd29e, 0x4f0becca,
	0x3d09c403, 0x72609a78, 0xe387bf32, 0x8fd027e9, 0x7c8af328, 0x84064270,
	0x1b6e6bf9, 0xf5f3538b, 0xb2a9ea04, 0xbb6f3538, 0x8adbbe96, 0x24605d7e,
	0x46e71b8c, 0xc40475fe, 0x311dcfe1, 0xef5f49d3, 0xa4e233fd, 0x71bbbe77,
	0x4034b37e, 0x9171af07, 0xc618d6e5, 0x1489ab57, 0x3dae3a12, 0xd769fc30,
	0x979851a2, 0x1f7c0248, 0x46c49570, 0xcafa97a9, 0xf8bedfc0, 0x45fb1b5a,
	0xfed7d416, 0x2072dfc4, 0xfe62609d, 0x888b4c72, 0x3d093b7e, 0x76fe02e5,
	0x57664b8f, 0xbbb7c42a, 0xf44e2b86, 0x3d76021b, 0x9f34fcff, 0x07bfc3d3,
	0x715a8f28, 0x454baddc, 0x62fb0dfe, 0xf83f5a44, 0xef7d97d7, 0x028b9f8b,
	0xfc25ff03, 0xf63ecbec, 0x5b891765, 0xf689a17d, 0xe8ef73bf, 0xb05507ec,
	0x3cd94383, 0x6b7e17ad, 0x7a4652eb, 0x710df87e, 0xe1ac99dc, 0xa10875b8,
	0xf5c47ced, 0xf7e35ce5, 0xb42e40e2, 0x741f9c1e, 0x7e7ee0ed, 0x933d721f,
	0x6bcfafa1, 0x214e2fac, 0x6eda18c2, 0x3890a2ac, 0xcf45aa42, 0x6fce22c3,
	0x887e6d5c, 0xb9b5ec1b, 0x3798556a, 0xa4237a9e, 0xf8fa8d42, 0x4f83b9c2,
	0xb61e6039, 0x3ce4d532, 0x5a8e4516, 0x70cc195a, 0x2be7c3da, 0xb9fcfa4d,
	0x8830a13a, 0xee3539f3, 0xce30d1e6, 0x86c79d38, 0xc54fdd81, 0x6567ab54,
	0x463ce2aa, 0x86a9eeed, 0xff3638cc, 0xb27b300b, 0xcded1e35, 0xdf059f29,
	0xd3d367ff, 0x3d1a3d5b, 0x4f923484, 0x69cf602c, 0xefef6659, 0xd20faaf7,
	0x9be20505, 0x02fe59a4, 0xfa569be6, 0xa143d7ff, 0x5af3095e, 0xe8a0debd,
	0xe7818f37, 0xd1ed755b, 0xed6d54ef, 0x5debbe15, 0xaed224ef, 0xefca9ee1,
	0xbc3ebe15, 0xd4eac1a2, 0xbaf1b1fb, 0xcd29b7bc, 0xe16bf3a9, 0x57b8e01f,
	0xafe0120b, 0x53afc382, 0x3c03afb2, 0x21e0826d, 0xf6045fcc, 0x4da5a55e,
	0x2ea8a8f1, 0x45cf80ad, 0xd5fe1ab9, 0x3b53ef39, 0x9935f275, 0xaf919e80,
	0x3d395528, 0x9e91d1f5, 0x317e6898, 0x5c6a2dcf, 0xd6e30451, 0x3f9b1349,
	0x07629294, 0x48cb8fcc, 0x53c40e5d, 0x215310cf, 0xf219e7e8, 0x985c63b6,
	0x15159e3e, 0x75e2e7ec, 0xce9e3f7a, 0x65f975ef, 0x52fcfaf5, 0xac325372,
	0x2f5d2f83, 0x76008093, 0x547e5f43, 0xcbbd6274, 0x185af548, 0x6ccbd7b7,
	0x24e45b3c, 0xafa53a52, 0xe64fb7f2, 0x8bf9a42c, 0xb57f1b22, 0x09e5dc75,
	0xe0f2fe8c, 0xcb4dc546, 0x771c693f, 0xf440b50b, 0x185ac0fb, 0x043bfcb7,
	0x523516d7, 0x7e94df7e, 0x3f9abd23, 0xcc9eb110, 0x106ca8e9, 0xfe2881dc,
	0x4c092280, 0xbbbdb8cf, 0xe2ea7242, 0x0f903920, 0x6b7c838b, 0x1d11253c,
	0x9e89369e, 0x8604d221, 0x09ff981f, 0xf9e29752, 0x46a7f52e, 0x34857fd4,
	0xff589fe0, 0x8e7f5a20, 0x7f9cfeae, 0x22c3fd2a, 0x568fcfe8, 0x9f6fe57f,
	0xf6a7e9df, 0x9fc5fca4, 0x271d083b, 0xc9754a4f, 0x8adf2a2e, 0x80763f2d,
	0x7e484f9c, 0x64f5e007, 0x440c2c40, 0x7756b719, 0x176ddbcb, 0xff06ee20,
	0x7a9ff5a4, 0x8f1827ee, 0xec8b62f8, 0x835a78c4, 0xfaa66439, 0xbcb8d558,
	0xfe616488, 0x7fdfcb28, 0x937c8456, 0xcfe57f1e, 0xf6193cfc, 0xf0a45057,
	0xfd0852f8, 0x9fcdaad9, 0x44f8e016, 0x8c8f50ba, 0x17fb41df, 0x2dfed013,
	0xcb22e254, 0x27189d29, 0x78be72f0, 0x56727f1b, 0xdabfc074, 0x7c6efe70,
	0xa7fb8cbf, 0xa4d8a5cb, 0xf7fd1b76, 0xec113244, 0x120fc6a1, 0xed69fe60,
	0x3accbfb3, 0xbd39e94a, 0x108735f9, 0x8f4d27c6, 0xff1705ce, 0xbbdab77a,
	0x7aa0edbd, 0x6907ee16, 0xc4da95e3, 0x9666eafd, 0xc721c856, 0x560ed455,
	0x7e5d946c, 0xf9e2b8fa, 0x027e9ea7, 0x327f98e2, 0xfad386bb, 0xffbf3c57,
	0xbf34c9dd, 0x549c9b62, 0x1761bac4, 0xe2e47b92, 0xceafffa5, 0xf94391ee,
	0x7515fb4b, 0x6f7e7b34, 0x563c8f42, 0x90a7db6c, 0x98fc91d1, 0xb4a7dc16,
	0x25c8a3d9, 0xfc00b478, 0xff67da84, 0xe2f8815b, 0x4902bdc9, 0xcfc288c9,
	0x0fd1fb8d, 0x1ca13e00, 0xe5ba9cb9, 0x4bdf7866, 0x5af602e5, 0xfcb19393,
	0xa04f6e3a, 0xe214753e, 0xb4dd85f9, 0x9b3fb2fd, 0xb2ffd05d, 0x4072ee17,
	0xd54b8e3f, 0xfe4fd70c, 0xdb4dd938, 0xc9fd932d, 0xf3d94c4e, 0x1bfd5fb2,
	0x5bd96de2, 0xf18c96ff, 0x334ee224, 0x4fe3d8e1, 0xd92dfe83, 0xb7fb1b30,
	0x77107894, 0xc58a4f65, 0x973eff60, 0x28b6e148, 0xf5c1d17a, 0xea26f8e2,
	0x1dfed188, 0xec23f987, 0xc45b79a7, 0xdc84557d, 0xffff4049, 0x7a85f78d,
	0xdcff9808, 0x5fb4e4c2, 0xa2bd7132, 0x5e3866de, 0x0adfdf37, 0xd83539f2,
	0x2ceb029d, 0x39f9225e, 0x69af843f, 0x335be2bd, 0x887c9852, 0xeff0e52a,
	0x0d3f38e8, 0xadfbc39e, 0xa59adbb2, 0x9d7c8efb, 0x2afed3d1, 0x3ba53ede,
	0xe3e7c606, 0xd5fdd1c9, 0xf7a6b281, 0xc30e9c74, 0x337e9857, 0x00fcdf7d,
	0xdf4d6fd3, 0x50852503, 0xd310e17e, 0xc60ef81f, 0x28574a3f, 0xddf7cb05,
	0xa03da02c, 0x7a68e6f3, 0x7ae659bd, 0x70d72fad, 0x8496e942, 0x40bc30b8,
	0x7fc809fd, 0xba595f5c, 0x66177e9e, 0x9ed0bd2f, 0x4d3eb223, 0xfd71976f,
	0x7ffa093f, 0x93fe8f65, 0x7bef4c0d, 0x2cfc9ff7, 0x9e07236e, 0x95f4027e,
	0x055fa7ea, 0xa18b957d, 0x6d6d9fdf, 0xaa56f779, 0x35059fa7, 0x4fdbd53d,
	0x6d969ea3, 0xe9a2409f, 0x177667e9, 0xf4a7aa89, 0xb53d5479, 0xff8e21b7,
	0x8d4fd94f, 0x9eb2f17f, 0xec3d9a7f, 0x7b468f8d, 0x22a482f8, 0x90f68d3f,
	0x39221dfe, 0x70d3f891, 0xfcade1a7, 0x81979537, 0xa5c6e9dd, 0x5c6ebb86,
	0x888bb86a, 0x67f8eadf, 0x621f7f2c, 0xf9ae944d, 0x30a9fa96, 0x1174b08f,
	0xdde5779c, 0xa9bae22c, 0xbd4102e5, 0xee3227cf, 0x54cf7c1b, 0xd0fc013d,
	0xe5bb7fa9, 0xde94ddcc, 0xb32fc4f9, 0x193af975, 0xbeaffafd, 0xed0a7afe,
	0xbf9cadcf, 0xafbb29f3, 0x2b98f2a7, 0x4a18a109, 0xf8893ce7, 0x3e2012e3,
	0xc38f902b, 0xa65f98e8, 0xd4dfc3cf, 0xfa7a9ee4, 0xce9bff7a, 0xfa6dbe43,
	0x5dad8f96, 0x30e903bd, 0xc70a5e6c, 0x95c80953, 0x5e3bcff2, 0xbb450c08,
	0x871526d4, 0xe31eabcd, 0xe9ade776, 0xff8026b3, 0x74673792, 0x10f9c31c,
	0xb97adf9c, 0x57e73afd, 0x9faec0e3, 0xf9c4ce6b, 0x8b83b9eb, 0x9beda363,
	0xdb38e16c, 0x3a55d7cf, 0x489d42ed, 0xba49df71, 0xdbf17fd0, 0x944b64ad,
	0xca1fbf75, 0xc50ebe26, 0x44ff46e5, 0x1cb9b72a, 0xa7e8f387, 0x7261d971,
	0x93faf9bb, 0x0e522392, 0xd871f7f0, 0xf2bbeb3c, 0xfc0d7017, 0x15b6b16d,
	0xcff14714, 0x37f9ca7f, 0x712fe5f5, 0xe6f4eaff, 0x38f8093c, 0xe2ea2edd,
	0xfa6bf71c, 0x028c8a3a, 0xbcbea6ba, 0x1409e1fc, 0xa283dec7, 0x7aabf60b,
	0x9e2acf9b, 0x235df328, 0xf07ea13f, 0x4ecbf723, 0xb961d7e4, 0xf5f00978,
	0x812b6cf0, 0x1477cb75, 0x3a346557, 0x3c599867, 0xfe291e64, 0x7ff0bc7c,
	0xe6f37f1f, 0x29f286c4, 0xd9d9ce3f, 0xfc48e07e, 0xe73fbd31, 0x02350214,
	0xf96450e0, 0x71002124, 0x79e202b2, 0xfa808a78, 0xfdb84d7e, 0x792a6bca,
	0x54d5f61e, 0x134e0b35, 0xda92af2d, 0xb7b1c014, 0xfe049b69, 0x712a75f9,
	0xaa41bc63, 0x58737d1e, 0x2cbf6b5c, 0xfe5abf21, 0xc0edeb7a, 0x9b37f3df,
	0x1ee5d009, 0xe301d675, 0x71e6f9fe, 0xf5bd07a8, 0x323e8feb, 0xf504ba75,
	0x1187c410, 0x3649050f, 0x34f67e5d, 0xe545c832, 0x76dcd536, 0xfc8a2b97,
	0x670c2996, 0x966fb6fd, 0xdbeccfff, 0x18df6a14, 0xfb70e5ae, 0xb0894636,
	0xecd1296f, 0x351acadb, 0x72b17005, 0xc80a664f, 0x4babe575, 0x6fb34406,
	0xfcd8f8af, 0x0fbe55fd, 0xb51073bb, 0xecc2636f, 0xdf6a20db, 0xd36dc4a2,
	0xecffcd14, 0xfe59bec3, 0x15eff477, 0xfa516fb0, 0xdbd14a3b, 0x1ae6c2b7,
	0x83856fb4, 0xa87edd44, 0xe7cf854c, 0x0b6fb57a, 0xf31b3e7f, 0x0516cbb2,
	0xb057c03f, 0x3b72af6f, 0x9d80ed07, 0xb138a45b, 0xb9dafefd, 0xb9dafe92,
	0x6b3e25ff, 0x60e56e76, 0x12239e76, 0xadcecc87, 0x6e7660cc, 0xe7661ee5,
	0x76670e56, 0xf2df68ce, 0xfb1bec23, 0xfd246abe, 0x198be71e, 0x968dbcbf,
	0x5d95cd17, 0x917efa16, 0xa85f9daa, 0xef6e109e, 0xf2122916, 0xb9dec239,
	0x9039e2ce, 0x9bddecbe, 0xa186ef60, 0x7a061b1d, 0xb5c7c464, 0xfdba6cc3,
	0x6cbf8772, 0xa08bcdff, 0x71147f2f, 0x899efd9e, 0x7ef68bcd, 0xf40e3ed9,
	0xe7a7176e, 0xb3c98561, 0x7b47e7c3, 0xd3146d3a, 0x3183caf7, 0x35544e38,
	0xf7bfac0a, 0xc615010a, 0xc45ebf81, 0x7bedf2f9, 0x8e797cd8, 0xfc83f199,
	0x5dcec8bb, 0x0c2c1650, 0x8bdcc3c3, 0x9cd718e5, 0xf80b112b, 0x5e0e0baf,
	0xd6fc127b, 0xa1d71705, 0x9e00bbbf, 0x6d89bec3, 0x69d36b6d, 0x172fb7bb,
	0xeda1de70, 0x6dd798ef, 0xec7ef52f, 0xfbe8e6fc, 0x7a72a634, 0x0423dea6,
	0x5f4e5f60, 0xe05e20fb, 0x6c4737fa, 0x37917e43, 0x2896d745, 0xd7bda3fa,
	0xe31727cd, 0xe62ae54b, 0x89f37737, 0x22154df2, 0x5d2544f9, 0x87b930b4,
	0xa0efb72f, 0xbdea4dfd, 0x22df1abf, 0x71b8e1f7, 0xbf80b33e, 0x341f1bd7,
	0x9ff4473e, 0xa9fa9df3, 0xc8c79fb8, 0x6766a08f, 0x41a324ae, 0x7933df2f,
	0x38009e1e, 0xe3112ffa, 0x1bccb7b6, 0xb3cf3bae, 0x7ae5f393, 0xc9e9d1cf,
	0x5491f02a, 0x2d6ece03, 0x993fb6db, 0x7746eff6, 0xcc843646, 0xf155ff67,
	0xc5a1fc40, 0x507685da, 0x99aa61c3, 0x8e33f0e1, 0x9d03c3c3, 0x69bc71d3,
	0x5fa89c12, 0xe39d8321, 0x94bcc8fb, 0xdebfa0cf, 0x513e3e26, 0x167e827c,
	0xc815e368, 0xfaf3fe85, 0x6f172666, 0xb97280b5, 0x001d7481, 0x092557be,
	0xaaad10ae, 0x8fdb69a0, 0x2bd5bf61, 0xf41cfa56, 0x6d704cbc, 0xa7b0ec62,
	0xb1c54725, 0xb8c70d14, 0xdc6c3049, 0x25ef005c, 0x3345bec0, 0x0ffb7fb6,
	0xfa323d98, 0xadcd5329, 0xa99e8187, 0x8d932eff, 0xff4030f0, 0xd181c30b,
	0x83d0898f, 0x27efb86f, 0x57efdb99, 0xe0760e40, 0xfe029777, 0xc6c43790,
	0x2bdcad1f, 0x6f91d3a9, 0xe89a1c9a, 0xc99e32f8, 0x8dfa9601, 0xcb51be7c,
	0xfde1fe03, 0xef864166, 0x24f95267, 0xa669a2d2, 0x78680f2f, 0xfc91ab37,
	0x5a427882, 0xfb00dd98, 0x596ebe16, 0xf216f4d5, 0xd455dae9, 0xf923533d,
	0xec07c9a4, 0x15f8a5e0, 0xfb4d3fa1, 0xfa9feea2, 0x6a93fab6, 0x5ecfebd6,
	0x636bd76b, 0x47b68e20, 0x9a42bb40, 0x83f175e3, 0x979b335c, 0x883d58b5,
	0x6557aef3, 0xd23526d7, 0xe5ce5cfe, 0xf095f302, 0xa0d37bf3, 0xec6eb043,
	0xb44f92b4, 0x38650f7e, 0x5e0f1f0b, 0x7e507ab1, 0x913fd5bd, 0x3f9bdfd7,
	0x0fbfe5a6, 0x45bec1ed, 0x719edf55, 0x49e2d23c, 0xba6bf57d, 0x6f8fd999,
	0x9dad2fdb, 0xe0eeba6f, 0x7f18ad25, 0x361fd6d3, 0xc85f9e89, 0x142e3f30,
	0x5d3afd24, 0xfe5fae17, 0xa71fea13, 0x887ea25c, 0x9f28851f, 0x14fad95f,
	0x3ccfabc6, 0xd006f477, 0x13bf159f, 0x53ea8589, 0x1258d6c7, 0x1440fb62,
	0x1bca13f0, 0xf3c63745, 0xacce50a5, 0x90833f30, 0x178fc65a, 0x94eed163,
	0x8a07376f, 0x3be5f7e8, 0xb882c93f, 0xcc7dc75b, 0xe39ff9fe, 0x65b7f478,
	0xb97f7ac1, 0x8df1d6c4, 0xe39bb9f2, 0xdb2ef4f3, 0x42dfb05c, 0x5aef3b03,
	0x9b239c1e, 0x950ce2c3, 0xb5c59966, 0x9f70d977, 0x0159ffb5, 0x7d0329f7,
	0xb52ce7e1, 0x9fa79ffd, 0xbcb97665, 0xb9c00e49, 0x6d86f2d9, 0x2f07101d,
	0xff46623f, 0x1670dbd5, 0xbda6edd7, 0x47fa3cf8, 0x175126de, 0x3f888d07,
	0x33218836, 0x2b1acfc4, 0xfcd00ed1, 0xa307cc51, 0x8afbe1c7, 0x7178ad93,
	0x653f4ecf, 0x9e978ae1, 0xd9b9e071, 0x8c0e2dd6, 0x3a5c3643, 0x6f111ffe,
	0xc9703e0c, 0x8e29e378, 0xf59b5f8f, 0x21a435eb, 0x9490e311, 0x28e29cbe,
	0xdc6e8b71, 0xaff9ff3f, 0xf4ec3d60, 0x057ecff6, 0xe3fc56f4, 0x01eeaffc,
	0xd5af6c7f, 0xf7b5e309, 0x9eb8c3b9, 0x8bb77da0, 0xb3c779eb, 0x4c3ae0cf,
	0x2ecc9fc7, 0xcf63ada8, 0x1eb021f1, 0xcbedb1d1, 0xaedb8864, 0xe70333da,
	0x4c76ab69, 0xe651214b, 0xb80a5a01, 0x1d63f40d, 0x96af28c8, 0x402196c6,
	0x6f2a19e7, 0xe3bad970, 0x164ac1c7, 0xdc79578f, 0xf5f46b78, 0x713888b6,
	0xaf1bace3, 0x51bbf186, 0x1fa4a976, 0x5443e2f1, 0x21fa638e, 0x680fadbf,
	0xfcaa3ef6, 0xa83fc0ce, 0xc833de9c, 0x25c6f3ef, 0xca027ebf, 0x8d7b131a,
	0xc1fa8717, 0x6f3d6d37, 0xb1fdd9b3, 0xfb66f419, 0x0f3e306f, 0x0d73a372,
	0xe7fcf1d2, 0x72ce2043, 0x03baee42, 0x31eccff7, 0xf2a8bee3, 0xfea1ef3d,
	0x0b78ec74, 0x5f08cbd7, 0xdd20eb57, 0x841d6c7f, 0x9bbce1cf, 0x999c5963,
	0xd0e21ff3, 0xf39f03aa, 0xb1c33378, 0x2dee8716, 0x61669cfe, 0x75b489fb,
	0xefcdcac6, 0xd710c42b, 0x4e417217, 0x2eb92f47, 0x09c1f1aa, 0xbe18987c,
	0xce3d129e, 0xc6eebddf, 0x03f205e5, 0xbd7babff, 0x4107e684, 0xbc203cfc,
	0x83d8a247, 0x1d6c8d8e, 0xbe8e43a6, 0x5f5b50ff, 0xf418b249, 0x75bfd034,
	0xffe8be95, 0x6191fca6, 0x922139b2, 0x8abfa74f, 0x5a27c76e, 0x1fb6ef84,
	0x588842a6, 0xfac0b7ff, 0x0551e37c, 0x38da1fe6, 0x34f7f5a6, 0x7e9f279f,
	0x1ef3c44e, 0x682d836b, 0xa2f68dc7, 0xa0f8b08a, 0x9c99de91, 0x3626aade,
	0x1ede9c4e, 0x7ad3b01b, 0x0bbcbf4e, 0xf5b55cf1, 0xf5a7e2a8, 0x4978681d,
	0x2fdb0b69, 0x2044e305, 0x2fd3fe8c, 0xeb62cbec, 0x6e5e6c47, 0x6f0e676c,
	0xbd1cdbc7, 0xb3d6ef1d, 0xf85676ba, 0xbf3b0a83, 0x4ef6e973, 0x5039ee49,
	0x9956a9df, 0x53fdfec0, 0xda30b141, 0x16c993fe, 0x33cb8b59, 0x25e3a1bd,
	0x658c779e, 0x04c51be7, 0x55ebfd05, 0xe247b9b1, 0x54552092, 0xd6d45388,
	0xb538fdb0, 0x82a5743f, 0x6fe36bbc, 0x3ab6f5c1, 0x499d7f03, 0x5f883cce,
	0x8f17a738, 0xed1ab807, 0xa4dbbc4d, 0x6c557fa3, 0xc79c0a61, 0x31fdc35f,
	0xfcf0b922, 0x2828e8a5, 0x4e88fe84, 0x651ad393, 0x17b6417d, 0x5f184f13,
	0xbcfea764, 0x9c6af924, 0xfb68f50a, 0xad2c2a68, 0xe9d0b007, 0x52c2adc6,
	0xef377b2e, 0xbbf62766, 0x279f2b73, 0x4cea89b8, 0x60c1fb66, 0x1edce8dc,
	0xe0c64597, 0xf14dc487, 0x85cfe368, 0x81f6fbad, 0x20e35a3d, 0x67aa78ee,
	0x98aaab94, 0xc746e709, 0xc04c845a, 0x7e37d9e9, 0x36b5eb47, 0xe87f388b,
	0x42fb6bb4, 0x67a0f1dd, 0xee10f236, 0x7f2803ff, 0xa743d89d, 0x81205f71,
	0xee7b9257, 0xda219895, 0x6e73de71, 0x88038b03, 0x4e5f8ae4, 0x12387161,
	0x78f9fa00, 0x79d382b2, 0xbf78520e, 0x1d73c154, 0x297d5ecb, 0x1c984427,
	0x5895f9c2, 0x5a5f3fa8, 0xc164756f, 0xbbf13cba, 0x4c9ce15b, 0x406faf29,
	0x29dcfeb1, 0xe83f3f55, 0xa7ae12e9, 0x382d2d9f, 0xd4aff608, 0x7aed14b3,
	0xb9fd5cca, 0x2b3ee354, 0x85f617a4, 0x427bbd51, 0x5577dc88, 0x5ae8fcd6,
	0xee472f98, 0x612322bf, 0x8939593f, 0x9cf9c171, 0xf2fa0d15, 0x2f3760bd,
	0xfb127607, 0x7d7de2a5, 0xc46db7f2, 0xbf8ca72f, 0x215d7f24, 0x2c6b7f78,
	0xbd9655c6, 0x93ed18ba, 0x5fcf5539, 0xafe7aaab, 0x8f91a46d, 0xbac73e7a,
	0xe6d37cf4, 0x39f1bd9f, 0xde7f572e, 0x8967c8d7, 0x804378f0, 0xf62221c5,
	0x446d35b7, 0x367c8dba, 0xc2ddb5f2, 0x5f38bdd7, 0x25b15fe9, 0xa06c9999,
	0xa10a4d3b, 0x28f5185e, 0xe0121edd, 0x029383df, 0x2b95f835, 0x2a7bed16,
	0xca508fef, 0x1e81b3be, 0x0baf4089, 0xf44e08f5, 0x91b79d81, 0x56ed9c0f,
	0xe427d610, 0x977b2beb, 0x7f255de7, 0x7e88ba38, 0x3bf001b5, 0x9d8af506,
	0x81204ddb, 0x53d00cda, 0xedc61397, 0x96a2cfa0, 0x09ff704a, 0xc1874b51,
	0x4c4e27bd, 0x50fbe11f, 0xdc11473a, 0x5d0c1c17, 0xf4fb0648, 0x0dd77648,
	0x4bbcf760, 0xc1d83148, 0x3cd8621b, 0xff4f3165, 0x5db85566, 0x35eafe9d,
	0xacb37df0, 0xcef0b9c2, 0xe1962de6, 0xf1126f90, 0x7c6f11fe, 0x7ed0e5dd,
	0xe8ccb347, 0x8604b52a, 0x8f62fc43, 0x9476ed8c, 0x95f3c14e, 0x335b7edd,
	0xd9d207db, 0x716389fc, 0x68ef3d98, 0x10e5d9fa, 0x14dc7acf, 0x08c9ff7d,
	0x5fdf89ab, 0xdfc72df3, 0xbbfec460, 0x3fb65611, 0xb4a191ee, 0xe725551f,
	0xf4cc38f8, 0xe72e2ae1, 0x16bd2c3f, 0x59a3bffb, 0x291c6150, 0x6ebb6f10,
	0xa4e7ed34, 0xc38f12c3, 0x78e4b8b0, 0xe22efefe, 0x4c7e054a, 0xa0089aba,
	0x44fe93cf, 0xf8d6df70, 0xaf38a5ea, 0xe2839dfa, 0x49d60b3c, 0xcec16e29,
	0xffa3b69d, 0xd255a13e, 0xba7e32e1, 0x99e605a7, 0xb4108f13, 0xe88f13b7,
	0x404973cb, 0xf4da76c4, 0xa13aafcf, 0x395be7cf, 0x19241dbe, 0x2bfebdf0,
	0xeceae911, 0x68fbae22, 0x03a59dbd, 0xce9bbef1, 0x976a700b, 0x85895fa6,
	0x59f9c6d1, 0xafca0780, 0xe38215c7, 0xed4be3cb, 0x797fbf18, 0x3065f969,
	0x03f17fae, 0xced165cf, 0xa5d98781, 0xcabfb638, 0xa789471d, 0x30235eb8,
	0x15a5d77e, 0xafafd947, 0xb5c358e1, 0xa5b4e786, 0xfb689e31, 0x32b43f12,
	0xe97f243f, 0x79814148, 0x00815ed9, 0xf3ee3b5f, 0x8cdcf25c, 0x0e97dc9f,
	0xce9b78f4, 0x696d9fa3, 0x75cfbe8e, 0xe6c1d595, 0x6bf9f77d, 0xddde3f60,
	0x3ec12954, 0x7aef5ef6, 0x0add579c, 0xcef85741, 0xcf10b752, 0x90b12ee1,
	0x96cf104d, 0x8a6ed2ea, 0x9b4fdc05, 0xfbd296b9, 0xe509b144, 0x42ecb8fc,
	0x8495fdfa, 0xc7817c60, 0x40dd076b, 0x479f8636, 0xef3591fe, 0xf7ad2b41,
	0xe513ab41, 0x0971e892, 0xefebbf40, 0xbd00edff, 0x4668bcee, 0xf3e40e39,
	0x2dbbed1f, 0x62634f9c, 0xff006bdc, 0xf5092ca4, 0xa871e5c3, 0x2f7089a5,
	0x947be501, 0x2fcd5475, 0xdb50f04d, 0xb049e946, 0x2e7ef09b, 0x4eab76e2,
	0xe119df6d, 0x03e985ef, 0xf6040909, 0x54f669a5, 0xb1421668, 0x2de3ff14,
	0x33cc10f6, 0xbf68ca12, 0x62560929, 0x4ab5f561, 0x55cfbba7, 0x8a773ee3,
	0xdc381ccb, 0x1b5f7044, 0xfa85a46c, 0xd9ab3b35, 0x04f135e7, 0x479acded,
	0xad2d40a5, 0x66d48367, 0x8649f885, 0xad87cd5b, 0x8a920944, 0x9707bde7,
	0x65b47d31, 0xeddf193e, 0x1f6550af, 0x41710ffb, 0x8fbaf5b4, 0x79e5f9bb,
	0x7595f81e, 0x7065ebb0, 0xd6565c6b, 0x05bf6b9e, 0xbb6ef3fd, 0x02b0fdc1,
	0xfa4eee3e, 0x0bf6c4d4, 0xfdc1ae84, 0x9a3ada76, 0x3d506ed1, 0xbd044778,
	0x782254fa, 0xff4dd73e, 0xdcb6d1cb, 0x3e0fd985, 0x5534e64e, 0x26efa0b7,
	0x3c016a8e, 0xde1af55e, 0x476111c5, 0xa9eebe26, 0xadbf7a05, 0x61e230fd,
	0x23ea886c, 0x1528cf97, 0x7670a9ee, 0xd5bca1e7, 0xdc77e7ca, 0x8c9524de,
	0x96bf414f, 0x5fc8cce3, 0xfa8daf4d, 0xd5dabd9e, 0x035ac662, 0x3b6304c8,
	0x43a1e844, 0xf47b04cd, 0x7dfe08ba, 0x0bc51e67, 0xd06eeba5, 0x2fcff03b,
	0x6e026604, 0xdf7f37d6, 0xadf1fa0a, 0xfa668fc7, 0xeafed875, 0x0e9e8a9f,
	0xee1fdb2b, 0xed543e00, 0x8fc7c0bb, 0x5bb9ca10, 0xc23f54ae, 0xee1a21e3,
	0xf4d7388d, 0xcc2e16a2, 0x71f3c4c8, 0x0a23e404, 0x99ac1441, 0x5f02706c,
	0xb6baff35, 0xc78d9fdb, 0x9cab3d73, 0x595abdac, 0x165dcbf3, 0xd8aaefe8,
	0xad4b94fc, 0xd22f7a8b, 0x79d84bf9, 0x85d4af18, 0x45ef33f3, 0xbf120485,
	0x689abf03, 0x7e3a39eb, 0xe144c525, 0xd1e80757, 0xfb27ff84, 0xcfec6593,
	0x7f4f6afd, 0xdf9e22ae, 0x90bb51b5, 0x1a7d5773, 0x943905c3, 0xbe0b8e1a,
	0x7e9bd95e, 0x06fd52e7, 0x9f422dd7, 0xa93c7a0d, 0x29b1ea99, 0x725d8f52,
	0xe75bde31, 0x7b4363da, 0x0bebd467, 0x1b5e5fbc, 0xe8b57be3, 0xf3031999,
	0x10d75371, 0x4a965dc0, 0xb1288b12, 0x5b224d59, 0xd44d6d5f, 0xe391238d,
	0xa4ed1fbb, 0x7e6a5fe6, 0x6ebdf1a5, 0x1b8f92bf, 0x68533c5a, 0xfda7f8a2,
	0x33c637be, 0xeb5af80f, 0x384ff364, 0xf2fe0a68, 0xdb9eac8f, 0xed1b3e80,
	0x6bac0c43, 0xb0650c8c, 0xa7484978, 0x97e9bd6f, 0xc13fa0cd, 0x98e38490,
	0xc3638e9f, 0x19e9de85, 0xe8cf1310, 0xfc0556a5, 0x84394194, 0x70455635,
	0x2ca0f75f, 0xa0cc8f76, 0xe3ef766c, 0xf5b0c47f, 0xd8627b98, 0x3fa5a1b8,
	0x05df16b2, 0xe22592fd, 0x7b7f6737, 0x885481ba, 0xe31bde1f, 0x61f813be,
	0x3f637429, 0x25c49dd2, 0x4ba5bc50, 0x37f60141, 0x02a85424, 0x36121b8b,
	0xeb4a40ee, 0xf3522f4b, 0xa74adc60, 0x20e216b6, 0x44efe0e9, 0x18fad391,
	0xbbc5bbf9, 0xa3ce231a, 0xfe618fac, 0xf68501f6, 0x9d88b137, 0xdb8ee947,
	0xbf81f250, 0x60b7b11d, 0x673e3b67, 0x78fea1eb, 0xfce367c6, 0xfd06040b,
	0xc7fe7892, 0x09ac910a, 0x9bf23f38, 0x05933be0, 0xe23647e7, 0x7cfd820a,
	0x55c58631, 0x75ae0ad7, 0xd4a9ff90, 0x76fb8165, 0x323ffc34, 0x449726e5,
	0x7d5c715f, 0xace60b2e, 0x039e1f54, 0x394c7579, 0xf60d6237, 0xc3086ba0,
	0xedd45b9b, 0xd6e4d77f, 0x66e4eb24, 0xb8487885, 0x70558ebd, 0xc421df7e,
	0xd43e60b8, 0x74605cb1, 0x3e7e160a, 0x69c7d240, 0xc6d43db8, 0x3263b781,
	0xf11b7e90, 0xc1fbc58f, 0xd00b2e2c, 0x7ddfd1a3, 0xce70d48e, 0x340e78d3,
	0x6e3bb335, 0x64fb8693, 0xe3b8158b, 0xb66b9c8b, 0x75e5ffa1, 0xe237fd30,
	0xc78c0521, 0x524dce25, 0x7c82b57e, 0x78eae453, 0xb729b7b0, 0x7c80731f,
	0x14e87c8d, 0xc00f63fc, 0xe51fd6fa, 0xb444fba8, 0x60753534, 0xa9a3f809,
	0x6a98a969, 0x52edebcf, 0x29e038d4, 0x1adf77ae, 0x62c4f5af, 0x829e1f98,
	0xbcf19cfe, 0xd51baefd, 0xe3e30bbd, 0xdf8c31f5, 0x47c68af5, 0xacf40e35,
	0x638aef27, 0xb3c493f7, 0x4c9c87fb, 0x967deb9e, 0x7f0a4912, 0xc8fe8dcf,
	0x399ee200, 0x7ac08c0f, 0x5c416c99, 0x768df8b3, 0x3a1a832e, 0x4678bf26,
	0x637c2fd7, 0x8cff604b, 0xe976636c, 0xd819fac2, 0xcfb9325e, 0x75f2823a,
	0x05c9b169, 0x8b339d71, 0xa380ecfe, 0x5bd28be0, 0x29ef0073, 0xbe910e70,
	0xc8f45877, 0xd7c38836, 0xc8944353, 0x477a0070, 0xd71332e5, 0xa29a171d,
	0xdbb67fee, 0x39bbfcd8, 0x6a6989c6, 0xd29290ea, 0x41f9e171, 0x8f0d2728,
	0x4ad30f54, 0x139cf7c7, 0x8248f8a6, 0xd4fa8d76, 0x58269329, 0x61ecd037,
	0x66bfe712, 0x487d358f, 0x75833d02, 0x1f6a62c0, 0xe50e7935, 0xbc6326af,
	0xe684ff12, 0xf984be57, 0x7ceae380, 0xff5477b4, 0x8cbea1d7, 0x0adbf664,
	0x4e2c34f6, 0xbde7b9d9, 0xf7feb0c1, 0xc7cf0fe1, 0x5fd03ac2, 0xb058aea4,
	0x7dee279f, 0x0dce1627, 0x8b2f787d, 0x9861dc57, 0x31b44d47, 0x5b13febb,
	0x6bf41671, 0x39efef81, 0x925c309e, 0x635d6cd5, 0x9c344079, 0xcbdfd727,
	0x344c1953, 0xc7e3d3dc, 0xe8a52b7a, 0x2e0af6f1, 0x375be587, 0xb42ae92a,
	0x06db71ef, 0x823db9c0, 0x2344f2f6, 0xa34a1fbb, 0xb1d6d167, 0xfe9dcc0a,
	0xebe66cd2, 0x1b32addf, 0xb045dc17, 0x7ce1e59e, 0x6079d233, 0x5beb0daf,
	0x3fb673f2, 0x6b6d2165, 0x9eafb535, 0xc2de7666, 0x1f258fd8, 0x542905aa,
	0x101e4b78, 0xef0c5e70, 0x29c74bdf, 0x71fbeacf, 0x4fd8cbdd, 0xc639bde3,
	0x7cdaabf3, 0x7f97196a, 0xfea0f129, 0x6d6b9c45, 0xc6d3eb66, 0x83b9dff8,
	0xbfec3699, 0x723fc78d, 0x0f3844c8, 0xd0e0fdbd, 0xa7dd4bb8, 0xc3df9a7c,
	0x434af704, 0x3047c27a, 0xeca9b2cd, 0xb7e68c9e, 0x5557000a, 0x9ef0db4d,
	0x6f6a6fb1, 0x3a4f9b2a, 0x66b30f60, 0xb91fa877, 0x4a43f01a, 0x597f9d05,
	0xc2bcf1b5, 0x0f8cbbe6, 0xb7e7f1b7, 0x60b37f41, 0x93fab59f, 0xb7ce5429,
	0xc217c855, 0xdbf321ef, 0xfa6ee7f4, 0x9fad5fdb, 0x493d7c95, 0xef11bfeb,
	0xa57f1c59, 0x0ed64b9b, 0xdda92ca4, 0x3f087c73, 0x72e7867f, 0xf1193c34,
	0x17148cb2, 0xb86109a4, 0xfb187e68, 0xb4afc9a1, 0xafef216e, 0xe3af953f,
	0xa8bc42a5, 0xf1189c2f, 0x0db721d0, 0xe235fd01, 0xfb97a3a1, 0x0db61e44,
	0xaa957ec5, 0x8fb002ee, 0xeb5d6dd4, 0x4e4bf30c, 0xee077548, 0xccdabd01,
	0xde361d70, 0x35ede732, 0x95efc719, 0xdc0a6ab1, 0x9a72879f, 0xcc00fb04,
	0x6b4f787e, 0x76e7dda7, 0xcf80930d, 0xf29e9885, 0x0d86bb15, 0xfa5f29eb,
	0xf80779f8, 0x09239dcd, 0x623a6dc6, 0xb1eef4f5, 0x1ee74889, 0x2ae71b1b,
	0xbc7fd6a4, 0x7369360f, 0x686fee2b, 0x7dc78aff, 0x461732be, 0xfe11e7eb,
	0x84f7e11d, 0x4af5c1dd, 0xe02c879b, 0x99a3bb72, 0xda2f5fad, 0x30f28250,
	0x5d7acfee, 0xd3a41670, 0xb1c13caa, 0x28dfc80a, 0xefae259f, 0x08afbee3,
	0xf8879139, 0xee0f003e, 0x17ad29cb, 0x9461ce31, 0x277635df, 0x56af373b,
	0x456dbce3, 0xb870762f, 0xfa8df4dd, 0xc2c7ec63, 0xa2ed0146, 0x9b65fe91,
	0x240ed66b, 0xbfd67fd0, 0x06847ec8, 0xfde21da1, 0x4a55fad4, 0x40df785c,
	0xdb507ac4, 0xff7c2435, 0xc5e6f2f4, 0x8abf0fb8, 0xb8b09ff6, 0x3481c611,
	0x8d7a35fa, 0x4f1028fd, 0xdb8816cb, 0x605c16ae, 0x23ef238f, 0x3beeeb73,
	0x6fb0d85c, 0x5dafc810, 0xdb64fb62, 0x03ce02fd, 0x6c203f3b, 0x809d603d,
	0xcabd67eb, 0xffed99af, 0xd58e5de9, 0x57dfdc0a, 0x2a8841ba, 0x79f565c7,
	0x766161ae, 0xa6607969, 0xde8e986b, 0x5907ee20, 0x7ba250d1, 0xdbd76a9e,
	0x8df4beeb, 0x8d47c754, 0xa5fa692b, 0x7fa69be9, 0x3655d8d7, 0x070291af,
	0x8ec033d2, 0x10f38a3f, 0xda47876a, 0x91fe7cd9, 0xaa95f479, 0xd6ebcfc7,
	0x32e49603, 0x8b112cf9, 0xf66f79f0, 0x6741f294, 0xfaedb38f, 0xb5df0efd,
	0x343f5a3f, 0x67fad0bd, 0xff230bd4, 0x519a38b5, 0x03fe460e, 0x781f305d,
	0x702d8f7d, 0xcefa009f, 0xb1eff4e8, 0xa91d9d22, 0xf7382ef9, 0x80f847f8,
	0x769559d2, 0xc5abe62b, 0x38ed1be2, 0xa4f3e38f, 0x178bfdf1, 0x6abf7364,
	0x8e3dd587, 0x4e2a1b9d, 0xad4c5c04, 0x71659b69, 0x943f9c52, 0x88f70055,
	0x6db47d4e, 0x17ba8416, 0xf962e43f, 0x58ef6d2d, 0xab8fd45c, 0x0e982ec9,
	0x1bb7167e, 0x0d995064, 0x4f35efbe, 0xabce973c, 0xe6f1fdec, 0x1eecf9e2,
	0x415e5666, 0xe3a16c79, 0x11a1c559, 0xacfd007f, 0x842a2d68, 0x44054d38,
	0x5678e9b8, 0x6c8476e9, 0x9efc6c59, 0xce7bdf4c, 0x788959e6, 0xc706b8ba,
	0x12438ab7, 0xc83913ea, 0xed12a0e2, 0xb77e95ab, 0xb9fa8626, 0x126bbf94,
	0xaf982e2c, 0x987ee7d2, 0x7049aec7, 0x73d86aab, 0x1df07e4d, 0xc4c6b1d0,
	0xbdf7e9d6, 0xedae223a, 0x3efbe312, 0xf302991f, 0x059f168e, 0x9e796353,
	0x10f3c4e2, 0xc7162679, 0xa93f9630, 0xa6a259d9, 0x0eaa2e03, 0x4d3e2c2a,
	0xac7fc0ff, 0xaa2f4c24, 0x55c73b08, 0xb9e08879, 0x0583aa95, 0xf6056e78,
	0xc3ac7ff5, 0xdce6bfe1, 0x18ae0f4a, 0x6125f29f, 0xeb86148a, 0x2eab76e9,
	0x4698a62f, 0x18887f42, 0x177382e3, 0x7aa9ba62, 0x78bfed3b, 0x3f294d19,
	0x844ba724, 0xa6ea59fb, 0x7ee1154d, 0x7f7e5aa9, 0x9d89ad4b, 0xdbdad72b,
	0xa5eb676e, 0x5ec27a5a, 0x9fb9041c, 0xc735b379, 0x702bd6c6, 0xb7f5abfe,
	0x01137056, 0x09fb59e6, 0x4ec8079e, 0x3fc02d22, 0x02e7711b, 0x13d90ede,
	0x3ad9bf38, 0x874bfd31, 0xbd3665d4, 0xefbc52a4, 0x0161687f, 0x2b829efc,
	0x065774ce, 0xbed1ffcd, 0x95c1f514, 0x419f3a6e, 0x7da6fc21, 0x695fcb19,
	0xe6943f3a, 0xb197b2df, 0xc2682c3c, 0xe5f6bc3d, 0xd051fe05, 0x56fbc70e,
	0x6f8095f7, 0x2de2c4c9, 0xae0acbd2, 0x40fb689f, 0x1589d0d6, 0xb710f1e0,
	0xf26b6b9b, 0xf883637f, 0x855bbe74, 0xf89b1dfd, 0x36df413d, 0xda2af8d5,
	0x167f784c, 0xf7ffc0a4, 0xb9353f39, 0x95f74690, 0x04960fb0, 0xbac257dd,
	0xe7bb09d9, 0xe337b023, 0x0a9d6f5e, 0xedf1bbf6, 0x7de0e73f, 0x7ab197e4,
	0xe74ebdc6, 0x673fb480, 0x63783b7e, 0x09f3faf8, 0x2027de7b, 0xf4062a1f,
	0x49d5054f, 0x587aa36e, 0x92aa26eb, 0xfd64f309, 0x3091b0fc, 0xad9cf4fb,
	0xda3b33f8, 0x5b8e1093, 0x33e2f605, 0x39ecd790, 0xd7e84d69, 0x6b25363e,
	0x72e308b5, 0x91d37a42, 0x7fff6045, 0x10f1eecf, 0xbfdc6edc, 0x3df762f9,
	0x883f6c66, 0x8083f60d, 0xaa48bbfe, 0xbbc7993f, 0x24993c58, 0x7bcd84e5,
	0xf7e83f79, 0xf97f61d3, 0x2fdb1b44, 0x8225fb40, 0x544b1d5d, 0xfc41c74c,
	0xe620132a, 0x126efcc1, 0xad0f723c, 0x8b2b31ff, 0x881a591f, 0x2a381e2e,
	0x25fdf996, 0x73dd990e, 0x026f0726, 0x2ce621ff, 0xd0ff8271, 0xe122a4f9,
	0x79c9227e, 0x1d87ae1d, 0xf7a01130, 0x84e03919, 0xcbae98f5, 0xe9137525,
	0xcb93afa9, 0x31f7ab5b, 0xe21cbd45, 0x9838b770, 0x1e4cfa7f, 0x5dcffdc1,
	0xac009527, 0x5ba42693, 0x3de3c3aa, 0xf777f9c3, 0x8b2ff33b, 0x9ef37885,
	0x4fed0218, 0x02631bdc, 0x6b66fc39, 0xf0f015b6, 0xf288f022, 0xbcecc121,
	0x384bea13, 0xc0cde94f, 0xbc5f6ce7, 0xa38d8ea4, 0xad7c9dfc, 0xa5fb855d,
	0xaf06b19e, 0xcf9ffdc5, 0xdd3ef09b, 0x09571517, 0xa73c5fe4, 0x3efec13a,
	0xc18c1193, 0xc26f3cfe, 0xd318bcfe, 0x4a4ac575, 0x592383f7, 0x11b24a3c,
	0x64b2ec09, 0xa4ef57ca, 0x32c7c7cf, 0x7a766afc, 0x9fd32c59, 0xfb8204c7,
	0x1e5325ff, 0x3fb68fea, 0xe08bb3a7, 0x37019cfe, 0xe3808ab7, 0x4e2d1298,
	0xbe211214, 0xa098a533, 0x2ec536df, 0xd81c39e3, 0xc4e70c0f, 0x3bfb72a6,
	0x5c0a83f5, 0x3812a03f, 0xb65df704, 0x59bdf9d8, 0x1af11d7c, 0x49ab938e,
	0xe47e089b, 0x2b8917d5, 0xe6bbdb44, 0x8fd514a2, 0x7debc19c, 0x1c52205a,
	0x82ef2f7d, 0xf2ee012a, 0x9bcfde88, 0x12705f51, 0x1669c1c6, 0x13f073c3,
	0x9e371e91, 0x34e19fe7, 0xcb1d07dc, 0x6421a2fd, 0x30bef848, 0x8667dd6d,
	0xf471ea38, 0x17150b53, 0xdd9b65f0, 0x73ac1efd, 0x72655bfa, 0xd3e1b8a9,
	0x6f7fb63e, 0x5c18c5e4, 0xb4f8a1ef, 0xa8ae2e03, 0x695bf3af, 0xc618afbf,
	0x821c07ea, 0x93def95d, 0xe7608949, 0xce3658e5, 0x3b86a969, 0x8e3397c0,
	0xa639cbe1, 0xc6573f47, 0x353ca066, 0x41dc037d, 0xc0e5bb3d, 0xc8eb68fc,
	0x632baf14, 0x083f4027, 0x927ecfce, 0x7a0b9966, 0x14d3b5a6, 0x4c6ff0cb,
	0xdcacd6d7, 0xfe38eb07, 0x3178d9cf, 0x2545e07d, 0xdf7fbc7c, 0xaaf5e8c9,
	0xa06eb375, 0x65daf3fd, 0xe649af5c, 0xf1c289e7, 0x17861692, 0x761d770d,
	0xf0d1df16, 0x3bd76d33, 0xf69f3c22, 0x0cce2139, 0xd10f3dd2, 0xcfd533f0,
	0x20f53870, 0xc2fa271b, 0x39cbbb8f, 0x0463cc1d, 0xdc320e6e, 0xe07c53e4,
	0x82f56def, 0x366e231f, 0xaf9b89f4, 0xaafbfcf0, 0xb92ed33d, 0xd3e4d84e,
	0xa634f3ef, 0xf7d16c93, 0x64ebbf01, 0xa94bbd7a, 0xec0b2ebb, 0x7626f5c5,
	0xe9224dde, 0xef9c5137, 0x91eed18a, 0xfc84ceaf, 0x9fd98936, 0xb466cd6d,
	0x1eecdb3f, 0x5359c60f, 0x9b0e782d, 0xd8369e48, 0x681aefc7, 0x377fc351,
	0x3f6e2ee3, 0xd2687282, 0x5fbff071, 0xbdcff265, 0xac6e1b3e, 0x4ca56923,
	0x284fe30e, 0xcf5a451b, 0xdfbc8ead, 0x0a3c3d83, 0xb8c16877, 0x7bc14c74,
	0x298eaa88, 0xbb7f1768, 0x8802adf7, 0x85fb6a67, 0xab7eee27, 0xbc147f20,
	0x0af670cf, 0x1e5aabb7, 0x9d804e8f, 0x3f43dc34, 0x92fcfba9, 0x62f91efe,
	0x4f564fc0, 0xf57ef1b9, 0x8ba27039, 0xb5373b8e, 0x598066b9, 0x3eafde30,
	0x8bcec427, 0x9ee23ecd, 0xe232a601, 0x878e757e, 0xceeb485b, 0xbef23118,
	0xff3e3a6f, 0xe67ffa05, 0x710290b5, 0x7d52a0ef, 0x544f9b25, 0xd1fd8267,
	0x28ff0ef4, 0x8e1f82df, 0x9fefddd4, 0x7ffd60e9, 0x7bb125c8, 0x5c14da9b,
	0xb0987c17, 0xdc7c82ef, 0x5b2c7bfa, 0xf55ec987, 0x87b07cc2, 0xb8dccae3,
	0xc9d2bb4e, 0x253f33e2, 0xc8264b21, 0xfae125cb, 0xa7565046, 0xde7a171d,
	0x48f15223, 0x3ddf2d3b, 0xb41c6620, 0x43c3ab7f, 0x49efe01c, 0xbbe1075d,
	0xc7b39389, 0x8fb6dd81, 0xe308935d, 0xa5374698, 0xbd8b70ab, 0xae8d0e87,
	0xdd5edc33, 0x1c4858ea, 0x6077d803, 0xb68e9a87, 0x0d7be05b, 0x673dc107,
	0xf0c3fc99, 0xc1eff200, 0xf200b083, 0x7cac1f1a, 0xfff2d63c, 0x06843c7c,
	0xc57a7c81, 0x1c21c403, 0x190f09df, 0x0f0d57c0, 0x1efb5fd4, 0x2d7f35e4,
	0x867db0a8, 0x41c35e5a, 0xdf0f3d81, 0xf7042973, 0x56bd910b, 0x13db2e76,
	0x2f13eb8f, 0x9d1b5939, 0xa10fb61f, 0xec99262e, 0xc6fa6048, 0x6c643f7f,
	0x72bf4048, 0xb708352c, 0x08371fa1, 0xf38ba1ed, 0x020bb48b, 0x7b89b3dc,
	0xbfc1d3c9, 0x5e82250c, 0x8517358c, 0x6ddbff00, 0x3fc1d353, 0xc94db6cc,
	0x1ced7c04, 0x1835eab9, 0x2c0e76b2, 0xdab3697b, 0x76693fe3, 0xab5785af,
	0xc1d33fb5, 0x6e35c6ec, 0xec081e76, 0x9a1d3876, 0x00b107fd, 0x8e68421d,
	0xda1b6be9, 0xb036e6eb, 0xe50740e7, 0x34813eeb, 0x67907f82, 0x034d2772,
	0x48406f3f, 0xf73b3a02, 0xe204397c, 0xafcd4594, 0x8b7a011c, 0x974ff5b4,
	0xe8d3fd7e, 0x8efe6b47, 0xfcd0af36, 0x0b3e6d21, 0x8f94137e, 0xf09dcfe2,
	0x7e30237b, 0x4e782c85, 0xea73b1f9, 0xbfae6ee5, 0x1147ed12, 0xa48dc7ef,
	0xeed2e915, 0xf381b919, 0x9d20e8a3, 0x39416687, 0x3e53d721, 0x19efcf5c,
	0xbfa5deb9, 0xdcc6e147, 0x688cf7e8, 0xbef5f4f5, 0xcab87c71, 0x5df44eb0,
	0x763e83d3, 0xf97fc8af, 0xf2773cd8, 0xc12fd150, 0xc69b9a80, 0x327065ee,
	0xa2541c3e, 0xe7bf578f, 0xd4d93bfa, 0x94e70596, 0x1bfeedf7, 0xef2f8f8e,
	0xe0bbdbfe, 0x293a4e27, 0x3ac7d811, 0x38f8e4f9, 0x4dcf8f5c, 0xad63f5c5,
	0x8da7ef5e, 0x239ec236, 0x59dfb47e, 0x71e94039, 0x059f402b, 0x7e9ddfd3,
	0xdf5067ec, 0x09126385, 0xa051273f, 0x1c418678, 0xdeff80b7, 0xf98101ce,
	0x01f95a4b, 0x0d173bfe, 0x01b0b71c, 0xc47fbb42, 0xebe7261c, 0x9a18bdf9,
	0x513faf5c, 0x8aca5278, 0xfdfc0f94, 0x5a0be233, 0xe737615c, 0x13f9691f,
	0x7ef9679e, 0xf8129de3, 0x154fdfe7, 0xddac3b89, 0xc19d2a99, 0xb639c587,
	0x4a7e0c39, 0xbb3fb3cb, 0xde2b8e81, 0x3adc45d7, 0xf6de6de8, 0x5be4165a,
	0x8df7a8c5, 0xfdfbf918, 0xbef13be6, 0x454e3511, 0xfb57dcbb, 0x38a0af93,
	0x27720319, 0x61cbcfcc, 0xe51875f7, 0xffeef2fb, 0xd51b6c4c, 0x937bbf3b,
	0xbf0e51bf, 0xeb8f9d3b, 0xc3c97d4c, 0xb4bddb88, 0xbfda7e9f, 0x9fa7ed10,
	0xfb2f63fa, 0x83ff989c, 0x1af3152f, 0x9e7bbd5e, 0x4e7f044a, 0x448ce9c3,
	0xbb499b86, 0xec48967e, 0xf232f23d, 0xdf9702ed, 0x7d9ae21c, 0x0ee7fd03,
	0xf68b15c1, 0x615a4fc2, 0xa731563f, 0x02a1ce71, 0x3f083ff4, 0xc71c61ff,
	0xf0a388e6, 0xbf9f7b9c, 0x4f2c3373, 0x1c6b7306, 0x57f7e0af, 0x71c6d700,
	0x3af5f0aa, 0x02b65c09, 0x63b31569, 0xe8d74fdc, 0x30f9ca32, 0xf47ec629,
	0x0711a746, 0xff357a46, 0x17ddfb5c, 0x09198fca, 0xd49bbeb4, 0xc45fec3c,
	0xd2f9cc38, 0x5bdbf8db, 0x78e3e2bf, 0xffe39f1c, 0x6fe989fc, 0xd37b7b02,
	0x8cdca337, 0x28fd9ae5, 0x31b20680, 0xa23f83f5, 0x3ea325c6, 0x88545c14,
	0x0c33f61b, 0x27779fd2, 0xde219745, 0x67b272ee, 0xeaade1bd, 0x127889a2,
	0x3727707b, 0xdc036a3d, 0x6cea92ed, 0xdabd1f10, 0xaa0b525e, 0xfcd3fd37,
	0x875ef19b, 0x90811336, 0xb3e68cd9, 0xf047102d, 0x1e78211e, 0xdf79bf20,
	0x1fe9c034, 0x479c56a4, 0xe4205e75, 0xb33f30d1, 0x06d6b9a9, 0x1253587e,
	0x2076cf3b, 0x1df6e89e, 0xcf8e3eff, 0xbb9d8eff, 0xfca51dc1, 0xe786388b,
	0x949dc459, 0x2c72e385, 0xd60a3fc6, 0xd3ffb099, 0x24fed705, 0xb1e65bf0,
	0xf73ba27b, 0x449fdc4c, 0x3db8ede9, 0x8ccced1e, 0x74effba6, 0xff044152,
	0x779f0e3e, 0x5ef0142d, 0x85d50281, 0x0cd282f9, 0xf131afdc, 0x8ab3891f,
	0x8ca67ca0, 0x62199bf3, 0xa8f10485, 0x3642a933, 0x0b7717cc, 0xbbf0356d,
	0xd612feb7, 0x13fa710e, 0x76f9fe61, 0xfc58e251, 0xcb5538ad, 0x03dfc70f,
	0xda798624, 0xf7e71daa, 0xaaf96999, 0xd7ee02d9, 0x274ce19d, 0x14fc30fe,
	0x1cf2a3ac, 0x9cd97147, 0x9eb80f92, 0x273fa855, 0x46d8bb38, 0x16ebe102,
	0x1def1382, 0x65f7c03b, 0x1efc0977, 0xd7e7ae7c, 0x99cfbc72, 0xaefba89b,
	0xd33f3084, 0xf76443bb, 0xdfb1e46f, 0xebf4d69d, 0xd787ae3a, 0x3cf1f9f2,
	0x8e8eba4f, 0xc0d28822, 0xf6c9d5fc, 0xa178dd97, 0x12e7870d, 0xf34383f1,
	0x8dd77b69, 0xc56bcc34, 0x8b88358a, 0x378eb654, 0x89bd761b, 0xeff53760,
	0xcfab98dd, 0x4be3d147, 0x1ecd09da, 0xe223decc, 0x3cece1ba, 0x448167ca,
	0xd4dfe9f8, 0xb9344c5e, 0xe83c43f6, 0xbc6e8ba6, 0x5ec22737, 0xadf8507c,
	0xa96fc5ec, 0xbd52e60e, 0xe3e38fae, 0x183260e6, 0x710cc6ec, 0x4700cfeb,
	0x34dc749d, 0x3691c147, 0xfdf368ee, 0x80c7aa02, 0xad9a721b, 0x98b8ccb3,
	0xb49cfb8a, 0x1db77ef9, 0x2b897ea1, 0x23b4bf8a, 0x3da3830e, 0x2bb34776,
	0x9c897e61, 0x92fdddf3, 0x551fd419, 0x41be81b2, 0xed0e3fc4, 0x0b25c619,
	0xc4142360, 0x62cf5307, 0xd12bc79c, 0xcf8e2bf9, 0x473b314f, 0xf42425ff,
	0x5fd187e8, 0x63cce2d1, 0xa53f9a9d, 0xbc7749c7, 0x3f7666f1, 0x029386a9,
	0xffe827e0, 0x75c622cd, 0xd68dc2fa, 0x09785f7e, 0x26047b51, 0x70bc57ab,
	0x78a6fbfd, 0x5f1b50f9, 0xfd619186, 0x0f8689c1, 0xf1c62f0d, 0xf10cbfe6,
	0x9bc6dea0, 0x066f180e, 0xecde3ef4, 0x5da3291f, 0xf9afcbef, 0xf8ecc9c4,
	0xca2738c4, 0x67cbdaf5, 0x8d10efe3, 0x1b4476e5, 0x5ae3bab7, 0xfb270cf5,
	0xb04916db, 0xfb05e47e, 0x0723d191, 0xe1ac1e2d, 0xc11d6ab2, 0x00ffe7f8,
	0x0251357d, 0x00008000, 0x00088b1f, 0x00000000, 0x7cbdff00, 0xd5547c0b,
	0x67b7efb9, 0x332479ef, 0x49926649, 0x9d804032, 0x20424210, 0x7860210e,
	0x200f3b88, 0x15019042, 0xf01d51f1, 0x28490201, 0xd6b4f5a7, 0xa4484cdb,
	0xd179fd14, 0xfd5bd6b6, 0x3d503b9d, 0x4320d687, 0x813c180c, 0xf0c50133,
	0x150106b0, 0x888da7ae, 0x31243688, 0xded80f54, 0xbefbf79f, 0x333277b5,
	0xee7a5a19, 0x1651373d, 0xf8f5ef6b, 0xbffdf7d6, 0x536b5ad7, 0x6abad1fd,
	0xdde80648, 0x0094012f, 0x41ca55d4, 0xa2b5fe1b, 0x899f99fd, 0x58ac19ba,
	0xa77f1507, 0xf1022c03, 0x2874a653, 0x62c03736, 0xb395e4af, 0xd176b401,
	0x962bd6ff, 0x45f58aa0, 0x6eb9f35e, 0x2dfb689b, 0x6401a9ff, 0xf7a6dc00,
	0x607f4c5f, 0x149ac5fb, 0xc5d7630c, 0x6fedd1a5, 0x73ef32bb, 0x896008a9,
	0x9e1cf316, 0xa22e52fa, 0x25f66a9a, 0xfa2abd61, 0xc933967d, 0xff10a17d,
	0x7ec61632, 0xbe5c032b, 0x352ef958, 0x6e7e96ff, 0xae1e5e1e, 0x002cca47,
	0x2e36f59d, 0xb3cfdf63, 0xc0e43f80, 0xe6282692, 0x00a90032, 0xcc5c4e85,
	0xb15fac34, 0x13469680, 0xf927c027, 0x43391d3a, 0xf8e00ffd, 0x8c371c01,
	0x00f207e3, 0xb93bd60e, 0x87bd66fe, 0xb052b3eb, 0x7ffe3a43, 0xc545aae8,
	0xff6fccf5, 0xf9c7e2ae, 0x78515fe6, 0x1eb4e9dc, 0x031fbe3b, 0x7f3d6863,
	0xeffe29ea, 0xfb50c2b7, 0x2d2ff6ba, 0x5ed7c9fe, 0xbf9adfcf, 0x75e54520,
	0xa4dabcd0, 0x281779a1, 0x9d70a300, 0xf9a3f30b, 0x2b13cc6b, 0x2df958df,
	0xcac7fbd1, 0x1eb317cf, 0x83d03e43, 0x87111a60, 0xa04c57ff, 0xfcb6bd4d,
	0xf163e506, 0x0d277ae7, 0x6bf00f7f, 0x78d0df5e, 0x4ba0bcba, 0x74164df1,
	0xd5d71199, 0x77c6290c, 0x5ce50520, 0x44e109dd, 0xc5d16c24, 0x2a15cfaa,
	0x8b9c12bd, 0x39c033c2, 0xd0f2de43, 0x20af73f8, 0xe686d35f, 0xbb20ab9d,
	0x1679e98b, 0xa3ace204, 0xa851c696, 0xb071807d, 0x79699b69, 0x9371d708,
	0x51f7ee05, 0x1fca2899, 0x2f1e253b, 0xbb7134e0, 0x266cafbe, 0xd76001b8,
	0x4072cc81, 0xe756bcfa, 0x10071831, 0xfff70332, 0xb72a49df, 0x0209227b,
	0x283f3809, 0x17d2365d, 0x1f201ca5, 0x69194ef5, 0x90e23609, 0x47d84acd,
	0x55e7d87a, 0xf6f501a0, 0x60efd18a, 0x91401ee0, 0xcf2e713c, 0xfd4d98d4,
	0xb0b35dc3, 0x8ac58ddd, 0xb89b05ba, 0xe977eaac, 0xab7eef7d, 0xedf5fa93,
	0x330ec7fb, 0x7815f38d, 0x73784291, 0xfde815bf, 0x4839876c, 0x7cae63f6,
	0xbd61365c, 0x8ac01faf, 0x0f2f67ed, 0xedca0057, 0x746ae826, 0xe4933962,
	0x077e4718, 0xaa22f5f5, 0x4e50231d, 0xcd397473, 0xc556edd1, 0x48ed997e,
	0x841c9245, 0x753b21ec, 0x39a32eb3, 0x63a256c8, 0x17ae1b4e, 0x457cdfdf,
	0xe6976b89, 0xfd96e3ea, 0xc9521409, 0xedc68832, 0x8f6136dc, 0x005341ca,
	0xc5b0aca7, 0x84bb27bc, 0x4675ccf4, 0xb6499f3f, 0xcbbd7113, 0x976ebdc0,
	0xf344c7f0, 0xe629cf7e, 0x25ff2b9d, 0xbfd71bb9, 0x307da2cb, 0x3fede90b,
	0xf8ed8661, 0x65622e1c, 0xb4be70c6, 0xf3075ea1, 0xfb17adae, 0x2a6a240e,
	0xf08bb3d2, 0x48faa0e3, 0x76ba2d4d, 0xfeeea2fb, 0xbb0e6c72, 0x902a979a,
	0xe53c70c3, 0xf7e218c9, 0xfceabe30, 0x8b67e58f, 0xe4764d04, 0xb7bb5973,
	0x30cb4c92, 0x1f22763e, 0xbf795fb1, 0x2f5cf3c6, 0xd8fd0d1f, 0x23512175,
	0x30baefbc, 0xdbf9a352, 0x86d3af08, 0xfcefbff0, 0x4fd92240, 0x20aaa3e4,
	0x365dfa2e, 0xafc676ef, 0x44687dc0, 0xd60b705e, 0x77ce3a43, 0x2d1ff625,
	0x322f7e24, 0x34d3b779, 0x4b71faca, 0xdcdd9327, 0xfb1e7e5c, 0x3f481a48,
	0x5491fd40, 0x658bdc27, 0xf087f500, 0xc6054816, 0x40421993, 0xf06a36f3,
	0x66739502, 0xefc429ab, 0xcbb31c01, 0x29a9e341, 0xcbf87384, 0xc9bee9e5,
	0x52def9c3, 0x79c2808f, 0x9a6deb5a, 0xb7b00b92, 0xb6f5c9de, 0x6f970f7a,
	0x6e5cabd4, 0x83fc963c, 0xa7538e20, 0x6d253459, 0xaa4a7fa8, 0x68398fd0,
	0x39ae8867, 0x88030520, 0xeb8f39b9, 0xe0a457b8, 0x84e48946, 0x27e089eb,
	0x3ba065ca, 0x4dbf823f, 0xe9f8d34a, 0xef2c0dac, 0xf71342e2, 0x7c1fe747,
	0x7b787b39, 0x7d547b94, 0x3a624b8c, 0xdd9a5cf2, 0x0ee3e585, 0x1a6b925f,
	0x43cee1e1, 0x29eb8097, 0xba45bcf4, 0xe384be4b, 0xc1970d4f, 0x4c3fd00f,
	0x5f10c145, 0xa21ee7f1, 0x05875a7f, 0x50e83e48, 0x758b2f59, 0x25afb47a,
	0x47ce02e9, 0x28edf3aa, 0x0ead67ec, 0x42f68e13, 0xbdf11a77, 0xa3b3e6c4,
	0x421d2146, 0x87749aae, 0x66f1c247, 0x32bc5ba4, 0xbe71ce99, 0x7f91eba9,
	0x2138e91d, 0xc8e8efb6, 0xdf5152c8, 0x0fede534, 0x9b35af49, 0x0ae22c23,
	0x84774f73, 0x1784cf1f, 0x904f149d, 0xf916fb4d, 0xe487f9de, 0x8c35db00,
	0x758ec873, 0x86f64c9e, 0xae9b9e71, 0xc256bcd8, 0x7d44753f, 0x5c98903d,
	0x3a19f644, 0x371d792b, 0x0a3ac4db, 0x1762fecd, 0xa1f0b3db, 0xbfdfb077,
	0x3d90000d, 0x23eba9bd, 0x0a9e9019, 0x37664153, 0x9a4879d2, 0x73e54290,
	0xc49e487f, 0x1ee4c9e5, 0x9301cfe2, 0x4f79a55d, 0xb925abd7, 0x5ded1788,
	0x60d00987, 0xa1d779cd, 0x3d4ef950, 0x5e22e494, 0x71b7adde, 0xc9dea279,
	0x0f7ac9e5, 0x3df08797, 0x7c2de9e1, 0x1b7b784f, 0x08fd53df, 0x18f2a7be,
	0xf1654b8e, 0x5e3c493d, 0x1649ddcb, 0x6481c75a, 0x27e63668, 0xc313853c,
	0xf805e0ad, 0x366f99ea, 0xbfa346db, 0x4b27fab4, 0xcf597053, 0x60a5537e,
	0x31fcd8fd, 0xdf0afc3f, 0x3f4acfcb, 0xb7bd21b5, 0x1eb4749f, 0xaa427ac7,
	0xe10753fc, 0x1a2258f3, 0xe56b5247, 0x98025a08, 0x2471b64a, 0x52835db3,
	0xf5e9a7ac, 0x254b7280, 0x45596142, 0x00b82177, 0x6e5972ee, 0x977f21b1,
	0xa7dffdd9, 0x5cd025ba, 0xd5137955, 0xbe9235d1, 0xeb20e64b, 0x5ee4967b,
	0x76eefe8a, 0xaecfff87, 0x49afff08, 0x7d91a69f, 0xe049ae98, 0x83bcb372,
	0xe7a1a5e3, 0x1ddbbb46, 0x724cff73, 0xb325c47a, 0x5b36997d, 0xe18e82d2,
	0x9bb46bfa, 0x24ad5e76, 0x38bf4df9, 0xc5ca89af, 0xfbae2e55, 0x44d8df96,
	0xb8e95ffa, 0xee0aff56, 0xcccba8ff, 0xb0572db8, 0x683f1c5d, 0x208a9bb4,
	0xffbbb8a3, 0x3b706248, 0xbf94fae1, 0x73eb0931, 0xb2c5d93d, 0xeb819b6e,
	0xe85b6dae, 0xad5bf57d, 0x24de57ac, 0xd3e5c52f, 0x0d32aba1, 0x243997df,
	0xe74c986f, 0xd29b8fec, 0xf253bde8, 0xb4cadb12, 0xd094ef29, 0x5bd95cfb,
	0x6a53f546, 0x93cb13a5, 0x4bacd94a, 0x7e7e6ed8, 0xfd86d78a, 0x787f864e,
	0x965bf099, 0x204de49f, 0x5f04af3b, 0xd7baa5a8, 0x69506dea, 0x2454cf1d,
	0xe4aa38d3, 0xe5bd6135, 0x46ff8ad6, 0x52fb9474, 0xbde89240, 0xf5f8a14b,
	0xb8fc3fb9, 0x5aed89d2, 0xfa4048c6, 0xf05c3273, 0xacbfa247, 0x404d5133,
	0xce2c5a82, 0x62d7ea4a, 0xb91b9c91, 0xf6a0abee, 0xfab33c81, 0xfc7b8e32,
	0x83fb3b6e, 0x712777ea, 0xeefc741c, 0xaa17ec51, 0x4e5d9ddf, 0x889371e5,
	0xaddfabd7, 0x26f7e2ae, 0xa9519308, 0xdc3be7be, 0x8fc56b6f, 0xfe38dd2b,
	0xb62eb1b1, 0x12a7282d, 0x624ec225, 0xffa8907b, 0xbedc353d, 0xe1fcca43,
	0x797f6c79, 0x15b14a52, 0x4ee79fe7, 0x955f6a88, 0x2faa8ae5, 0xa2511dc8,
	0xeac9d844, 0xf551d949, 0x92a44b5b, 0x78f8c8dc, 0x7d544276, 0x24aba569,
	0xedfda237, 0xeaa223d5, 0x8ecf6ecb, 0x669997aa, 0x0f51fb08, 0x9e852bb3,
	0x05ccaecf, 0x4f644ca1, 0xdbeda29d, 0xd241fef8, 0x7e2223f3, 0xfc61762a,
	0x3ca97284, 0xb97ec252, 0xafdbaec4, 0xa6797400, 0x3f17fd93, 0xea3c7047,
	0x9dfc4107, 0xf890f14e, 0x78c2eb29, 0x0523e280, 0x3d0476fd, 0x3f688e95,
	0x216a055e, 0xceaadfd9, 0xcd4f1c05, 0x44a92cf3, 0x463e4635, 0x1f92abf7,
	0x0c487117, 0xcc47c5dd, 0xcaade971, 0xc46fee8a, 0x7d3a5575, 0x537f262d,
	0x0162c52a, 0x1ae28bad, 0x1d063d63, 0x954f5ad7, 0x8a256f7c, 0x2bae6fff,
	0xf5807e96, 0xd2c45f9c, 0xf3d2efd5, 0x38a78c53, 0xe54cec0e, 0xdc7f10f8,
	0x2303e2f1, 0xfb46a9ee, 0x6fb48ae6, 0x64bdc90e, 0x9bedb5f2, 0xe2b5ee31,
	0xa35c633d, 0x3ccb343f, 0xf07fd1bf, 0x7fc52ab9, 0x27db03be, 0x96ee79c5,
	0x297f3fe2, 0x451cfdba, 0x1ea0746d, 0x1bc9051f, 0x571f7e20, 0x2ac90a15,
	0x544d694e, 0xafc8fdce, 0xff3a3c50, 0xca89a07c, 0xe3c13d59, 0x2dff5c56,
	0xfb4ab2f9, 0x143c460d, 0xa9a9aebb, 0x7a390e22, 0xf8abb545, 0xdaa025be,
	0x7968bf29, 0x1e53b55c, 0x1541a2d5, 0x38da8be5, 0x37ca7ad3, 0xb12c42b4,
	0xec2a9b9e, 0xbfbd04fc, 0xfd976e51, 0xacb15213, 0x4d3f75b1, 0xd5ed48b1,
	0x03050b7e, 0x9bce2947, 0x3bce3c34, 0x341d04aa, 0x83c7d1df, 0x1d845f0e,
	0x2f38debf, 0x8d36c093, 0x916929f0, 0x96c2a476, 0x8dda45a0, 0x54574eb9,
	0x1553aafd, 0x4467bc79, 0xd45bbf54, 0x1876a8ec, 0x1c53e6bf, 0x7c8168d4,
	0x29a8ec85, 0x5df14bd1, 0xd65f1f2c, 0x3875efd7, 0xb3027c29, 0x71fd955b,
	0x42b792fc, 0xb9f62ff0, 0xcf4b8f4f, 0x7cb07ad0, 0xb2e5553a, 0x2089f649,
	0xc266e30e, 0x731d6c43, 0x1e34e5d2, 0xdc21ec8e, 0xcba6ed79, 0x5d437a18,
	0x0a2dd16a, 0x54ef7dfa, 0xc38c3fd3, 0x2b534ffa, 0xdf10516f, 0xd7a659de,
	0x64feb072, 0xbf515cea, 0xecd534c1, 0x9867f805, 0xb6254b77, 0xf77dba77,
	0xfa5f22a5, 0x12cd8ecc, 0x498a33c6, 0x50f76282, 0x05a4fbfe, 0x160a29fd,
	0x90b9a641, 0xe455bb56, 0x6809b5cb, 0xb97da8ff, 0x6abf12a6, 0x77390c13,
	0x875f9067, 0x644d3307, 0xcdfc8c2f, 0xd87ec16e, 0xafe6cf3f, 0x27097811,
	0xbe9768ab, 0x266e6fb7, 0x54e9e2e1, 0xf0bfaf27, 0xb21e59b5, 0x77d74857,
	0x47ffdda9, 0xe8f102ba, 0x798b326a, 0x2b0a5a7a, 0x8e16efc8, 0x43487145,
	0x9f74c2f2, 0x1084279f, 0x6b971c2b, 0x8deb091e, 0xe2978b2e, 0xbc75a7f4,
	0xa8d96f5e, 0x76c84fef, 0xc5391b81, 0x96377eb4, 0xf2f1d0bf, 0x5a2f3e9c,
	0x104b31ba, 0x1fece00f, 0xa8b274b3, 0xb9641e13, 0xede29fb8, 0x7924effe,
	0xeace3f39, 0xb08ffdff, 0x85bdc1fe, 0xcfa38a5e, 0x2cfe0a26, 0x7634e60f,
	0x358a7d63, 0x748c3a38, 0x0fe69a3e, 0xb6ee0e12, 0xde33c706, 0x6893eb1c,
	0xce03497c, 0x0efc8c43, 0x32d538f3, 0x3fdc786e, 0x11b05e7c, 0x219cef9f,
	0x8bcc6cf8, 0xdf91b53c, 0x3c54a0f9, 0xf9c0e837, 0x837fc443, 0x203a419e,
	0x02fbc9cb, 0xe691f620, 0x0fb10eca, 0xf789a9fb, 0xf948ea4d, 0x79dafeb0,
	0xbd75e713, 0x9a015e46, 0x7e74c563, 0x78ccf3c5, 0xc4cca367, 0x3a77f006,
	0x4a7f9ab3, 0x9e72d6da, 0x3a2bad3e, 0xd3b1bf4f, 0x7ec0e15f, 0x7f187e37,
	0x3e96643f, 0x6504296e, 0xba33d7f2, 0xd2cddba3, 0x1759f4f3, 0x4f1f9fa3,
	0x48dbfdd5, 0xcfb91918, 0x7fcf41b1, 0xa4e78e06, 0xd6c94e10, 0x8b77c8c9,
	0xea69432a, 0xad68dd90, 0x647976c7, 0x4e5c6d1f, 0x807ce53e, 0x047afcf3,
	0xa4ec85b4, 0x9f434b87, 0xfb829f26, 0x1e6228a1, 0x1f06f71d, 0x7c143e07,
	0xff9dd29c, 0x3758d9cb, 0xa8219a77, 0xa673ad0e, 0x1001a7ce, 0x5a701e7c,
	0x8fd3cf98, 0x186a7afc, 0x263d591f, 0x97d62350, 0x1a8226a0, 0xf9ed4f61,
	0xd97551a9, 0x671e8f90, 0x4fc7d54c, 0x1a8c8ef2, 0x0c3788c7, 0x3a91bdf9,
	0x90e293af, 0x1cd58ea9, 0xe694a477, 0x725b8d44, 0xc84e563c, 0x91db8a38,
	0x5c515fc8, 0x8a894a7f, 0x07746e33, 0xfa500388, 0x97131291, 0x8f49956c,
	0x7e8f9e66, 0xfbe9a72e, 0xbb72b153, 0xe8a13f16, 0x7fddb397, 0x5a5d3f3f,
	0xaad33f34, 0xee99f9a2, 0xe667e68b, 0x8dbe68f2, 0x65f347f0, 0x5189ead4,
	0x2faf47ef, 0xfd8faa8e, 0xf6a8ccc1, 0x2300e8d9, 0x2f36e3eb, 0x7e3f6a88,
	0xfaa8d2eb, 0x8eefe784, 0x5c105f6a, 0x70bef519, 0x92eb9ac7, 0x86d0e4ff,
	0x5ec476a8, 0xff915fd3, 0x458f6d0d, 0x2d5ff3cd, 0x68b48aff, 0xdba45dbd,
	0xf686976b, 0x4fc878b1, 0xd90af6d1, 0xdbfb5749, 0x25ff6957, 0xbef2ae50,
	0x78016053, 0xcfddf11b, 0x76449f65, 0xdab2146d, 0xc9a37684, 0xdec9ab04,
	0xf1326d3f, 0xe7a1a43e, 0x7c44d2ab, 0x8f4d2ab1, 0x14dedc13, 0x1d865fb2,
	0xfada6b3d, 0x6c9b8f0e, 0xbf665f53, 0x4cdf0a63, 0xe5479779, 0xe48abbfd,
	0x4bf69552, 0xc5de91e5, 0x968711d3, 0x2ba032e3, 0x3fe3c684, 0x7df6877b,
	0x2a6c3b2e, 0xf54e54e1, 0xe15fc807, 0x632f42ba, 0x0eda02f1, 0x1d06a3f2,
	0xc787d41f, 0xd4647e53, 0x3fd67b97, 0xdf97ed41, 0xf29e365b, 0xf7e7c1d6,
	0x8caf8c76, 0xbae47fe0, 0x8b89c696, 0xa6bad036, 0x6ee7ad0d, 0x8dd8daab,
	0x85914f74, 0xb07f47dd, 0x7dd70d21, 0x2cdc7a56, 0x9980abe2, 0x8ff42be2,
	0xc2efdfbc, 0x96037a40, 0x487e4329, 0x74c116fd, 0xf97c12d6, 0x51cbe239,
	0xeff94bd9, 0xca2088ef, 0xeca96c1f, 0xec32eff7, 0xb8a6aaac, 0x701ae822,
	0x03a9c744, 0x3b638e0f, 0xcc3ee67c, 0x67af11ba, 0x463d622c, 0x1dba8bfb,
	0xc3b742fe, 0x237f643d, 0x6f579bf6, 0xc51259fb, 0x45f267d7, 0xff3c6d3c,
	0xa7389a55, 0xcc9a55f8, 0x23bb5d72, 0xefb919c1, 0x45721358, 0x46daebd5,
	0xe047cf38, 0x1eb1ad70, 0x7ad0a4bf, 0x53fae9d6, 0x7c9dd9d3, 0xfe3c7037,
	0xfc70d23f, 0xef976dda, 0x4dfd4bdb, 0x8fc219fd, 0x3bbe7806, 0xeb8e003f,
	0x4433fcef, 0x49bfa5c5, 0xbf2bfb13, 0x865ae9d1, 0xb0711385, 0x8bbb7d0c,
	0xcf67b7ca, 0xe7c3bd23, 0x8beb0961, 0x714cc13b, 0xb67f12da, 0x127f9899,
	0xe0f7a7bc, 0x54d35ad2, 0xe0eddf5e, 0x7c5f9333, 0x249abeff, 0x9e38376a,
	0x002a0e31, 0xb81f6dc5, 0xda0ce602, 0xe249b9af, 0xb3e701b8, 0xbddf73d1,
	0xff209ea3, 0x3ef7cc6b, 0x469d2ff8, 0x2f052c7c, 0x0f8c6b8f, 0x87651a90,
	0x4c205acf, 0xb38137fb, 0x48cbe0d6, 0xdf8a06cf, 0xf61b0f10, 0xed9db267,
	0x3b1ff35b, 0xf776c39f, 0x4d1eea8f, 0x35d9cc71, 0x5c23ce7f, 0xda3cf5dd,
	0xae6b5c5d, 0xb841dfdd, 0xe672f833, 0xf449cbc1, 0xc611e31e, 0xf562bc15,
	0x5d9c9e92, 0x645e4af3, 0xad2c7fbc, 0x83f530ec, 0xe7b8b4d2, 0xe579b111,
	0x9ff04b1a, 0x3bbd231e, 0x0cf1e66a, 0xe3a23e7c, 0x9ab64373, 0x0dcf8919,
	0xe4f88349, 0xcbc374b8, 0x0d95db32, 0x5cf813fb, 0x8b8eb4e7, 0xbeae57ba,
	0x154a98fa, 0x827e0f11, 0x97115538, 0x554e229f, 0x10cfedd4, 0x2f5f54a7,
	0x709dfefb, 0x9f53c9f2, 0x7c3e7324, 0xddd1f5fb, 0x7fbff527, 0x88f7f10f,
	0x1801afd0, 0x58fd9f78, 0xf14a816b, 0xabdec56f, 0xa87d93ef, 0x3ef2b56d,
	0xf75725ec, 0xfda817e1, 0x7da8093e, 0x8d81386d, 0x14ab6d7a, 0x35abfda4,
	0x8d37bb6d, 0xe69afac2, 0xd3042525, 0x3b6064ba, 0x0522db56, 0x42eb3f69,
	0x3ce8b87d, 0x378a9fda, 0x71a05eae, 0xe310df7b, 0xe70fac5e, 0xdbd48c51,
	0x34f7e2b2, 0x2b56bade, 0xe7fc5024, 0xd1465b0a, 0x10a5bb7c, 0xf43ab7cd,
	0x5fc6858c, 0x5c92d2fd, 0xeed6ff0a, 0xb91f18e8, 0xf7bbd41f, 0x3e454584,
	0x667d6ead, 0x44aede9e, 0xd460f7b8, 0xc123e8b9, 0xbcc8bc8e, 0x0858a311,
	0x420b7c50, 0xfce8ef5e, 0xae3ede5f, 0x7689d891, 0x120bcf6c, 0x9bbb31db,
	0x9d81d8ec, 0x34affeff, 0x197fbedf, 0x9281b84f, 0xf837e3eb, 0xd4371c02,
	0xc5c0f3ea, 0x03ca1693, 0x17cd5b6b, 0x3cff9de2, 0xdc79f6ec, 0xd8f286d3,
	0x3379f8d8, 0x2be503ea, 0xd644ec81, 0x6fd1d90f, 0xfcf48159, 0x3d201a84,
	0xb2dfb38a, 0x539beb12, 0xb63976f5, 0x77fcbc60, 0xfe615b85, 0xf9c472d8,
	0xfbfbec72, 0x7287f7f4, 0x7ed0b0be, 0xd17aad5b, 0x0dadb842, 0xe5ce2e7f,
	0xa79e3edb, 0xaf77e9c5, 0xb33df85b, 0x5b7ab7c9, 0x6c7e90c9, 0x93763690,
	0x6fb0dadf, 0xbe71ca82, 0xf4cdd02b, 0x695049ed, 0x3f7b151d, 0x311dde9f,
	0x1f111fde, 0xab7e11b9, 0x45c7d776, 0x6bdbe266, 0x4929171f, 0x337bcf43,
	0xede3ab1c, 0x16ebdc93, 0x6489f77e, 0xb79a45df, 0xdd55af66, 0xf04ef8c8,
	0xeddf0986, 0x40cf3e76, 0x96365b7c, 0x2efbe244, 0x5db6bba6, 0xadbf92f6,
	0x6fe25b6d, 0x5e49f6e0, 0x56dc8312, 0xc99c2016, 0x11e31f4e, 0x4df382fe,
	0xd071cfd7, 0xff6ec91e, 0xe28bc252, 0xc48f8f08, 0x7ba9ad5b, 0x6c2b9d0c,
	0x96b7fb36, 0xec9fe845, 0xdd1ba808, 0xaf34cfc4, 0xcfc90eac, 0xe972126c,
	0x5393bb55, 0x1fa26fc9, 0xde957da7, 0xc4c9e7f0, 0x0f6d4dff, 0x73ef48d8,
	0xa75e4edd, 0x695012cd, 0xd52c665f, 0x2d9b6e51, 0x57a4d5be, 0x4512339b,
	0x7d759b5e, 0xa4bd65fb, 0xfb9d0aaf, 0xa2df79f9, 0xef5bc757, 0xcbfb6068,
	0xd0666577, 0x6bd78d2b, 0xda93bf03, 0x1475b5d5, 0xdebdfa45, 0x897a777d,
	0xe8a2733e, 0xaf02190f, 0x493ef3b1, 0x99392338, 0x8b2d6e56, 0xedb1fbf0,
	0xd1e3aa7e, 0x012803e0, 0xa9c13fde, 0x1df878b5, 0x206f2ee9, 0xea913c39,
	0x4c3b27cb, 0x8c1cba5b, 0x74b896aa, 0x449ffb60, 0xcebeffb6, 0xefd98b47,
	0xd7aebe24, 0x8f8b66eb, 0xad8a8cf9, 0xae0f1e92, 0x5712c72f, 0xe9d25ecf,
	0x2d1d9cde, 0xdb76d8f7, 0x536676f5, 0xe892b3c0, 0xdeb3203c, 0x2cfda9f4,
	0x5f5da37f, 0x7f90aaf8, 0xe95be5fb, 0xece6cb3e, 0x2fcf8c65, 0x2c50537e,
	0x2c7b8c47, 0x76483cad, 0x0f0319e4, 0xe88780e6, 0x1d662a7e, 0x9fefb74e,
	0x34fb11dd, 0x2ebee590, 0x3f9e809c, 0x877f7579, 0xb7ef13f9, 0x97a241f5,
	0x3d6efbec, 0xc7c0504f, 0x5783b138, 0x834638e5, 0xa2cf7463, 0x5b04c3b1,
	0x9b4c9ab0, 0x62e71141, 0x48c9b2c9, 0xa61b34b2, 0x4b4c74c2, 0xaf70dfef,
	0xeb84d05e, 0x590107dd, 0xfbd143c4, 0x9a49a003, 0xf02fb914, 0xfbf89ae6,
	0x1bfa2f02, 0xd6ffaf49, 0xb08cc0be, 0xe5258569, 0xe81fdfef, 0x99e74772,
	0x2655bbef, 0xf02f942a, 0x06270a17, 0x4c133ec5, 0x4f3efc25, 0xfff7c4bc,
	0x45a511e8, 0xb9b7cdea, 0xd7b8dfd0, 0x1b3cd96c, 0xac572bf5, 0x048dea9f,
	0x67114ee2, 0xbc37ee0c, 0x5ce39139, 0xe73243b4, 0x969d4edb, 0x6095b918,
	0x6f7c047c, 0xbf6a3527, 0x9bf87c22, 0x3bbbb264, 0x4977d553, 0x6447fd2e,
	0xa09197be, 0x715c5b74, 0xc52f6af4, 0xa88718cd, 0xdabec2e9, 0x9e79c4da,
	0xfc80d54d, 0x39d3827b, 0xafd08e45, 0xa83fba53, 0x8c767c39, 0x4bc8e305,
	0x93c9e3a6, 0x7b75fc70, 0xdb69925a, 0xf799ed6b, 0x9815d3a6, 0x857fc572,
	0xb485faf0, 0x7146cf2d, 0x1160e6e1, 0xce1427f1, 0x3b7f2149, 0x52808159,
	0xba9e9c3c, 0x09398be7, 0x0f9e7dad, 0xfb7261db, 0x9f1455d4, 0x7ac585d6,
	0xbe330e69, 0xae03682a, 0xa635b6f7, 0xff7578d2, 0xd9247fb6, 0xc5d257a7,
	0xaf6fec7e, 0x15fd144c, 0x527da850, 0x53074bba, 0x73fb44d0, 0x7afbe8af,
	0xdc4c57bd, 0x727f98ce, 0x44ec995b, 0x6f0a4c1c, 0x88fbc83d, 0xa38e56ed,
	0xc1025e12, 0x3e04f68f, 0x303ba9c7, 0xf50fc81f, 0xe12bc0b9, 0xfd899dfb,
	0xeff4f71c, 0xce74aab7, 0x0adce099, 0xf53be7a4, 0x0805517b, 0xd0c716c8,
	0x84be6373, 0x1ed25ff6, 0xcf82e11c, 0xad94135b, 0x92239370, 0xefcc49df,
	0x3a55c222, 0xd13613cd, 0x78ff4439, 0xd74c31b4, 0xf3c09d10, 0xb016741a,
	0xe969df7d, 0x3723f0bf, 0x1c24e5d3, 0x13a08014, 0x9e7027da, 0x78d4e09a,
	0xd54e091d, 0xd386901b, 0x81845755, 0xd3cdea17, 0x8f50611b, 0x12ebaf49,
	0xd436ea87, 0xa0399d85, 0xb8bf7f9f, 0x447672a5, 0xe94c0c9d, 0xf48aff50,
	0x29a5b9ff, 0x02d3f78b, 0x8eda8a32, 0xad2a5265, 0xa1f5e553, 0xc5e9684a,
	0x3f740f82, 0xef136ece, 0xce23db07, 0x8877541d, 0xd3ab5e76, 0xf59b20be,
	0x078b0e85, 0x49efb2e3, 0xa3370be1, 0xe33cf6be, 0xeb84994b, 0x7c1d31ea,
	0xfddb19b4, 0x8f284571, 0x64be6fee, 0x8e9adff5, 0xd1febdf3, 0x932727ca,
	0xf669ddbd, 0xe9dd9356, 0xf1cb3c0e, 0xeacd6fef, 0x83bd0896, 0xbe0cfeac,
	0x4f33177f, 0xcf8d99dd, 0xb7db7c52, 0x9ce9524f, 0x3fdccfb9, 0x6daee886,
	0xf642ccff, 0xc7df6ebc, 0x4a5ecf1c, 0x8e9ddff7, 0x6b6d2bf8, 0x33647be0,
	0x23df2b60, 0x82e3d42b, 0x93d84790, 0xdb795381, 0x10e4221b, 0x06fa1748,
	0xe4b1fefd, 0x7d75da9f, 0x2e79403d, 0xee3a7b96, 0xefe3471a, 0xa370f3d1,
	0x1c1c035f, 0x08df7c45, 0xe839726f, 0x154a826f, 0x7df0ace1, 0x445afddb,
	0xfd74c7fb, 0xcf9f4c7f, 0x4f5fe199, 0x38edaef4, 0x75a64967, 0xa18d0f9e,
	0xf98432bc, 0x1d8e33b8, 0x18dfd419, 0xfa53aa7d, 0xeebed42d, 0x415db022,
	0xa0a53779, 0xbf795efc, 0x7c0ae26d, 0x926507be, 0x19c27142, 0x31ee1f91,
	0xfb5146fb, 0x175fd386, 0x495b1d91, 0xbeffc242, 0x2c76bfde, 0x5ff10df1,
	0xb67a489e, 0x19aed81b, 0xf4893a7a, 0x224ffb14, 0xbd5097fc, 0x4ef2ed80,
	0xd602d74b, 0x20263dcb, 0xb3fc44bd, 0x9dfe203e, 0x39278fe4, 0xffb81f51,
	0x9df3d604, 0xe38d265d, 0xe3ebb458, 0x1b7e5eb9, 0x557677d5, 0xe9cf593a,
	0xf498be7c, 0xc7907c35, 0x278c0109, 0x8be049d1, 0xe5388fdc, 0x0dba664e,
	0x0dce797b, 0x5350dfba, 0xbb0eb8bc, 0x47e9472c, 0x75149f84, 0xfcf68fdd,
	0x3f2ddde2, 0xa44722cf, 0xeea709fb, 0x76143f1f, 0x5f741fff, 0x99ade1b5,
	0x1e299b8b, 0xf7e6477f, 0x90fdf407, 0x83938eb0, 0xf9087efa, 0xb8aa750d,
	0xa7cf4b4f, 0xedef9d61, 0xc82beb6a, 0x6d56951d, 0x4ce5443d, 0x4282a85f,
	0xbbcbd9c5, 0x9a85990e, 0x5afe1217, 0x4852de0f, 0xcefad4f7, 0xf5aefc88,
	0xffdffe9b, 0xe8f6d716, 0x1c7fe401, 0x61cb853f, 0x357c61fc, 0xdfc33c0a,
	0x1d8649f7, 0xf280b739, 0x7956de8f, 0xb2be8ea8, 0xf54d8116, 0x2deef48e,
	0x3aac2401, 0x20937b43, 0xe7e99b51, 0x37c4efb2, 0x7b96a419, 0xbce39d4e,
	0x15a2d5b9, 0x735a7e12, 0x838cd530, 0x99ba50d3, 0x856250e5, 0x9f80e7b8,
	0xb07d8ba5, 0x293c00bc, 0x3b2c5e71, 0xb7379483, 0xe3059aca, 0x58108b9f,
	0x8dec8b36, 0x10fa5fbe, 0xfe1a3fe8, 0xd61e7ca2, 0xbc510fab, 0xe1eb7e82,
	0x673b0f9f, 0x569e1137, 0x2bf04bb5, 0x17eafb5c, 0x3003dfe3, 0x691e91f6,
	0x147876db, 0x4bcd73ca, 0x0dd6edd1, 0x710f2bde, 0x39aeb9fe, 0xb3ff7cfa,
	0x196e3d74, 0x6e28e307, 0x7db13c41, 0x69d02b30, 0xcd6efc45, 0x38a69ff4,
	0xe09315f1, 0xd655da13, 0xdd6ed3cb, 0x7b0b94cf, 0xf8097fd4, 0x8ec14ede,
	0x1fba21d0, 0xdb39b333, 0x54cc734b, 0x6d99fbc4, 0x4067ecd9, 0xbe74ca09,
	0xe7f9aa5f, 0xd01d3c71, 0x8c3dd14e, 0x049dbad5, 0x7ed2fe27, 0xd5aebe8a,
	0x48f73c7a, 0x19ee9a30, 0x79a46c10, 0xf710ed56, 0x88eed67d, 0x4ebf2f7f,
	0xf3dd671f, 0xf6d30e27, 0xba284d5b, 0x9fce9d5d, 0xe7e8b6ba, 0x7b377dc6,
	0xac7fbe86, 0xdebeebdf, 0x347f07fb, 0x3de2f88b, 0x7de31c7d, 0x4dc08661,
	0xf247922d, 0x8394175d, 0x52d59b84, 0xb7c45920, 0x748158e0, 0x45e0603f,
	0xa0fa9fbf, 0x74079fce, 0xb0baf0bc, 0x528bcd7f, 0x1eddce90, 0xfe9a2a7c,
	0xe62b4287, 0x71621e11, 0xccd9bab5, 0x581aedf1, 0x36f8a16f, 0x066b5716,
	0x42d5b2f1, 0x4f162c7e, 0x1ae97eb5, 0xfcb88b74, 0xb5ee96ff, 0xfbef30e6,
	0xe485fdac, 0xadfd100d, 0x3ed0b5df, 0x10fd70e4, 0xe0635df2, 0xdfd75f44,
	0x19f99ebb, 0xc227fe3a, 0x556f9644, 0x41e675da, 0x6ef4f1d1, 0x018fd08b,
	0x1b4fec45, 0x3fed89f8, 0xe7c78f4f, 0x5e5c0f3f, 0x4c9cbb6a, 0x5d7dcdfb,
	0xa5c0c903, 0x1ffc8aa9, 0xec2373d5, 0x22199dce, 0xf9e4de5f, 0xd78a69e4,
	0x7b36efe7, 0xbad69ee9, 0xf91f66d1, 0xdfa375e9, 0xf08dc8ca, 0xdbd1df2b,
	0xd0fddfcf, 0x67da04c6, 0x25e48df8, 0xff6bebf5, 0x07aa41fe, 0x78ef259a,
	0x6bb87fec, 0x2f7477e0, 0x9f63c6bb, 0xedd5e34e, 0x13b85b9f, 0x4fb787eb,
	0x95e646f5, 0xfac55387, 0xb3368fe6, 0x6919ecdf, 0xed3575ff, 0x58db6a03,
	0x78de7b8f, 0xedf7c2cd, 0xc1e04a77, 0x0e7b0e89, 0x7e401abd, 0x613decf7,
	0xa2bc60a1, 0xfba584f5, 0x9703c4af, 0xf30add30, 0x0b56e93e, 0xf3dc2fdf,
	0x41ce85a9, 0x98fa5f6a, 0xb4d69ff7, 0xd6476c49, 0x550728bc, 0xfda1ebfc,
	0x47085baf, 0x6412cdb5, 0x37be4766, 0x77b27bf3, 0x59acff54, 0x9f034fd8,
	0x1a3c752b, 0xbaf034f8, 0x0f33b752, 0xe3c68e6c, 0x1a6da0c3, 0x6a1ffd89,
	0x63f7c15e, 0xdf1ada1e, 0x6af618ce, 0x688fe515, 0x1f3d57ff, 0x4191eedd,
	0x0ed8061c, 0xe7b3dac7, 0x00533b0d, 0x81c38405, 0x0ab1caf0, 0x13ebfee2,
	0x9c42c66b, 0xbae39873, 0xe6fc36df, 0xdbdaf8b5, 0xfe42d976, 0xcccb2eae,
	0xd65d4379, 0x9c489657, 0x3271d76c, 0x964bfdaf, 0x077b754f, 0x045cefdf,
	0xdfc475fe, 0x2776ed45, 0xddd5c1c5, 0xb4176f42, 0x8941835b, 0x9fb133e8,
	0x26a1045b, 0x01df7f92, 0xe0445df1, 0x21e3890d, 0x2ad8edd0, 0x74abdf9d,
	0x3cc2aefe, 0xf7dd146b, 0x47e8f3d0, 0xa61db7f2, 0xfab511ab, 0x0e4775f3,
	0x179f1325, 0x0b33b080, 0x18cec242, 0xc4fc32f2, 0x7fd87f70, 0x6d7bc91f,
	0x59ef95bb, 0xccedd42f, 0x1df166c2, 0xf7deac56, 0xfb8bb08d, 0xbd047bee,
	0xb6b17eb1, 0xabfdba35, 0x1cbe2219, 0xdfdae3d0, 0xbaabc8c5, 0x7093ec1f,
	0xecaa05bc, 0x2eaf720d, 0x2cefe685, 0xb31cf892, 0x12971d53, 0x51919eef,
	0xd78f4efe, 0xda62fa8d, 0x21f6c2df, 0x644756e7, 0x299a5e3e, 0x199ac7fc,
	0x1ff88072, 0x2e2cbf91, 0xbf9b8ece, 0xed819a7c, 0xe07acedf, 0xf99129a9,
	0x8f2db68b, 0xcf13f870, 0x7ee9aacf, 0xb0b35d4e, 0x38a5bd27, 0xe3c50a6e,
	0x5d6df1c0, 0x794835b3, 0x88e21d46, 0x9c22a3bf, 0x4bb67e90, 0x18270973,
	0xe3497fff, 0x3ea3a12f, 0x3692ff5c, 0xfc38c7f4, 0x192fca92, 0xc5724777,
	0x996f91ba, 0x2301f2f1, 0x22bda80f, 0x79e34de2, 0xf9cdd2ad, 0xb8bb6d40,
	0xf07adc5f, 0xa46c98ea, 0x7fff6fb7, 0xe581598c, 0xad0f9d38, 0x7473a1e5,
	0x9debe64f, 0xe571b8b6, 0x9a96dda0, 0xcd6a4f58, 0x771c19dd, 0xeef8c3ec,
	0xde1fcc46, 0x87f382fb, 0xf70983d6, 0xd2b95c73, 0x57f9d63f, 0x1b00d4e4,
	0x08dd3e39, 0xfc525c4d, 0xadcf1912, 0x377b8a72, 0x8efeeb0f, 0xae238fea,
	0x73b6c61f, 0x85d9e38a, 0xd259a6c0, 0xd8607b70, 0xef1d1a95, 0xdb6d276b,
	0xb1fb5b44, 0xae8d4e71, 0xb3c11847, 0x6f8d8b7f, 0xff75334a, 0xe1b4e3a6,
	0x578e44bd, 0x4ec88efb, 0xbe45d3da, 0x8a48d3fe, 0xcf4e30df, 0xf98fb389,
	0x1ecb8e85, 0xa1b4bcfd, 0x99be6654, 0x88d28866, 0x8c7f9087, 0x8e13be97,
	0x85fbc520, 0x21cf5e07, 0x81ddaff9, 0x0ef522ed, 0x7be7e7e5, 0x5f96414f,
	0x67cec84d, 0x57fbc632, 0x913ebc0e, 0xdef0d670, 0x2e427937, 0xee2cf357,
	0x9467d36b, 0x58f22492, 0xd8f22493, 0x32774a3d, 0xfb754fe5, 0xbde45f64,
	0xb7ce4373, 0x4501f8e8, 0x328bebe4, 0x86efd655, 0xd30b8176, 0xfce2517e,
	0x8d7ec4cb, 0xf61fe799, 0xf2f11cbe, 0x101afc57, 0x3afb285d, 0xaee33f73,
	0xe98984ee, 0x90313ba9, 0x03dfe911, 0xd9266e34, 0xc07586bd, 0x640ec476,
	0x77d21767, 0xf85f587b, 0x4bc70261, 0xac9e7387, 0x2395bb66, 0x47add903,
	0x21335bdf, 0x97bc3fd2, 0x8181ce21, 0x68a1e0f8, 0x7e62e7e5, 0x611b0f9d,
	0x0bef9ea9, 0xc461df1c, 0x47fe99a3, 0x49e4e332, 0x36ef1bd7, 0xed02b7ec,
	0xb59dd703, 0xaf9a3df2, 0x3ce2aff7, 0x27f8ae1c, 0xbf019d90, 0x1f2a06ff,
	0x026ab03d, 0xc0faff3d, 0xfef03723, 0xca31b4a5, 0x3e88057f, 0xa745c50f,
	0x963be833, 0xf9a7fd9a, 0x7ecd5ffe, 0xf54fd333, 0x58f5ff48, 0xef3fd8a6,
	0x7de048eb, 0x0472090a, 0x6a37200e, 0x6fad75dc, 0xaeb11c71, 0x0efa8e4d,
	0x45b7e8c1, 0x0369e71f, 0x63492107, 0xe516ef39, 0x98d7b6ba, 0x10e6b59e,
	0xd9a1b1cb, 0x14efde2c, 0xe297c625, 0x0d48463b, 0x69bbfd10, 0x6b9c5aff,
	0xb6057ef0, 0xc818fd64, 0xf7d2082f, 0x11e8c70b, 0x682075f2, 0xcadcf102,
	0x9d8dc1e7, 0x98fbf8e3, 0xdcd7ce81, 0x71c5fcf1, 0x5241073a, 0xfc8b668f,
	0x22fdf622, 0x3847d88f, 0xb1d8467a, 0x09fe65a3, 0x0059ecf1, 0x2dbe45ca,
	0x356efce9, 0x4f3bc557, 0xb78fa85b, 0x94702b23, 0x3bb3d3d6, 0x7ad3cf81,
	0xb45f625c, 0x4288e5a2, 0x6dac59df, 0xff91a695, 0x01ff9b58, 0xf581877f,
	0xe15bb612, 0x586e7c7d, 0x9e7bbcd3, 0x918e8716, 0x05bf811e, 0x91e7f896,
	0xec532bff, 0x6f049d37, 0x3d1f9eba, 0x4ef9c269, 0xe29d9b56, 0xfdf12a7b,
	0xfdbaade4, 0x99916dbd, 0xa09392e3, 0x83b9c59a, 0xac581f38, 0x755bd1db,
	0xbbec3cbb, 0x09e117de, 0xfd881f3a, 0xc3b0d7ae, 0x2fe3e877, 0x8dc78d05,
	0x0efb3efd, 0xc3bbbe3d, 0xa4fcfd17, 0x20f37f61, 0x086fec8f, 0x7bc901fd,
	0xfb024143, 0xc79385d5, 0xe80b8dc7, 0xff55677b, 0x434a99de, 0x1f050dee,
	0xda3abfb0, 0xbe55e671, 0x01267f37, 0x6b9ce272, 0x432bf90d, 0xf2176fdf,
	0x6a0bcfd6, 0x4346829c, 0xf33097ee, 0x3297dc89, 0xceb5fee4, 0x7df4ffff,
	0x22507c97, 0xcbb629f7, 0xcec9affe, 0x387ad8d4, 0xb015c69e, 0x8d75c2df,
	0xc635d7d1, 0x2e8fe11a, 0x1711588d, 0x4beb43bf, 0xefbb080d, 0xc0a3b2e6,
	0x13577aca, 0xb63bf892, 0x27c8b09a, 0x3e452a6b, 0xe22ad799, 0x4bb765ca,
	0xf3624d41, 0x33e88a75, 0x26d8b3f0, 0x9381b7fc, 0xf8e97e41, 0xcfe4f7a1,
	0x79fdd56f, 0x40268e2c, 0xe7da3cd7, 0xbc9353bd, 0x16307f74, 0x4f974b4f,
	0xf3cc8b79, 0x7883f0b5, 0x63ffefe3, 0xe3d4b471, 0xe749ed1f, 0x64d970bc,
	0xc168f71c, 0x37086367, 0x9bd0d7b5, 0x76af5d52, 0xc9470238, 0xd16bafdf,
	0x0a5bc1cf, 0x1f89bada, 0x5ef1c09d, 0xd36bab8f, 0xf3071106, 0x384d7839,
	0xabfbbf81, 0xf7f3b769, 0x0dad354f, 0x3f291389, 0x76bd976c, 0x9eb757ac,
	0x567e24a8, 0x197b8897, 0x8e7e96b5, 0xbfb76537, 0xe45be898, 0xff3a88ed,
	0x16bce836, 0xdaed63ce, 0xec3cfd42, 0x2cdecabf, 0x6f3c08f4, 0x63397238,
	0x2e754e22, 0x7cc55fcd, 0x16b7eb7d, 0x9bab263a, 0xba3cfaf8, 0xa3d0b50a,
	0xcd45bb72, 0xfdb44d1d, 0x62ffd06a, 0x57d853a6, 0xe38b3073, 0x77d749c8,
	0xdf61a41f, 0x371445db, 0x291c76f7, 0xbbe044b2, 0xe7da0367, 0x006bf238,
	0x0ab7ae93, 0x54b49297, 0x1e846f8f, 0x943fedd7, 0x3d06fb41, 0xa893bfa4,
	0x7e4c9d3c, 0xc9f766b1, 0x6714f1e4, 0x31a511ec, 0x9976a5de, 0x9dd281db,
	0x24524777, 0x7d304f7d, 0x1c624297, 0xdbbcee80, 0x6fbe4726, 0xffad7ffc,
	0xf1a67a8f, 0xfa512777, 0xb309f06f, 0x350efe76, 0xe7cac070, 0x124e74ea,
	0x59ea9f79, 0x6237d71d, 0x3a7a4372, 0xc785ce83, 0xc0a62851, 0x205754bd,
	0x39d2a4ac, 0xf716586d, 0x7ed8b2cc, 0xbfe7d74f, 0xd0770951, 0xfa19d47d,
	0xe84ce2b9, 0xa07376e2, 0x9c0d4b9f, 0x396d1dfc, 0xb52cb978, 0x9a521785,
	0xe2142937, 0x19c244ef, 0x4d82eb8a, 0x8e375eff, 0xa6f887bc, 0x1f8305c0,
	0x893f9d32, 0xebb17bfb, 0x8f58c579, 0x850eec26, 0xb50f7412, 0xde7c4214,
	0xeb74137d, 0xd7f1dee7, 0x34f30b31, 0x09baef3a, 0xf9912775, 0xb3f6e411,
	0xbc723d69, 0x642f74f5, 0x93a54331, 0x19c293e8, 0xd7ed6fa6, 0xba3e8ebf,
	0xc4fb4895, 0xfef7f40f, 0xbce864a8, 0xf6fedbd0, 0x566f7487, 0x57be34d2,
	0x8eefa5eb, 0x2b092f29, 0x2c76833d, 0xb3cda007, 0xdfc92f72, 0xfc012ef8,
	0x6229f7c0, 0xe5a04bbf, 0xba18cc5e, 0x37dc65a7, 0xaa5c11dd, 0xb0b7bfd2,
	0x7fe36ddc, 0x36d8a59f, 0x0fed2a66, 0xdfe69a3e, 0x567c7a4b, 0x83cf1e6a,
	0x1c69c128, 0xb2b8ea77, 0xeb4a5683, 0xbbe33497, 0x0cbc6008, 0x019ef77e,
	0xdd8a7dfc, 0x791bbe2a, 0x4b687112, 0x74abf465, 0xaf1e17df, 0xddbe2950,
	0x2979b2e4, 0xbd12b37e, 0x1b7a21f6, 0x83dee26d, 0x962b7f71, 0x83c88d8f,
	0xaf3fd62e, 0x98e2e38d, 0xb7ee59ef, 0x5f10cff9, 0x9e5497be, 0xe16ef149,
	0x8a1ed9ae, 0xeff51bbf, 0x00a51a62, 0xcb80e1db, 0x821dee24, 0xa371c9d6,
	0x116ea2c3, 0xbfdf25f1, 0x1cab701b, 0xda4a1e5f, 0xeb113894, 0xbe242b8d,
	0xae98d4ef, 0xd09764a6, 0xc81976bd, 0x567637ae, 0xa05f9274, 0x37af14fe,
	0xd51a7cba, 0xf7c0e903, 0xb3ff88ef, 0x869bfe0d, 0xefd21ff8, 0x5edb14e1,
	0xeefb4d1d, 0x4150dc53, 0xb584a6fd, 0xe30bc4f1, 0xc7940ffb, 0x531e489f,
	0xa1f7d1c2, 0xfdf27140, 0x081e4307, 0x53b50610, 0x1f21b397, 0xbaddf1a7,
	0xb77d44a6, 0xc9edc86e, 0x331f2144, 0xc71944dd, 0x371a557d, 0xff062e56,
	0x62670fff, 0x48106171, 0x00004810
};

static const u32 xsem_int_table_data_e1[] = {
	0x00088b1f, 0x00000000, 0x27dbff00, 0xa3f0c0cd, 0xa5f5811e, 0x798a1818,
	0x8968c550, 0x1819393b, 0x0331036e, 0x00430317, 0x2064ded0, 0x6bc4029d,
	0x101d7881, 0x3033708b, 0x08710304, 0xf9033710, 0xf36e685e, 0xf0606265,
	0x2040e207, 0xafe2060e, 0x31bea340, 0xae7f6f10, 0x43169010, 0x19c4cdf0,
	0xe9245c18, 0x86c1ffe7, 0xd7d3ebbf, 0x06032cbe, 0x044b7b06, 0x0305917f,
	0xaa258383, 0xfc4b471a, 0xc9a13866, 0x5df1a33b, 0x4097e8f0, 0x06b26ff3,
	0x8b543f2a, 0x92066181, 0xfc0d149a, 0xc7c7416e, 0x004f7a81, 0x54850031,
	0x0368f919, 0x00000368
};

static const u32 xsem_pram_data_e1[] = {
	0x00088b1f, 0x00000000, 0x7de5ff00, 0xd5547c09, 0x73b9f8b9, 0x2cc99997,
	0x6cac8499, 0x1689b0de, 0x1a424270, 0x8b61db10, 0x5c18a3e8, 0x84c0b82a,
	0x01327b25, 0xf69e0fa9, 0x69b08197, 0x6b1b6351, 0x304ed1b0, 0xa0d06828,
	0x1c048201, 0x69f42d40, 0xb15a7d0d, 0xb22834b6, 0x0dc06486, 0xcefab3df,
	0x93739df7, 0x82266f7b, 0xd7ff7f6d, 0xcfe3fef7, 0xb3dce1df, 0xbef9db7f,
	0x44e77cef, 0x74891252, 0xc0df2105, 0x588487ef, 0x7190842d, 0xd521293d,
	0x7250ad3c, 0xdc04845d, 0x84999ff4, 0xd094b994, 0xa64234ca, 0x3fc3976c,
	0x7af9a04c, 0x79a56421, 0x963b5ecb, 0x7cb1d677, 0x08f8a5d8, 0x40d73f2d,
	0x6f6d02f3, 0x5af87b6d, 0x2ed91e5a, 0xedd08d92, 0x490b18c8, 0x8d84e422,
	0xcd265fb0, 0x6f921167, 0xfab2d967, 0x7da1737d, 0xd8958b61, 0xbb657f69,
	0x4b5e660a, 0x650705f3, 0x36ca5502, 0xd3fa50ad, 0x6848517c, 0x64d77c82,
	0x0ee0bf36, 0xd689b431, 0x25b772ef, 0xe424e6dd, 0xa88da54c, 0xae55210a,
	0x475ba4b6, 0xda1c5211, 0x8aed0396, 0x2c2f051b, 0x4df6ca75, 0xbac2a46f,
	0xab5e08b6, 0x66c9484a, 0xb2475107, 0xff437c39, 0x862cd13f, 0x97cb487f,
	0xda1275d0, 0xcea9016f, 0xff8c2221, 0x7abaa2a8, 0xd2a677e0, 0xf968e383,
	0x1c742db2, 0x05fcaeda, 0x2c4b0bc1, 0x137f10b7, 0x9773bf1d, 0x4ed3f67d,
	0x650adf58, 0xb5d60b84, 0x057a8156, 0x761dbca1, 0xaf57e615, 0xe2f2d0e4,
	0x7f257aba, 0x257f4f54, 0xe719fb9b, 0xd9343b55, 0xa7372baf, 0x51092a67,
	0x8be4f447, 0xd135f109, 0x5214897e, 0xf9ee8d66, 0x238911fe, 0x17fa1124,
	0xe9eb6a89, 0xbf12429f, 0xffa5df07, 0xee0af0a4, 0x355c2171, 0xd0f12dbc,
	0x783dab7f, 0x78e1e0bb, 0xfa592294, 0x61f4b5fe, 0x4f9d03c0, 0xa689c035,
	0xdcfcf9eb, 0x8924c913, 0x11f6eff6, 0x5efa408f, 0xcb56968f, 0xb1d08f24,
	0xfb470616, 0xaf34f1a4, 0x4bc4c590, 0x6557cfc8, 0xfcd2a6f9, 0x173fc443,
	0xf04abde6, 0x089e0217, 0xfa014a69, 0xd990235d, 0xc31ffeb0, 0x9af969a4,
	0x149f4a54, 0xb2d3d5ee, 0x3e05169e, 0xe7c804f7, 0x1a60f33f, 0xfd8053f6,
	0xa19fb4c8, 0x93c7ee97, 0xc7e86d93, 0xf5a85393, 0xd8fd8153, 0xea9faf2f,
	0xf9c6099c, 0xfd6b14e4, 0x5c7ec72c, 0xcf2eb797, 0xf38d13f5, 0xfb14beb9,
	0x25ea9b89, 0xd45f5a7e, 0xf9b481e8, 0x6cee5a44, 0x20fb1b8c, 0xe4c5d3d1,
	0x2effc0d5, 0xba7a25ca, 0x318ecd88, 0x2f9c61d0, 0x3da790de, 0x8f7c4e79,
	0xe120e9e7, 0x57c70538, 0x17282bfa, 0x61b7f526, 0x4efedefe, 0x4ef70b94,
	0xa1e95ff0, 0x49b180f3, 0xfe2bcd2a, 0xe8513c6b, 0x2053ce9a, 0x16aa9029,
	0x6be5cd48, 0xc9870665, 0x711abe03, 0x580fb68c, 0x68e22322, 0xf4984ebe,
	0x26cb806b, 0xc4f84162, 0xea02a488, 0xca0958c5, 0x5969b5a7, 0x7075074f,
	0xe288375a, 0x77e9e85f, 0x014fec9d, 0x6e42dafa, 0xadbd020b, 0xd3d74419,
	0x82e7909f, 0x128386b7, 0x3f283f6d, 0x5569e005, 0xc7eb7f28, 0xa3f8e857,
	0x6117fc70, 0xfe30eddc, 0x5be3deb8, 0xc61b6487, 0x342e0db7, 0xe8536f8c,
	0x77de94f8, 0xf8f9bb91, 0x08137e14, 0x17782579, 0x5c1d6f8e, 0x55afe388,
	0xfc61a148, 0x5ff1ee98, 0xef5f7185, 0x2643fd6b, 0xb83fd718, 0x857eb8d8,
	0x5910ffad, 0xc18fc7c4, 0xb836fff5, 0x707fad90, 0x95bf5b31, 0xbe3ddbf5,
	0x6ffe1bbb, 0xf6efb8c3, 0x13a1feb5, 0xa2bfeb8d, 0x2b7eb8d4, 0x527dff1b,
	0xe277c7c6, 0x960c7ff8, 0x515ff5b2, 0x562be38a, 0x48e817bf, 0x11531019,
	0x8193e3a2, 0x51922194, 0x1d30f946, 0x6d084f19, 0x2086435f, 0x618dee1c,
	0x0c79f774, 0x8f6737a5, 0xca2123bc, 0x959e5451, 0x692f9a73, 0x9c80a49c,
	0xf72a72c5, 0x2ea9f116, 0xbf71116c, 0xd0d63521, 0xcedf3a70, 0xf9083116,
	0x85d73585, 0xc8efdc44, 0x27685cbc, 0xff7c3091, 0x1bd1b1f8, 0xa732ebf5,
	0x13e5aa8b, 0x623e06ed, 0x264e09f3, 0xfce82b23, 0x8c1101a6, 0xa09fc9eb,
	0xf9509472, 0xa39521f9, 0xe9949e90, 0x71fbf478, 0xa289672a, 0x6c159be7,
	0x77920f1f, 0x9c812646, 0x1213bf60, 0xa589f783, 0xffe00842, 0x158ba3f9,
	0xaa8b4f90, 0x3de8141d, 0x3c7008f3, 0x43597645, 0xa784051b, 0x1db9f00a,
	0x3f909159, 0x52a6b453, 0xf6d416d0, 0x8bbbb433, 0xd0a75684, 0xe7d60bfa,
	0xf5d0f20d, 0x3adb39df, 0x83fd8456, 0x905806f8, 0x4b00c98f, 0x9bb32136,
	0xd007951f, 0xe5b3edcc, 0xed75db0f, 0xf98df8e7, 0xf98d0b3b, 0x5b24394e,
	0x1228df40, 0xf7ed3d48, 0xb9630aee, 0x109c4e36, 0xc7caf0cf, 0x9b1271fb,
	0x8e90ddef, 0xc41ecf85, 0x6b0f5ceb, 0x7027cdab, 0xb8c24c9f, 0x1227b65f,
	0xd6227fc4, 0xbad87bf3, 0x2b9df3cd, 0x74b97cdb, 0x8b97733e, 0xfcf34f08,
	0x7c3af7db, 0xad343196, 0x120644fd, 0x3cc7af34, 0xcccb79ff, 0x1ea0f1eb,
	0x7f341796, 0xa6627467, 0xa4cb40a7, 0xf575c77e, 0xe86e9aca, 0x5f475c77,
	0x19679b25, 0x39a145f2, 0xb505fa86, 0x45f28679, 0xf28645d5, 0x1b16eb05,
	0xe5c179f2, 0x96f3fa86, 0xdf9430ad, 0xa180f15d, 0x47c2cefc, 0xfe39f90d,
	0xb7fa860d, 0x9437aecf, 0x755ef65b, 0xd551f013, 0x7d8122bb, 0x89e733e3,
	0xfc1f4187, 0x017929cc, 0x532aa71f, 0x54ce0f90, 0xb67698aa, 0x4cfcd864,
	0x8a83e60e, 0x534568b3, 0x9044dd70, 0x67e504cb, 0xc11d8ad1, 0xddaa40e0,
	0x4fc22a0a, 0x984855ac, 0xe240b092, 0x2238e9bb, 0x2fdbcaea, 0x194b5e51,
	0xb977a33d, 0x7bfd1ed8, 0x15de6360, 0x92fa7720, 0x0037f407, 0xbe2eb9f6,
	0x4bcb9bbf, 0xffab9205, 0xe44ac84e, 0xce5c8bf3, 0x1e4c2a96, 0x3a94be94,
	0x1f21b899, 0x6df1511e, 0xa05135e3, 0xed049c82, 0x81e8113c, 0x5e818172,
	0xbbf81a86, 0xf3889f63, 0x3099072a, 0xee4e441e, 0x4ce4017a, 0x5be0c0f8,
	0x7c3cc346, 0x77c0090f, 0xafb8892d, 0xef4e5477, 0xfc025c77, 0xaa7a62e4,
	0x27a63672, 0x1e98fd2a, 0xf4c42caf, 0x4c0acac3, 0x61972bdb, 0x8832b47a,
	0xd72a9fe9, 0xcac7fa61, 0x548f4c6a, 0x87fa62d6, 0x9da610ca, 0x354c3e95,
	0xbf96e87e, 0xe55f5c09, 0x79dd0576, 0xaf817f30, 0xdbad1565, 0x4dee7c86,
	0xe0bf3e01, 0xe8047cfc, 0x588e17e3, 0x7dfbe809, 0x6f4ccbc1, 0x87d1e37d,
	0x887e4afa, 0x77a33fe2, 0xe1863db9, 0xd3216ec9, 0x0f479509, 0x3bc67f0c,
	0x25e6147f, 0x21ba1920, 0xa2b96779, 0x208c3bf4, 0x27852ebe, 0xb98c8be2,
	0xc4e3e299, 0x0595ff13, 0xfbe45efd, 0x1101cc5f, 0x7e1261f7, 0xd2f80bda,
	0xb5f70dc1, 0xef2e76c8, 0x73bf012f, 0x1b6bf0dd, 0x413a684c, 0x5dfd20f0,
	0x0912b668, 0x08ead8e0, 0x1727e251, 0x06ed3e0e, 0x62925c7e, 0x028f1cf1,
	0x6b2d2d07, 0xf538f34a, 0x318b4ffb, 0x985aa17f, 0x58f284de, 0x3475bd8d,
	0x73c795d0, 0x3fe0187c, 0x9fad5305, 0xe78a2925, 0x33d7e538, 0xb2c6879b,
	0xf6c43bfd, 0xa438c6c1, 0x62176a57, 0x7cf47ffd, 0x9b47eafa, 0xe4cd210f,
	0x03c81b23, 0xd2f4365a, 0xbc2f4ef6, 0xb92a9f4b, 0xf956af80, 0x6217d073,
	0x0cdfffe8, 0xcc257e81, 0x9a06fd6b, 0x1af5a0c4, 0x1868def8, 0x3553b68f,
	0xf5da1b9b, 0x3912b74d, 0x9515d1a1, 0xcb180a57, 0x3dda2768, 0xce257dc6,
	0xa4b40f90, 0x0cfb0c7a, 0x3ff283fc, 0xd0129415, 0xa2a7294d, 0x4eb9c92e,
	0x063bf3a0, 0x25e293f2, 0x657ab020, 0xafc576b6, 0x81b63922, 0x5b3f319e,
	0xf6f53ba3, 0x3fbca80f, 0x7932effd, 0xa2bfca10, 0xe9eacab3, 0xc410ee8f,
	0x780bf342, 0xc9737e6e, 0xa77b900c, 0x5f9f6c2d, 0x60dd7248, 0xea9214f4,
	0xce73d02c, 0xa074cb11, 0xf7e473ff, 0xbd9d0cee, 0xb828b5e1, 0x8ceb05ce,
	0xcfd52cfb, 0x5a82f90c, 0xdc9f3e63, 0x9ef4049c, 0x9093235f, 0x2c697c00,
	0xec1e2d57, 0xac5480b7, 0x8abfb901, 0x3df32bdb, 0xe7401a44, 0xc9f3b657,
	0x8f3a3cac, 0x9e985bef, 0x45efd9ae, 0xc5fe6cf1, 0x8f8af54d, 0x9cd47f96,
	0x096be3f1, 0x01ad0fb4, 0xbb70463f, 0xf6a4dde0, 0x9d77dfc6, 0xdabe79bf,
	0x8fcbd27e, 0xb651e7c0, 0xa285f059, 0x2cd327ec, 0x82b7d702, 0xeb06de98,
	0x79ade9d6, 0xbe5a0e1c, 0x6e5f94cc, 0xf4cdffca, 0xf40c4096, 0xe7f04c76,
	0x7d191259, 0x4820be81, 0xf7ffc511, 0xabd29ff4, 0x687fb2ff, 0xff6903ff,
	0x97fe8659, 0x1ffb43ff, 0xabfe6bd6, 0xb65ff5a3, 0x208eeb73, 0x2fc53795,
	0x7426e63e, 0x552d3a1f, 0xfe297927, 0x76ad374b, 0x929c1d03, 0xe7a06e82,
	0x7a7121d3, 0xbedd8a28, 0xfd01e81b, 0x00a73e88, 0x93fc1576, 0xb9e67ff6,
	0x7d84cd9f, 0xb24df3e6, 0xcda5ed07, 0xf295b0d6, 0xd173796b, 0xf306320c,
	0xed7e58c7, 0x2df21179, 0x7e2cfa46, 0xf024b1f6, 0xe14a51bf, 0xf51844f6,
	0x8f86f2a5, 0x0a1f6073, 0x99f20890, 0x7f8c1db9, 0x63e51e31, 0xbbdb129e,
	0xf513ce9c, 0x4b8700fc, 0xe767f9a0, 0x927df045, 0x3507e676, 0xfae42fd5,
	0x95c5a34f, 0x4e9a8270, 0xfbe4fbe4, 0x78352f20, 0x7fd31090, 0x3e3cb6aa,
	0x4f9d18e6, 0xbbbfc347, 0x349c1d05, 0xb4d0bb3e, 0xa8afd7e0, 0x4ee3cb7d,
	0xb4f5e76e, 0xb53b610b, 0xad6deb85, 0xc3952d2c, 0x4b8bd06e, 0x906f65eb,
	0xfadd2e7e, 0x804f33f4, 0xd5befa9d, 0x5ff69c3b, 0x3ff5f5b2, 0x92f9a04c,
	0x0cc2726d, 0x90a70cb6, 0x009783d4, 0xd8d97ffd, 0xbf143c1e, 0x8ea2bafc,
	0x8fefdf66, 0xc947c1ef, 0x190a7db6, 0x531e1bdd, 0xed29f69a, 0x697828ce,
	0xfa03963a, 0x2f96d555, 0x4f27b014, 0x724815ef, 0xd678145a, 0x027a8ebf,
	0xc8f109c0, 0x378dd4f1, 0xc500fd53, 0x0d73c80b, 0x87f2e64f, 0xfe81fcb9,
	0xcf4851d4, 0x7e02bc2f, 0xbd5a3fe5, 0x17c2feb0, 0x3ac371ee, 0x8c154a4e,
	0x9d5c9fae, 0x16e3a3e4, 0x0f24c1ca, 0xe17beca6, 0x7a413f53, 0x93fc382b,
	0xfa0f6624, 0x37b82d52, 0x7d615305, 0xc36eea8b, 0x3f13e5f5, 0x93e15dd2,
	0xc7c82e62, 0x7d3224cf, 0x48be145b, 0x9c5f1917, 0x2e1548dc, 0x6093beba,
	0xff3c8097, 0x84da18bd, 0x04c590fe, 0x9a27fff8, 0xc12c9c7f, 0x863667fc,
	0xe1689b27, 0x3db5457c, 0xac36bd3d, 0x9cfc036d, 0x064be419, 0x48805a3f,
	0xe10f0e41, 0x78afda1b, 0xc3325a78, 0x2ca5510f, 0x01ea8ede, 0xd43be053,
	0xf67d936f, 0xe4768631, 0xf19eb49b, 0xe9f1f297, 0xff6063bc, 0x0a44993e,
	0xefaca29b, 0x7be3516e, 0xe8eb8fba, 0x8cdfc74b, 0x601e1bdf, 0x7bf1adfc,
	0x2874d668, 0xc61df4ff, 0xf60ed03f, 0x70af3a47, 0xbbef9632, 0x60794055,
	0x7c68e125, 0xbe7320dd, 0x746b9636, 0x092de742, 0x817a3ab1, 0xfe11e3fe,
	0xafcb3fe8, 0xf274eda1, 0xb9e30032, 0xf1a7f77b, 0xffe7016d, 0xff91a251,
	0xfbe31d49, 0x20abf5be, 0x72a573ee, 0x802799e8, 0x067f295f, 0x3957e055,
	0xb67dd617, 0xee1fc0f1, 0xb67a7ca0, 0xa353e349, 0x69f334fc, 0x049b4be1,
	0x9f334fa0, 0xdaa42d9e, 0xa53e3448, 0x69f2a3df, 0x53fffb61, 0xefc1a9f9,
	0x34fc1356, 0x1c17d879, 0xbcf0f2cd, 0x9a784545, 0xbdfd21e5, 0xd37ab243,
	0x1a77469f, 0x5f3f15bd, 0x0bfa0576, 0xe8d4ba34, 0x352e9bae, 0x7fe5ebba,
	0x5ccfc031, 0x8168183e, 0x2eee49d2, 0xd2aaed19, 0x461e7656, 0x2031bddb,
	0xc3e4e113, 0xbf548c6d, 0x9f412031, 0x4df2990f, 0x533efaa6, 0xdf54d73e,
	0x1857ca6f, 0x1cb697ea, 0x3fe20850, 0x5d67a86c, 0x28f904f6, 0xeda43d8a,
	0xf3e68137, 0x62e8104a, 0x79014460, 0x4124af27, 0xf707f817, 0x762f6888,
	0xa1af1851, 0xa63574e3, 0x6e548285, 0x3b33b6ac, 0xaca8923c, 0xe5d73901,
	0x21e3b889, 0x6ffa676f, 0x1dc46e57, 0x8f23d3a7, 0xa7288ab5, 0x7a6443db,
	0xdd07bf34, 0xedcf1041, 0xe672afa4, 0x3a269cef, 0xfb032f07, 0x82f45ab3,
	0xc570bb49, 0x8d706eed, 0xbd0eb574, 0xbefd3669, 0xc78890e8, 0xee315d28,
	0x122f3031, 0x3aa949f4, 0x0914e1fb, 0xf82272fe, 0x1d995b2f, 0x49bd70b1,
	0x91eb20ff, 0x4b9df27e, 0x549f9015, 0xe8d0ffef, 0x507c65bf, 0xac2bfbcc,
	0xed6b9633, 0xec0b04e1, 0x6306e2b9, 0x43db9fb9, 0xe02f813b, 0xa49d253c,
	0x43015ca3, 0x2e71ec07, 0xa389a787, 0xe14d9a6e, 0x245075df, 0xa1797e70,
	0x5ff84455, 0x95e76468, 0xfc889824, 0x28224e55, 0x753834ff, 0x7d28ff00,
	0xed8ea7cb, 0x0fbace7f, 0x07c764e8, 0xd3457e63, 0x8fef1d8e, 0x9df90dd8,
	0x80fe0def, 0x653faef4, 0xc4fd1daf, 0x485d7b5d, 0xde7b5ddf, 0xe41f7c1a,
	0x3fd15977, 0x8bf7b5d7, 0x5d6f4031, 0x2085ad2b, 0x5106badf, 0xb03e83fc,
	0xed318be7, 0x42ae9fb8, 0x2a287dbc, 0xfd6a1f4c, 0x0242a3af, 0xa05574a4,
	0x2075ec27, 0xb15e04ff, 0x6ba13fa3, 0x7e5917cf, 0x3d6e3fe7, 0xa6fcfce5,
	0xbf6645cb, 0x638bf304, 0xeec0ef7e, 0x80af4ff1, 0x7de6e7f3, 0x3e5a02ca,
	0x8ebfd5e5, 0xf5d9b901, 0x3a7fd312, 0xe0a7f6e5, 0x789ce27c, 0xe14c857c,
	0xd44c09dc, 0xa407909f, 0x4f8193e1, 0xafe5c37a, 0x5cb927e8, 0xffd24878,
	0x3e087816, 0x215cdf26, 0xfeeb009b, 0x2007e8f2, 0x915af607, 0x9ef5b52e,
	0xfa815a6d, 0x3dd6a5c9, 0xbadcfff4, 0xace5f085, 0xfcc4b27b, 0xebacff0f,
	0x38aa283e, 0xf41f334f, 0xf73df3a6, 0xcbab7e62, 0x4cbdf38b, 0x7fff9f7a,
	0x512fef0d, 0xbd2fbbbc, 0x6bff15ee, 0x2e687ef1, 0xce07bbc7, 0xfeaf03f7,
	0x5df7e715, 0x3ffd5ce5, 0x5afbde39, 0xffc7a6bf, 0x93bea2c6, 0x274feb4e,
	0x2c504ed5, 0x7fdb286e, 0xfe969d28, 0x3881e066, 0xd364ef98, 0xfe968d79,
	0xd276625e, 0xf682c164, 0xb813891f, 0xa6ecc7fd, 0x187f5c01, 0xf51f34b0,
	0x1f030190, 0xa4837a62, 0xe379c0d6, 0xf02f066f, 0x1904ec62, 0x790fc47b,
	0x6f3c75cf, 0x257f1fb4, 0x851c1f10, 0x2ffc180e, 0x1d8f4107, 0x3d445038,
	0xdfa8a697, 0xce9ee6be, 0x062a97be, 0xd506e73b, 0x24e4f768, 0xa9a3ed18,
	0x8469bfbc, 0x539a7fcd, 0x1c288508, 0x45fa0f26, 0x2743f802, 0x4089970f,
	0xbfc439f3, 0xa989ec0a, 0x2f7f634e, 0xb8cd99c0, 0x740e381e, 0x2e80962e,
	0xda1e83a6, 0xb3a7ea0f, 0x84a0c0fc, 0x0f5c39e7, 0x2c5d5ebd, 0xca7e6905,
	0xe00974c0, 0xb96b605b, 0x36ebfc11, 0xb8f380af, 0x7282c3b2, 0x202996c8,
	0x95ac8cfd, 0xe2d87f30, 0x99f80719, 0xb3ceed79, 0x63f809cb, 0xa78b0a7d,
	0xf57e65c9, 0x66f9beaf, 0x71a1c422, 0xffd017b8, 0xe3fe047f, 0xa18e123a,
	0x91245a70, 0xf83c6c60, 0xa1f20553, 0xcc6a9fc1, 0x4907efc3, 0xaa5cfd3d,
	0xfbf45f7e, 0x52774e8f, 0xc290f97e, 0xc3a4177c, 0x6f497870, 0x95bf7daf,
	0x26f02bc1, 0xe7610d09, 0xeeae62f5, 0xcc9269fc, 0xff3bbbfc, 0xd80652f4,
	0x46ba934b, 0x1e3e32c5, 0x80697a86, 0x8817a5eb, 0x0275eb1a, 0xc58d0f1f,
	0xa283b573, 0xdabc5a2b, 0x3dc76e16, 0x340b710f, 0xd5206aed, 0x2409d822,
	0x60c1fe82, 0x8a6c8d83, 0x4a313712, 0x1c1ffcd6, 0x6627f46f, 0x8d9f9f81,
	0x8d3688bf, 0x63ade3d5, 0x4c6969c6, 0xefc03c6f, 0xc739dd43, 0xb05f0bdf,
	0x5bbe011b, 0xb939edec, 0x07fdf851, 0x99f7e332, 0xbf44bffb, 0xf5add5da,
	0xabdfa016, 0x73862c1b, 0xeb992cbb, 0x58c963fd, 0xfdccd798, 0xe0265776,
	0x85e8a0e5, 0xeb40c138, 0xe51fc579, 0x4f0cc9bc, 0xb4fc1fe8, 0xe20f654b,
	0xb4dcb76d, 0xfbbae000, 0x7d808d9c, 0x2ea94bb6, 0x13cf3689, 0x22e79b0a,
	0x98cf74d2, 0xf83e7fb4, 0x8672ea4e, 0xd39d8327, 0x6d3db840, 0x74823fa6,
	0x0933617c, 0xbb071c81, 0x85c2e408, 0x08fb8246, 0x6043c905, 0xff7e51df,
	0x703fdea1, 0xe7b6cb65, 0x6f29ff61, 0xbae03c15, 0x15da972e, 0x5a05fff0,
	0xf79044e2, 0x4716aae9, 0xab7d19e9, 0xca962f8e, 0xc0f7c212, 0xc277dd84,
	0x28749fb8, 0xdf43f604, 0xec37116b, 0x66b49f17, 0xb5f41f20, 0xc92b97ae,
	0xe825538d, 0x3343c987, 0x8c6a8c3d, 0x15afe431, 0xbf81fdfd, 0x97db5a66,
	0x2fe0a37a, 0xb2efe389, 0xffe85be5, 0x8ef6f933, 0x62fcdf26, 0x8e8f8eae,
	0xc96f96f6, 0x12dbe4d1, 0xb8064d41, 0x3433d92f, 0xe4baf019, 0x4d189c90,
	0x64ad6dbe, 0xf22f67e7, 0x66aed7f8, 0xd1aedf2a, 0x2a66b7c9, 0x19c4a2df,
	0xf95cbc1c, 0xe19ffa16, 0xdf20adbf, 0x03f7aca2, 0xbe4d3f0e, 0x863d698d,
	0xb34c6df2, 0xfa2710c5, 0x37ca4bfb, 0xd056f121, 0x5eca0ec3, 0xd9fa1447,
	0x17bef5ca, 0x8c1bbc79, 0x4e2e7203, 0xee726ef9, 0xb9cae5c2, 0x6b3821ff,
	0x76c96e72, 0xbdb3f182, 0xb9c990e9, 0x9ca8bb25, 0x991e8013, 0x87b25b9c,
	0x498fff30, 0x25ec8dbe, 0x2fd608df, 0x81f6b30f, 0xefc7b496, 0xf58dfda2,
	0xad1b5ec9, 0xde47b63f, 0xbbcbd38d, 0x790fa538, 0xe4f2f077, 0xef2e76dd,
	0x021b1ca8, 0x1f4cd5f2, 0x9c6356de, 0x27f1eef1, 0x7e065f1b, 0x73c44b79,
	0x7616c3ac, 0xf1bbf0ee, 0xbe813327, 0x143e610a, 0x4615138f, 0x41959d7f,
	0x6bca7fec, 0x4e657d6c, 0xde5c7f16, 0xf2c3f4cc, 0xd2a42146, 0xf84ce67f,
	0x17f98152, 0x324811ed, 0xb2b2cfcd, 0xed59e4fa, 0x48cc861c, 0xc2c3d1d7,
	0x1ff412ec, 0x0d88942f, 0xce25c3fc, 0xffa0d39c, 0x7f336496, 0x5eff0972,
	0x0d7da874, 0x368b55f8, 0xa70e7808, 0xf16a4dc5, 0xe3cebda3, 0x1fa0575b,
	0x3f2e7cd1, 0xcce3c793, 0xd5085e7c, 0x282b8947, 0x238a6cd9, 0x4b3cf4e4,
	0x9178476c, 0xa6ef45b7, 0xd5a3fc28, 0x41d386eb, 0x1106a70e, 0x386ed3f7,
	0x69a9b851, 0x3144e1bd, 0xa93d233d, 0x6f452e07, 0xf666f5d1, 0x6e0d5ebd,
	0x7e6b75e6, 0x4fde12d2, 0xe0d0705f, 0x1cfd6bdc, 0x402ed4ee, 0xc7866939,
	0x7fdba53c, 0x2ff1019a, 0xce506e94, 0x622b7f04, 0xa4ee44dc, 0x147b86e1,
	0x64fd388b, 0x029a4f54, 0x20b3e4c7, 0xe796995e, 0x237e2ed7, 0xdc63c295,
	0x6c2c7511, 0xb04ed7a7, 0x6f7ce1fa, 0x72823d8b, 0x5dc3a350, 0xc17f0e9c,
	0xbfddd9fb, 0x93da3262, 0xf407822d, 0x8ed84090, 0xb8500d70, 0x8096bdc2,
	0xa01bf0c4, 0x77fc08f4, 0x0ce7c360, 0x15047b8e, 0xda3908fc, 0xa178057e,
	0x195a33f5, 0x0121025e, 0x224992f1, 0xaf2fd7e8, 0x8061bc15, 0xc23d4b5f,
	0xf4cf934f, 0x49e3d4e7, 0x3452bf47, 0xba4ac5fa, 0xd784b2fd, 0xfead699b,
	0xccf3d003, 0x8f526567, 0x7dffa6e0, 0x225f3d1b, 0xa78cc4be, 0x5b5e1c9d,
	0x804e9e01, 0x5de9845b, 0x9ef12fe1, 0x901e568d, 0x4e780682, 0xb7e2e279,
	0x069c6bc2, 0x9063a02f, 0x2279ad6f, 0x045bf3e4, 0xf7ad2fd2, 0x4d9ce17a,
	0x7b45efcf, 0x9ffeb18e, 0xca24bc14, 0xae9b2fba, 0x42e7a0fb, 0x97e0b74a,
	0xcdae8bef, 0xf0a5da70, 0xcf4e3273, 0xde47b3bf, 0xde7a00cc, 0x939f2023,
	0x79c338d6, 0xd30afbd9, 0x29d8b623, 0x4775d3dd, 0x8ddec90e, 0xf0796f6a,
	0xb05f0e5b, 0x98f7f41f, 0x408582ae, 0x1b66e21c, 0x3ce191c6, 0x54fd3086,
	0xdab79f2f, 0x99ade249, 0x847ff77d, 0x7e97dff7, 0xc347e5a4, 0xdd971078,
	0xd91bc742, 0x7f799e33, 0x9705fcd0, 0x5cc7d75a, 0xebadfdce, 0xaef9c6d2,
	0xd2013671, 0xe2d57886, 0xfe098e6d, 0x73e83269, 0x18c905d3, 0x72e116b7,
	0xffeeefeb, 0xefb13943, 0x078a49fe, 0xe3dd69ef, 0x907bbed1, 0x843d733e,
	0x7c4d239f, 0x4ffdf60f, 0x2cbcec7c, 0x9dde42d3, 0x64c7fb08, 0x7d5d0099,
	0xfe8ca6f2, 0xb2a64fce, 0xde9bce78, 0xcb81203a, 0x6b1626e7, 0x271a6e45,
	0x18759da0, 0x7a0f1eba, 0x46f88db8, 0xe032fc20, 0x437a583e, 0xf29514f5,
	0xa1cdd8f5, 0x53bd482a, 0x03bf0922, 0x09124dbc, 0xd7cdade0, 0xe6938a6f,
	0xa498f9ef, 0xea8dab83, 0xec7ed807, 0xf5089241, 0xd112f826, 0xfcdf198c,
	0xd0b73be9, 0x537f8c79, 0xdeb4aaf4, 0x274e03ac, 0xc8f4faa1, 0xebf10b3a,
	0x848135e0, 0x34dfc0aa, 0x16efb8fe, 0xd5217798, 0x41fee077, 0x957d6b61,
	0x0275f21b, 0xfd040fb6, 0x9eba6e39, 0x73e7b5ad, 0x817207be, 0x026e83d6,
	0xa05eac75, 0xe842f041, 0xa3eb7e6b, 0xdf92b718, 0xb545e020, 0xd88121ad,
	0x1b21bf58, 0x1d6b77ed, 0xfb099f6d, 0xfd0f6d17, 0xe77f9c36, 0x743b9016,
	0x91bed89e, 0xd3e6f79d, 0x4bf02a76, 0xafec62c3, 0x70204ea8, 0x91b0a24f,
	0x6f854bed, 0x6f285eca, 0xf701b7de, 0xbc7419db, 0x87d834d4, 0xbef153c2,
	0xc1e08649, 0x838d787b, 0x45d7bfd0, 0xd2c8fe18, 0x098e4c81, 0x1eedcf3c,
	0xd67bef4d, 0x20f9043a, 0xe942bbdf, 0x5df9fb47, 0x059a6276, 0x9e3ceae9,
	0xf0a71ee3, 0x1f7853f6, 0x071071e6, 0xda523fb2, 0x6be2fb75, 0x07c8a1d6,
	0x61265b0b, 0x9222c07c, 0x3301f18b, 0xf37d33c7, 0x21ecebed, 0x2dbdf3f0,
	0xf7c20647, 0xf159d703, 0x2656e77b, 0xb5073b87, 0x64f75fa3, 0x7ee04c9d,
	0x889d5544, 0xa364e2f2, 0xc52ef78c, 0x78f9d927, 0x7fa656c1, 0xfd63a81c,
	0x0dbd049e, 0x4e50ebfc, 0xb45b05f3, 0xa72673f3, 0xdf33fb35, 0x35f5cec3,
	0xd7c65bb9, 0xaa1f6bdd, 0xc900a159, 0x196de59a, 0x24c5c797, 0x59b2f68c,
	0x79c196ee, 0xd2f81bad, 0x64e47f1c, 0x18ec18f2, 0x97f083a0, 0x6fe5d748,
	0x18ec04ca, 0x1c8ea3e1, 0x23da778c, 0x7c7c7fa0, 0xf383e0ab, 0xd623c2f2,
	0xa1dfea10, 0x06ff79bc, 0x56fbcbfb, 0x27b0a102, 0x4e540f00, 0x7f235b65,
	0x7efd05fa, 0x220db0fa, 0xe4dd284d, 0xf8b5dc21, 0x2c4dccd1, 0x70f3244e,
	0x13dc124d, 0xa1fb5325, 0x15a8281c, 0x27275f89, 0x5bbe0b4e, 0x83fb60ee,
	0x9a271f47, 0xc3e754a9, 0x95b9fafe, 0x937547c9, 0xe417b10c, 0xd3932b49,
	0xf8c03ed4, 0x8f5da2ce, 0x3a3a2926, 0x68f3da28, 0xafbf4892, 0x551671e1,
	0x76d2bfb0, 0xa71b0a45, 0xa9e0af68, 0xf5a38dd7, 0xecabf5a3, 0xee86ed62,
	0xfd5f6961, 0x70fcc117, 0x20299f9d, 0xf4fdcc2f, 0x7e8fbf1a, 0x62e3ffb2,
	0x95e7408d, 0x4188b6fd, 0xcd1fd9d0, 0x3f3faa18, 0xafcd52d0, 0x858ef59c,
	0xcbf074f8, 0xf10c53fe, 0x3cddf0e9, 0xc53df28e, 0x845a8fdf, 0xfc805d90,
	0x132ca531, 0xf3e01ef3, 0x2e7fee72, 0x85ceca9f, 0xaf0fd39a, 0x919fbe02,
	0x903d2029, 0x97e95fa0, 0x0a9afa80, 0x9905cc71, 0x6d017dac, 0xbcd8fc0f,
	0x9527f181, 0x91c82a13, 0x7347baf2, 0xa0837eb0, 0xf5cdff42, 0x148fa879,
	0xcb048b66, 0x7ea18e1b, 0x2c72d854, 0xf298f801, 0x03e80d6d, 0x1ead13e5,
	0x3f1ae390, 0x36fdfc6a, 0x36263b8f, 0xfb8868cf, 0x2f9801bf, 0x6f8b5f0a,
	0x681eb932, 0xc818fc64, 0xf6fafc66, 0x78561956, 0xfc8dfc39, 0xe333727c,
	0xdbc9f157, 0x759ee072, 0xcf7626c1, 0x14dd40fa, 0x93e9f405, 0x9bf70121,
	0xf4cdfcde, 0x577f3356, 0xfbdf6c09, 0xc6a5faae, 0xd31f1adf, 0xbc608fdf,
	0x70a7ca52, 0xd7cccf2f, 0x3fa6e533, 0x7be743dc, 0x3d740bd3, 0x7e53be74,
	0xaedddcb0, 0x9f349393, 0x897cf904, 0x726909c5, 0xf1624ca5, 0x7e79df64,
	0xac4bf1a6, 0x93c8ff46, 0x471638d6, 0xdd2320dd, 0x7b3f8a5f, 0xf265d9f1,
	0xd5f2e5e7, 0x1b53f8a5, 0xec63dc5f, 0x6f4e49e7, 0x293afee6, 0xae14c35c,
	0x1a7c69bf, 0x3dcf47e3, 0xe0266c77, 0xa53764a7, 0x46afa073, 0x9c830917,
	0x5fb84293, 0x3e8b3715, 0xc295af8c, 0xf4b8b759, 0x83e2cc7c, 0x21745e4a,
	0x64bf153d, 0xeda0cd0d, 0x347c778b, 0x5635e306, 0x29de3046, 0x97d71cf8,
	0x8063ed83, 0x16258a0f, 0x0b9664a7, 0xfd31b3df, 0x639763b9, 0xd84fac36,
	0x2825decc, 0xb65dba6e, 0x8625ceea, 0x971c64d8, 0xc3f3c3d6, 0xb863a520,
	0xd3f30a17, 0xe2d787df, 0x30b63a93, 0x22dc5139, 0xbc581da3, 0xc4275b79,
	0xb11f16a5, 0xb02bbfa2, 0xd9c63cf9, 0x2b71794f, 0x2d0253fa, 0xaddce1a2,
	0x66e03c57, 0x78856c31, 0x3c32e6b6, 0x63f9a427, 0x1e8a6f98, 0xb8a97b17,
	0xf71792b5, 0x105208ec, 0xacfcbc96, 0x99cbe41b, 0x806e4db6, 0x5bf7ed3b,
	0xc57b71e3, 0xf03d35ff, 0x677ff1ad, 0x71941fe0, 0x7a71b56e, 0x3727e2d7,
	0x923d43f7, 0x372b2fce, 0xb74739ca, 0xb3f5be5e, 0xbd3e20a7, 0x4fb3a5e3,
	0xbf4b7cc1, 0x8829e4fe, 0xed7b223b, 0x9e05dfb8, 0x7be3177b, 0xc6dde9bb,
	0x9e5b43fd, 0xcee8b8c5, 0xe85eadf7, 0xc9cf73ad, 0xd67710c1, 0x24cbedb9,
	0xdd2e5bf0, 0xbafd0d33, 0x494fb74b, 0x0bf65126, 0x0dba052d, 0xb65c465d,
	0x9a075f19, 0xd47c600f, 0x906f8a39, 0x9cf1dd7f, 0x3e2c654d, 0x9c71e556,
	0xdfe3d18d, 0x366dc57b, 0x75d372df, 0x999bf720, 0xf8c978fe, 0x1e2877cd,
	0xfc0cb9af, 0x817e6a35, 0x073bf8e8, 0x5a78a0ff, 0x67dfc26f, 0xfd7e8bcd,
	0xf7359404, 0x337e33eb, 0xd370197c, 0xd8e7ebe2, 0x80db8f7c, 0x1e7a5e6f,
	0x6f0165e3, 0x7fd85433, 0xf70c1b3e, 0x91c94e12, 0x6d6f78b9, 0x7103d58f,
	0xde7bc588, 0xdce9fe43, 0xd0fd187e, 0x77b9c784, 0x8b1fee92, 0x3af8164b,
	0xee2c5c1b, 0xe21fc393, 0x7e375542, 0x8c9ff1e7, 0xd0b8b58e, 0x7f41e2be,
	0xb67a6367, 0xd65ff716, 0xb38f01f0, 0x9097c1ec, 0xf63a780d, 0x1ab671ad,
	0x0e5c3c1c, 0x4737c4f7, 0x8eedbb8f, 0x02f8e783, 0xd43ec1fc, 0xf34cbf1d,
	0xdfa2c703, 0x45123de8, 0xb3d6741e, 0x394ee8b8, 0x2d537dfa, 0xcd90f9de,
	0xba1ce714, 0x4be738bc, 0xc2bbffcd, 0x7e5015e7, 0xa9c37b12, 0x72e8abe3,
	0xfdf383bc, 0xa65f7cdf, 0xc7df3054, 0x58f40b39, 0x014c7cd6, 0xcedbb83b,
	0xe0edebe6, 0xe78ef57e, 0x5d838c44, 0xe50074d3, 0x945e59b8, 0x511c3bc3,
	0x9f35fbe6, 0xdb0b796f, 0x725e3a27, 0x9fb49c85, 0x90bbfd8e, 0x8f1bcb9e,
	0x1bee1c61, 0xda565f9b, 0xb0117175, 0xf374844f, 0xdf6178ef, 0xfcdb9418,
	0x38f30fbd, 0xabf73b4e, 0x271f46b5, 0x30de78d0, 0x49b0494e, 0x3d2f38f1,
	0x77c919de, 0xa677f43b, 0x6783e98d, 0xd1e9c49a, 0xc1758bee, 0x5ce789be,
	0xfba52cd5, 0xe26bbe25, 0x8898ef62, 0x2fd418ee, 0x8fb2ba97, 0xaa4026c4,
	0xd5505c60, 0xf4471e0a, 0xe00a6f53, 0x2375cabb, 0x06aef981, 0x3cfceaf8,
	0x404fc7b2, 0x7253952f, 0x60afc133, 0x824a3796, 0xf8748485, 0x9e9aea5f,
	0x4779e2ac, 0xf3e02078, 0x1949fa68, 0xc98bfdfa, 0x8917f54f, 0xf3a649ac,
	0xf0504bfb, 0x92fda0ae, 0x941a3eaf, 0xbfddeaeb, 0x2fdff796, 0xe54afc1a,
	0xb051c8d6, 0x76abc84b, 0xf7106f8c, 0x88fdf1da, 0x5c7653c0, 0x5fed81ef,
	0xf5fa833c, 0x9d84adaf, 0x85eb50fb, 0x0f02abca, 0xf6e4e3eb, 0x2ffa9e2f,
	0x31a19fd0, 0x29e0bf1d, 0x86ec1f5a, 0x39da0746, 0x8ec52f5d, 0xc148bf01,
	0x04cdf7ab, 0x60e05679, 0x62f058f4, 0xf68aa872, 0xe5912277, 0x841d6c4f,
	0xbc9415ef, 0xc4f8c2e4, 0x9677db03, 0xf9d4bec3, 0xbec083a2, 0xd72af9d4,
	0xefe79ff3, 0xaacad51f, 0x88b94e3e, 0x9efeaa48, 0x59e40948, 0xc137de39,
	0x23e7165f, 0xc4b557f0, 0xaa12fde2, 0x39fa1aff, 0xf5ee4727, 0xfb071d22,
	0xe1357bb3, 0xcc0f20fe, 0xdbf2b4f5, 0x06ce4cec, 0xb39db4ac, 0x89407ea7,
	0x757cb3e4, 0xda4f267f, 0x3b7cfeb0, 0xf2b573b3, 0xfab2fdde, 0xeedfad7e,
	0x72fb587e, 0x9989befe, 0xbf78cb7e, 0x7aff9b25, 0x3bf7b465, 0xbf1fcca2,
	0x412044ff, 0xdb29e80b, 0x12aef8ec, 0xb887cfdc, 0x3b0a1df8, 0x87752ad7,
	0xdd94fdf1, 0xc6971e5c, 0x973df184, 0x501e7cfe, 0xd6c4f21f, 0xcbbe02fe,
	0xe04ed3b5, 0x57b29f7d, 0x77c03e5d, 0x4e2f8ed9, 0xe2132afc, 0x7f181cdf,
	0xbfeaf65d, 0x59941d22, 0x1f8173c3, 0x64acdb22, 0xb6f9f023, 0x5f818343,
	0xe0f0e43b, 0xaf396ff8, 0x1ab26b2b, 0x75f395ef, 0xbdaca99c, 0x6b51ee16,
	0xfb8b35f7, 0xd86f3390, 0x9fd6bdd9, 0x76d57ddb, 0x3be377e4, 0x672a6741,
	0x7dfdc067, 0x2db17ead, 0xb06c5cba, 0x1c9f7fcb, 0xf7baf677, 0x39f300d8,
	0xc092da47, 0xf54e53ef, 0xc5e7906e, 0x8206d39b, 0x5dbf609f, 0xc6aedfbb,
	0x5fb47ec2, 0x869ed156, 0x9ccfbf54, 0x4866f4aa, 0x337fc0c3, 0xeba24332,
	0x9f3faae8, 0xbc409fdf, 0x34767da2, 0xeec3b7b9, 0xb629ba40, 0xeed17d59,
	0x72e01e4d, 0xfd181379, 0xc078d8e3, 0xfbb8da1f, 0xe1ca10e5, 0xd62a3149,
	0x1176a62b, 0x3cd92f7c, 0xaef0c327, 0xf58d5487, 0x3c229f28, 0x928d488b,
	0xdadf93a9, 0x32cb4578, 0xf80ca433, 0x3767fd2e, 0x783d8abd, 0xd404c126,
	0x630e250b, 0xb86a9352, 0xb9c92087, 0x429f8036, 0x08923d72, 0xfc8d52a4,
	0x309a431e, 0x8b755275, 0x41557fbd, 0xe29e4e40, 0xefe0f6e7, 0x5e07b482,
	0x07ee51cb, 0x3c321107, 0x5019de0d, 0xf83a3d63, 0xecddd9b5, 0x82a93a9d,
	0xc3317930, 0x1088fa03, 0x286f93f4, 0x4e55553d, 0xa47a00cf, 0x6fdc1f3f,
	0xce83d343, 0xe379edcf, 0x2883d04b, 0xe277b29d, 0x5542407e, 0x7610c414,
	0xc9d57e8a, 0xb66fbd84, 0xdbd108ee, 0x3c719f1b, 0x943ee090, 0xf3d24e63,
	0x883cd08b, 0x55b79055, 0xc3675fb1, 0x43d3a239, 0x3a17a0c2, 0xa0ec249c,
	0x749473a9, 0xeeffcf46, 0xd1d79a4c, 0xb1a267a9, 0x5417ccdc, 0x6dc699ae,
	0x7ed1f842, 0xfbf5353f, 0x4fdfa9a9, 0x0d5fadbf, 0x46db014e, 0xb07fbc2f,
	0xc39732ba, 0xe3678d8d, 0x19f0a370, 0x11b3ef09, 0x9f978c4b, 0x635c2387,
	0x50ac6cf8, 0x3b35e29f, 0xf4e10d26, 0x11bdd8b3, 0x0925b788, 0xdeec04b5,
	0xa7db0255, 0xa9d72fe9, 0x363c476b, 0xf807c3e4, 0x4c31d938, 0xe2f76a8e,
	0xa3b7d77b, 0xbeabd5fe, 0x31faafbd, 0xfabbebd1, 0xfa238f9a, 0xe8fae27c,
	0xb511dabf, 0x972aefff, 0xef7d5fca, 0xdb6e7077, 0x143c9f2d, 0x333d46f4,
	0xccf4063b, 0xb75f13b8, 0x67a617e3, 0xf11a06da, 0x4df4031d, 0x98662de9,
	0x4e99bbf1, 0x3cafa2fa, 0x779a0ebe, 0xdc3852a6, 0xda9fc7c1, 0xefbdcec0,
	0x74fcca5a, 0x41f43cd4, 0xfd793bfd, 0xe8056c3b, 0xdfc6386f, 0x96abba81,
	0xdd7791e9, 0x74f9e22f, 0xe08e77af, 0xeedf941f, 0xc284265e, 0x6dded169,
	0x0f700d22, 0xdf1f1e6b, 0x9f920efc, 0xc4eb39a8, 0x3120ef68, 0x6feed4ba,
	0x583fdf99, 0xfbf97248, 0x7befc656, 0xf96e9eec, 0x67aa3d59, 0x4a3e0b1f,
	0x4ff41ee9, 0x2e70f74a, 0x3092d70f, 0xb0adc42e, 0x41b690b8, 0xc9a69e78,
	0xd5230bbf, 0x89afd858, 0xeefb306f, 0x8c97df61, 0x74e39357, 0x18ba5df2,
	0xa6077863, 0x80a6f64a, 0x5e2f937c, 0x2a6a544d, 0x5248d42b, 0x6f54e575,
	0xf087e645, 0x2953944d, 0xa2e40852, 0x0525c9e4, 0x8ccaf7a0, 0x4afab59e,
	0x7addd5c2, 0xfff4dbe6, 0xa444988a, 0xd58b25cb, 0x21e71864, 0xf80aee47,
	0xbdb3ba24, 0x7a6f677e, 0xeb656e08, 0xa77582ae, 0x954f5ef5, 0xbea2f5e2,
	0xddfba13d, 0x4fcc1b1c, 0xa9efaab4, 0x977fbf30, 0x7a5df809, 0x2a7bc7c3,
	0x842fcb44, 0x887c6006, 0x04633b18, 0x03bdaf8c, 0x0532aeb9, 0xf15767cf,
	0x555721f7, 0x83fcc48e, 0x35cefdfc, 0x1aa62a95, 0x6ade6cfc, 0x36d0b77c,
	0xf36ff58c, 0x5824fc70, 0xa8fc7c38, 0x2a52d95f, 0xeed0dcf0, 0x7bc308a9,
	0xdd206461, 0x9eda6057, 0xe29f846a, 0xa4b7e821, 0x856f31f5, 0xdae54d3c,
	0xc90f8851, 0x400a4153, 0x9ff872df, 0xabb43e07, 0x21ef0dfd, 0x7c86535a,
	0xdd87fbeb, 0xc981b4f4, 0x4f4e04d1, 0x2824f866, 0x8d507dec, 0xc3d2fa8e,
	0x6f5c78aa, 0xadff7f15, 0xa221de0a, 0xd2ac7970, 0x7f156987, 0xc28aa88f,
	0x98bde58f, 0xb33b7226, 0xcb1b32aa, 0x2efbe71f, 0x8d3007dd, 0x95f93077,
	0x27d8a960, 0x09e29c03, 0x04268ff3, 0xc22cc0c9, 0x97e14842, 0xe42a2412,
	0xd54673b5, 0x47a21f48, 0xa763bd32, 0xaa780e3e, 0xc05b2439, 0xbb2e2ecf,
	0x54bf70d1, 0x038bed9c, 0xf4e89bbf, 0xfe7fb00b, 0xe74cf00c, 0x279d28f7,
	0xe9cadbbe, 0x83a73563, 0x1e3e9cb5, 0xe9a17a00, 0x1e4e9c43, 0x7c84eba1,
	0x43dd9795, 0xc59d3f58, 0x5ba425cb, 0x616e3bf8, 0x8b478fa2, 0x851136f3,
	0x687513ae, 0xa77c5315, 0x22b11c8f, 0x114638fd, 0x47e5089f, 0x3bd88796,
	0xb0a9b99a, 0xef69c6ef, 0xe3544e66, 0xdac5e0e6, 0xb3dfc4b0, 0xd2dd9913,
	0xca7df516, 0x1b7eef2a, 0xcd7dffd8, 0xa5f5e1c7, 0x39e3a6ad, 0xafa85d6a,
	0xcee7f3f7, 0xcef34459, 0x13bfaa5a, 0xea746728, 0xd02ef3a4, 0x0fa387d1,
	0xe39d41ff, 0xcf81af86, 0x8b0d81bf, 0xb5e7f5e2, 0x5f00ed43, 0xfc156b0a,
	0xb9c98f24, 0x1e0f20a9, 0xefee8b8b, 0xf4c31d39, 0xd5e6776c, 0x91aefa06,
	0x33ced87d, 0x0f81ac71, 0x8a1cb86a, 0xf0c13a9f, 0xff3b935d, 0xc87bfbc1,
	0xd0778fe1, 0x9c5d24f9, 0x709c7c8a, 0x54397473, 0x78412b25, 0x346aa05f,
	0x3cc17b93, 0xbd67e985, 0x7f410ae4, 0x88ff05fb, 0xd167e08d, 0x61256be8,
	0x98482c72, 0xebada2de, 0x28ef4097, 0xf7483c6f, 0x680f80ab, 0x20a61c5e,
	0x65dd24dd, 0x0d773b41, 0x3907b3e7, 0x7ce7ad7f, 0xd5f030f5, 0xd6c77808,
	0x39cfe98b, 0xff00d53f, 0x48e7d4d1, 0xfe0c7e63, 0x2fa6913e, 0xc58db4af,
	0x9caae8f7, 0xd24b9416, 0x1390d6fb, 0xe37dcff4, 0x105fe03d, 0xbf1e995d,
	0x6d33ca0b, 0x8867383e, 0xbd00f4cb, 0x785aee7c, 0x51c5b7c5, 0x5df111d2,
	0x7e664954, 0x2e424f2f, 0x9e1470f9, 0x68fde082, 0x013373d9, 0x09e3e83f,
	0xf3807615, 0x87660e35, 0x2165e6d5, 0xa63e29dc, 0x31e77439, 0xec6fb3c9,
	0xba0c4f7e, 0x7b8fbc7f, 0x5c1cb3d6, 0x24181e2f, 0xa1f274c3, 0x4757bf96,
	0xa91920d4, 0x872b1393, 0x1ff010e7, 0x7d0f96f5, 0x4c4dcbc8, 0x7c09565e,
	0x5de1321f, 0x7934f7db, 0xfbde0129, 0xeae79ef5, 0xee1ba62b, 0xde5cc987,
	0x3b15eb9b, 0x86b63d98, 0xa17e2378, 0x53853977, 0x2f6743b1, 0x76370929,
	0x8c3fc3db, 0x5cb30eb2, 0x25fb053c, 0x8fc91ac8, 0x542c9aef, 0x83c7c7d4,
	0x8b2df9bc, 0x9f4be9af, 0xb82bc6d0, 0x417a8858, 0xdc6cc5fe, 0xa76b0a97,
	0xf010ff23, 0xb0ecebf6, 0x713f7593, 0xd64f5e03, 0x3ad7f3f2, 0x2f710439,
	0xf7de36fb, 0xcf0a1cf0, 0x78894f85, 0x00f70afe, 0x04fc5d44, 0x0f5154c9,
	0x3b75ded4, 0xadc7ba19, 0xffcf273f, 0xfa07dd85, 0x98745f65, 0x3fdd175f,
	0x04ff0550, 0x477896bd, 0xf54ade82, 0xf4184887, 0xf1db9f8b, 0x1f2d0bbd,
	0xfa88e8dc, 0x63a9558e, 0xf70023da, 0x71ef8752, 0x1e338948, 0xe6fa03cf,
	0x09ee3607, 0x39c2c9f0, 0x8e3c13dc, 0x967dc297, 0xcec73fc1, 0x7f704ee1,
	0x51f5b10b, 0xd5cbc31e, 0x2cddca3e, 0xa278865e, 0x7ecdff97, 0xecbd518a,
	0xa7c05d80, 0xd767b565, 0x8c5f8fbc, 0xdcd3e6fe, 0xd1b85d8e, 0x45195a11,
	0xefc858bf, 0xe7e42e39, 0x9d7d1a29, 0x18e3d6ee, 0x9dc3765d, 0x97d219d2,
	0x67858e89, 0x7edd2347, 0xff465072, 0x75ecf0a0, 0xf94c9ef8, 0xa5103a45,
	0xfbd152cb, 0x9191c408, 0xeba445b7, 0xc38d0e7b, 0xd30eb473, 0xb967963b,
	0xf9a5a1be, 0x7a0d8b17, 0x81687e6f, 0xfe417a02, 0x77a472c5, 0x7b84d788,
	0x7f9c84f5, 0xe9c4927d, 0x3fb40276, 0xed256d37, 0xf19da0b7, 0x2c189907,
	0xbd673f47, 0x30fe0bc3, 0x759c7d33, 0x47bf06a8, 0xf6297b41, 0x92419c4f,
	0x58378ba0, 0x2f6bdfc8, 0x6ddec8b8, 0x49209e24, 0xf2e17e01, 0x8dee87ac,
	0x5876f6ef, 0xd7983d18, 0xe75f15fb, 0x9debdd57, 0x7f7ac7d0, 0xf5cbd6c0,
	0x6cf6828c, 0x357ebad3, 0x7abada3e, 0xdb1133d6, 0x9677f297, 0xef0c2d4b,
	0x2770f95a, 0x4f4b5f1b, 0x1b86ce54, 0xbf88a442, 0xba1f9997, 0xa1f78147,
	0xe2e2ebf2, 0x0b3add05, 0xc434ef6a, 0xe6d7e4c5, 0x0560fbe1, 0x7cca7975,
	0x8dd4fedd, 0x0df3a0a7, 0xaf869e3d, 0x9e00e6b7, 0x71b91cea, 0x67cfe04e,
	0x857deeca, 0x6f0cbf40, 0x98e094a7, 0xf75b940a, 0xa3dda3b8, 0xe134ee19,
	0x6de396ad, 0xd28c9058, 0x5f0d31c9, 0x3627f6e6, 0xe70bdc95, 0xb03627eb,
	0x96fa50d7, 0x69f1d163, 0xc38fa386, 0xc70dd7cf, 0x75b71891, 0xcf7e3869,
	0x27d59f10, 0x35fe391c, 0xa9df6938, 0x89de375e, 0x9ef612e3, 0x65f66d60,
	0x7c67afc1, 0x14a71f46, 0x200d88df, 0x061ca91f, 0xccfd3d3e, 0xdbe8c6cf,
	0x4d263a95, 0xf5487183, 0xbdef9de5, 0x84cff0e2, 0xdec9c1fa, 0x73ca2a83,
	0xd7455bd1, 0x44fb145d, 0x6b571867, 0x57571fdc, 0xbf81d7aa, 0xd729da89,
	0xe657df81, 0x7d011afa, 0x4fbd8d2d, 0xacdded1f, 0x77a64ec5, 0x40acaeac,
	0x05b1317f, 0x92fc0789, 0x3925f184, 0x3bfe8195, 0x33d469c9, 0x01efd914,
	0xefc2a17f, 0x7f92cb61, 0xd8265a5d, 0x41e909d7, 0x4e037c1d, 0x4fad1fa6,
	0x3f01efd9, 0x0ff695b0, 0x40db037e, 0xdfc182e9, 0xb0b49af0, 0xed3ba51f,
	0xd218d459, 0xf40413e4, 0xf9305cbf, 0xe6182e5f, 0x6de74091, 0x708d27d8,
	0x3c6e6c91, 0xf70891b7, 0xd07871bb, 0xd787282f, 0xd2bc3972, 0x6dfdc6e1,
	0xb41615cd, 0x3fb86a4f, 0xc7e097ef, 0xe848b843, 0x21b0859f, 0xb2c4afa8,
	0xefc1d875, 0x10dd822b, 0x5e0bbcc6, 0x09f111d2, 0x71f20132, 0xdf201544,
	0x80d7848f, 0xa935dc1e, 0xeef85efd, 0x001ffbb5, 0xb53cfdbe, 0x7e00a8ed,
	0x95ff5cdc, 0x315ae700, 0xfad2ae98, 0xe92316bf, 0x2d306f50, 0xd2cf123a,
	0xdb8e202b, 0x621f3baf, 0xe4f694ef, 0x2bf9dec5, 0xf3a64996, 0xd4aeaf92,
	0xeedcff97, 0x547985ab, 0x3dbbd9d9, 0x28091f09, 0xfdbaaae7, 0xef78b9f4,
	0x8b2765e8, 0x00ba41db, 0xf4c83aba, 0x1a920b80, 0xbffe8f1b, 0x19af1991,
	0xe435e1e6, 0x35576e25, 0x74953a50, 0x24c312e7, 0x68e8059f, 0xaefd3578,
	0xfd14679f, 0xcf89de2d, 0x0f3d46f4, 0xc747e6d1, 0x2f157a45, 0xc67db0e6,
	0x05bb0f44, 0x9160ff36, 0x243fd995, 0xe75e0228, 0xad278468, 0xa238f962,
	0x78eed0fd, 0x93d3f35f, 0x61ef2c55, 0x767cc0b9, 0xcf9e682e, 0x6db5d69c,
	0xd39f1fe0, 0xce00ba9a, 0x5e14e689, 0xbba431f9, 0x077ec8e5, 0xb09f89c8,
	0x78ef4677, 0xb61935f7, 0x6cefedd0, 0x6fdcfbc4, 0x4b9c7e73, 0xdfe03222,
	0xf30a3c4f, 0x7bd887f3, 0xf3cbc41e, 0xcfd8324d, 0xb7438577, 0xeee688fd,
	0x23f42d7e, 0x1ee65f50, 0x680ebc8c, 0x727937f3, 0xb5ae97d0, 0xc1bef16b,
	0x375dacf2, 0xeffcec1c, 0x5c364890, 0x6dbacf57, 0x9d6d0708, 0xa3e226b4,
	0xddfc4e1b, 0xdd2e0d24, 0x79dc76eb, 0xfb2ff823, 0x6c736f92, 0x71663fa3,
	0x665e6cc5, 0x450a7d38, 0xc1fe3e54, 0xf20b3be9, 0xafa775ef, 0x5b52d203,
	0x0434b064, 0xf90226f9, 0x457fd172, 0xb9c38512, 0x132bfe41, 0xfd6d1e01,
	0x3d8f4b2e, 0xe0f2676a, 0x3f669a68, 0x6be8f7f0, 0x8f365e99, 0xed9adbd3,
	0x3efddf27, 0x621d13c4, 0x899540ef, 0xa1f74dea, 0xd1244e3f, 0x3d2d6af4,
	0x9b5fedca, 0x6ddfc2cb, 0x279ceb65, 0x6bcf7831, 0xa4bde076, 0xc344cb79,
	0x96f3d33b, 0x223f78b1, 0xd5b98db5, 0xe2aef7a0, 0x1fbbdd74, 0xfdcdcfb0,
	0x1936582c, 0x8a1db6ed, 0xebda1267, 0x5b3a314f, 0x4227d530, 0x7584f49c,
	0xc643fa02, 0xda5b571f, 0x28417e69, 0xbaec0bce, 0x0c92f960, 0xbca1ef78,
	0x92ebf98d, 0x3fe9c5c5, 0xfb63e9a5, 0xf90bfed9, 0xa72700c5, 0xfcea754f,
	0x45721ddb, 0xf9e807ba, 0xe40fa76e, 0xbeadde41, 0x9a9f01f7, 0x11e9aebd,
	0x0cbee93b, 0x77796f71, 0x1f40d9a9, 0x1f764d79, 0xc52236a6, 0x2796b950,
	0xc9a41b11, 0x90ec910a, 0xa41b10c6, 0x7bd92b59, 0xb3b5f9de, 0x67773f70,
	0xaef02ae7, 0xb3eb5e6f, 0x02fb419f, 0xd04fbc29, 0xeb5e53d1, 0xfef12fa1,
	0xe3172f90, 0x59b7bf1a, 0xa351d831, 0x6bf98c9b, 0xf4f98c5a, 0x719f31b0,
	0x0f5f98d0, 0x6f4e8eea, 0x9d87bfda, 0x659c97e7, 0xa15f21f7, 0x1e019030,
	0x1f28ad5b, 0x66b494a7, 0xd9f0f9c1, 0x28165c17, 0x6657fddf, 0xd8b64647,
	0x7db77df1, 0x31218c7f, 0xa2f8a710, 0x9f94237d, 0x02ca698d, 0x8fad193f,
	0x77741e71, 0xd076011d, 0x7a35ab8e, 0xc83c610d, 0x3c59af8e, 0x358b647f,
	0x67cee704, 0x02fb3d77, 0x2dd9e7d0, 0x7a3f5003, 0xa05a0845, 0x0c03e0df,
	0xdc6213ff, 0xb2553906, 0xce5f68d9, 0xabbd3171, 0x0f32b4eb, 0xd6571bfc,
	0x557dd71a, 0x73cf98c8, 0x9f353931, 0xc1a7bee8, 0x26baba79, 0xa7d9f605,
	0x927bd449, 0x9e2f9c85, 0xe8d14e7b, 0xb0efe456, 0xe7a93511, 0x9eeed77e,
	0x03a5ae73, 0x00951d28, 0x7cf4862c, 0xab8d312f, 0x62e19ff5, 0x3f0240fb,
	0x25bc885f, 0x54ce7c22, 0xc3ce1a16, 0x4ad8f5bb, 0x61d4ca6f, 0x76b13d3a,
	0xea1e525f, 0xe692fb8f, 0x2db7edeb, 0x84ee9207, 0x12cd9e78, 0xd2ab9dfe,
	0x3c3ccf39, 0x8bbe0121, 0x285f304d, 0xa3b21d07, 0xd43775e9, 0x58ea7aa3,
	0x414c7c7d, 0xa994b8ed, 0xaefd3e3a, 0x3efdd974, 0x67c187b7, 0x2dee7667,
	0x2ef8a23f, 0x50bd13a9, 0xb6e9a4ad, 0x700d197f, 0x3ef193af, 0x1936e96f,
	0xd40f8bdf, 0x8afe8b5f, 0x39c3c692, 0x86e12ef8, 0x2bcc2f3c, 0xe2b9224b,
	0xdc517458, 0xd6a9e90a, 0x5f9ef8ed, 0x146b9fc9, 0x1af98549, 0x1bd283e9,
	0x94d521f2, 0x1e066eb2, 0x38c0adf0, 0x19bbed5c, 0x632145ae, 0x5ebe337b,
	0x7f43f4e6, 0x3778f523, 0x2337ebd7, 0xa62f7f88, 0x4f951974, 0xf4a43b3a,
	0x01c63578, 0xe741c79a, 0x1dbcee94, 0xf91539f6, 0x7bf7ced1, 0x78b2d822,
	0x9650ec9c, 0x810577c7, 0x57fd60be, 0xdc2aa993, 0x4c99bce3, 0x2115f487,
	0x3228b0fc, 0xc7ff46be, 0x75f20756, 0x99fda787, 0x343d015f, 0x97f3c68e,
	0x6b5efcfe, 0xf7c61a87, 0x33bfb518, 0xf961e1d1, 0xc63b56e2, 0xa73d9c91,
	0x015bdca0, 0xff506bf1, 0x42c5bb05, 0xdbb3aef5, 0x78864dfa, 0xf6268ec8,
	0xa699ef4e, 0x6f95937e, 0xfccd47d9, 0xc76fedab, 0x1f749fe0, 0xfdf2e23c,
	0x8df60b87, 0x345e2c55, 0x7a455fb9, 0x693c1445, 0x8a9412ed, 0x2233b074,
	0x1bbd3b77, 0x26945e99, 0x05381fa1, 0xee3cfeed, 0x362cf8e7, 0x75fa1db7,
	0xfa3ebad1, 0x7141fc7f, 0x47d7d023, 0xcf5ef7a2, 0xc1739ed0, 0xbc7e9985,
	0x107f8b37, 0x40bf8e82, 0xea896122, 0x7f600bb1, 0x94798318, 0x04ea0b83,
	0xb85a9f8c, 0x781eb8de, 0xafbf5637, 0x265fc215, 0x30f10a1b, 0xd616984d,
	0x608bcb19, 0x9c63701f, 0x1409c60b, 0x09cb1837, 0xa77fa309, 0x6b1bf1b4,
	0x467db834, 0xfef9f5b4, 0x1f9065d3, 0x8f8fca32, 0x5f5c5cc5, 0x34a55809,
	0xb3ef83bd, 0x29d9e581, 0xb5da690b, 0xc2ca426c, 0xcbdfb80c, 0x156423f6,
	0xfef647e4, 0x1254c954, 0x03dec41e, 0x95cfb021, 0xd1e10ab4, 0xa091b790,
	0x0efb2c7b, 0xbac022ef, 0xb463f7f5, 0xf57ac375, 0x0c3bc9df, 0x2afddaaf,
	0xbcbeaf58, 0xb4a1c394, 0x33f06ad1, 0x8214684c, 0xdee06bae, 0x2bb63b46,
	0x6ac6fe6f, 0xa3ef97e8, 0x7625ff74, 0x8509af8a, 0xe62c22f5, 0x1c796eb1,
	0xfc5a2aba, 0xbf0e51fd, 0x4fcb6ec7, 0x047d7e05, 0x1cfec8f4, 0x3c84d9c0,
	0x02734208, 0x8e8d8443, 0x9dd19317, 0x95acf2c7, 0x773dff2c, 0x03b5f5e2,
	0xfb25dda9, 0x81645cf1, 0xdc06fb98, 0xf1ef5aeb, 0xe3a6e35f, 0x06f8b02c,
	0xbeb7c84b, 0x5bafe811, 0xf8f0e0c6, 0x2aab8ad8, 0x1ab7d8a2, 0x34297f7e,
	0x706579e1, 0x5d0fdb17, 0xef591199, 0xcdc1bd8f, 0xfeec51e4, 0x10cfbc76,
	0x3de02ed9, 0x31c20dca, 0xe1b867bc, 0xfd809506, 0x04f1429d, 0x408372f2,
	0x5ffbc156, 0x16b3cd99, 0xce780ebf, 0x39c2f18c, 0x24f35968, 0xeb89ccb1,
	0xa3937a67, 0x27ce1ea2, 0x1c8de792, 0xd74e740b, 0xfa66ef3d, 0x8ab726fd,
	0x193aa5e3, 0x065653de, 0x828c96d3, 0xbf1773f1, 0x3a387c0e, 0x26dfef06,
	0xe2b95853, 0xfa075d31, 0xdf490a50, 0x653d7207, 0x7c163a86, 0xd9b98fc1,
	0x71168938, 0xd7d02cde, 0xfc7cb2c6, 0x236f82fd, 0x38a3e112, 0x4c95b24e,
	0x77c2f987, 0xe06cefd0, 0xf0ea700f, 0x1d22a53d, 0xca1e4fc6, 0x8c2504d2,
	0x6a6f5171, 0xf1656f78, 0x043d4b49, 0x2fd2f4e5, 0x3d832527, 0x350766f6,
	0x7afca98c, 0x2f66a073, 0x4fa89d86, 0xeac91b0f, 0x697a7d73, 0x4ffb8b3a,
	0x31e9ac18, 0xec975eac, 0xb900cd8b, 0xd5e9987a, 0xe87d3a9f, 0x8956bd47,
	0x9cbc771e, 0x317029e3, 0xe7748486, 0x9fd98113, 0xb817bea3, 0xdd2126e8,
	0xd9ef013e, 0x4b57e3e9, 0xbbe3f70b, 0x0da465e2, 0x9acba0e3, 0xd7b6f18c,
	0x571f44c6, 0x45c0f3a3, 0x43f6090b, 0x76081e32, 0x64429bd4, 0xbc04a2cd,
	0xd9fe880f, 0x048545c0, 0x2e07e375, 0xddf31bc6, 0x7ec24cf3, 0x6311ea7a,
	0xb02f96bd, 0x776ec91e, 0x9e9d38c3, 0x0247dc76, 0xa76c2517, 0x215d37ed,
	0xfca6504b, 0xf2b2a9dc, 0xa4be7e2e, 0xebfad7d5, 0xfbf0ad9c, 0xe19dec3e,
	0x782a4a8e, 0x689e5c28, 0xd27e8f3d, 0x087dd6d2, 0x7a1e8d17, 0x4120e3e0,
	0xaa927c1d, 0xca16c2da, 0xfc3e2fdb, 0xaea3b5e3, 0xcfd8a8a2, 0x7b3838f9,
	0x40d28fad, 0xaea3bc12, 0x66476be3, 0x98a39f37, 0x7222cc79, 0xb59ce67f,
	0xf2ea0753, 0xfb777ebc, 0x43d71de0, 0xd628e679, 0x77c3d77e, 0x3a2566fe,
	0x5c79aa1f, 0xae706473, 0x99b7974b, 0x1f9a4ef2, 0x4c7bcbad, 0xf2a609e5,
	0x207e5314, 0x0ae1dfab, 0x84bd160f, 0xbcf0f6bc, 0xe5efe1eb, 0xe786a475,
	0xeb05cbc2, 0xc3d7f9c5, 0xcb2cc7df, 0xb1ef7f64, 0x0af055bc, 0xde59f93a,
	0xaedcbe7d, 0x7005182c, 0xe4037b68, 0xe08b6940, 0xd9dcfd01, 0x798c2db4,
	0xdaeaa768, 0xb03b3135, 0xb618e9b4, 0x91ffb3eb, 0x07e3e416, 0xf5887e47,
	0x422e752e, 0x5eff1866, 0x24e75f4c, 0x9fff04c7, 0xef3d89dc, 0x7b6c771b,
	0xf5efe7af, 0xa99defd1, 0x472803be, 0x035ff74d, 0x0f671f30, 0x7c70689f,
	0x7c05e470, 0xd183f1ef, 0x3a82efad, 0x7e7a58e0, 0x7f97e805, 0x0e393b2e,
	0x33782df4, 0x5f8df612, 0x60aba10a, 0xf8827a3f, 0xef7182af, 0x0fbe1b2e,
	0x2a3f209e, 0xef093fb7, 0xb91e3b01, 0xce897aef, 0x7daba8ef, 0x2449fc10,
	0x961aec57, 0x97c76c4f, 0xd7638a24, 0xf6a0fcb2, 0x8f9a1641, 0xf88edd8b,
	0xfdbc3a3a, 0x8f8fc849, 0x47e5927d, 0x3d120fb7, 0x753c4a60, 0x7f5a54fd,
	0xbf3a2793, 0x3d99625b, 0x31cfcda4, 0xd857f7cc, 0xdb29487f, 0xa57ae06f,
	0xb9d3ca8d, 0x6eb667c5, 0xfb98f0a2, 0x73940e6f, 0xb96e3a9b, 0xc1c9e991,
	0x4a9f885c, 0xfdc6f0e6, 0x84bae510, 0xec2a44fa, 0xf83df181, 0x536e0d74,
	0xbab8bf71, 0x0de81b62, 0xe14773c9, 0xe5d8717e, 0xec4d892b, 0x9a44a549,
	0xac5839c2, 0xd16dc987, 0xc9f5e782, 0x8f50b9f7, 0x0fbf847a, 0xe90ef94e,
	0x92f1c9c3, 0x66e4cb1c, 0xbfb32c72, 0x61a6ba2e, 0x7c147f3f, 0xa4226c1b,
	0xbf476824, 0x2bea0c58, 0xb953d677, 0x0d7ae542, 0xa3cd779f, 0xe1bfa157,
	0x8ef7f04e, 0xd4beef82, 0xfa3d51f8, 0xcd3a4d7f, 0xb3ec7b3b, 0x54be599a,
	0x4d6b79fd, 0xe4d72b3d, 0x6b1a4d56, 0xc957edaf, 0xe49c6c55, 0x08daae47,
	0x044870eb, 0xcd1756e3, 0x0571b11e, 0xe337ffee, 0x97cf897c, 0xf1f4f60a,
	0xd01621a2, 0x8cfc354b, 0x874be619, 0x39f83bf2, 0x6ea7868d, 0xd996397d,
	0xaa440b85, 0xe4be803f, 0x547f63f1, 0x0ec3189f, 0x513e99db, 0xf18cd742,
	0x44be1cd0, 0xdf071f6a, 0xe9c10fff, 0x7f4740c7, 0xd6fe9c37, 0x1c935873,
	0x18a6f2a2, 0xecb653e6, 0x0fdef1a4, 0x852ffb87, 0xa99c9cb0, 0x7e858f7b,
	0xd333fb07, 0xab1c5fed, 0xbdccc3f3, 0x4ef50caf, 0x7f8e3d6d, 0xfe1d39dd,
	0x3f99a6a6, 0xd1e17acd, 0xa3d6da3f, 0x4269503f, 0x46f47c79, 0x8e4ff782,
	0x34b0f7f2, 0xdfeb36bd, 0xfb04de4a, 0x22b1cfed, 0xc101e7c2, 0x78f00a97,
	0xdc03d280, 0x62ce0f5f, 0x7eda34f1, 0xda17135c, 0x70f40f90, 0x973c28db,
	0xae2c22ef, 0x81ccb826, 0xdae26af5, 0x19af3ed1, 0x4ce87aaf, 0x8f103e80,
	0xfa0a3991, 0x19d26a85, 0x5d14d59d, 0x2849f78d, 0xfdb104bd, 0x3577461c,
	0x17da08b3, 0x90527335, 0x6424ecde, 0x45f4f987, 0xcc55493f, 0xdf24468f,
	0x7ab9fd18, 0x8e07970b, 0xefedf6cc, 0xdebb1e81, 0xa02c7a8e, 0xaa4bcf12,
	0x94be7193, 0x2780420e, 0xbf6dd9a2, 0x883d0d48, 0xfd17a276, 0xbe5d6b01,
	0x4fff9c3c, 0xbfcc2a1d, 0xd9d64ece, 0x43f982c6, 0xe49ca156, 0x8fd521f3,
	0xe6857c63, 0xe14bfd67, 0x1fe81705, 0xfb76c62f, 0x9f607c03, 0x7cac27cf,
	0x638efdfe, 0xbfcd4f60, 0x4bafbd9f, 0x19f34dd6, 0x5ce83fcf, 0xce4fc093,
	0x1711b57f, 0xda1f8dd0, 0xffffa1b9, 0x23fdc174, 0x3eecfdff, 0xf6d2092f,
	0xefda7b23, 0x573efce7, 0x9527f364, 0xfbda350e, 0x7ef9fba8, 0xd3efe740,
	0x638da78f, 0x91da97ee, 0x145e0007, 0x67b861ee, 0xfb29f915, 0xf9e60e7b,
	0x87912826, 0x6e7cb4ec, 0x7f0718a5, 0xccbfde07, 0xe6d5eb85, 0x72392f3b,
	0x4c29fa1d, 0x94709ffd, 0x5c3f8167, 0xfdc87fb3, 0xe10ffb3a, 0x45e4f4a2,
	0x82208778, 0xefaf5476, 0xdb366edc, 0x6d7c849d, 0xbeebd7d5, 0xa60aa0b7,
	0x52ba73f9, 0xe6f00905, 0x8af9e7e7, 0xf20b9912, 0x0d6f3cca, 0x9cb9e79e,
	0x0cc2e8d1, 0xc07df3ef, 0x1f69413b, 0x97fafd04, 0xe64e1159, 0xf4fdb5fe,
	0x9fe53b71, 0x129f8878, 0x976b5e90, 0xec7f703b, 0xc19e47b2, 0xaf7b9d7b,
	0x16777c47, 0xdf70a8c5, 0xb6aa09e0, 0x5ec879e3, 0x35d21e76, 0xf0047da2,
	0xb35d2753, 0xf3a7e28f, 0x283eb12d, 0xfaa09368, 0x46e25bd1, 0x5dceffa0,
	0xff3f6037, 0x61bcd60d, 0x008000d0, 0x00000000, 0x00088b1f, 0x00000000,
	0x7dc5ff00, 0xd554780b, 0x733ef0b5, 0xcc923cce, 0x24c93324, 0x124fbc99,
	0x4e220108, 0xa07c0422, 0x35180843, 0xe2d101da, 0xf090e2e3, 0x44c93048,
	0xb578bd6d, 0x4844033f, 0x44683110, 0x8a1388a0, 0x06f6ad8a, 0xc134188b,
	0xb5b15141, 0xedaf42fd, 0x17e7ed15, 0x4ae3e221, 0x6c520232, 0xad6bfeb5,
	0x67324fbd, 0xbd2d2892, 0x3d3ef9bd, 0xd9f7b3ec, 0x5ed6b58f, 0x7fa7bdef,
	0x72ca9c65, 0xc633f319, 0x0cf0894c, 0x8b0575fc, 0xa198ec67, 0xa1f2c4c7,
	0x9e6669dc, 0xdf7f4642, 0xf0fd7fc2, 0x63094d5f, 0xc0434103, 0xb13c2178,
	0x81633262, 0x93e0b8ce, 0xd5f058b9, 0x0d632732, 0x75b2c4b7, 0x920d3c12,
	0x0df500c7, 0x570426cb, 0x858dd44b, 0xc75630a5, 0xd67a84bb, 0xe97f4124,
	0x28ec6b32, 0x82d1f2c2, 0x9d788b3b, 0xc76eed02, 0xeed4a87f, 0xabf304a0,
	0x91efacb3, 0x0ecc7e61, 0x32fd41ff, 0xbf7187ac, 0xa02bbfc5, 0xf9fffadd,
	0xb0dfe706, 0x196de607, 0xb3dd779a, 0x632c75fa, 0x9a7aa1a6, 0x64b18077,
	0xae60e2c6, 0xce567f38, 0xbe616382, 0xab8e5136, 0x08ca09e8, 0xec65e5a7,
	0x7d341258, 0xd7b677b5, 0xac1df58a, 0x4ffe9e0a, 0xf3082798, 0xfdaba4be,
	0xef680cb5, 0xc2c9e8a8, 0xdf97fae5, 0x45df5179, 0xb1907fd8, 0xbcf34329,
	0xcca36bb8, 0x7d1e34ac, 0xecf15307, 0xf1bb52b6, 0x7c882f73, 0x92efa2ae,
	0x386df20d, 0x4abe2f5e, 0xd278e043, 0x53671824, 0x1d619e6d, 0x814e2bcc,
	0xc5d73057, 0xac76e3ad, 0x0a7b3824, 0x7b18dae6, 0xe6dd9e34, 0x4bba7825,
	0x7adfd0bd, 0x3b6cd97b, 0x28ea97f4, 0xe64f619b, 0xb86d78e3, 0xc5d4587c,
	0x7e8bf343, 0xdad1f06a, 0x1637e6a5, 0x6f475a37, 0xb87134e7, 0x0424b785,
	0x147ce077, 0x7e4bca89, 0x475f6c63, 0x6e8853f3, 0x373c7cee, 0x61aff388,
	0x756f44ad, 0x3262682c, 0x40b0b3b4, 0x12c5d03c, 0xcf009668, 0x4ccd9ba5,
	0x6d5fc08d, 0x53ae5f50, 0x78a40742, 0xfa1e97a4, 0x515df6fe, 0x642ce5f5,
	0x0b7afa83, 0xb3e1c50b, 0xc0df5f43, 0xbfde82c2, 0x67be4735, 0xb7bd7c6d,
	0xca3bbc09, 0xd60fb283, 0xb18625bd, 0xd06c4498, 0xe4b9f84a, 0x67c276be,
	0xf7278942, 0xf857587e, 0x077ba32d, 0x0247edd0, 0xbe7c1a5f, 0x06bb284c,
	0x1b2b1ee1, 0x95e1fd68, 0xb01dc171, 0xab033efe, 0xe43ffc41, 0x85cdb760,
	0xd50aff67, 0x810c6635, 0x41d21269, 0xbdd79c34, 0x74835314, 0xa0ddaf73,
	0xddb72ba3, 0x35eff048, 0x4fdc1ab1, 0xbfa0aba5, 0x71fd88a2, 0xdf87d5a3,
	0xf44bb2ad, 0x7affe21d, 0x4d5b3fc4, 0xa47b61df, 0xf88bd8b3, 0x05aefb53,
	0x6cbd13db, 0xef854fe4, 0xb1b54dfb, 0x21bf88ed, 0xa230347a, 0x09af22c7,
	0xe092f4e1, 0x7c692f13, 0xf9ccc9a2, 0xb05f6284, 0x7d2fca1c, 0x075ee452,
	0x9e856270, 0x751f4885, 0x48aac59f, 0xfb3e871f, 0x83bf03f9, 0x989f93fa,
	0x2fd43354, 0x3c019a42, 0xfe7124bc, 0x9629b812, 0xeaef093d, 0xb8e31b60,
	0x05c77b75, 0x5eefd003, 0x7efd5328, 0x17538d1b, 0x18b2dbef, 0x3e7ba9fa,
	0xc9940dd9, 0x9f06365e, 0xbbeb0a79, 0x424fdc63, 0x9cb175bf, 0xca5eeb4e,
	0x89efefa0, 0xf88d3df1, 0x7f073749, 0x03e44bf1, 0x4fdd98af, 0x0b24e3c2,
	0x9ff9c12d, 0xb09188ec, 0x575c51dd, 0x4ea13c02, 0xc17575c2, 0xa5df7c78,
	0x8eef862d, 0x75f2a4b5, 0x7b1d3809, 0xf9d12270, 0x2f1f2326, 0xf6a24fb0,
	0xd9de8d47, 0xfa3e5069, 0x257bb142, 0x4d780d54, 0xa7d01321, 0xdfdba1ff,
	0xab189366, 0x11dba836, 0x1c7f6c4e, 0x87c357cd, 0x4ad2c37f, 0xbb2ff7ac,
	0x77e43aef, 0xe45beda3, 0x0f822cdf, 0x3670b3f6, 0x35ad8fee, 0x18211d79,
	0xbc6bbfb7, 0x175aa65b, 0xc3e81f20, 0x19f6dbce, 0xddc35c39, 0xe7bfda46,
	0x57ae3fda, 0x04f2e529, 0x9f03f1c7, 0x227eda65, 0x96511b3e, 0xfe032a47,
	0x97febd60, 0xd15e0952, 0x7cdb97f5, 0x357f9047, 0x0fe7fc3c, 0xc37c1396,
	0x6b58e7c4, 0x3eb3ed32, 0xd20167a3, 0x643ca3ad, 0xfba08aaa, 0x409f702f,
	0x97336a93, 0x4c858c33, 0x7d745df8, 0xee9e9969, 0xec5867b5, 0xe70f5b17,
	0x0debc3d7, 0x6f5d3f62, 0x0974b946, 0x41cb329f, 0xfec560b9, 0x92ffea55,
	0x6aa6424f, 0x17dce728, 0x4f112d32, 0xef0027dc, 0xddd60590, 0xfc46c5b7,
	0xfd80c100, 0x48c6992c, 0x59912dfe, 0xdf04a593, 0x80bd9dab, 0x382fe397,
	0x0d7d7d38, 0x2f780150, 0x999da264, 0x2f805b35, 0x8524d8bd, 0xe16ed02c,
	0x988ef366, 0x1ed7dc5c, 0x7cf886d9, 0xb4be225c, 0xc14669b0, 0xdb2f2816,
	0x3fe10173, 0xcba71a7e, 0xc9074165, 0xbf044bb9, 0x4d0736ab, 0x5f83ee0a,
	0x01f70c48, 0xfd84dff4, 0x6947c1d7, 0x80e1c325, 0x0f475a7c, 0x1e7288c1,
	0xf9c1dbf4, 0x3cfe0324, 0x21bcd788, 0x597c8dfe, 0x9bfb3df7, 0x011f4f59,
	0x9e10be4d, 0x73a9d160, 0xb3e2182e, 0x3378265f, 0xc6a7c41d, 0x017e22a4,
	0xed0e5c9f, 0xf5ae0896, 0x83e491ac, 0xc707d7c6, 0xb8e17215, 0xc7f2e01c,
	0xc59e91bc, 0x6f1a5c8e, 0xf920eb19, 0xd189c9a0, 0xf1d8a0e8, 0xe25074dd,
	0xeebea950, 0x0e9a1613, 0xc7ddd5e3, 0xf893f542, 0xe48936d3, 0x167b971d,
	0x19f0f72e, 0x2ff20e7b, 0xcb45de5a, 0x96b968b7, 0x4bf2e26a, 0x9fa6b3c3,
	0x72e4cea4, 0x82fb92fd, 0x9df58332, 0xc9bc79b5, 0x14f48653, 0x8b16bbff,
	0xbd96217a, 0x1dda0f2c, 0x2578cdb6, 0x57e3e005, 0x55f70798, 0x1da5c01c,
	0xc31e3fde, 0x2fffd802, 0xbbdd3852, 0x8d7e9c4c, 0x5b15978a, 0x213d2f11,
	0x9925e203, 0x351e91d9, 0x836e3e78, 0x3bf04aef, 0xbf066f2e, 0xd8a6b0b7,
	0x5ecbef88, 0x7abe218a, 0x682d9f66, 0x97c2fd26, 0x52fe80e3, 0xde9337de,
	0x8d92ffd9, 0x91bf63e4, 0xf680efcd, 0x892fd44e, 0x3e70d65e, 0x829d7880,
	0xc19654d4, 0xaba5f690, 0x6a059033, 0x83bd56fa, 0xf5c34deb, 0xdb9f511b,
	0x2ba72373, 0xf1fc8ab3, 0x6ef7a38c, 0x587cc32c, 0x08b7ca00, 0xccf7fb3c,
	0xde17be2c, 0x3756bdfb, 0x18afbe87, 0xff2cd5e9, 0xd00b46e8, 0xbef96cd7,
	0x8eb03df0, 0x1dab2cfa, 0xce795ce5, 0x1378fe9f, 0x63dd3f94, 0xf3c46664,
	0xb3e73393, 0x6ff9d1bc, 0xb478d06d, 0xdcbf6237, 0xae5f4bbe, 0xfd97d0ef,
	0x2af2fa9d, 0x7c79cd87, 0xf70ef122, 0x66d740b7, 0xed27e373, 0xcbf35f30,
	0x3f479266, 0xe2d6f874, 0x84306a7e, 0x9b3840df, 0xe49f3e73, 0xfae83a43,
	0x19a7c242, 0x88a7a768, 0xf5f71fc3, 0x39859899, 0x36e011f6, 0x31663f04,
	0xfb419c10, 0x73e24fe6, 0x9c4fb17e, 0x07a7cf26, 0xe64bfd60, 0xd157dac6,
	0x94e54f1b, 0x690fd452, 0xf9bfcc8e, 0x49a54faa, 0xf116aed4, 0xb40e7c7f,
	0x6cd57983, 0x8eb0f2e6, 0xbee3c4f5, 0xd23d006d, 0x223e2802, 0x537b70f0,
	0xff0434b8, 0x18ac4b6c, 0xbe54f38f, 0x1f48bc51, 0x08dfb16b, 0x1d3ff7bd,
	0xbedc0e5c, 0xa7dec62b, 0x5743a383, 0xd9a677f6, 0x9ff722fb, 0x532c3fe0,
	0x9bed2252, 0x7fdf250f, 0x2deafc22, 0x3019a6bd, 0x9cdf15fe, 0x74bf7e26,
	0x05d91579, 0x99b27a43, 0x7bd2d3f8, 0xb5fef47c, 0xa42e572d, 0x51896df5,
	0x1fc7ee11, 0x97de8897, 0x16835a66, 0x0e15e7f8, 0x852f3fae, 0x386924ef,
	0xf6e1a31c, 0x5d2bb6f1, 0x331f4748, 0x83a05e3e, 0xdb1f1feb, 0xbcf95e01,
	0x71f7f60d, 0x12e3e827, 0x4fcaf9c2, 0x7d2e2f91, 0x9ea3765c, 0xee6dbac0,
	0xb3cb0cb1, 0x62b62fc6, 0x6692a77f, 0xedb6fb40, 0xbd32ecb3, 0xdfc8bd97,
	0xb9ec0f40, 0xdb2bde02, 0x771e92a7, 0x9f3371f0, 0x14f2c3a7, 0x6f8ae3ae,
	0x8a57da64, 0xdf50f981, 0xc679336d, 0xb7567ee3, 0xf11b393d, 0x749cf1f2,
	0x4e7fb503, 0x87847662, 0xbe0a7963, 0x5e292a5f, 0x9b35bfdc, 0xf5232b6b,
	0x2643bf1d, 0xb9c8cefc, 0x4ad7a52f, 0x9446e9fb, 0xc38ff5a3, 0xe7f1c1fe,
	0x9bc7f7be, 0xe9fb919c, 0x886652ae, 0xb5db7ef8, 0x17f84f44, 0x152d7802,
	0x7ddf3af0, 0xf6d38e65, 0xf2016345, 0x1aaba5d1, 0xe823ec0b, 0x62fb8315,
	0xa787df1b, 0xd6fb121c, 0xa8947480, 0xb3461bb3, 0x0685acb3, 0x37162b92,
	0xcf093cf3, 0xd1733054, 0x2a25769e, 0x9a266f9c, 0x57ca3e08, 0x2dfaee77,
	0x8709ebac, 0xf7844a4f, 0x8c53cc39, 0xf6c35778, 0x11635032, 0xb177a4c4,
	0xc7ae666d, 0xde8f5c2a, 0x5a9ecc94, 0x3b5f6117, 0x17c07f45, 0xfe9fb162,
	0x81bf5f23, 0xfec86d70, 0x07ea127c, 0x4da7b3fe, 0xdad7ac2a, 0xb73f1125,
	0xe90cbdba, 0x8735dfc5, 0xe21a2a2d, 0x97377ec3, 0x5aebd113, 0x17edc898,
	0xfd4c33bf, 0xf7c4935c, 0xd3839b6f, 0xb1e5d6e7, 0x5bafe441, 0x9c18c19d,
	0x4fbbdff4, 0xd6a97d35, 0xd96cf1c2, 0x8c8f2bf9, 0xec941df4, 0xf2acb163,
	0xb35031fd, 0x38c32820, 0x0fccee9f, 0x0ccf7950, 0xd6750cb7, 0xce6b3f9d,
	0x1a753843, 0xeaded8dd, 0xf5c78dee, 0x58f3ba7d, 0x66afae3c, 0xaeeb4ca7,
	0xb2917e09, 0x2f8868b8, 0x15f24efc, 0x5d98bc23, 0x1af8e2b2, 0xe774f87f,
	0x564594a9, 0xfc93ff6e, 0x5c323c9c, 0x4a331d52, 0x570e0113, 0xf2f1ce5c,
	0x20e673d9, 0x62cfbdf2, 0xf045be40, 0x5c6ccfdb, 0x6a2455de, 0x36475af6,
	0xf2c19bca, 0xe40685ad, 0xf3b23f13, 0x1d4d3bf5, 0xff1fb8d9, 0xb3f7d247,
	0x82c0d9ac, 0x9b6bdbc0, 0x8fc03401, 0xc5e67b3e, 0x9ff7e46c, 0x7662f93e,
	0xa2fcc455, 0x739ed3bf, 0xd97d8513, 0x02c798fa, 0x6d3155e3, 0x8e2650bc,
	0x7f36e557, 0x3585fc88, 0xee0cf2cf, 0x8cfe3c9b, 0x7b36cf6c, 0xb80e0f88,
	0xa1d22acd, 0x4d40ddf6, 0xdbf507ac, 0xfe216601, 0x8725d557, 0xc79fd8cc,
	0x7689c633, 0x547df68c, 0x3d049bff, 0xf9129d49, 0xc28ae203, 0x61ff8fc4,
	0x7c04ef7e, 0xc07bf046, 0xf1225273, 0x191bf0fb, 0x84c3e88c, 0x58353370,
	0x294f9415, 0x857d39ab, 0xbb206c7f, 0xb2ee94ca, 0xa2bb3f22, 0x00c9b620,
	0x1b19d11b, 0x7e81893f, 0x485e9595, 0x9c6503ed, 0x8c2903ee, 0xac6967fc,
	0x6d7e2251, 0x4f7f25ef, 0x5f6634e6, 0x1217c507, 0x62ea9eb9, 0x3e72cdee,
	0x7f425de1, 0x4d0f068f, 0x20fd202e, 0xb24cfc7f, 0x5d48fd10, 0xb29de912,
	0xf60163a1, 0x3d3d1a3b, 0xd053e1ac, 0x5ff960d3, 0x34db4f44, 0x4f461dfa,
	0xc9e8953e, 0x9e991965, 0x5dfd8954, 0x8bc059ed, 0x80aa6bf6, 0xef8243d7,
	0xe16c7f84, 0x19002c7e, 0xf452b7ae, 0x86b16957, 0x6e1f9464, 0x11bde7e3,
	0xd036ccf6, 0x4a4ed17f, 0x9e1dfd43, 0xaa17ab19, 0xd3d63784, 0xb882fe8b,
	0x8f9216a9, 0x727a180f, 0x9d495f51, 0xe91bb8d0, 0x51417522, 0xffb26ac9,
	0x0f281d32, 0xdf92b650, 0xb7997966, 0x5f42292f, 0x4cf6e6e8, 0x7a1e3dc3,
	0xeb8bb33f, 0x2631fe07, 0x9dfd87d2, 0xdcf10052, 0x510535e0, 0xb8916a0f,
	0x60f0257f, 0x917e8a8c, 0x12ba8736, 0x27eda7e9, 0x46a03baa, 0xb77b73fa,
	0x56f48bdf, 0x47bf2563, 0x65b8239b, 0xa1bbb609, 0xfdedda88, 0x1fc7cc9b,
	0xb6fc68cb, 0xe3d20ee2, 0xb952aedb, 0xafe0457f, 0xcd278e6d, 0xb340fa81,
	0xb5b73f7e, 0xe112d27b, 0x000d80fd, 0xad55e303, 0xa43c218f, 0x2cce1ccb,
	0xcfe5c2c1, 0x7e40be70, 0x026994e3, 0x918fad31, 0xcfb833be, 0x39605381,
	0xe5b7d45d, 0x0f3038c2, 0x1737915b, 0x1b59ef35, 0x0b143e9f, 0x7e829af4,
	0x05946e37, 0x7f27ef50, 0x3b932f2f, 0x4c0351f8, 0x576b1d24, 0x2cbf2bae,
	0x0fda2ca2, 0xa6bf6f7d, 0xeee4933c, 0x1b4e3d60, 0xf656b1e4, 0xd6bcc0c4,
	0x15ea86da, 0x9d2d77d0, 0xb03eff12, 0x2059eaff, 0x6d2407a2, 0x1e2d95fc,
	0x30c5fff4, 0xf39178dd, 0x37faa253, 0x5556ff42, 0x62a3bf6b, 0x6f9818d6,
	0xbafe5689, 0x7bf303d9, 0x8fefa8c8, 0xc7be2a40, 0x1fde3682, 0xadd72b92,
	0x0bd21ccf, 0x25304f40, 0x07e90f25, 0x6cabdf6b, 0x8ac610bd, 0xa1329fb3,
	0xbce4d5dc, 0xfe9129df, 0x5d5fbd11, 0xfc3f9c49, 0x1d557cc3, 0x92bb47a6,
	0x3d1e90a6, 0xd824b71b, 0xfdb7c41f, 0xea1979f7, 0x648fa073, 0xf23e9126,
	0x5003f1f9, 0x2ff73fdf, 0xd8a8646f, 0xa8058eee, 0x2acffaf7, 0x5dfeb744,
	0xba025072, 0x02fd88b5, 0xfcfc9c72, 0xb32d3d1a, 0x04753a0b, 0xda2dc618,
	0x0129a5ba, 0xecc6afa2, 0x2b97001b, 0x68e33c93, 0x4657611c, 0xc493dbaf,
	0x617f07ed, 0xec0296d9, 0x50c4a77f, 0x7857584f, 0xd9116534, 0x2ca61f4d,
	0xb6aef88e, 0x678251f3, 0x88e32eed, 0x7124f470, 0xdf61b6fd, 0x1be41e0b,
	0xe225059f, 0xb04a3509, 0xd72812e5, 0x135018d4, 0x0b839364, 0xc5b8a26f,
	0x0b1b137c, 0x39402beb, 0x75d8f387, 0x5c12e07d, 0xc127fc37, 0x25deadab,
	0xceb74f24, 0xee2958b7, 0x07755853, 0xeb1ec1c1, 0x2bac3841, 0x71c34b2c,
	0xb6cce61a, 0xf403bc53, 0xb86fac38, 0x0bf266e7, 0xd75af369, 0x3d40ac69,
	0xb9f414a7, 0xb3bcc15f, 0x70aeaf12, 0x90ce3ec3, 0x05df1777, 0xf0a34de5,
	0x9c9df7f1, 0xde49378f, 0x93260fc0, 0xfa45941f, 0xb93a7335, 0xc93f38de,
	0xcf6bf3a4, 0xecfae24f, 0x999e8165, 0x95fb3e48, 0xa7d438de, 0x05f3ccfd,
	0x6bcccfda, 0x3c249f55, 0x5ce47e71, 0xcc7f92a1, 0xe07dece2, 0x4cbfac42,
	0x2985fb21, 0xb8e08fbd, 0xf74e2dfd, 0x01f6263a, 0x2229ef96, 0x24cde7bb,
	0x6fc462df, 0xfb53d0a9, 0x8c595df7, 0xef4d447e, 0x16d2796a, 0xd4fc855c,
	0x815c3ea6, 0x852bf4fc, 0x84b324f8, 0x3f42667b, 0xa44d7fb5, 0xf38a5f7e,
	0xb6bd2235, 0x905b04c4, 0x32ed020e, 0xb5ce73b5, 0x4f9fb084, 0xa3b5b29f,
	0xb674697e, 0x3063a432, 0x625fc857, 0x0a997a71, 0x858199e5, 0x22f2848a,
	0x89999f4a, 0x57b22afe, 0x2dafe49c, 0x2c63fb13, 0x0b71c150, 0x6fa6856d,
	0x9bf48693, 0x53cf5f43, 0xf7a6a5f0, 0x7fdc2c18, 0x963f3e5e, 0x4d6cf8e1,
	0xfa030df8, 0x0c3d9deb, 0x0efae0f5, 0x2fa9c689, 0x7684de7c, 0x7c1dedcb,
	0x9d85fb7f, 0x46cbf001, 0x2925a2bd, 0x4d97e84e, 0x7ac1cfdc, 0x3840c8de,
	0xc9f1cb3f, 0xf08bb418, 0xe1cec2af, 0x67f440fc, 0x7a867112, 0x490257e1,
	0x24fcf5c8, 0x255d6f4d, 0xfe568df4, 0x926ee314, 0xc2323c7a, 0xf9d258b3,
	0x2fe7b5c3, 0xaf09f7c4, 0xfee36786, 0xa17d030d, 0x348b697f, 0x61d78ee7,
	0x4ca65b7d, 0xe60aa370, 0x4b927202, 0x22903df0, 0xe7727dc0, 0x6e91b317,
	0xfda30558, 0x4339d0da, 0x78f2b7ae, 0xa90bea0c, 0x58ed8d71, 0x215b7a9f,
	0x8f8c67c9, 0xb7655c60, 0x959a6b80, 0xab5cebfb, 0xbf18b902, 0x7bd5784c,
	0xfe38ebc7, 0x6fe4b105, 0xd8dc054d, 0x8cd9e912, 0x2b172dfe, 0xd7f2803e,
	0xe096a955, 0x1d38b47c, 0x14e6f9c6, 0x72a71f11, 0xecf25ba2, 0x49cbe780,
	0xd8175a0e, 0x5f381577, 0x0eb41f7c, 0x6fd10dc5, 0x5c62e387, 0x69fd9f0e,
	0xfcfc8521, 0x449fcf20, 0xdb34ed3a, 0x9d955e11, 0xf28bbe6f, 0x3ac2d2b6,
	0xa51a8e28, 0x7f1cdcb7, 0xffa441fd, 0xb7c71381, 0xbaf38fdf, 0x47dbaf61,
	0x23ebd1f8, 0xf5ce5c57, 0x8c9ecff2, 0xdc8f5153, 0xe836f821, 0xf2fe3c8f,
	0xa323b71c, 0x93f7c8f5, 0x60e47af4, 0x47ae9ff9, 0x6005f9f2, 0xf0464f7e,
	0xfbb0bf77, 0xc64e6a06, 0x78fafca3, 0xff203e70, 0x94f4874b, 0x1f719daa,
	0xb41b3ee2, 0x11f4a22b, 0x7fc79da5, 0x7c49ac30, 0x711261d7, 0x216b8f2d,
	0x051c3ffa, 0x3d0e7fc4, 0xba401715, 0x4311d939, 0x30e2997a, 0x4d5e7085,
	0x0683982f, 0x80a0f909, 0x5788b757, 0x2c1c4499, 0x854540b1, 0x4bc9af62,
	0xbcf03f7c, 0xe2abc791, 0x053ccf83, 0x69fdbae5, 0xa8c59e22, 0x38bec0ff,
	0xac5d7782, 0xd7fd809a, 0x61893afd, 0xc6006a9c, 0x13df3c43, 0x539c93e3,
	0xfbc5ae30, 0x5598af67, 0x150b3f1e, 0xed0e0038, 0x1dffae41, 0x4c84342b,
	0xd476eeb0, 0xf5dfb017, 0xaf8b5c5a, 0x0cc1e073, 0x6541971e, 0x16b2ed04,
	0xd6aa2fee, 0xb9fb55e2, 0xc45aae1f, 0x5dcd8ea5, 0x468604f2, 0x0ac6a49a,
	0xacced3b4, 0xf3fe419b, 0x439e1fbb, 0xbd66eacf, 0xfa097fbf, 0xe287f3e7,
	0xbddf9ac1, 0x5c4db98a, 0x1ff21e7f, 0x519f401a, 0x9432959b, 0xbeccb99f,
	0x1a81e50a, 0x854dec00, 0x513c1367, 0xca009789, 0x71694ed0, 0xd7be22c6,
	0x6e481936, 0x1e0c9a05, 0xcbd1a76c, 0x672e4e05, 0x9d82a167, 0xc410244c,
	0x9367b471, 0x441bc451, 0x21992b7f, 0xc4834f84, 0x4aed6b9f, 0x5bf248c5,
	0xd8c9afeb, 0x7a819968, 0xfc819673, 0x9e4c67dd, 0x4e2fe4f9, 0x353c202c,
	0x2b9b1ad9, 0xa5ed3d78, 0x2f613133, 0xb8574fd5, 0x44d4c962, 0x4ef9a7e4,
	0x86885f1e, 0x7d56e2db, 0x530e3a39, 0xab97d41b, 0x5a5c6f99, 0x441b8f3e,
	0x7277cfbe, 0x5d66767e, 0xdbb780ae, 0x5b577c84, 0x0e4ccaff, 0x7f164337,
	0xcd9565e6, 0x73c83a47, 0x230f2898, 0xaafdc1cf, 0x7f9a12b0, 0x44a774de,
	0xdf3511f4, 0xa7a70726, 0x43f70b40, 0x8ff3bdfe, 0xceb5f79e, 0x3c372114,
	0x565b8c2e, 0x87144ddb, 0x497f573e, 0x97cf5383, 0x7cffcb06, 0xf3db96fb,
	0x97c8b22d, 0xaa5f13b1, 0x1cb5f3b2, 0x854fdc93, 0xf415bdf0, 0x8b475c06,
	0x647c825c, 0x5a56f5e6, 0xe07ec347, 0xbac71823, 0xe51b37af, 0x6f59437a,
	0xa26bc601, 0x55b38be1, 0xed067e34, 0x8f609caa, 0xacd0dea0, 0x8f0dc78f,
	0x23567aaf, 0x70d4789f, 0x289bf76c, 0x90c776bf, 0x1d7f82fc, 0xdffee330,
	0xcd7c4b97, 0xe03df361, 0x3632fd44, 0x5ce9fdb4, 0x1eb863d4, 0x6e65df55,
	0xaab13d47, 0x87be2229, 0x8faf5bff, 0x44e6b1f7, 0x36b3bbf2, 0x6d9afbfd,
	0x8b0ddf51, 0x5e12b5ff, 0xe37c9936, 0x1c83bf71, 0x1383bca2, 0xf88606b5,
	0x4bdd96ad, 0x889d4850, 0x27e7ebd1, 0x3f5f1c6c, 0x85fa6a77, 0x3cf100bb,
	0x67861e58, 0xb9e20177, 0x917cc0da, 0x9e23d4fd, 0x0275bf01, 0x985e27cf,
	0xfe78805a, 0x02d4f77c, 0x6326f3c4, 0xcdf707ab, 0x97efbb7a, 0x59be9f08,
	0x30afd25e, 0xd1f7071f, 0x6863d2b9, 0x1e9c9e70, 0xf3cea343, 0x196fe39f,
	0x3dbe3e4d, 0x7cbd0f38, 0x4cd49a74, 0x165507e4, 0x49ca77f3, 0x9fd11bfc,
	0xff933167, 0xa7d7ff63, 0x463e5036, 0x89fa4c97, 0xc57edfd6, 0xd1fa8f97,
	0xee5d77fe, 0xff7a3480, 0xc73b0977, 0xf4016165, 0x817668b3, 0xf3465fa6,
	0xafb15ee3, 0xfcf4ecff, 0xb01fe920, 0x71ff354f, 0x0963688d, 0xef7ae29e,
	0xfdcdc94e, 0x4fe41dc7, 0x685ee86e, 0x27f17f47, 0x6e3fee41, 0xfc98a178,
	0xd7c1b5c7, 0xc61f9842, 0xda3b24ba, 0x3f3bb523, 0x003cc78c, 0x3b05eecd,
	0xf2938cf7, 0xeff6f46b, 0xf163c127, 0xf3003798, 0xb3f506be, 0x84d86738,
	0xf600df74, 0x3525831f, 0xb037e128, 0x232706df, 0xa77260bd, 0xe2d41ede,
	0x26bd5bbb, 0xbb5bbbe2, 0xebf220a4, 0x372f9314, 0xcb1ae513, 0x1b8f1fb4,
	0xb24a67da, 0x39393f27, 0x31eeae32, 0xf3581c61, 0x496ef53f, 0x35edfa20,
	0xf91d8f32, 0xe09b16d9, 0xb7f10a67, 0x8239b72f, 0x86f422eb, 0x4f5c832f,
	0xbbf2d5a8, 0x00521614, 0x79e64b5f, 0x91be208e, 0xf8a287df, 0x8b59647d,
	0x42cedfd7, 0x31ea9724, 0x79e449c3, 0x8e8bb645, 0x5c1c63e7, 0x2c6b0fd7,
	0x764fd156, 0x714dd5ab, 0xcd6fceae, 0xb700fafa, 0x2c3f619b, 0x5fa2192f,
	0xfd1a0f0d, 0xb47f0836, 0x1ae8e6bf, 0xa77f5fa4, 0xbafb4764, 0xb7e9cdce,
	0xf32fec0e, 0x9dfbe1a4, 0x46fd0075, 0xf6d1bbf0, 0xbf5927bf, 0xffcb07ff,
	0x35eb7f22, 0x58bd7ac9, 0xbfe6bf5b, 0x97675c1f, 0xd465f7c4, 0xd6eda2ba,
	0x66bbbf68, 0x3f2b9e77, 0x47828aac, 0x3c32ffd5, 0x0d87e346, 0x43f1a3c9,
	0xefe35c7d, 0xcbff87e6, 0xba278df1, 0x00378b1f, 0x0dcda8ab, 0xe75eb8b8,
	0x678bc5d1, 0x8f0f56cb, 0x9f3cca9b, 0xaeee3a22, 0x777116ce, 0x7b5f9fbe,
	0xd57c2641, 0x7d70f88b, 0x4d8dcdb7, 0x294bac6b, 0x3f1d1b3e, 0xcf76c65d,
	0xc7451446, 0x1f70eb51, 0x3c7f7fe7, 0xc1e4b1f5, 0xcc5c853c, 0xd3ce8853,
	0x2a7acd7a, 0xef8117c9, 0x043022b2, 0x8b6ba046, 0x11896012, 0xe64c9fef,
	0x226bf4fa, 0x6265c89f, 0xf2a798cd, 0x83ce2d90, 0xc0cb8c76, 0x26569df3,
	0x7e469f79, 0x3c055168, 0x1990fdf7, 0x184f2e00, 0x049f883b, 0xe46eadea,
	0x471f9a7f, 0xfc20dfeb, 0xe74ae711, 0xf9d144af, 0x7de2ff2b, 0xefb696ff,
	0xddb8deff, 0x6e8d8066, 0xdfa2303f, 0x94ce31b7, 0x476e9c3b, 0xfa3467eb,
	0xf7b253fd, 0x7eb993bf, 0x95f2893f, 0xc4bf91cf, 0x431f0e4d, 0x63db117f,
	0x89bfd156, 0x8b9212fe, 0xbd84d3eb, 0x439d2eee, 0x52eed679, 0x00fb17cc,
	0xe8f179ff, 0x41c9e3fa, 0xf1fd70fc, 0xf9f8a8e4, 0x65c7f4c7, 0x5c69ef76,
	0x4f0cdf67, 0xb5b7ca01, 0xda3f9836, 0x3cf0cf85, 0x9c316da3, 0x9c49b73e,
	0xa4f2d92e, 0xc4bbf273, 0x9bede8a6, 0x98bff2c1, 0xfca4a67f, 0x5fe7f8ab,
	0x3a8fd1e2, 0x91013f7a, 0x11e3d9ef, 0x23b634f1, 0xefedbfc2, 0xe37af9e1,
	0xf7b49c04, 0x771fd8b2, 0x310a78a6, 0x23f3edef, 0x004b0b16, 0xe7326795,
	0x2b5e0d8b, 0x3a1a17c5, 0xc34bde78, 0x77f88c7d, 0x514ffa03, 0x61ce747e,
	0xe13defa8, 0x4ca495f0, 0x358ab8c1, 0xdfa02720, 0xfd432e7d, 0x2f08ffae,
	0x2be1d0ff, 0x7dff7ac5, 0x68cf14bd, 0xe519fb9b, 0x7b7e955d, 0x64c54d6a,
	0x11f92f9a, 0x559f229c, 0x14c2df9b, 0x9ed07f1e, 0xede1060b, 0xe7febf21,
	0xdb3f3c35, 0xd1d8f4ef, 0xc5f9a11f, 0xf21ed4e3, 0xe1ec3533, 0xcca95b4a,
	0xcdeec3d7, 0xd86a7a24, 0xfd18a333, 0xa623aca7, 0xd2dcf518, 0xef64adf7,
	0x3a4f7e7d, 0x99bc49e5, 0xe116bbe4, 0xbc1c9b61, 0x1cd2f50a, 0xddf50718,
	0x555f77cf, 0xf8d6f38c, 0x9ff426df, 0x364dfb43, 0x599c5fbd, 0xed7cde78,
	0xff9a19d3, 0x6fec46fc, 0xcc87d893, 0x673a5ada, 0xedaf7d84, 0x40d954f7,
	0x62dea7fd, 0xc6b938a1, 0x9919360f, 0xc43f92cf, 0x7c8ba647, 0xe453bf42,
	0xe1cd7633, 0x6ca229f9, 0x3af3ea75, 0x359cecff, 0x3d30f11d, 0xbcbf3945,
	0x3cb0eb30, 0xf317ea01, 0x073ed0c2, 0x259f928c, 0x9fd72cee, 0xa226ecf3,
	0x37ec1b23, 0x1d00cf8a, 0x597f1ea1, 0x026667b8, 0x5b4c73ac, 0xef8432e8,
	0xc206b3fe, 0x6de73293, 0x4824cf8a, 0xf5fcbc7c, 0xd0e32dbd, 0x677f62ff,
	0x6d52a23a, 0xa86197b5, 0x378709ef, 0xf4fe4290, 0xaf1c42c6, 0x9e460fec,
	0x471dd947, 0xecb6857e, 0xeca3ca3a, 0x3baccf7f, 0x0cfd1357, 0x379455b0,
	0x5ff9d799, 0xedb02714, 0x87cc4691, 0x958a69fd, 0x3d02afc7, 0xe6b729b3,
	0x57f12732, 0x8a7dfba5, 0x0a2d2b4f, 0x64d61e72, 0x906218f4, 0xe464ad7f,
	0x66db1ce7, 0x72be2037, 0xc0cc5e44, 0xf24ebffe, 0xc5a29d91, 0xaf3c8205,
	0x06bbd8c9, 0x65652fed, 0xc401e5ef, 0xa1871ec7, 0x0bfb08a1, 0xa59f9037,
	0x9f218e3b, 0x5fcce9cf, 0x73942975, 0x0714ed9a, 0xf6e9781b, 0xc2abf21c,
	0xb08ec73a, 0x9e14a6ce, 0xc774a487, 0x298e5019, 0x471b991b, 0x65291c55,
	0xa147ef34, 0xbffcfd0c, 0x5a674e14, 0x4ffd14dc, 0x4cee9f28, 0xfd2075f1,
	0x5a279e0e, 0x13cfcb1e, 0x624fdc29, 0x73defe5b, 0xbb674e78, 0xeaf1a738,
	0xc97389fe, 0x48a2d7df, 0x0e338788, 0x25d9479e, 0xf870f1f6, 0xaaf94abf,
	0xc5ffdd79, 0x01cc19e5, 0x9c8c57fb, 0x6716945e, 0x0f15fa3b, 0x9f947cdb,
	0x2429bd3b, 0xdeccdc53, 0x1a8548f7, 0xe66cdf61, 0x1761a5f2, 0xeda3c7b7,
	0x2b93ef99, 0x2fe4187f, 0x960cae5c, 0x4afa45ff, 0xf93c946f, 0xa614edbb,
	0xf5a2efb7, 0x6e7b6896, 0xd51dfe98, 0x8bfa68df, 0x36528796, 0xa3d70e34,
	0x147e9a6d, 0x94e9e5d0, 0xccb8f959, 0x477fefa2, 0x2ff79da2, 0x565276f2,
	0x3f312bab, 0x4613fc3f, 0x7f2d3a7e, 0xf3c65028, 0xe006027c, 0x6f18b987,
	0xa1bca56a, 0x2492160c, 0x32f5a3f2, 0xf3152efc, 0x13bbe087, 0xc7047929,
	0x59bb99c7, 0x4aa97e26, 0xcc18ef38, 0xd53ca13b, 0x382596e0, 0x1a560dce,
	0x4ef30627, 0x01d4c22e, 0xafe416cf, 0x5c786b33, 0x30e41d21, 0x18fa6fd2,
	0xf331874e, 0x9689fe79, 0x83e5a25f, 0x13287068, 0xb71f4df0, 0x60f91724,
	0x067be48b, 0x89169ef5, 0x20f027c3, 0x39b42bf7, 0x7286af40, 0xca04ed5b,
	0xbc601bff, 0x818d40ff, 0x0fcb52e8, 0xf2ab1b6c, 0xe37f4073, 0x8adae5e7,
	0xb0c9be79, 0xb82894bc, 0x9929796a, 0xa9b1bef1, 0x11e743c9, 0x8d123cb5,
	0x17f0224e, 0xb6f18188, 0xbe7d7376, 0xeb44c6ac, 0x9abda818, 0xb50391fc,
	0xbf728606, 0xe9cccbac, 0xadbc6a2e, 0x842c4df3, 0x18c12afd, 0xfe1a9fe4,
	0x059f4fbf, 0xbfa216bc, 0x1515d5f7, 0x8c01f517, 0xd2f0ae0f, 0xea462073,
	0x277f3190, 0x3880bc26, 0x35d76b95, 0x6798c5ca, 0x8096ce13, 0x1e5b6c64,
	0x2e4054a9, 0x3f87240c, 0xe6c672c0, 0x1b1e5e6e, 0xfb412ede, 0x25655762,
	0x4c5a47b5, 0x31fcac67, 0x7ac0654f, 0x6beef21e, 0xe1bf9d16, 0xb3d6b845,
	0xe43d35de, 0x6ef21227, 0xac87e732, 0x7ee41cdc, 0x65fc952a, 0x4972d387,
	0xe616b00f, 0xfac1e9ed, 0xd7f9334c, 0xfde89ea0, 0xbc19d8f0, 0x6778e55e,
	0xc79e3699, 0xc8037ac1, 0xcee70ecf, 0x3d753f20, 0xa7d007ee, 0x7cfab4be,
	0x13cf00a9, 0xb8ddcf52, 0xfacf0e0f, 0xefa422f7, 0x1def7b13, 0x4ae6fc83,
	0x23e9e813, 0x2e3397f0, 0x8c065fce, 0xfa0966d6, 0xabeac179, 0x1bbc75c5,
	0xa63660b7, 0x9a4fcf96, 0x04a3c261, 0xcc8cf02c, 0xbc0410b4, 0xfae3cc77,
	0x2bdca3a3, 0xeae81e61, 0x648f3e18, 0x7d21e29f, 0xba4f37c6, 0x5abfd601,
	0x530dfa12, 0x290ec813, 0xbcf01354, 0x37389d5f, 0x7cfd8b2a, 0x1946c771,
	0xafdfe7f5, 0x4552f778, 0x5f2e5d19, 0x686f651f, 0xbe54e6cf, 0x7ab2b98e,
	0x1ac7d201, 0xca9bf429, 0x4abdf18b, 0x2fc567ef, 0xd3f98c9f, 0x4e35c657,
	0xb0e9ff46, 0xbef009f7, 0xe66ca228, 0xe12ceaed, 0xd9e8056c, 0x8f5be31d,
	0xf0b33970, 0xff71bbc3, 0xf87e9dde, 0x385fcc03, 0x38fb146c, 0xc1fe124b,
	0x80f199b6, 0x1df237af, 0x42c2ff22, 0x1c637bf8, 0xe60e0ff7, 0x28978d97,
	0x1e72aedf, 0x0d79b73f, 0x85ea69eb, 0x0089c9ef, 0xe5a7b3f5, 0x29579e92,
	0xbf6621f2, 0x7b478deb, 0xc30ff67d, 0x3477e20a, 0x32e95cf8, 0xf411bdaa,
	0x2faa957a, 0x2fa8535f, 0x97d6eb5f, 0x9bed307f, 0x87e59171, 0x20cf3c63,
	0xf12cbd5d, 0xc5c0cc7c, 0xacfa4ecc, 0x7ea00a53, 0x74c5f131, 0xe795de71,
	0xd85cfe0d, 0x634e2f43, 0xcbb29f54, 0xf9f303b2, 0x2cb2bf35, 0x98ba27ea,
	0xe0912725, 0x2c28f241, 0x2743fc89, 0xded85ac5, 0xbfdcec3b, 0xd04d6d0a,
	0x2a85decf, 0xac5365c5, 0xee397606, 0xda16c987, 0x9619a50f, 0x579fa458,
	0xe769fd05, 0x2c7a3597, 0xf3179855, 0x79e86020, 0xb46c3cf8, 0x723f401f,
	0xe74653e0, 0xa19b18bd, 0x18a43e50, 0x5495b18b, 0xf9d04c7e, 0xfe9f1aab,
	0x7df84289, 0x7c2266dd, 0xdb96bfca, 0xec600e51, 0x27c3fd06, 0xf9a04fd7,
	0x7608fb69, 0xd90c18fd, 0x57eb4c49, 0x0a24e031, 0xd1acbced, 0x53a18539,
	0xd2316e50, 0x5978b547, 0x3bf06596, 0x26977e0f, 0xc0deb9fa, 0x54acd6e3,
	0x39c5e3c4, 0x2f5114ac, 0x15f9bd75, 0xd4e9cbd2, 0x9defa25c, 0xf48bd7cc,
	0x2adc9b2a, 0x3fb6b3d2, 0xdfc9caec, 0x7ae1a654, 0xeb4c7e0a, 0xc766dab9,
	0x9cc214f5, 0xd3d227e6, 0xfd825493, 0xe5a7c4a8, 0xf5fdfe58, 0x552e4715,
	0x7c23f822, 0x8fbfcf5f, 0x82ef7fd3, 0xbe2313ef, 0x8bef878f, 0x58cf7f86,
	0xb5739088, 0x22d5ff98, 0xcda774df, 0xc24c3212, 0x5ed54bfe, 0xe14e4ef8,
	0x87898fdf, 0x0a2f28f7, 0x6c1d79f5, 0xf942db9a, 0x1c7951c0, 0xa5f74a57,
	0xcab97ee1, 0x0bd5df52, 0xf029bffd, 0x77c1a573, 0xdfef0eda, 0x1070505c,
	0x258555f7, 0xdd1e60a8, 0x06b42c35, 0xc3303691, 0x9f2384f7, 0x0b9c7df6,
	0xfb20d8e0, 0xf94225c6, 0xcc75b184, 0x2fb4b91d, 0xc329aeac, 0x5fe1afe7,
	0x01d2075b, 0x1d20d3d2, 0xc35bcd44, 0x83aebb17, 0x071edf12, 0x9a9f05fd,
	0x2358c33e, 0xb35673cf, 0xc405d686, 0x38d2db32, 0x3789f506, 0x0fc4036b,
	0x423c74ae, 0xe9695079, 0xd79c5cbe, 0xc8bf0bfc, 0x6bb1b056, 0xd7d438e1,
	0xff79be61, 0xf4d5f397, 0xbe7961b6, 0x79749a9f, 0x1feda3be, 0xea3f5c6d,
	0x03e63263, 0xaede53b7, 0x8dd59e7f, 0x98fc33e7, 0xe2993a77, 0xbd8fa445,
	0x373d7124, 0xfe845920, 0xc0f9ae74, 0xf559eb8c, 0x2e967a83, 0x98adbd9f,
	0x0eedbbcf, 0x97b4f495, 0xb03ede25, 0x6e3d7190, 0x6c5fa88e, 0xef2d7aa7,
	0xfb9dadbd, 0x185edae9, 0xa0bf62a7, 0x671c917f, 0xcbbf4209, 0xedb5fce5,
	0xe01ed562, 0xca5266e0, 0x26f69e50, 0xb71bd723, 0x94a5dc1a, 0xbd026257,
	0x3981c78a, 0xc7cb1a7f, 0xd5e7f68f, 0xbcfef4b9, 0xc93ff2c1, 0xeedeb79f,
	0x2d5d23f3, 0x4b64f22e, 0xf7179c06, 0x6e7d01eb, 0x6e9861eb, 0xf50638d6,
	0xe358abed, 0xa27c863b, 0x7ee31fcf, 0xe8113f9a, 0x9f475f33, 0x3992bb77,
	0x4579c43f, 0x3a6883f3, 0xb7de39bc, 0x736dc702, 0x80dfbc74, 0xd9976a7a,
	0x7958f3cd, 0x1f345e5e, 0x22cf9888, 0x29c7cf85, 0xb59f34cb, 0xe6a25fb4,
	0x24fb2e73, 0x19533e92, 0xeda30fdf, 0x05855497, 0xfb43256c, 0xdf18e1e5,
	0xe0ef5c26, 0xedc359be, 0x96f36192, 0x375f44ad, 0x16e3c4de, 0xd72e38fe,
	0x06917e30, 0xe311cfe3, 0xe9c2d8df, 0x337fc6f0, 0xf4c2dd11, 0xb9ff3843,
	0x574e7ea2, 0xcd2de53d, 0x8d1e372d, 0x9c5aef94, 0x3768be64, 0xc46c59cf,
	0x52af302d, 0x7f989f1f, 0xdc8f8f2b, 0x388d1ac0, 0xe9e71bdf, 0xd6cf99fb,
	0x5879817f, 0xbfd56ff3, 0x1835de7f, 0x718718d7, 0x7ec2838d, 0x82fd801f,
	0xe4f5e9fb, 0x00eedba5, 0xd3f71dfa, 0xf7f412a2, 0xdda94acc, 0x4fca11b9,
	0xe5409d6f, 0xf96e53d7, 0xdfac61d1, 0x72e5405e, 0xfb432a4c, 0xca23f703,
	0xae9bd29b, 0x0f7185ce, 0xef7e88c6, 0xaefb79e0, 0x1cdb5f58, 0x949ae768,
	0xe587f947, 0x2c0cdf82, 0x5cd7f5e6, 0xa629e368, 0xdfe4a9b7, 0x2f0d8f2b,
	0xbb7ffa40, 0x304bbff8, 0x4f3cb61f, 0x9e5e4b94, 0xd283e580, 0xbeee7417,
	0x20aadebf, 0xb9d21bfc, 0xa162745f, 0x700f1a14, 0xfd144f29, 0x5575f3d7,
	0x8e933c96, 0x8cbca3fb, 0x3dd133f7, 0xdb1f25a3, 0xb9524e19, 0x8f12dd3f,
	0x67db50fc, 0x297db547, 0xd8af24f4, 0x3e7a2ff7, 0x7e824a6c, 0x8dc916bd,
	0xfb4ef44b, 0x665aec90, 0xbcb9e7e5, 0xfd055c9e, 0x3c3d33aa, 0xb2ccb25f,
	0xe2ed0d32, 0xc9a67ceb, 0xa5bb2eb8, 0x27ea20f8, 0x4c66d309, 0x0b5afca1,
	0x039ca233, 0xfb4e3fba, 0xd917ea70, 0x566c48f1, 0x746bdd3d, 0xf7a34735,
	0xc35d3d72, 0x95dcfd7e, 0x5afcfdfc, 0x4331d747, 0xfe9a3d74, 0x8afaf30a,
	0x7aa5e3f6, 0x4e3835f9, 0x1e8cbed4, 0x817e3477, 0x74fc917f, 0xb41d7e68,
	0x0b3132ff, 0x67f71f2d, 0x633fb6ab, 0x261e60d3, 0x6b9d0f43, 0x13dc91c9,
	0x28e820e8, 0xbf36867a, 0x9675f42c, 0xfe179f0c, 0xc79e9a29, 0x0f689cff,
	0xf87a8a67, 0x8712c3ce, 0xa7e305e6, 0xac3d21a7, 0x5c79f3e1, 0x45fce46a,
	0x1d9ad9e8, 0xb7ada0dd, 0xd2debf53, 0xdcce7e58, 0xf20efe85, 0x184f1775,
	0xe039f79c, 0x5f8f5b41, 0x1679edc8, 0x6b04cdaf, 0x4d51c1bb, 0x1643f3f4,
	0xa3f50178, 0x0bbead4f, 0x1aaf9e71, 0xbf68dd02, 0x8a1e662c, 0xb87d0277,
	0x5f02fe69, 0xe1a37cda, 0x3f0a30d4, 0x344f5e8d, 0xd6f0867c, 0x769dfa43,
	0xbd706c6e, 0x4d4eb8e7, 0xf49a712f, 0xe144a67e, 0x7e144a17, 0x9428a420,
	0xd62c95cf, 0x4cfe7a8d, 0x45fa44b7, 0x5f10b325, 0xf2e0acae, 0xf5cad13c,
	0x8fee4d0f, 0xb8ae3fb6, 0xaabf119c, 0x9ce263ac, 0x34575f1a, 0xdeb2a61d,
	0xd2b3e31f, 0x84596ea2, 0x14f51efb, 0x95fe6875, 0xae3fee56, 0xdf84934d,
	0xca0a77b8, 0x30f2c1f9, 0x053bdf39, 0x5902cff9, 0x3ca9571f, 0x8994fdcb,
	0x2b3d1967, 0x414e1fdd, 0xd1589f39, 0xd8f9053b, 0x967827bf, 0xc0f87ee1,
	0xd1b9fdc0, 0xcd3bbc70, 0xcf29f9a0, 0xf7a33e89, 0xfaaf168f, 0x07bbead2,
	0x1afcd1c7, 0x529ea427, 0xc929b46c, 0xcbe7d62e, 0xd8763a45, 0x7fa06773,
	0xe4059e62, 0x00e30191, 0x1df895be, 0xbf6fcff0, 0x9b0f6345, 0x286f1c02,
	0xf0afddf7, 0x770e0961, 0x12cc380a, 0x36e4f572, 0xe502e299, 0xd0c7c29e,
	0x643fef75, 0xafda4164, 0xda8b921e, 0x41275cfd, 0xfb610a81, 0x67a46d67,
	0x9aab7d2c, 0x36e31ae2, 0x211a981b, 0x6307c727, 0x4c52f775, 0x2ba895dc,
	0xae91d05f, 0x67617f6b, 0x38beae9e, 0x7f574134, 0x5d12a1d1, 0x25cf4a79,
	0xdf53f6ba, 0x2f95d32d, 0xd75abdee, 0xe64fd2fe, 0x3120caea, 0x53f75c14,
	0x15b624fb, 0x7c3d3dd6, 0xfffbeeb3, 0x10fb3ad9, 0x098f17c6, 0x3c0599fb,
	0x8700853d, 0x9edd1a45, 0x17f7d2ad, 0x29524292, 0xb7fe7bee, 0x8fcf3d68,
	0x8b90019e, 0xab7177ec, 0xba589f5e, 0xe9ae5f59, 0x7906b8da, 0x8abcf0e3,
	0x348732c6, 0xdca2af3c, 0xf480d0be, 0xf40d2079, 0x538c140b, 0xebcc54d9,
	0x7f9f6d1a, 0xd80bfe1f, 0x3fc3ef98, 0x44d9bf6f, 0xb7d2fd7a, 0x821a557e,
	0x1e976657, 0x1eaa31ff, 0x7a8571ff, 0x7adcdbfc, 0xd34c27fc, 0xd1e1dfe3,
	0x42a93fe3, 0xaf64ff8f, 0xf3a9ff1e, 0xf34ff8f5, 0x519ff1e9, 0x567fc7a3,
	0x39df1ea3, 0xccf8f5cb, 0xd5d32c0d, 0xe35fe347, 0x77cdf997, 0x7801dbea,
	0xa074110d, 0x6f22d1d1, 0x8ccbe50d, 0xdd0ffd6d, 0x00f4d138, 0xee81a376,
	0x6e3b034f, 0xf4ee74ab, 0xfc8adc01, 0x21f4d1ac, 0x53bd0ba5, 0x23c805d0,
	0xd214fa43, 0xa8e98c2f, 0xfa138cf7, 0xfd6477be, 0x915fe342, 0x2ed23cf2,
	0x0daf8d1e, 0x4ec25393, 0xa14e551e, 0x64331c9d, 0xbf468f27, 0x87db3047,
	0xe4f5a8f4, 0xcec9ba47, 0x5f0a71e7, 0xdafe8c5d, 0x3e5c925f, 0x069c1302,
	0xeb823df3, 0xc48ff181, 0xc6ff244e, 0x7a442c2d, 0x4661bffb, 0x1b760c23,
	0x78cb4626, 0xcf4a92af, 0x17b7216a, 0x3b87ff0b, 0xe10137c6, 0x72fb20d5,
	0xccdc7052, 0xc49f3a1e, 0xa73a4ede, 0xa28e1b7b, 0x6f181eff, 0xe1effa1f,
	0xe9c31fd9, 0x57c6b8e6, 0x46754c3c, 0xa66ab3c0, 0xad7a4854, 0x46794b1c,
	0x48943f55, 0x99fd553e, 0xb9d2cb3f, 0xae7e8b3c, 0xb3c1ae5e, 0x5c03e855,
	0xae98582f, 0xf30f788a, 0x6e6e0959, 0xfa19e23b, 0x9ff4fee3, 0x73d9ff71,
	0x25a65312, 0xc22eb1d2, 0xcf1be233, 0x3e16c91f, 0xcc8ce7cf, 0xc89cf082,
	0x3e07a47c, 0xe36b00a0, 0xfde04dfd, 0x7f43ce1d, 0xbb8f2c9a, 0x70f01cb6,
	0xf30b8e23, 0x3375659a, 0x2ecb23f4, 0xd5bf4337, 0x2e7bf7b0, 0x06294ba1,
	0xc3b78ccb, 0xe68b843f, 0xf414cc0f, 0xb8c6d3b2, 0x3fca2bdf, 0x07032198,
	0x23197cc6, 0x52ed8f3f, 0xf27b7336, 0x39b3770d, 0x198cdd62, 0xee7e781d,
	0xcc21f4fb, 0x911e3d6f, 0x69780e8f, 0x4fde491c, 0x6579e0cf, 0x4e1457ab,
	0xf88afc27, 0xd42bfdd3, 0x91af18e9, 0xa1e53715, 0x8e467de1, 0x4e4def88,
	0x1be08fa8, 0x5750b58a, 0x04bd5a36, 0x1a2b3597, 0xe28c6e89, 0x99b5a5de,
	0x117dda77, 0xe995897e, 0x09667c7c, 0x130a7b30, 0x7dfc31aa, 0x7ae19332,
	0x5c72bb65, 0xe9fee767, 0x5b8458db, 0x6d37a0bd, 0x8c1766be, 0x03eed113,
	0xf6f5a741, 0xffce131e, 0x9eed5c83, 0x8a64de93, 0x26ce6d63, 0xe026dff8,
	0x8523de6f, 0x5981dcf0, 0xd8a233c1, 0xa61fef4b, 0xf9ad7d02, 0x7c6191ad,
	0x573dcd66, 0x687dc21e, 0x83746c4a, 0xfaeecfe5, 0x6fbb62ed, 0x4f6a7804,
	0x13394bb3, 0x22b6c7c9, 0xe21b8b1f, 0x87cc2363, 0x765dc1f8, 0xf75dcdfe,
	0xbd0ec918, 0xe518dfeb, 0xf0e5b33f, 0x9f043a57, 0x7e26e664, 0x7a6160e4,
	0x6c057eb9, 0xd78db010, 0x5f30b0ad, 0xd62fc801, 0x0a537a48, 0xad1d10f3,
	0x37441f77, 0xf2707b29, 0xae7c5e3b, 0x8ad9dc2b, 0x4503dbea, 0x69f07a7b,
	0x938ed8c5, 0x78824af2, 0x6586cc56, 0x4057ff8c, 0x158fc619, 0x5e1eb1f5,
	0x71f5138e, 0xe8fb78d3, 0x7baa40b8, 0x9f1334ae, 0xe457dfd6, 0x64ad3ee3,
	0x38ab5cfc, 0xe5f9af1f, 0xf7bfad93, 0x517e44ce, 0x8cdc44ce, 0xd62a3fd7,
	0xd1dd6499, 0x97f5879c, 0x111febe9, 0x8eeb0ef5, 0x7fec32d6, 0xa37ebe8c,
	0xfac13fe8, 0x07ba21fc, 0xfe3f5325, 0xc63ea243, 0x194f7cfa, 0x7dd07dcf,
	0xcdea22df, 0x02b79e56, 0x3f7116ff, 0x8c56bf5e, 0x81ab729f, 0xcee822f9,
	0xf9962f39, 0x589ef022, 0x1b2ba899, 0xcf1c3fb1, 0xb56defc5, 0xbeeba797,
	0x5fbffad7, 0x597f1f8c, 0xcb7bee9e, 0xf6fa0998, 0x3744593d, 0x9bb80a77,
	0xf5744b32, 0xcb5c5afd, 0x38f9f8c1, 0xa699d395, 0x4bce293f, 0x2c9ffd74,
	0xee301354, 0x60781c7c, 0x7158e20f, 0xdf1f705b, 0x454bcb69, 0x98ae0d3a,
	0x56714746, 0xb2819d03, 0x78bb4f05, 0x557bc4ba, 0xd9450b94, 0xe15ccf4d,
	0xa2bd5c8f, 0x803bca82, 0xc4f9f15e, 0x1f3d0f0a, 0xdf0ab287, 0x05fa14fd,
	0x40b6c649, 0x0c7e58bf, 0xa3e7c5fa, 0x1f3e2fd0, 0x7eb17e81, 0xe58bf423,
	0x583e6087, 0xc1fa107e, 0x3fd003f2, 0x78565b96, 0xc576bca9, 0xbfde7a7c,
	0xd5cf47c2, 0x3ea86a2b, 0xbf3a4335, 0xc0c9a93c, 0x71754b60, 0xe48cd4e3,
	0x2d7f7ca1, 0x1a6edc6e, 0x989aced9, 0x1cacedc1, 0x7e803de6, 0x8a6fa01e,
	0xefad6563, 0x68f68038, 0x27e39792, 0xd5237d6d, 0x38f82a3b, 0x19cc77da,
	0xfca59960, 0x83e72378, 0xa3ca2aea, 0x9e78cf18, 0xd4c02b9a, 0x13ee7152,
	0xf93094ff, 0x3d4295f3, 0xca8dcd3f, 0x259ed3cb, 0x63c82e42, 0x1cb83d1a,
	0x086f34cb, 0x6ead88f3, 0xcf039d1f, 0x261b3b39, 0xecebfb09, 0x38c54ce5,
	0xdf5ea540, 0xd12f2c4d, 0xd9f295e9, 0xc9676a06, 0xced759bc, 0xb5d2ace4,
	0x773dbaab, 0x91e10b8d, 0x5e61d7c1, 0xc1a592bf, 0x36db8bb8, 0x0ab7b8d2,
	0x037ac1bc, 0x2ddfafe4, 0x7d0af5f1, 0x58bb69ea, 0xd93d65af, 0xbc1ce309,
	0x30109058, 0xfcfc1f20, 0x1fb40957, 0x40c27a9e, 0x2cf1c2fe, 0x4d7c4068,
	0xf58cb104, 0x2a5eb017, 0x155c885f, 0x954cc5ca, 0x0b117cb1, 0xfa099e93,
	0x1e0cbcd4, 0x06227a47, 0xbe5948e3, 0x4a9e79a7, 0x02cdf488, 0x4d028f81,
	0x44acdcaf, 0xce6edbfb, 0x7f57fb20, 0x738b458e, 0xa695b4ae, 0x3fd11ea2,
	0x9c511e4a, 0x174be6eb, 0xd2e31c01, 0x7b53d3e6, 0x186a80ff, 0x8fe75cf1,
	0x37ce97ce, 0xd3d23f03, 0xfd708ff9, 0x8f7e8a27, 0x61ac3899, 0xe7ec984c,
	0x5f8d46d5, 0x2fc809a8, 0x04eeca86, 0x695d6f92, 0xced91f04, 0x0ad4f3e1,
	0xb54dc51f, 0x155fca75, 0xa5af31db, 0xedd1e440, 0xa5c7715a, 0x03f911e5,
	0x428eb141, 0xe50871d6, 0xe0d3a141, 0x4b9df6e6, 0x8cc60f67, 0x39e0f569,
	0x73027963, 0x78c5ce63, 0x6de74ad6, 0xc4c9bfe5, 0xaf57e47f, 0x15e82a62,
	0xc320f6b1, 0x5fad11bc, 0x1fcaec26, 0xda7a3e09, 0x96f34e5a, 0xed3935b3,
	0xb4e67d21, 0xbcc76ddd, 0x466dd399, 0xaa3e48fa, 0xbbb42faf, 0x5d01f5df,
	0xe713d92e, 0x16c5e9c6, 0x713dd2b6, 0x658976f2, 0x9e0f344a, 0xf5c89707,
	0x52e6e356, 0x4808b816, 0x266be0d2, 0x7baaf6b8, 0x87909a0d, 0xa649f576,
	0x1aa7e81d, 0x78417087, 0x3824298e, 0xddeb162e, 0xc12562b5, 0xa10c85e9,
	0x70696747, 0x1e61f317, 0xb72bde0f, 0x87b34da4, 0xa07cebf5, 0x5807eca8,
	0x5323d4df, 0x3c346c1e, 0x31ffc44f, 0x5d101e3e, 0x6ffb9135, 0x202f9e60,
	0xef382afd, 0xa32f8424, 0x9bb52cf5, 0xb41e7882, 0x20a8ea5f, 0x81817379,
	0xb4b1c645, 0x2be09767, 0x7e761965, 0xc16bb98f, 0x8a2e8ba5, 0x744adf2c,
	0xaf169cfd, 0x6e5c29b7, 0xa46a3c79, 0x669d6ddf, 0xedfc887f, 0xc1df3158,
	0xf026a87b, 0xeb2b327c, 0x1df98cd9, 0xbf17d9a3, 0xf9a5c8cf, 0x8017d90c,
	0x299fa41a, 0x5887ca16, 0xa8bde5a7, 0xebca5587, 0xdfe62785, 0xae9d045b,
	0xdfefe9b5, 0x77d62d3c, 0xc063e05a, 0x8c50f5c2, 0x44a714f3, 0xaaefdb9c,
	0x8b5a7b26, 0xf1740d0b, 0x5fcd56bc, 0x60482b51, 0xc38720e0, 0xe29936c0,
	0xd75db541, 0xbb0efbf0, 0x227ba11f, 0xe9152fa1, 0xafb45aa1, 0xcfdbd66e,
	0xd77a768b, 0xedc3aac4, 0x402c25f4, 0x7db46276, 0x7f976d1e, 0x56f42191,
	0xb8c62b37, 0xf9f5b1cf, 0x7cc2c46f, 0xce8cb94d, 0xcfc8660d, 0xa0ac3dd3,
	0x3de2b675, 0xdf88ac8b, 0xf78d1233, 0xe1132ca2, 0xd7869777, 0xffa256b1,
	0xfef8535d, 0xe4e075df, 0x9fa16375, 0xba48e4df, 0xe4dfd23c, 0x058e0918,
	0x678760e8, 0x23156307, 0x65250de5, 0xcf8fce1a, 0xefbfa65d, 0xf7b3bebf,
	0xf895388d, 0xe226625d, 0xc4bf8df1, 0x08fed117, 0xd7f4fdd3, 0xf993bfe0,
	0x7f7f31bc, 0x058be1b7, 0x90507491, 0xc17d50a9, 0x5cabcef9, 0x4513af3f,
	0xcd5ca4ef, 0x133635e7, 0x68e860e5, 0xb65e644a, 0xa3ddaf36, 0xed3d0fdc,
	0x4d33e77c, 0xe0220f2f, 0x33e71534, 0x9b769c1a, 0xb5cf9e46, 0xfcbf7c99,
	0xefbf20e2, 0x74bd7860, 0xb533f77e, 0xe27be7e9, 0x911b9ed9, 0xaf7cc35d,
	0xbbf6bc45, 0x062852fa, 0x31d7e025, 0x64e7d059, 0x64dc77c1, 0x7bff3113,
	0xa98f2953, 0xfef5e143, 0x95c125c4, 0x03eebf40, 0x1e50728b, 0xe9988ed8,
	0x68ff1a9e, 0x1d626d79, 0x11a5d3bb, 0x933ab0e1, 0xb781fdd3, 0x07bfa8ab,
	0xe43335de, 0xfee24d07, 0x1dec07a6, 0x547fbc16, 0x4b962383, 0x8537e9e0,
	0x3cb1b897, 0xb545b4f9, 0x819e308e, 0xd450f78f, 0xd3c6d1be, 0x2cc93f9e,
	0x3a5072e4, 0xf6be6328, 0x43bd9743, 0x343d04f7, 0xfb9e2159, 0x7d7fc30f,
	0xef43fc14, 0xe9c75ca4, 0xff0827e5, 0xf8a3e906, 0x2fd9401f, 0x84577f85,
	0x68f933f0, 0xccf7fefd, 0x0e1a5dac, 0xbf411aa7, 0xf5b4fada, 0x4db6f36b,
	0xf2f9445f, 0xf89c0f88, 0x935ed16a, 0xee420913, 0x4e48bae1, 0x7cf0a65c,
	0xe10a29f7, 0x9769a1f5, 0xdd84f9d0, 0xbe1d3e22, 0xbde234d8, 0x7012bff2,
	0x7fece07b, 0x197da0f5, 0xb9d232e8, 0x5de7b070, 0xf91d03d7, 0x3dd0ab7f,
	0x154f40b3, 0x81cdef78, 0xa3c64fb7, 0xc991d75e, 0xa64759f9, 0xb387cb89,
	0x1b9d0572, 0x5db4fb78, 0xddffa08e, 0x4bd0b299, 0x3cf07a7a, 0x9e1286c0,
	0x7a156cff, 0xbeedf580, 0x75bf9c1a, 0xa5987fda, 0x9edb3908, 0x36efa669,
	0x6e29c298, 0x2ddfcfe8, 0x03e910b3, 0xd77f74bd, 0x3b2779e0, 0x64c34387,
	0x78453010, 0xd7bf2a0f, 0xcaa6776b, 0xdef307e7, 0xc763ef0b, 0x6357b69f,
	0x2f1864fd, 0x9b7be86f, 0x7633e39d, 0xe347bf0a, 0x6f7ecba1, 0x12c37bc7,
	0xdff74624, 0x75196516, 0xd546fc7c, 0xe9edfa20, 0x602dfd41, 0xb0ff2857,
	0x05a77423, 0x5f6d7af5, 0x6a657358, 0xebdc56b7, 0x615a76ba, 0x681fcf10,
	0xcb273c74, 0xcdd23af7, 0xcf17d806, 0xe3d5de93, 0xb1f0499d, 0xe69e6317,
	0xdd0f5273, 0x62981257, 0x297ca3b2, 0xfb741834, 0xd38b252d, 0xbd04f68d,
	0x1f9df494, 0xe4d65a0b, 0x616edcbd, 0xcbe9be78, 0x501273b3, 0x34b3952f,
	0x476dcf3d, 0x9d697e38, 0xc7e1fa47, 0x47d75baf, 0xe7b5ffc6, 0xe6f02b47,
	0x62f2a1fe, 0xb63677b7, 0x6b7cc25f, 0xd25d1f50, 0x7bceeb26, 0xf9f62c7f,
	0x2cb1b3e2, 0x2fd7a114, 0x9d33769e, 0x367c595b, 0x4f40859e, 0x339c58fa,
	0x05e458fa, 0xe0fb129d, 0xcb8cf15b, 0xe97e4f3a, 0x8f37928e, 0x5553f7ff,
	0x429e5f9c, 0xbd4bd7b8, 0x1b73e426, 0x9d0bf92e, 0xec08f817, 0x77c150f4,
	0x858933ad, 0x6c19c622, 0xeb42d677, 0xa70bc219, 0x5af5a1bb, 0x811f0e09,
	0x70ddfffd, 0x71c1d0cc, 0x1d3cffa8, 0x5ff7871c, 0xb47fe340, 0xfa7bf0a2,
	0xff4a389f, 0x43fe6eaa, 0x71a18efd, 0x7aad5ffb, 0xcbf60e3a, 0x5b55a1ab,
	0xb6fcc65f, 0x37ba66fd, 0x9476759d, 0xe7a639d1, 0xbb6f9d18, 0x1f57ff7b,
	0xdddade60, 0x1c6e4c3b, 0x5e18c063, 0x3e411ee0, 0x00f6618c, 0x3da423de,
	0x69f2b2b3, 0xb7bf457f, 0xe63b4128, 0x150a59a7, 0xf5154afb, 0x2ae09eb2,
	0x5b2637b4, 0xfe693f88, 0xafdfad71, 0x1ced6432, 0xed6bed2d, 0xe29788be,
	0xd059257c, 0x5ab1a7ff, 0x0360529e, 0x7f6ac9fa, 0x3e79db26, 0x10ec83b4,
	0x30ad7fcd, 0xcd1bf91f, 0xff30cbcc, 0x77c73dbf, 0xfbf41671, 0xe8036053,
	0xd82f96cf, 0x9dfcc3e9, 0xf7bd8507, 0xcb8f4c60, 0xaeefc11d, 0x8fce52ce,
	0xe8a35b6e, 0x9f1fca76, 0x7339710a, 0x5ea3ce35, 0x5565f9ee, 0xf61de62e,
	0x5482fb8a, 0x27fdf913, 0x8cf741bf, 0x7af66955, 0x3b7c7473, 0xaffa81cb,
	0xc78f6fe6, 0x11d423fc, 0xa6fbf036, 0xb978e3aa, 0x944937fa, 0x4b760de7,
	0x9ff2115c, 0xdf9bb2dd, 0xb827672f, 0x186b149e, 0x46c86cb0, 0xb8080e78,
	0x8d7aec9e, 0xd93bb3ee, 0x5ff0963c, 0x74bdcafd, 0x74eed51f, 0xba067f2e,
	0xaa7f246d, 0xbc52eecd, 0x3a776d2f, 0x943b33d7, 0x84497c50, 0xb336b9de,
	0xe7eaf88c, 0xa80d63cd, 0x5d706b97, 0xd4e5c596, 0x985fc106, 0xbcc52e12,
	0x8727cffd, 0x6ff2477e, 0x3efd0c4f, 0x57ef618d, 0xdeaf74a5, 0x47dd3306,
	0xfc77b65e, 0x5f50f9a6, 0xbca0605f, 0x18dec34c, 0x7589cf9a, 0xfc1f5efc,
	0xfd74e516, 0x5dfa0cde, 0x30b8ea9d, 0xc7d555e5, 0xfe300bba, 0x52f7bd51,
	0xd8fc4fba, 0x91b3e383, 0x564d1e5f, 0xd53ee9b3, 0xb0e80107, 0xe3dda3ee,
	0xa996fbf8, 0xb6ce5e74, 0x9237ce21, 0x239342ff, 0xed06f7d1, 0xefee2f4e,
	0xb78cf844, 0xf94077b8, 0xe3cdc923, 0x73c2875f, 0xb8af8a55, 0xb560dce9,
	0xe86fb3f5, 0x0fb6af9e, 0xdef4656f, 0xd9ab7449, 0x55e3d161, 0xdbb3390b,
	0xbf805e14, 0x5abd546f, 0xf3c4ddc0, 0xc50daabf, 0x1a5fbbf4, 0xdd4437dc,
	0xf82ed9af, 0xf63cf6af, 0x94f742b6, 0xc6cffc81, 0xfb63e7fc, 0xc76744cd,
	0x73a44c36, 0xd578dab2, 0xec3b1300, 0xea89a3cb, 0x2eebc424, 0x57aaafc1,
	0x7b52fb73, 0x58d86d5f, 0x770e7881, 0x32df94cb, 0x63c70f60, 0xa76b437c,
	0xd3d70795, 0xf4efd325, 0x403f4eec, 0x627a06f8, 0x57864f48, 0xfd5f246c,
	0x207798af, 0xcc9f3f3e, 0xb7487102, 0x3ddff2ef, 0x4cdbb57a, 0x11c0ef7a,
	0xbb0e976e, 0xce1ac9b7, 0xfd0b7bc6, 0x1f1064af, 0x6f0ac81b, 0x0c727ae7,
	0xb0edcfbf, 0x8388aa6f, 0xd07b89a5, 0x3b3f50d2, 0x42131dd3, 0x149e0cfd,
	0x9db008d7, 0x3fbf7a2e, 0x06dfa18e, 0x3852419e, 0xfa2e3da5, 0x2ad60bbd,
	0xefa1efbe, 0x8df6ceef, 0x777cbe43, 0xc56ff43e, 0xdda8fbef, 0x85df3c99,
	0x74bf8658, 0xf53a5e31, 0xa1cbe59b, 0x1769d2f7, 0x56871dff, 0xf543df51,
	0x2a6fb37e, 0x1b7de3ad, 0x9d611f6b, 0xd7df7be7, 0x4449598b, 0x01bcdabf,
	0x45efa4ce, 0x2ca3e5c3, 0x0f9df883, 0xba688f0e, 0xf7e7c41c, 0x26fd0fcc,
	0x9bb45e74, 0x78dd71e3, 0x2d23e713, 0x65af4913, 0x3cbab14d, 0xfcdd95a2,
	0x83ff77fc, 0x80f3c236, 0xca18f3d1, 0x2361f0a3, 0x8169f7e3, 0x85fe8046,
	0x97ef2369, 0x715e44cf, 0x37cf0b6d, 0x8f99ecfa, 0xf15a17b3, 0xbac7e45c,
	0x9f9a9173, 0x47893a0f, 0xadd58a3f, 0x711557c6, 0xf9a65b3d, 0xda13dff1,
	0xf7e95460, 0x8e0f029e, 0x31c23f27, 0x7e97ba93, 0x05dd6a97, 0x16aba406,
	0x813de737, 0xed3ebe56, 0xbeed1e9e, 0x8cf8689d, 0xbfe7cecd, 0xb77cc283,
	0x47cddde1, 0x82229a99, 0x58ef7468, 0x400bfe0d, 0xe0c6335f, 0xd0fe2189,
	0xf8617248, 0xefa65efd, 0xffa83df9, 0x1cf8f2db, 0x716ceb46, 0xae51e207,
	0xf6e7627e, 0x45fe9d1e, 0x75f32eb9, 0x69aa5dd2, 0x17bdaf28, 0x3d532764,
	0x244fc3f1, 0xb9f1af5e, 0x7a47eb61, 0x1db07ec1, 0x3b3d35f4, 0xb827db97,
	0x347ef1e9, 0xbe613016, 0xfc9f269a, 0x73c06292, 0x350e7dbb, 0xafb1e91e,
	0xed113f25, 0x9a872ae5, 0x17411252, 0xce8c83fe, 0xcf78aaab, 0x5dfc54f1,
	0xf424cf0b, 0xd44eedd7, 0xe7a20bfb, 0xde8cfcf3, 0x57f59105, 0x77397366,
	0xf7b73643, 0x61336456, 0x8dc3453f, 0xc0a97de3, 0x77db8b7b, 0x518fd939,
	0x4e6e96ed, 0xf510f410, 0x7fe5f5be, 0x6d907ca7, 0x5ce9fbfa, 0x4fbc7c39,
	0xd202990e, 0xa58cf885, 0x8d9adefc, 0xbcd5cf9c, 0x0f705955, 0xeeb9d32f,
	0xd3f7ed19, 0xda2c80ef, 0x7180ab31, 0xd07845be, 0xb65171e8, 0xb8f500a7,
	0x8ed916f0, 0xb366a2fb, 0x5169f34c, 0xe05b2d5a, 0x46cdf1fd, 0xc46aefd2,
	0xfa678e7c, 0x0a6f09e2, 0xf7004c53, 0x9e2f8ae3, 0xe22dd7f4, 0xd6a24ef7,
	0x51deed01, 0x8f80464a, 0xe099e385, 0x1d023f93, 0x9e10361c, 0xd1efe116,
	0x25da3ce1, 0xcf1e4bf2, 0xe586ddf2, 0xe9dbb03e, 0x5ad6e1de, 0x1a2347ba,
	0x3e2dc7de, 0x62a5cfa2, 0xa33c1a3d, 0x39e0d1c7, 0x7d44f080, 0x9256d0e9,
	0x6547fe7b, 0xa07658a4, 0xd3d914eb, 0x7d67ba33, 0xdfbe2970, 0x8a8b7a08,
	0x77ef3672, 0x6b9ca0b7, 0x5477e996, 0x53f3baaa, 0x46bc9458, 0xb7eab1bb,
	0x110de2f3, 0x4da5b272, 0xcb49f8a6, 0x8bf1b998, 0xebc9fda9, 0xaa8ebe90,
	0x889294ee, 0xc1ecc176, 0x5f0e8178, 0x1aff1bd5, 0xacd4e38f, 0x34bad237,
	0x9cc00cbc, 0xc6b6ff88, 0x2068bf91, 0x6afd4c33, 0x6fa41a78, 0x4f4683c4,
	0xb650eed0, 0x0649e45d, 0xe5f51f88, 0x23dd4afa, 0x4792c9d0, 0x6fec5c60,
	0x4dee8db3, 0x3571d73c, 0x5be20c78, 0x232a6bec, 0x92e7b71e, 0x5870dbff,
	0xa3eb64a1, 0x50c3b0ad, 0x817905cf, 0x296a86fe, 0x5fdd01fc, 0xfba66dd9,
	0xde37ab5f, 0x578e1b7e, 0xc06cc47d, 0x57fdbefa, 0x4579a24e, 0x94e015e1,
	0x0fbd123d, 0xddb386e4, 0x7d03f011, 0xb6b7f682, 0xd379889e, 0xa29ec03c,
	0x7206507b, 0x7c119f01, 0xae6ccde0, 0xbb7b4177, 0xdf9be889, 0x5eb833c3,
	0xed7ad47b, 0x877deb51, 0xb7337d11, 0xe8b3d68f, 0xdf01b33d, 0x9af87a2f,
	0xf5aff402, 0xeb499bad, 0x4cf44bea, 0x97d5fdc2, 0xc08ffd0d, 0x0c3d172f,
	0x8efa2ceb, 0x10c6b675, 0x675d46be, 0xfb3b7862, 0x09f6758e, 0xf9d6d43a,
	0x63c6a291, 0x9f7fb35e, 0xe25fd0cc, 0xb86ef2cf, 0xf7e99794, 0x0f22fca9,
	0x8e31bfc0, 0xbbfb1ef2, 0x1ae8bdf8, 0xcef1801f, 0x440c1e91, 0xea657d0f,
	0x5f4869a6, 0xcc76ca0f, 0x775beda3, 0xf7f0efd1, 0xc836fac3, 0xfa13d476,
	0x80fc38ca, 0xeedc901f, 0x475ef6cb, 0xfa46fde5, 0xad63ac1d, 0x9d23fd7f,
	0xd236ef3f, 0xe40efaef, 0xc7cc377a, 0xf917cc32, 0x46e5c01a, 0x691aafae,
	0x8fcd2dfd, 0x607d6336, 0x5e7485f3, 0xd67cb862, 0xbd66b9c3, 0x4c87dbac,
	0xff3c6951, 0x7f7419c3, 0xe0670684, 0x0f6805b0, 0xf2c0f069, 0xe0860bbc,
	0xade717e2, 0xf7e02f51, 0x867e092f, 0x72e3c9f0, 0x208dcf02, 0x2bf3c31f,
	0x68abc9a3, 0x47ad13fe, 0x2348e4e5, 0xa8daabca, 0x165ca5df, 0x8a3dbe55,
	0xd545d46f, 0x83d547d7, 0x246ebe7c, 0x3943f3ff, 0x2556be7a, 0x41f9a8e0,
	0xe7e41e07, 0xd514ab9c, 0xf3cff684, 0xae7cb833, 0x72e59856, 0x3cfc97da,
	0x9ac2954c, 0xdef825cc, 0x93b48a6d, 0x7326bfa0, 0x39639422, 0x1576821f,
	0xc6b288a6, 0x5cf9b56f, 0xb1f7c39b, 0xfd87fcf6, 0xc6a39502, 0x19cdae2b,
	0x2253ae21, 0x6deafde7, 0xc9f6afb4, 0xdffa5764, 0x7d87f2e2, 0xb3d36a7d,
	0x36d7bc4e, 0xb4c1f29f, 0x71c347f5, 0x3c54f3a0, 0xff60defe, 0x679d1321,
	0x2a4aeaae, 0x312bfb23, 0xabdc223c, 0xfeb4fac5, 0xf8de95fa, 0x337a9139,
	0xfc8f8deb, 0xceaadc5d, 0x9ed02b53, 0xe405f805, 0xac7e3e08, 0xed0cb93b,
	0xa75feaca, 0xdb79e197, 0xdd9a3935, 0x3d6cfeaf, 0x667d9bee, 0xbff447f2,
	0xdf80df35, 0x2355bff7, 0xfdd3779e, 0x1d1ffd71, 0xe3f1c6cb, 0x05fbfa0d,
	0x76e1cdee, 0xc3e1b549, 0xff91d3ed, 0xbb9a94bf, 0x5cdfc23a, 0x7b21286d,
	0x786359f8, 0xf41bce01, 0xbbcc66fc, 0x9359fad4, 0x8d7cf2a3, 0x476f1f7d,
	0x436c70fe, 0x95b20956, 0xc8e37dfe, 0x723fedfe, 0xec9d8151, 0xf237348f,
	0xea8d6785, 0xb15edcdd, 0x6bdf71b9, 0x1838e1fd, 0x37dfec67, 0x05fd14b5,
	0x7cf847fd, 0x03fe4ca1, 0xfcc01768, 0x78dfad49, 0xe610fa83, 0x1b5fb381,
	0xf3b88ec9, 0xcc54fc9b, 0x8d378a6b, 0xbb419f1c, 0xbd079f41, 0xddadd68a,
	0x576d1de7, 0x9e5e622c, 0x7f651b67, 0x4782f769, 0xac3589db, 0x34af4d75,
	0x45045edc, 0x114812dc, 0x7f4e0fbf, 0x6fef241d, 0x59adf5df, 0x40724f7f,
	0xf10b4fec, 0x8fd82ae3, 0x14dfc8eb, 0xa05eff24, 0xee311e45, 0xc787307a,
	0xfb8b1fb7, 0x08de82db, 0x30351ebc, 0x3d7005c5, 0x5716626a, 0xe37648c9,
	0xcfb46c99, 0x1f8bdb86, 0x3aa31f93, 0x36329ef2, 0x5a3c6edc, 0x832d6c16,
	0x275d1d79, 0x9c18efd3, 0xfd18ddaf, 0x0d3bf6bd, 0xf13d0baf, 0x26cce628,
	0xacdd977e, 0xcf06af9f, 0x19fbf118, 0x94ffedd1, 0xc288edc3, 0xc1e6646f,
	0xa46ddf7d, 0xed713df3, 0x82dd37a7, 0xb465d9f4, 0x5f14aae7, 0x6079dfa1,
	0x0fca64fb, 0x163ae81c, 0xcce50cbf, 0x98e88bbe, 0xb39da0d9, 0x4938a64f,
	0x14a9e77f, 0x3f40a78c, 0x77f63714, 0xfa46ea3f, 0xfd1e6d1d, 0xc5f9f239,
	0xf1513d6b, 0xee3f1137, 0x805e3f6f, 0x60f81dfc, 0xfec1f23f, 0xfdc5af82,
	0x48a5bd5e, 0xd23f307f, 0x678207df, 0x74b4bf48, 0x9bde23c9, 0xe774c945,
	0xbd0abf33, 0xc3e616df, 0xf34329d4, 0x26c3506c, 0x1fffb394, 0x97541322,
	0x00008000, 0x00088b1f, 0x00000000, 0x7dcdff00, 0xd5547c09, 0xb3b9ffbd,
	0x24992665, 0x21258493, 0x02564c24, 0x26c27124, 0x04b0ea2a, 0x55869151,
	0x243788d0, 0xb41d9081, 0x9b4b697d, 0x8b520081, 0x4146bc35, 0xa0503a8b,
	0x2a17d168, 0x1bec5628, 0x96eb1140, 0x6d6d6ad6, 0xb0b8a269, 0x68fad0c7,
	0xdfffabeb, 0x49ee77f7, 0x69410ee6, 0xcf9f7bdf, 0xc39fad3f, 0xb3dcf7b9,
	0xdbf3b6fc, 0xce7399ce, 0x857142b8, 0x8cff3fa0, 0x2c4241a2, 0x54bd3fc6,
	0x219f281e, 0xfa9884e2, 0xd76ae55c, 0xb5ce2158, 0x7a28be6a, 0x2ac0715e,
	0x319400c4, 0xbd066f41, 0x7ae6ee1f, 0x60d623f9, 0x59a7d514, 0x80b3be27,
	0xcfbd2fda, 0xaea28bea, 0xc6fd6e0e, 0x7f7a763b, 0xe05d8b6e, 0x04238d3d,
	0xc84cb38d, 0x6e0765bf, 0x38d1a13e, 0xebb85f4b, 0xfa59c610, 0x17e3e680,
	0xfa0752d6, 0x1349b65d, 0xbff51a49, 0xa77efede, 0x05f37e53, 0x6ad957fd,
	0x9d112fae, 0xb534ac8b, 0xcfcd9ba5, 0xaf4ce885, 0xf6ab7ea6, 0xc5ee7947,
	0xf7c8c178, 0xf348bc42, 0x9dfe3069, 0xb6e1b397, 0x6f3ed443, 0x70e183ab,
	0x474425d6, 0x75b0bd3e, 0x4328120e, 0xb125e99d, 0x0fb9fcf4, 0x6f54bdd3,
	0xe57ff9f8, 0xf817f9e2, 0x52e2febb, 0xf01d881c, 0x85108c51, 0x917c4d5e,
	0xf7fefd49, 0xfd2599f9, 0x5a86d7b4, 0xc4281884, 0x88607b2e, 0xda1fde8f,
	0x277a59fa, 0xd39ee795, 0x5fdc7987, 0xb808bfd2, 0x4328c92c, 0x6c72812e,
	0x8226e7bb, 0xec2fc35b, 0x6d86debc, 0xa36f66eb, 0x3b79ebba, 0x39ea80cd,
	0xe62092ee, 0xbe03c2fd, 0x5d7eb0ca, 0x4ed8d156, 0x589a5df5, 0x2a38e5c0,
	0x8d2f31f3, 0x30eaf5e7, 0xd83aee59, 0x9fa73333, 0xcc3abcf9, 0xb438c42e,
	0x1d6e5c17, 0x978b7256, 0x025b47da, 0x680b2271, 0x10077bf7, 0xbe83359c,
	0x351a9a5a, 0xad164f3c, 0xed150e5c, 0x84223e5c, 0xe17b46ee, 0x42ce00f3,
	0x7e0025a4, 0xe18be056, 0xfd016299, 0xe1c0dd7c, 0xd690e8bd, 0xc1104817,
	0xeb6ff41d, 0xc6b0a756, 0x9d10e10b, 0xb628f871, 0xc3fdf660, 0x37fdbde8,
	0xf4468b56, 0xf8534d67, 0xad0479f4, 0xb9ee2fe3, 0x3bf8e1f1, 0xe9e2daf8,
	0x9f6eafe8, 0x7f514455, 0x45daf667, 0xddf68dc8, 0xbfb3b40e, 0xc64767f6,
	0x1343cc58, 0x068eb439, 0xc379e3aa, 0x183f9b44, 0x5ee59706, 0xccabc33b,
	0x59e5cb9b, 0x0ce8ff9b, 0x67acf7ea, 0x45e023b1, 0x05d3153f, 0x5e4f63f5,
	0x0ebcc0ec, 0x99d936be, 0xd825bc01, 0x1dd66f98, 0x7876e350, 0xe59e7fd0,
	0xf4499ed7, 0x4d9c7bbe, 0x1fc7a36c, 0x00dee4bf, 0xfde355be, 0xf3f12bdc,
	0x82513361, 0xe579efa3, 0xf0d3b9d8, 0xafa112fd, 0x692d1d03, 0x18508ab3,
	0x976c7ffd, 0x10bcaef8, 0x6149422d, 0xe6cf25df, 0x885e5575, 0xd431a113,
	0x7ddb25ce, 0x62e92b1c, 0x8fde3193, 0xffbe1251, 0x766b28c3, 0xc3c73cb9,
	0x4f6baffa, 0xf61bd530, 0xe78e78a7, 0xf06bd5f5, 0x5ba0148f, 0x5ad78138,
	0x3ccf0f83, 0x909ddbf2, 0xbe9a5d45, 0xa7547409, 0x429b4e75, 0xee4bac43,
	0xac6ee871, 0xb94223d3, 0x24ceb65f, 0xa71b0a11, 0x2705ddb7, 0x6e0fa7af,
	0xdf475e5e, 0x870cdd7a, 0xbf939b0f, 0x26a98e02, 0x9ff5f638, 0xc5e38269,
	0xf8f2e7fd, 0x7de7361f, 0x2ea3ff45, 0x34d7bfd1, 0xb37ebeff, 0xf935dc79,
	0x74471116, 0xa8dde6b5, 0x939b3320, 0x885e37fe, 0xd6ef8328, 0xbd3aa684,
	0x406ff0fd, 0x13154d4c, 0xeb5efde8, 0x19f1d074, 0xf80f62cf, 0x72409edc,
	0xdefa4ae9, 0x0d7e9fee, 0x90951bf5, 0xfdfa0498, 0xaf166f4f, 0x4684b3eb,
	0xd2cfe3a6, 0x2c035b46, 0x504b1bdf, 0xc2b4335f, 0xbad9bcca, 0x837de589,
	0xfb1f8e53, 0xf8253102, 0x30672ae7, 0x3b9fda87, 0x9ca796f0, 0xa69599c6,
	0xae3bc6ff, 0xe3b13e6f, 0xb3c0145e, 0x830fafd8, 0x43c7b81c, 0x40fccb7c,
	0x75eb4d7c, 0xd763fa68, 0xdf883f10, 0x541d8945, 0x87d2e67c, 0xf8f8c27b,
	0xf3c1d7b8, 0x85486e23, 0x36880c5c, 0x9ff61b2e, 0x897b3867, 0xf52eb17f,
	0x337441be, 0x62d7c1dc, 0xe6d26830, 0xf5fbf7e5, 0x7d0525e1, 0x37fd50f3,
	0x580eecbc, 0x5ea2ff88, 0xc038eff8, 0x7bad9cf3, 0xf6ca8fa6, 0x7098d603,
	0xe0ddfef8, 0x7f69c993, 0xe7a4ec2e, 0xe48ef8f5, 0x517e37d3, 0xa7f21c33,
	0x10bbaa3e, 0x8bf43ef3, 0xde4217bf, 0xcd42f67f, 0x45df3c30, 0x9cbfb1ed,
	0xfbd77473, 0x16cbfac2, 0x4265809e, 0x0367f95f, 0x77cf910f, 0x0432d0bd,
	0x624dd8f3, 0x38d22448, 0x8e63d54d, 0xfc1c8127, 0x119c843f, 0x60765f24,
	0xc73fdb7f, 0xff52b90a, 0x543110b6, 0xdc9cfb1f, 0x89a6c7df, 0x53f085a0,
	0x0bdbc2ff, 0x71faaf80, 0x96858f0e, 0x11d45d12, 0xa3ef4d5c, 0x1a3d39c7,
	0xaa6bffb5, 0x7d81df1c, 0x17df0b3d, 0xf96f0127, 0xfcf16724, 0x5b07965f,
	0xe841e422, 0x69bbf5d7, 0xe76b3abc, 0x9201c84c, 0x8832430b, 0xff5fea5e,
	0x5ef91bf3, 0x041ee8b4, 0xa862fcfc, 0xa32df71c, 0xfa19199f, 0x9dd3b430,
	0x495df79d, 0x4fcde6ed, 0xae09d749, 0x43a11665, 0x0419898e, 0x5740ab94,
	0x0bb30525, 0x575fdbfa, 0x5e7b5cb3, 0x21c075d3, 0x61f4e290, 0x2a95199f,
	0x5704299c, 0x9ccc1c91, 0x6616e34d, 0x237a0c58, 0x8f79a3ae, 0xe4f8d634,
	0x0915f690, 0x13059fbc, 0xecff4741, 0xf86757b8, 0xec0c65c7, 0xfcf6ff6b,
	0x7ef40bdb, 0xce1417f8, 0x2fb47078, 0xebbb3cc7, 0x846dbedc, 0x15e0dfbf,
	0xf9e3f77d, 0xe92b2151, 0xeeece759, 0xdfd11af5, 0x8e8b31bb, 0xec78240c,
	0x0053eb73, 0xdeb7059f, 0xed750eb8, 0x05779250, 0x73acb9e8, 0x73e9f03c,
	0x7de037e9, 0x361f53ad, 0x26789688, 0x8f1e1f4d, 0x4924b8cd, 0x149449e2,
	0x7f3bf494, 0x4d329f39, 0xe9665f8e, 0x0d4af478, 0x0b3eadfb, 0x1d5ba9eb,
	0x5b4ef52f, 0xafe678c7, 0xbfb90335, 0xd5510e33, 0x24faefde, 0xeb198e3c,
	0xd7176839, 0x1e75a05d, 0x6bef18dc, 0xdc5779a1, 0x06a2eb73, 0x252d2b2a,
	0xd3564283, 0xf9e4effc, 0xa586ca07, 0xc675fe90, 0xc9bfcc6e, 0x93cdbf98,
	0x91d7ce1b, 0xfa516ff3, 0xe0b477c5, 0x18830c8e, 0x206cfea9, 0xd52f7821,
	0x7fe72ca3, 0x72fb0733, 0x7d87c581, 0xf1344b79, 0xde2168d8, 0x08f9e634,
	0x91339ff1, 0xf3c7af9f, 0x7df968e4, 0x609683f2, 0x325f7d0b, 0xd7c639f9,
	0x3eddeb8f, 0x26558d2b, 0xfcd17048, 0x81df85ca, 0xe9387ff9, 0xd2742fef,
	0xa193beba, 0x771d6137, 0x7fd25926, 0x47d0f3c3, 0x347e82cd, 0x4be3ae51,
	0xc75e43f4, 0xb3b1e16c, 0x58362512, 0xf6cc1fb0, 0x6a54a5c8, 0x08e64f92,
	0xcde31dbf, 0xfbb73a13, 0x1f8759f5, 0x09affffa, 0x7de682e7, 0xf3f008ab,
	0xe5c82285, 0xedc422ed, 0x5c9d10ef, 0x3a26f057, 0xa48073b9, 0x5b078f93,
	0x03f7fe19, 0x298abfdf, 0x75a26b4c, 0x3c34dacc, 0xb6cfa047, 0xaf9f0c81,
	0x832cf79a, 0x378f887e, 0x4b9e3e2b, 0x29beccfd, 0x0ea78f82, 0xf9ccf854,
	0xe8ea7e32, 0xdc77b5e9, 0x1b870429, 0xe0de940c, 0x477b61af, 0x57ef0f08,
	0xb7f8335f, 0x0316ead8, 0x5e1d3f08, 0x17306fb2, 0x18faf6bf, 0x649f4faa,
	0x3cd2f715, 0x78255e5e, 0xc8b97b3f, 0x315a641a, 0x46999bec, 0xcd2633bf,
	0xed4f1359, 0x39de7da6, 0xf4e54436, 0x847f64a1, 0x071bbbc9, 0x40935d6c,
	0xe6d94de5, 0x0e8b37e7, 0x233ae01b, 0xccaf6cdf, 0x776e6b1c, 0x0e426310,
	0xf82b5689, 0xb48640e8, 0x3148c437, 0xb7c60bf2, 0xa7af84b0, 0xc779c667,
	0xf9c79a39, 0xe030fd0c, 0x0f96e2b9, 0xc04c8917, 0x063ebc4d, 0x721bc0fb,
	0x1e93ef5d, 0x8e281449, 0x418ed337, 0xa447d67a, 0x09fea16f, 0x4f2845e9,
	0x3cb97b36, 0xde0c7a4d, 0x71f66d9f, 0xc966707d, 0xf177e86b, 0xc06d4ffa,
	0x092e3dcf, 0xd6f6aaef, 0xf5569869, 0x2823f6fe, 0xd325422b, 0x392eddb0,
	0xe50478da, 0x5676bd3d, 0x2ced93a3, 0x1977de63, 0xec577a74, 0x080b9bec,
	0x673d77ce, 0x6d3d71f5, 0x065b9cf6, 0xfae76ea0, 0xeea8e8a5, 0xe90cd102,
	0xff56f54b, 0x7fcbcc31, 0x1248eba0, 0xe6e3efad, 0x13ef3c09, 0xf79e7ecd,
	0x5ce9e6a9, 0x8e4b32fa, 0x29f13b73, 0xecb799eb, 0x52a5b2ee, 0xe6bf62fb,
	0xe75edf07, 0xf120c117, 0xdcbb66df, 0x7ed3360f, 0x549e3e00, 0xbb91fb30,
	0x7eb5e405, 0xbbcfdf16, 0xc6315969, 0xcca13999, 0x7eb77686, 0x4652442e,
	0x157e9d1f, 0xd7f5abdd, 0xf33b7819, 0x78e18d0b, 0x1afde2c6, 0x2fc09ef4,
	0xf77fbcad, 0xd4aa68d8, 0x23bbcf7f, 0x85a20183, 0x06b2fb15, 0x61587f43,
	0x0c4e0ef7, 0x114e87d3, 0xbe98453e, 0x7fc9ea7c, 0xdfc3d64b, 0xf67fb627,
	0x3fb1c87b, 0x9a46394a, 0x430f47cc, 0xf64d0dce, 0x6b3c8ec1, 0xdfa409d8,
	0xabbf60c5, 0x71df1077, 0xfa851f5d, 0x677168a9, 0x3fc7d509, 0x7c193a95,
	0x82a0f184, 0xfb953929, 0x6fcca6d4, 0xdbc6fb7b, 0xfbf95ed5, 0x267ea987,
	0x69d80968, 0xda233a3f, 0xeb1cfecf, 0x41f6eeda, 0x6cd3cb9f, 0xd74c4dd1,
	0x3cdbe641, 0x226b6bcd, 0x53f8f439, 0x91f90c8f, 0xc42c7ec0, 0xfcff7a04,
	0x539618c6, 0xc77ddbcf, 0x23fdf09a, 0xfc9ffbf2, 0xefef9be0, 0xdd5f7947,
	0xbfa26fe8, 0xa7ee44cc, 0x8d97dfe2, 0xff69bac4, 0xdfd42916, 0x42d59f4f,
	0x0a2142ae, 0x4eae0eda, 0xb15cf9a1, 0x8432cba5, 0x5aeda2ca, 0x6951ca0b,
	0xdf628fd3, 0x32f4cc2c, 0xceecc65e, 0xbd82a6b0, 0x7f7f0486, 0xe6ebef3d,
	0xedbf3efd, 0x4443c9d3, 0x523fbedf, 0x8ab93f6b, 0xda4f7ef0, 0x9f59a33b,
	0x8f3cad15, 0xbce6077d, 0x83af3b75, 0xbbcc0a34, 0xfde3e1cc, 0x0ad81825,
	0xe7a33b3a, 0x2e7f58f9, 0xfc043c09, 0xf907d19e, 0x433cdfb0, 0x68d5f4f6,
	0xebc6cc7f, 0xaffb767c, 0x895fe0e2, 0x45d53b27, 0xba8aebef, 0x5d7da1a7,
	0x1e80579a, 0x61bd1ed2, 0xbf53e03a, 0xee56df77, 0x83e9d6a7, 0xefb559bd,
	0xe85491fc, 0x5f0a3781, 0xaf6be80e, 0xaa7f7fac, 0xa5a567df, 0x8bfd6d56,
	0x709477ac, 0x7bb484bd, 0x4b97da1b, 0xb19367fd, 0x42ce89af, 0xb24c7796,
	0x7d7c3ede, 0xfde35e9f, 0x4a408ce6, 0x3f6fbba3, 0x566c7da4, 0x21c05826,
	0x7c98efbf, 0xe5c33a7b, 0x8731f732, 0xfea91fb1, 0xc0443936, 0xd1a4fd45,
	0xacfb0d73, 0x3bbfee43, 0x5e806e48, 0xe34bfed4, 0xefca6596, 0xa99790fd,
	0x2f60ad56, 0x537523c1, 0x970feb14, 0xf882fe3b, 0x2b1fbc75, 0x5a21aa3d,
	0x3416b7ca, 0x71dfefa1, 0xb49975eb, 0xff634afe, 0x3e6f3616, 0xdc978bf4,
	0xd64cfafe, 0xb1d3baa3, 0x5717da06, 0x256f5ea0, 0x4c2b2abd, 0x5e2772af,
	0xc278bed6, 0xf7c26fed, 0x727edb97, 0x1e33cd0c, 0xc8a3b2a5, 0xce57e8aa,
	0x876eee66, 0x4a207d9c, 0x31d8d9ca, 0xfad44f2c, 0x4c3ffb22, 0x5c93ae7c,
	0x09f68979, 0xc53f609d, 0xf8c6c93d, 0x7b52d17c, 0x62d7f684, 0xd9080239,
	0xeb963096, 0xdf8258fe, 0xe855b754, 0xaae7d8fd, 0x026d7c24, 0x880da6be,
	0x1e2bb531, 0xff00e090, 0xadbaee5e, 0xd1ac7e06, 0x0ef17f6a, 0xd6feee10,
	0x9779d72d, 0xc060dc6b, 0x7976b265, 0x56cb7deb, 0x30f004f2, 0xfbc45dc5,
	0xacf714dd, 0xf9e0ba63, 0x91fe63b7, 0x8f5c8ceb, 0x1e9e5e70, 0x044d75f4,
	0x4fbfe02c, 0x3ae7ec1d, 0xe9fcef60, 0x0f3c107f, 0xc1f7cb2c, 0xb2067f1e,
	0x9c49f616, 0x03d4f583, 0xb90022b1, 0xa0d66072, 0xe7f2ec20, 0x6e420761,
	0xbdf2140c, 0xb03fb64b, 0x1bef1070, 0x3ee4a243, 0x368f6e22, 0xf181a7fa,
	0xfcc1aafd, 0xf8d68b7d, 0x5fbe016a, 0xe772c315, 0xdb94a0dd, 0xdba1096d,
	0xedbcf4ad, 0x76815cd3, 0xfae08aef, 0x695bb44c, 0x3ef476e5, 0x6dfa81b5,
	0xce52365b, 0xde561ff3, 0xfc8ada27, 0x966e8929, 0x6a4fece3, 0x494fe59b,
	0xc0d92b80, 0xf956db57, 0x92fc087e, 0x75419f78, 0x976f7f2a, 0xda336fed,
	0x4ba0cefd, 0x039673e2, 0x1b18ccfa, 0x991ffce8, 0x7f314f8b, 0x468a7f08,
	0x915c3fe3, 0xdbc2bec3, 0x60cc6faa, 0x12fc31fa, 0xadb90c0b, 0xce07c3fa,
	0xe583d0f1, 0x1dcac2df, 0xbcf3d02e, 0xed17572a, 0xaadde2c0, 0xcbb0b1d5,
	0x50d6e9e7, 0xb9c5f414, 0x7d5efec5, 0xfae3132c, 0xca15b8e5, 0x03950bbe,
	0x76e8bfae, 0x6f597b8a, 0xb7098d0f, 0xeb7e1497, 0x852527da, 0xa2cbc5db,
	0x11397ca4, 0xe7f6f92d, 0xd15ffa31, 0x1bfec36f, 0xe5edc293, 0xe36b9585,
	0xf18cdf98, 0x93fb374e, 0x1f43678e, 0x1aa5ce9b, 0x7d338d4f, 0x11afd3b6,
	0x46f67a7e, 0xa77b3eb1, 0x510de741, 0x5790f9a1, 0x91dd2e8d, 0x4faa7185,
	0x076f8216, 0xc78bcecc, 0x62bdcffc, 0x8e4fb015, 0x1d877819, 0x1a06b806,
	0x845e9963, 0x9dbfd751, 0xe91176c4, 0xfa5f4c93, 0xaeb8a3fd, 0x9529fc3b,
	0x4415dfa0, 0xc707443f, 0xb1fdf23c, 0xbfa604da, 0x5e6bfbd2, 0x63df0413,
	0xd3a60e25, 0xecac0763, 0x9343fabf, 0x3820e435, 0xe17d9d9f, 0xeefa5cc1,
	0xc60fcaec, 0x73b2a66f, 0xffac7bf5, 0x9baeae97, 0xab4aef81, 0x3ec4ce57,
	0x2a3e2977, 0xf3828dad, 0x636e17a3, 0xacdefcb3, 0x85df5881, 0x6fea1623,
	0x43ed4d48, 0x96674095, 0xd7f5839e, 0x01eb3a3b, 0xffe7fa8f, 0xe5bb0e98,
	0xd93f73dc, 0xa7ca8473, 0xfc11f563, 0x190df57e, 0xad99d16b, 0xadf0173b,
	0x40be11b7, 0xd87ec63f, 0x2bcfd060, 0x1815fa59, 0xcbf576a7, 0xe4c767ac,
	0xb5f94877, 0xfef8f2f2, 0xcf1d81e4, 0x4d5df468, 0x2e7a81f4, 0xcc42c1ad,
	0x8a1694eb, 0x5700b2d3, 0xf69cff69, 0xa812e284, 0x2f522dd4, 0x5e65d9ab,
	0x90754f2f, 0xefa15fe1, 0x7eadda6a, 0x413bdb17, 0xd91fe607, 0x739e86be,
	0x5e7ccbbb, 0xf3e5da2d, 0xb83ffd84, 0x143fe246, 0x7c9efc22, 0xf01b673c,
	0x4fdf667f, 0x497f1772, 0xf9e2e31c, 0x069ff5ca, 0x4f5c11bd, 0xe83b13d3,
	0xc994776d, 0x78fb3f0e, 0xcede898a, 0x083c3e3e, 0x9efd573e, 0xf08be435,
	0x059f8fb5, 0x8fb7f03e, 0xe4aabe87, 0x17b6708a, 0xd79d1db2, 0x51bb085e,
	0xd25123c9, 0x83cfcb9e, 0xff68b9ed, 0x25fa458c, 0x3fd5b8d4, 0xaf7add4d,
	0x2c06aff4, 0xb51f5163, 0xefd5750d, 0xf86fad57, 0x3ea98766, 0x7fae6822,
	0x0dfa4b23, 0x9e82789f, 0x1ab77e4b, 0x2af09cf6, 0x1ea57a3c, 0x9df970cc,
	0xeee5c143, 0x355f9254, 0xcf265b98, 0x27fdca5b, 0x99e2ffa4, 0x72153d22,
	0x43d62cf5, 0x81267cf3, 0x43d0f9ea, 0x5d55bce4, 0xde7221c1, 0x24b77fab,
	0x6dcc7e15, 0xe5dfca59, 0x69fa0c1b, 0xd5394971, 0x203b2762, 0xd561f61f,
	0xd836e398, 0x0ae4be8d, 0x961c1f5b, 0x82722e6c, 0x296e97fe, 0x43d38672,
	0x4731aecb, 0xa7166769, 0x987cd977, 0xf82d8b72, 0x2db9e803, 0x01edacbb,
	0x7e9defc1, 0x7dda7f6a, 0x5bb40de8, 0x346125b2, 0xfdf552f4, 0x92e3cdd2,
	0x39e6c22b, 0x9e19976a, 0xfae6ed05, 0xf5cdfb15, 0x06d5d0dd, 0x15dff3fe,
	0x31f5cc85, 0x8ff5cd47, 0x7cf7737f, 0x35955d90, 0xf42b03f0, 0x1da6f7ee,
	0xc9f23ec5, 0x01c6cf33, 0xac7f353f, 0x627b0238, 0x9c3366e9, 0xf41a6f09,
	0x8d4ec0ed, 0xc165d1f7, 0x9fe8fe48, 0xc558856f, 0x3a2837fa, 0x45aa4e9c,
	0xe32d88e0, 0x44a7f6e2, 0xd13f7cfb, 0x8ad36d55, 0xf4c7c731, 0xfb557bf5,
	0xa1f40746, 0xc52f71c8, 0xf7edc2a7, 0x3654afc2, 0xbabbbe41, 0x80f8b269,
	0xe1b124b6, 0x7f40d357, 0x78d7df65, 0x7a7b2dff, 0xd3908bf8, 0xde167b5d,
	0xe9fce5c4, 0xefe50f0c, 0x0b407a5a, 0x33dd52c5, 0xe56dd241, 0x68282d66,
	0x44d78bde, 0x71e03e29, 0xe798362b, 0xfccda4b1, 0x83fee97e, 0xb95c457f,
	0x03a8f9ca, 0x16d558fb, 0xe75a7bf3, 0xd537d861, 0x77f6089f, 0x22ff6f54,
	0xae5efcca, 0x23ad52ab, 0xfac09d70, 0x7a4d96ae, 0xa8e394f5, 0x4bff1c90,
	0xc829c97c, 0xb6dbabf9, 0x3ab7015a, 0x93c37fa1, 0x287bf6c5, 0x24b1e686,
	0xd1b1f48a, 0xbaf2ffbc, 0xe78e6fce, 0x173d3978, 0x5e7e7a2e, 0xbec78c74,
	0xac6f7e7c, 0x3a51c64f, 0xbea87bc6, 0x5b80ea94, 0xf8656895, 0x5afe42d4,
	0xc3f8bd25, 0x853c0be6, 0xb4ab45d7, 0xa16d6a67, 0x8d438083, 0x80efe4e8,
	0xb576f0bf, 0x1377aeb4, 0x7c447fa1, 0xf7ec7c2f, 0x183b706f, 0xbffb0d6f,
	0xaf7f0a88, 0xef652aec, 0x63e7bf29, 0x8345b7d5, 0xfe6ad7ae, 0x94569c87,
	0x40473dc1, 0xbcdccbc7, 0x55b6dfef, 0x3836f3ca, 0x6e17a0bd, 0xe5fac11c,
	0x173f9a6d, 0x5d1b15eb, 0x25b65f6c, 0xe2d633f8, 0xa53cacfd, 0x1f900637,
	0x3a2cbdd0, 0x8bef0db8, 0xb6dabea4, 0x87f59730, 0x10f6b5e7, 0x01e070e4,
	0xb36d2fc9, 0xddb4fd24, 0x7fefc297, 0x40a6a98f, 0x4a7a94af, 0x52e1c6db,
	0x79cab5ef, 0x5963fb88, 0x1865b63e, 0xe5e81af3, 0x72bd2979, 0x911f4783,
	0x9d6fb03d, 0xaf49ab15, 0x77c41e44, 0x1ffe02ad, 0x59749551, 0x630ef9fb,
	0xe8deea9f, 0x7f3fc20a, 0x82392b5c, 0x776a8b38, 0xfb94b675, 0x77fb27e3,
	0x8fd8ed1a, 0x7599615f, 0xef18f5ef, 0x25b78b41, 0x7efe0c23, 0x82ec2e7f,
	0xa35d1be3, 0x93f1a781, 0x58e61fa5, 0x31df9491, 0xf11f8563, 0x32d929fe,
	0xdb253b3e, 0xa3932a62, 0x9fa92e89, 0x9fd2c5e3, 0x84b63b1b, 0xab845efd,
	0x53cbfb3b, 0x4fd19af8, 0x97e4a385, 0x1f33f6d7, 0x55311f05, 0x72f8e7e2,
	0x179c9b6d, 0xe3ea97e1, 0xfec5ddff, 0xfec6e3b2, 0x7442f0a2, 0x5bf78e34,
	0x346d7e43, 0x25e367e8, 0x1f4cc7e9, 0xe47d91b7, 0x7d10fd02, 0x04131e30,
	0x7d14ebfb, 0x3d30fd10, 0xcb17df74, 0x31fa2770, 0x418463e8, 0x0dfc423f,
	0xed2c53f4, 0xa88f6523, 0x1eca5f75, 0x01a8ba21, 0x4bb6f45d, 0x3c458ee8,
	0xb083d14f, 0x597dc705, 0x84f1617c, 0xa11af184, 0x0226d522, 0xec370451,
	0xefb70c89, 0x69ab82d9, 0x126d431e, 0x4936693f, 0x04bbb487, 0x7b7347a2,
	0x65ea83bf, 0xfc2a5c3f, 0x552cbed4, 0x9b275fb0, 0x44f891f4, 0x44a04efe,
	0x7f0ace18, 0xbef89507, 0x5ff65e2c, 0x57045836, 0xdf9fdc6b, 0xb5086892,
	0x0a1f88f1, 0x7df01bd6, 0x3efe68dc, 0xfbdf9160, 0xcb0e546d, 0xbdd3fc92,
	0xb0f98a36, 0x5cb49eec, 0xc98ccbd0, 0x96397a66, 0x5503f52d, 0x096488de,
	0x63242fa9, 0x66bc597f, 0x2d2fef04, 0x7dba92ae, 0xd293fb80, 0x775b282e,
	0x30e32dc7, 0x7c92a7bf, 0xce4e6150, 0x8571c3dc, 0x7e166bc5, 0x13d86dfd,
	0x7cfc5cbb, 0x30fe8e49, 0xf3527ee0, 0x0f47da2e, 0xec3bcf16, 0xf5efa648,
	0x7e6759f6, 0xc0cce54e, 0x3fa0379e, 0xe56b9ccc, 0xf48533f6, 0x72358a6f,
	0x9f025b9c, 0xbfa992da, 0x1c6a265b, 0x7972ef26, 0x9e2397d2, 0xa777e060,
	0x2e2d87c1, 0x6e67e0b1, 0x372d2bcc, 0x02df9e93, 0x3d1fb20d, 0x2f8303f6,
	0x5b69265a, 0x9b0d07a0, 0xb550f922, 0xf7e83f47, 0x7b77c184, 0x3aa8b80c,
	0x57db95c1, 0xcaea8fac, 0x0f69438a, 0xe072a70d, 0xb2fbc9f0, 0x4c8cfde9,
	0xe0336d31, 0xe72b4dfe, 0x44b9747f, 0x4779e988, 0x1741e301, 0x60f75ddd,
	0xf147db7d, 0x7926bafa, 0xd98457d2, 0xc11e95b9, 0x24d7407a, 0x3a783e43,
	0xffa51363, 0x72dded87, 0x6c3e0483, 0xe201f96a, 0x9d2be5a4, 0x2a37d85d,
	0xf1c3981f, 0xb236f2ed, 0x165f6977, 0x2ef6cc1b, 0x67afa5d9, 0x46bf63f7,
	0x11a0a9da, 0x06c54dd0, 0x586ee98d, 0xc291cf8b, 0x60f34df2, 0x50ee153d,
	0x857fe436, 0xfbc3e5cf, 0xcfd8ec8b, 0xe1e3ce09, 0x0c9c154f, 0xffa39dd4,
	0x6b29701e, 0x31bb632d, 0xb9675f26, 0x704acc35, 0xde807f01, 0x05f83700,
	0x9d6c8f21, 0xfbc3e029, 0xce1d25b2, 0xbae4f448, 0x025d8e99, 0xeecba0f2,
	0xbafcc5c9, 0x882cbad6, 0x2d58cce3, 0xccf899e9, 0xbfefa369, 0xe0d11367,
	0xef8c27ff, 0x4ad9574b, 0xa87d52b6, 0x1362d853, 0x4c454f41, 0xeb870bcf,
	0x4faf307b, 0x402623be, 0xb0df283f, 0xa0cbce51, 0x98eb6107, 0x7ce3449a,
	0x346323b2, 0x7e8aeafc, 0xdc9f0e16, 0xd2f63803, 0xf18d5cc1, 0x0a39eb4f,
	0xe1c0e57f, 0x3de02f8b, 0xfa083f3d, 0x94393198, 0x5b16fc0d, 0xf61f856b,
	0x41f0b27c, 0x9211e89f, 0xdbd67bbf, 0xb929ae58, 0xd107e4a2, 0xa839df83,
	0x8e4adf0f, 0xa9a66cec, 0x35779c11, 0xa27cb93b, 0x246c23d9, 0x27377603,
	0x66a9fd73, 0xcded972f, 0x67fcfc79, 0xefae3ecd, 0xf5c09e6d, 0x5cfd9a67,
	0x9d3cdfdf, 0x97379fcb, 0x0f8273f0, 0x672521cb, 0xf4523c94, 0x2452e4a5,
	0x30222d5d, 0xbf9a375f, 0xe4a7f967, 0x1961d61e, 0x148f27dd, 0x27ebed9e,
	0x68cfd859, 0x7ad8b9e0, 0x0167c9fa, 0xe7372a87, 0xc5c2f62d, 0xa4b864ed,
	0xd87ec43b, 0xfdcb2deb, 0xed84f75d, 0x6957b7bf, 0xb74616c2, 0x84ba3477,
	0xefae8c2d, 0xd5304a6c, 0x7ade9b4b, 0x7ff53069, 0xcfcf4e3c, 0xeefbbc81,
	0x96fc8f47, 0xddf63f9e, 0x3bc03993, 0x26c763cd, 0xda32bb8c, 0x9ca74798,
	0xef074ad7, 0xff0cc35b, 0x619cfe0e, 0x196597f9, 0x04fc6f09, 0x22700d72,
	0xf03dfefa, 0x83fcf043, 0x06639f81, 0xcad6ca7e, 0xa02bad7d, 0x5fb43505,
	0x7ae9f063, 0x279aa782, 0x14fdf3c1, 0xd90319d1, 0x710217ed, 0x93bff795,
	0xd6be0e9b, 0x852a98c8, 0xcbfd6cdf, 0xad1c62ef, 0xcdeb28e9, 0xf9cdd3ba,
	0x3f602202, 0xd68fde1d, 0x89db8474, 0xbca6a1ce, 0x7eb198bc, 0x4d03fa07,
	0xf38b5f03, 0xb7f0090e, 0x403cd568, 0xbcf18551, 0xfac6bd62, 0x9cf78288,
	0x53f32b1c, 0xcb8db66b, 0xb675e033, 0x3f795a5f, 0x724a7452, 0x2aebf383,
	0x4b1c8b5a, 0x62efe4c2, 0x9e7979e3, 0xd77f94c5, 0x7ee0ed9a, 0xe86980ce,
	0x65e6f7ff, 0xde592a3a, 0x0fa01d79, 0xde717ed5, 0x639975e8, 0x60b20fd1,
	0x33bfbefa, 0xb7dfc6c7, 0xbee47b66, 0x2b7da4e5, 0xfa51f396, 0x6f4aff95,
	0xbcff04f9, 0x76cfe78a, 0x3f53f554, 0xad710a7d, 0x78a2f7ea, 0xc2beaa1f,
	0x07e43bf0, 0x7d61cfc7, 0x68d6efc7, 0xde06f59d, 0x8ff4fea7, 0x6a03c871,
	0x8bfd2bd8, 0xaca17654, 0x7ec5595f, 0xf11f7aae, 0xabe42245, 0xe2fc2e39,
	0x75c5ef53, 0x90227fb2, 0x7283e46a, 0xdefd535e, 0x49df380f, 0x7e4537e5,
	0xce7da0d7, 0x7b8aa876, 0xf16378ab, 0x97e6760b, 0xf634e786, 0x3bec3613,
	0xadf2083f, 0x83b585e1, 0x893fcbfa, 0xc1c557ec, 0x41ac1f95, 0x0ad4f86c,
	0x043b21ba, 0xff6c8c70, 0x6e231cc3, 0x92b8a57d, 0xc1361cfd, 0x8c2b0a79,
	0x609eb1bc, 0x12f8bc4e, 0x66c351ff, 0x8831fe62, 0x91e37a87, 0x4c8e7b3f,
	0xf4f0fead, 0xa7dc8e6e, 0x213f10cf, 0xb76e7a1e, 0x73c4f595, 0x7f9963bb,
	0xf0ff77ea, 0xf5abe208, 0x670e35db, 0x860e89d5, 0xab5efd5b, 0x85c98670,
	0x926ff806, 0x9acf3d2e, 0x8236c69f, 0x6bb596be, 0x9f341dfe, 0x7e37a71e,
	0xf67cd860, 0xaf7a48e5, 0xcf1f6a89, 0xffe63178, 0x524f4353, 0xf81d96ed,
	0x51f7e721, 0xbfacb3bb, 0xc70c47fc, 0x7ae7697d, 0xb53cf303, 0xf60f8c65,
	0x3df6b2eb, 0xd88758f5, 0x12c1e31d, 0x727e1a4f, 0x6341cfd5, 0x523983bc,
	0x788538ef, 0xca7fbe01, 0xe60e76ca, 0x693cbe09, 0xefaaffe4, 0x7bbe365e,
	0x43ea4739, 0x0e1608b5, 0xacbf6bec, 0x9b2e2bbd, 0xffbc7fda, 0x657f2e2d,
	0x7732cdf0, 0xcff62147, 0x4cc6f78f, 0xa3f9720f, 0x78d3cf69, 0x0d27da67,
	0xecf8c2d0, 0xf25d8e78, 0x779916fd, 0xaf2a8228, 0x73d79da8, 0x06aa776a,
	0xe01d5eff, 0xb539f04d, 0x0b38e9f7, 0x7fe071f3, 0x40b65f96, 0x97e785b3,
	0x7ffa6975, 0xe31e848d, 0x78c874ec, 0x5fe1b755, 0xbfe9dff9, 0xa5de78de,
	0x74e31895, 0x19df243b, 0xc18f7e71, 0xc1fcd677, 0x5745ffe0, 0x1dbd6f78,
	0x9955f3f2, 0x7a8627a7, 0x5bcec137, 0xdb1266f4, 0xa3ef88e3, 0xecd7e7fe,
	0x3459771c, 0xc92b90c6, 0xe7e0e39d, 0x7a90caec, 0xe27aed44, 0x0d690244,
	0xe08057d1, 0x08b41b57, 0xb971ea9d, 0x53a78c99, 0x8e0eff44, 0xe172847b,
	0x10e63cff, 0xf1f42b01, 0xafd8b99f, 0xca199b5f, 0x14f95f85, 0xdaca89f8,
	0x126e50c4, 0x9d0670fc, 0xf7a6ced4, 0xbb52f461, 0x3d0b942d, 0xfa43b4e9,
	0xf61ef117, 0xd968ed50, 0x73c32bae, 0x7ddaed96, 0xab7a02b1, 0xa658d9e5,
	0xb89fbac3, 0xed8545b6, 0x52b9a9c3, 0xd87ea62f, 0x29d81abf, 0xae2cb3e7,
	0x6d39fb95, 0xe8b2f7d0, 0x31df9e56, 0x996c6f23, 0xecbbd643, 0xdd1ce382,
	0xbdb1478f, 0xe3a53277, 0xf2738c19, 0x171c11f1, 0x2e08caef, 0x49efcfd9,
	0x56f823ff, 0xc215113f, 0x1e3c4ebc, 0xe9a6fecb, 0x08bcdddf, 0x47b67bed,
	0x277f9069, 0x32470a06, 0x18ec4fd5, 0x09f6fbc8, 0x9171cbcd, 0x7124af13,
	0x4dcdd57f, 0x26a87f1c, 0x93fd0131, 0xdbd0e9ca, 0x2878ec4e, 0xf54bfc1d,
	0xa2eba8f5, 0xc0b7d175, 0x1c64bba7, 0x7f13e4ed, 0x879e111f, 0xedeacaa1,
	0xc2957f66, 0x4d7f7aa7, 0x6bc7e4ae, 0x5f3f2572, 0x7861eb9f, 0x3fb4c5d5,
	0x93ebc998, 0x66704dfc, 0x69f880fb, 0xc7d8fc10, 0xa41b9fda, 0xcfd53f51,
	0xcfb1fac6, 0xb943d977, 0xc438623f, 0x821f7918, 0x3b13c9ed, 0x4e8fd893,
	0x73f734da, 0xfb016762, 0xb6ee4fd9, 0x06663c73, 0x63c63674, 0xd8b7c301,
	0xfd90a5ba, 0x2c63db57, 0x3df563c0, 0x5fb05a57, 0xff59bad1, 0x7caa7eae,
	0x23f75186, 0xadfd5f4e, 0x05782b6f, 0xfda2ffe0, 0xad68e587, 0xeeeb4721,
	0xf91e26b9, 0x2b4de2c6, 0xb79fd9e7, 0x4e4306f9, 0x4365c246, 0x9f4721ae,
	0xb6f98479, 0xf91ce896, 0x3c46353e, 0x8d09e6b4, 0x759abdf5, 0xf9626cd7,
	0x205d86f8, 0xfb74f8ef, 0xe1c2e30f, 0x9fa30dfe, 0xdc7defbe, 0xcbda86be,
	0xe38d5fef, 0xfbb4ecf9, 0x7c489f30, 0x4ff7f65d, 0xefa5ff58, 0x0f49dbab,
	0xfd78bc28, 0x37c745e7, 0xd81c83de, 0xf805f2ed, 0x4f9f3b69, 0x5f6f6539,
	0x7a9ff582, 0xe1f2c5d2, 0xbf918254, 0xc05efb4f, 0x7cdcf981, 0x7ebdfb3f,
	0xb440473d, 0xfb9a0d2f, 0x76faf355, 0x75cf94ae, 0xf078be49, 0x03e11d61,
	0xbe7e11fd, 0x69bfdfc6, 0xd723efe7, 0xaef8d0b3, 0x8c9f0f97, 0x353c3a61,
	0xd4e5e244, 0xdf79c353, 0x74904ae9, 0x7b65f34d, 0x2c8254f5, 0xf4043271,
	0xf491ed50, 0x3b526a70, 0xb4a7e7db, 0xd9765c3d, 0x4dd577e5, 0xe8961c46,
	0x03f41934, 0xca1c459a, 0xfa03a1b9, 0xf8f1e406, 0xa2865cd1, 0x5ff62f12,
	0x9db31d13, 0x4fc196f7, 0x8f208350, 0x7ec27e39, 0xe40776d8, 0x7de86ea9,
	0x8e2fbbb5, 0xb54f01ab, 0x078e35bb, 0x53572cfd, 0xef3e77fe, 0xbc252352,
	0x7e6809a8, 0xacd519e4, 0x740cbe59, 0xf1b8d35f, 0x5a83f076, 0x4c4d8d47,
	0xa5d61d87, 0x643e7959, 0x3b39dfdf, 0x14f1e2ff, 0x1be85f7c, 0x3ed47847,
	0x1076bc43, 0xb281d241, 0xd5fd4ade, 0xf036d1ae, 0xfeca1938, 0x7053eb94,
	0xf81169c2, 0xe05f94dd, 0xf357eb52, 0xde7cd4bc, 0x5750e436, 0x89fef786,
	0x56ebf7c0, 0x3fe72796, 0xf89f131f, 0x671b7a25, 0x68feab8e, 0x4e93effe,
	0x43527ec6, 0x94e0d59e, 0x7733cd04, 0x92ae398b, 0x1f5cddb7, 0xcf5cdbb9,
	0x17ae6bdf, 0x7dd7301e, 0xbfeb9a2f, 0x7055c634, 0xfc8c3d82, 0x28c3d835,
	0x28e30f61, 0xd461ec0f, 0x84a30f61, 0xb0e78c3d, 0x3d875187, 0x61ec3a8c,
	0xa30f61d4, 0xe78c3d84, 0xbee5c349, 0x31f86b56, 0xabce0781, 0xe2a5ce7a,
	0xe72fcce8, 0xf2920e16, 0xc5ed26d7, 0x59f2cb73, 0x4972ebcf, 0x2cf74f3f,
	0x96fb0fa7, 0x2eb9cbca, 0xdcefff56, 0x76778871, 0xe0c94bac, 0xdc2fd8ef,
	0x17e973f0, 0x72ed1dae, 0xb9d11fc3, 0x5075e3f6, 0x7562124f, 0xc871f0cb,
	0x09deea63, 0x1d35d6f8, 0xe774f8e6, 0xd79bef2a, 0x5fb1fc4b, 0x94d9e544,
	0xdc835f61, 0xe3821c46, 0xb8673e90, 0x3e32335f, 0xd5843623, 0x99b4e7a1,
	0x18f191eb, 0x89bf35c8, 0x4e195aaf, 0x53bbd98f, 0x783ff720, 0x9de7c9dc,
	0x68fc303e, 0xf5878162, 0x2377a526, 0x6572174f, 0x36da7dc5, 0xc359d7ec,
	0x3d9f1913, 0xe74c7347, 0xf2cb22bb, 0xaf59a30b, 0xd06fadec, 0x9867182c,
	0xc58ffa43, 0x9789563b, 0x9fde38e4, 0x38e632ee, 0xd87afa1c, 0xa30447fc,
	0x6a34f44d, 0x1c446257, 0xfda98871, 0x2333fb15, 0xcd2388e2, 0xabb9adf1,
	0x9efec20e, 0xa98c61b3, 0xeff079dd, 0x32b3ec58, 0xe4a2a72f, 0x96b8889a,
	0x7c8f4f31, 0xe89d9776, 0xb5dfda85, 0x87f7852f, 0x7fb79a0a, 0x8249e20c,
	0xb5d2e8f3, 0xe3963ac0, 0x3fce355b, 0x1ff6372c, 0x8fde64d1, 0xe0226cab,
	0xc6809c41, 0xbb587e87, 0x9570706f, 0x557f47d6, 0xa04fe11e, 0xec8d96fe,
	0x9ec10c28, 0xe3c7e578, 0xd6754f41, 0x8388e9ad, 0x7705addd, 0x4e6e887a,
	0x7419ee26, 0x93ffbd15, 0xfa039f45, 0xdc747d3b, 0xce08131b, 0x7d5b77a7,
	0x1edd2718, 0xddda341a, 0x76e97747, 0xbff0344f, 0x76cad5b5, 0xd659fc04,
	0xd8fa3ec4, 0x9d149ada, 0xb75beeed, 0x8e6187a2, 0xb0bbd0d0, 0x58b99fae,
	0x9abd22cf, 0x47f3abf7, 0x55cfacad, 0xac02d24d, 0x5ceb1af7, 0xa9df91e1,
	0xec371cf5, 0xfb2d9143, 0x7f78dbbd, 0x42c1c47a, 0xcda5e22f, 0x90add3fb,
	0x3bdd96eb, 0xe85ca853, 0x9eb1ebd4, 0xbf39adaa, 0x54e3489d, 0x88156dbf,
	0x36d87f4f, 0xe82aee25, 0x7dda4f9d, 0x4f7ea833, 0xd01d8feb, 0x416dabef,
	0xaad4ec07, 0xfc3ab7c7, 0x6bb0de54, 0xb25f3f2b, 0xf5ed8cab, 0xed91a2a5,
	0xde544fce, 0xaa8f01ad, 0x0f16dac9, 0x436dfbcd, 0xcb45548e, 0xeb628f7c,
	0xa79097c4, 0x56977e7e, 0x735eb384, 0xca38f64b, 0xe1faf9e8, 0x823e9c46,
	0x9b5e7a5f, 0x7e103c53, 0xe18d76a8, 0x98fe297e, 0x44744387, 0x782e730f,
	0x617b9cb9, 0x6fbddb24, 0xb08eb20b, 0xd847e47f, 0xf3c9afbf, 0xdfc83d5d,
	0x39573c21, 0x00e60342, 0x33b0bf0f, 0x7e88ea1e, 0x5d868c26, 0x54d5c42d,
	0x9ab44c96, 0x6a61b7e8, 0x17de898c, 0xa23e3088, 0x218be6fe, 0x19dcfaa6,
	0xb7f6a659, 0xc1151dce, 0xdefba30f, 0xbabadcb3, 0xebd53def, 0x1abc0656,
	0x364cc1e7, 0x2572a73f, 0xa64dd9d3, 0xecc4ebef, 0xf3a076be, 0x3862bfed,
	0x80e1d10b, 0x9c6554fd, 0x77a05847, 0xf93bcf19, 0xc4c42d39, 0x7cb2c397,
	0xa4fb95bf, 0xcaf9fd9d, 0xff00bdbf, 0x9f6feace, 0x1bcdee8c, 0xfc289e44,
	0x0f59ba11, 0x523b60e9, 0x19d43c48, 0x3cbaa2fe, 0x0baa2fe9, 0x87903874,
	0xa5b7f04b, 0x5bea4812, 0x5203f635, 0xa26a677b, 0xf3c4afac, 0x05f3e6bd,
	0xde02efe8, 0x8196b51f, 0xd7df225f, 0x1fb1bad3, 0x03bfc3d4, 0xdfea953f,
	0x67d157e8, 0xc8ecb9e4, 0xbcf2527e, 0xbbd5cf4c, 0x42191cf6, 0x92539970,
	0xa9fe0450, 0x2f659f6d, 0xce98bfcb, 0x5f3fbc94, 0x54ff6165, 0x99876bcf,
	0x6caa7ace, 0xfc87993e, 0xf7a8f0e5, 0x24683f4b, 0xf5a12dfd, 0xc9726f20,
	0xd417cd5e, 0x65c03b64, 0x0232e808, 0xc0fda92e, 0x17a9c14b, 0x97ef116e,
	0x91631fe2, 0x2105a09f, 0x8b822f27, 0xffd1a382, 0x7eb05d12, 0xf209f349,
	0x13fa227c, 0xeff92213, 0xdf373e2e, 0x1e1345b3, 0x30e1abed, 0xabf482fb,
	0xeb92cb0c, 0xf9a7deee, 0xbfcfa7a0, 0xbde7e360, 0xf32252f4, 0x30cee7a9,
	0xfd2f67f3, 0x997e4894, 0x7f106177, 0x474dbff7, 0x2a3f455f, 0xa799126e,
	0x0cfdceac, 0x8bfc33cb, 0x2fb8c4e3, 0xeb3c89fe, 0x1ce7bd61, 0x04fb4ce2,
	0xec092ffc, 0x3bef316f, 0x84263ff0, 0xb4651be9, 0x80c77a9f, 0x820e875e,
	0xfc37567f, 0xeb1e4a7c, 0xd6eb7f46, 0x7f79f164, 0xd6be9df5, 0xf4d6fece,
	0x965c4955, 0xb0833cb9, 0xb2ad945f, 0xf7fdf9f2, 0xd07837bf, 0xf7a3a204,
	0xcc07dad7, 0xffde2ea0, 0x5174d8e6, 0x97317a80, 0x5a8c6c1f, 0x570fee10,
	0xb93cb4e5, 0xf77dd46f, 0xcebfde5d, 0x5b8b5e58, 0xbb5b3e00, 0x37290e2f,
	0x1adf6b35, 0x7b7da1ef, 0x979f45ad, 0xc0fe0e37, 0x0b6fbcad, 0xf842d6cf,
	0x50de94c3, 0x3078b6bd, 0x7fdaf7f6, 0xfb147e1c, 0x3ecabebb, 0x89e6fa08,
	0x513cc8df, 0x5f58b7da, 0xe925c4f8, 0x311d93f7, 0x13edde7c, 0xef11f84d,
	0x583d6659, 0xa3ed31e8, 0xfc63e607, 0x2e349c07, 0x3b8375c7, 0x2fae3193,
	0xfa95f9c0, 0xfef89caa, 0x6caa24fc, 0xb8f52cd8, 0x6bafca9d, 0xbfa17ff8,
	0x1dfd0ea3, 0xefe82441, 0x477f43a8, 0xcf1dfd09, 0x07e7e11b, 0x1774b49d,
	0x4c0cfec1, 0xbc8d7916, 0xa0f3baaf, 0x45a5df9f, 0xee6720fb, 0x39837cd2,
	0xde5dbfbe, 0x21e8a043, 0x76d73e72, 0x4615ae93, 0x705fd79f, 0xb4fcf08a,
	0x54c12249, 0x314ce29f, 0x64f62fb5, 0x90dfde98, 0xfef4c23c, 0xa9916f46,
	0x55de737e, 0xf8b7f6a6, 0x5fea9926, 0xa9a3709b, 0x2cff2cfd, 0xf4ce7d53,
	0xf3f6a685, 0xef4cca4a, 0xccb05d6f, 0xbea17ef4, 0xbdbf54dc, 0xf6a69bea,
	0x32ae3477, 0x8f0bf7bd, 0x01dafb0d, 0xf70455d8, 0xa2aec05f, 0x73d7aef2,
	0x9d78e1dc, 0xd8d2c538, 0x4b7edf9f, 0xde63d49e, 0x04dfe118, 0x0f79c4ba,
	0x719a61d0, 0xec09e39e, 0x1711031f, 0xaed2690c, 0xdd0148ed, 0x7c8bb644,
	0xd0e6313f, 0xe3482f79, 0x6d7365f1, 0x5e260f24, 0x164c6879, 0x1e3e27d5,
	0x0e6bf594, 0xf5499d3d, 0x49ff8f69, 0x7438afd6, 0x3e0fef1e, 0x8dae63be,
	0x39c4cce4, 0x928a5582, 0x06e6f311, 0xaf131d68, 0x93e0dccf, 0x77d6117e,
	0x80af452e, 0x0122f203, 0xa2219407, 0x8887944f, 0x48be513e, 0x2d9159f4,
	0x4fa211c4, 0xbec94794, 0x925ff3c4, 0x35f2897d, 0xbe512fb2, 0xca25f641,
	0x512fb20e, 0x0179bafe, 0xd669bf97, 0x9a77bbf9, 0xb77cb8ab, 0xff9f91b9,
	0xcb89b9be, 0x6407343f, 0x3a9a79ff, 0x16fecf27, 0x47aa8715, 0x9af10ffc,
	0xe1d3f6fd, 0x2fcd5971, 0x37154df7, 0x9d14696c, 0x4ed3e031, 0xce47c25b,
	0xa5e078be, 0x7c4daae5, 0xfd67a614, 0xabffcbbb, 0x0c63f63c, 0x367cb0f5,
	0x73131f9e, 0x9e1346d2, 0xdff43352, 0xd1bcfde2, 0x49e36be5, 0x79ff5c7e,
	0xf2f41da3, 0x73ffa5b6, 0x74184fc2, 0xff8473b2, 0x2a23900f, 0xcee2adee,
	0x612cf9bd, 0x93c47171, 0x8a8cde55, 0x585ff387, 0x538a8c3e, 0xeb9c7cab,
	0x54737b8c, 0xdbe55a1c, 0x2f8b7ea8, 0xd77b9608, 0x7eb1b7ae, 0x21136b12,
	0x6af2a38c, 0x17b675ae, 0xdae0df21, 0xfbe7375a, 0x8ee7a60d, 0x6fcedcd1,
	0x5ffb72a5, 0x5f617da8, 0xb1b07bdc, 0x5c9b588e, 0x9d05f147, 0x1ad7b4fd,
	0xef7c7f71, 0xf803ef94, 0xd059b91e, 0x7994a833, 0xb3f49a6c, 0xda3c38aa,
	0x21f6c8c7, 0x19fd97f4, 0xc7d7178d, 0xed896947, 0x4ad7c845, 0xbe7377ab,
	0x214996d6, 0x2735c73e, 0x3afbbae1, 0x8dc7c8ad, 0xa8f83aff, 0x198f432d,
	0xf57fed41, 0x47cd3782, 0x5989d9f5, 0x32ce5103, 0xc12fe0f4, 0xb8c4678f,
	0xb829783e, 0x78297c2b, 0x312fe587, 0x7f0abf9c, 0xc48b7891, 0xf153c297,
	0x03f83e85, 0xa7e3177e, 0xbff07f0f, 0x9f82fffe, 0x3e76b6b1, 0xeb55181f,
	0x5f5e61f4, 0xbb3baf85, 0x3f9c34c5, 0x3de0bb2e, 0x4c96f282, 0x53f009fd,
	0xcd3498b9, 0xac791803, 0x44e3f005, 0x997f9bb6, 0xd113beed, 0x98e250ee,
	0xbacb7ff5, 0x8896ddb8, 0x63092d76, 0xfa4dfc36, 0xfec56e91, 0xe76bd47a,
	0x2eabd6b8, 0x77e10f95, 0xa71e1117, 0xa8e8f218, 0x83fde468, 0xf000b2d4,
	0xf540d53b, 0xaca5fc94, 0x9b754ecf, 0x9f69c3f5, 0xd773c897, 0x65f42203,
	0x937d2e23, 0xa20defd1, 0x3c8dfb95, 0xa1937d97, 0xcb9e4687, 0x7a411aae,
	0x64989924, 0x4e4066db, 0x393e154d, 0xfd5ce32f, 0x37ec8f54, 0x2c97a0d5,
	0x044c55af, 0xcf9d083d, 0x7388bf73, 0x371885f5, 0x451bf5c0, 0x459bcb90,
	0x85b9fb88, 0x5fea2904, 0xcf2ec213, 0x82f3cbd3, 0x4ffd56f5, 0x39d4b3d0,
	0xff4b9f41, 0x70e7f816, 0xdc52cccc, 0xcc65307b, 0x777c6c94, 0xf597aa68,
	0x2cce4393, 0x57c097d6, 0xfe3ec4f6, 0x17f6857b, 0x1ce05aa4, 0x639c4a1b,
	0x796626cb, 0xd41ff699, 0x255bca6f, 0xaf34ddf0, 0x7d460f39, 0xb267b37f,
	0xb4b98db0, 0xf0b9bf7c, 0x0fc8a1b9, 0xf8613578, 0x5fb9f854, 0x2a72b84d,
	0xc26afbd6, 0xa32c8b60, 0x3c165c1c, 0x3e9fdd9b, 0x6fb9e8a7, 0x96c269bc,
	0x2b386974, 0x53c246b8, 0x805ff9c1, 0xb3c80eeb, 0x013eb848, 0x1c438c58,
	0xf87ae9ff, 0xa462ea7b, 0x1b3ff13c, 0x5c17102b, 0x7fde4fb1, 0x44530276,
	0xc253b5de, 0xf47fd229, 0x0a18b371, 0xf1ed8b78, 0x63dd5cfc, 0x3574d955,
	0xd34973af, 0xd12efe04, 0xfc0b3fa9, 0xca1d1e9e, 0x7c458d25, 0xcf85a5bc,
	0xca799efd, 0x5fbe83ea, 0xf06ef56b, 0x6abc8641, 0xf13f7ce5, 0xc474e1f9,
	0xfef6c4f7, 0x9d6b90f3, 0xaeca8e12, 0xc2599259, 0x633c28fc, 0x5b3de592,
	0xdab31cf2, 0xc94687ff, 0x9e755e3c, 0xc0fa52f6, 0xb72968f8, 0x39494686,
	0xdf47f0ab, 0xfa953d71, 0x29724f19, 0xd668fef5, 0xfe3d33ff, 0x425f0137,
	0x567f49a8, 0x00cf7cf6, 0x44ebc709, 0xd1f826ee, 0x8bb51ea6, 0x99efbd20,
	0x5bf94c2a, 0xdb94afc5, 0xb9d5df20, 0xb264a893, 0xdff8c2b3, 0xde168de5,
	0xc98dfa30, 0x63d5344b, 0xed4c437d, 0x9a6427e3, 0x47f827de, 0x4d27de9a,
	0x0faa6d1f, 0xd4dab92c, 0xc982f07e, 0x7e8a7aa6, 0x6a7da993, 0x5d536cd5,
	0xf954a1c9, 0xde35a448, 0x587efa66, 0xfb5362d3, 0xe9b5408c, 0x3bf808bd,
	0xe9fbe8f2, 0xeb59f7c6, 0x13df9857, 0xfbe32d78, 0x51f8b7ee, 0x31673c9c,
	0xef84bddd, 0xfd69c8b9, 0xd63e7996, 0x57d8adcf, 0xbe35e352, 0xaf06e0a7,
	0x2715ee59, 0x3d53eb9b, 0x75022f45, 0x79913c53, 0xf40d213f, 0x3368da94,
	0x691f8f3d, 0xa285dfd8, 0xafefed90, 0xd23ebfc2, 0x7848ff84, 0x4f0f4c5d,
	0x0d7ee117, 0xd7c3e5f8, 0x387cbf05, 0x0f97e05c, 0x1f2fc3af, 0xf97e1ede,
	0xcbf0f7f0, 0x731fbf87, 0xe3074cd4, 0x7074cc3a, 0x3a66bbe5, 0x8919f450,
	0xcd3aabaf, 0x4d7421f4, 0x5f04bed7, 0xa6627cd7, 0x08fc489f, 0x9bf8cdd1,
	0xc3c4d6e6, 0x7c73ff19, 0xf6348f15, 0xbd5f0339, 0x437821f8, 0x342ebd9f,
	0x8a1ff38a, 0xee055a8f, 0x58c478c3, 0x1aa30de7, 0x4f2499dd, 0x5fe9b09f,
	0xa28b9e43, 0x491496ab, 0x9f473d57, 0xcfee4176, 0x653fe88a, 0x24773e88,
	0x4905a3c9, 0xa01dd3e7, 0xef796e8f, 0x61ac26d6, 0x249e5f60, 0x9cf2e5d9,
	0x7de4b7f3, 0xad2cc72b, 0x23f3e41a, 0xc6297a71, 0x51bf33bb, 0x5935bc43,
	0x8259ec94, 0x8cff98bc, 0xd17d474a, 0xa1bf7930, 0x73e4efc8, 0x2e2e4a06,
	0x3379954a, 0x3b0d2315, 0x67f327c8, 0x7a948e96, 0xc3cfac6a, 0xf965bd79,
	0x99051cf2, 0x0a8be92f, 0x5cd78f00, 0x368f01c3, 0xd7d7df0b, 0xf3c6f769,
	0xac57bb39, 0xe822f102, 0xd327d0ad, 0xe5ae7d0c, 0xe6274e77, 0x30b37c3f,
	0x8223abed, 0xe93e534e, 0x531e5da8, 0xd93da0bd, 0xfd8afed4, 0xa2fbd35e,
	0xfde99e50, 0x533ea398, 0x04c75c7d, 0xdf2bfb53, 0x57ea9bf5, 0xb5374e75,
	0x1293e6bf, 0x74553d53, 0x0ef8043f, 0xfcdda4d3, 0x094cc8d8, 0x8f8caf27,
	0x4127ba2d, 0xec34839e, 0xab97a569, 0xa0dd633c, 0xdefd48e7, 0xc1344081,
	0x35fa41cf, 0x279505f6, 0x05e447ac, 0xf7bffd2b, 0x9cc0429c, 0x83f2ac27,
	0xc303ed7b, 0x273de81e, 0xd783f2a1, 0x1783f398, 0xfd7e8945, 0x948c4f0c,
	0xf9c8b1fe, 0x8e4579ab, 0x91e39a9f, 0x777e8ded, 0x373ffb38, 0x1948ecf3,
	0x559e3faf, 0x7d3a0ed2, 0x777beed4, 0x3f3fc669, 0x67ec4b4e, 0x87e73a29,
	0x5a97f9c9, 0xcace772c, 0x16aa7be7, 0xdc6c2cfc, 0xcf78c623, 0x7d741be5,
	0xc5167189, 0x6fce711b, 0x2f47e71b, 0x43b26e31, 0x701e81ac, 0xfbf686c7,
	0x4b481386, 0x7dc6ad1d, 0xf03b4152, 0xe932633e, 0xa3f04557, 0x49b9b625,
	0xc9b478ff, 0xd7917ec6, 0x479b2e47, 0x39ef599a, 0xcf646188, 0xc3a00e80,
	0x29ba0ec0, 0x31f32adf, 0xef3e4a47, 0xd04407db, 0xf9e767c8, 0xd83934f5,
	0xae87ea4e, 0x7ad4de98, 0xd8f3affe, 0x6bd3e123, 0x26741a8f, 0xecbe7c8c,
	0xe757ba08, 0xedcbbc09, 0x7cdcdb25, 0xf23a612e, 0x50e57aa2, 0xc33794be,
	0xa0384946, 0xa5cde41d, 0xf35b15da, 0xee2fe1e3, 0x4f78de11, 0xcaa6f43f,
	0x28782bff, 0x7cea5fb8, 0xfff8a5d2, 0x2293e752, 0x3e523ef9, 0xff9dc244,
	0x92bce32e, 0x1f928bc2, 0x10b9d176, 0x6d982c72, 0x3df278e1, 0x9d7e66b1,
	0xf7c24a39, 0x5d3fc1bc, 0x0b20cf5e, 0xc3c9bce8, 0x219547fa, 0x569d153b,
	0x0bdc603e, 0x357b2016, 0x5b95bd6c, 0x11efbdad, 0x7711d507, 0xa3fbe389,
	0xb8b0afd8, 0xa56e0b55, 0xe602caef, 0x645d98fd, 0xde9cbef4, 0xf8b8cc1f,
	0x07a563de, 0x7bc91c71, 0x4bc83df1, 0x3715bb0d, 0x232f8003, 0x51fe26e3,
	0x13e61e86, 0xbae42fbe, 0x5be90ed8, 0xc1574197, 0x8663ce2c, 0xfe956b1d,
	0x529fce19, 0x8e22f270, 0x2757d491, 0x61e74678, 0xeb635e5f, 0xc14dbf37,
	0xbd38e2f3, 0xcf104fcc, 0x518ed8b8, 0x88d3fa71, 0x2aef03d3, 0x3fb4624e,
	0xdc0ab01d, 0x6f7a7237, 0x8cf5c314, 0xb8f9b5e5, 0xae37a99a, 0x463c5172,
	0xa0bf21c4, 0xdbccb767, 0xe89f14bc, 0x1e53169d, 0x57ef45c8, 0x367be3ed,
	0xf1949f6a, 0x0f27da97, 0xdb0eca0f, 0xb28c963f, 0xb5acdd31, 0x06a375e8,
	0x543de5f6, 0x88582dff, 0x37e18672, 0xaf4f5c8a, 0xf3289bbc, 0x7d687bec,
	0xcba6ef2c, 0x2f24cf73, 0xc54cf805, 0xd08967db, 0xce2a9400, 0xc09fafa1,
	0x8e715078, 0x5e04d0b2, 0xa596bcc7, 0xd8355c76, 0xe2cad0f9, 0xfc5f6f68,
	0xe64d33a3, 0x0e2a5ccf, 0x8f82e732, 0xe17b9bfb, 0xc367ee6a, 0x97290ca8,
	0x1cb7dcd6, 0x5dc8e8fa, 0x74380ec2, 0xab97e446, 0x7f8373f2, 0x8d2ba052,
	0x59cbcb0b, 0x5f3cb1a5, 0xcb195e01, 0xcf2c3a79, 0xab7cfd55, 0xf5962f51,
	0x7acad6bb, 0xd2cf71a7, 0x815fc34e, 0x7ac4a275, 0x36ef4760, 0x075819fc,
	0xcf03ac4a, 0x8750c721, 0x721d431c, 0x31c8750c, 0x78639094, 0xa49458be,
	0xbc655917, 0x1f386a66, 0xa98a705e, 0xe2107a61, 0xc475e135, 0x23dbc26b,
	0x1efe135e, 0xf7f09af1, 0xd784d788, 0x6f09af11, 0x784d788f, 0xf09af11d,
	0x84d788f6, 0x09af11d7, 0x4d788f6f, 0x6bc47bf8, 0x5e23dfc2, 0xbc475e13,
	0xe23dbc26, 0xefefe135, 0xf14cd26c, 0xf38d3b9c, 0x139be5f9, 0x93be3e99,
	0x28caf251, 0x629fefc2, 0x7b75f1fe, 0x607cf026, 0x4576e819, 0xe24fb45d,
	0xc4ba75b9, 0x3c4845bb, 0x3c642f77, 0x7ac874af, 0x8de7ccb1, 0x45c41fa4,
	0xb8cb66a6, 0x45c44a08, 0x822e2250, 0xa9917112, 0x41171936, 0x9e08b889,
	0x12822e23, 0x88941171, 0x5c44a08b, 0x22e22504, 0xc1171128, 0xa08b8877,
	0xcf045c44, 0x89411711, 0x1f9e08b8, 0x3e2079a3, 0xbd05e6a2, 0x5764db3d,
	0xec9a1d12, 0x0ea98f4a, 0x3dbc3dbd, 0xf7f0f6f4, 0xdfc3dbd0, 0xaf0f6f43,
	0x6f0f6f43, 0xbc3dbd0f, 0xcbca351e, 0x3dfd05fc, 0xefe83bfc, 0xd682f5e1,
	0x49f04bc0, 0xece5b2dd, 0x633b288b, 0x8f3547b5, 0xdaf9d110, 0x3aafc47c,
	0x827a5a5d, 0x55c5f68f, 0x4953f98e, 0x7c8dd36f, 0x6dd142b8, 0x3e39be01,
	0x43d3784d, 0x0b77f382, 0xefcc9afe, 0xff94bc55, 0x7b45ef08, 0x8d01db05,
	0xea5e72d9, 0x58f09f7b, 0xa3215ef9, 0xffbd5f7d, 0xabe39176, 0xc32f2c76,
	0x620641e6, 0x8a15f211, 0x2347ba56, 0x45a77d2f, 0xab9b7993, 0x246cde65,
	0xe8675d5d, 0x7b2d3b4d, 0x77d3450e, 0xe71a65dd, 0xc4dae64f, 0xc068fb51,
	0xf43471a9, 0x04fcdc88, 0x578d5d63, 0xcd476f23, 0x490ff95b, 0xb1b9f04e,
	0x51c2dd89, 0xfb5ce341, 0x3dc0e167, 0x521c33fa, 0xb077c08f, 0x3405471f,
	0xfa30b6ff, 0xfdcbe5f6, 0xbf2c0f4f, 0x8f9e82ba, 0x3578ddda, 0x88cda3ce,
	0xe4fddf96, 0xe38638b1, 0x36da35cc, 0x713213dc, 0x7ce3f0b7, 0xd2f955e9,
	0xdbb5191e, 0x71e0a8e3, 0x4d8e7c3d, 0x25b65bf5, 0x95ddcf9d, 0xc9a9ce89,
	0xf8d0531c, 0x37056c3e, 0x588bdf5a, 0xa3f8891f, 0xcbff03f0, 0x3d4859e7,
	0x2cf39cbc, 0x284d8ed7, 0x389a1e46, 0xbc15ef20, 0xdad96c65, 0x3d2f3481,
	0xbc15ef28, 0x2f8dcff6, 0xbcbb7d71, 0x67c99057, 0xc3b54cbc, 0xa03c387e,
	0x33197df1, 0x032d5b03, 0xbb5738bc, 0xed083eca, 0xd41f0b77, 0x9e42e181,
	0xcaeb550b, 0x97161d17, 0x87117a06, 0x8fe8c293, 0xd05cc724, 0xcecf914b,
	0xb2cd6ef7, 0x3790ec79, 0x6446fa91, 0x1fe9075e, 0x413ccab7, 0x3af58dbb,
	0xf32a3f43, 0x5f9eb9c8, 0xa3fd6763, 0xbf719f6c, 0xa1be847a, 0xef483df2,
	0x8fb085f0, 0x17d9bdef, 0xcbb557a0, 0x8abce6df, 0x9dc11993, 0x64f217b8,
	0x13f99ee6, 0x5c9217a0, 0xbd253c81, 0x81fceee1, 0x12f9cf38, 0x0ce84b9f,
	0xc6facd3c, 0xc40f35f9, 0x3248f3c9, 0xc061521e, 0x2a8bf949, 0x18547c0d,
	0x37ef3d79, 0x695b7bcb, 0x1f210ddf, 0x7acbe683, 0x289ea445, 0xe41de784,
	0x7ad1559f, 0xe9736670, 0xc975b286, 0xcfdfbfa2, 0x707ccbf0, 0x6b65dc63,
	0x53bf9cec, 0x1503dc65, 0x351a7bf9, 0xb359fe86, 0xfefcfccb, 0xa3dfc37c,
	0xff754ef4, 0xeca6d19e, 0x58f3c3f5, 0x73b469ef, 0x2ae979de, 0x3d8907a9,
	0x05f38822, 0x58a6aba5, 0xe943bf70, 0xeb4fbf3e, 0x34de6e87, 0x1819a1f4,
	0xeb39e094, 0x91cb3442, 0x708617d9, 0x6485fe7d, 0x90bd6f2e, 0x17c39f27,
	0x2cee7844, 0xdfd1e796, 0x79a0f432, 0xfe046fc8, 0x8e998302, 0x318e887b,
	0x9f21a144, 0xc3b5fa46, 0xb0cfa370, 0x3f916beb, 0x60ab6339, 0xe816f2bd,
	0x0162f44b, 0xe031a7f4, 0xce628c83, 0xf1ae9dab, 0xc65b9379, 0x9ee8372e,
	0xdcb040f8, 0xf431fbe0, 0xc882b3a9, 0xefa05997, 0x8adf00b1, 0x1740f5fe,
	0x4b78a3df, 0xbee07340, 0x9fb0dd39, 0xf2477d15, 0xc318a2c1, 0xfe96e5bf,
	0x117b5eab, 0x6b4be593, 0xfee3e6ca, 0x45f045a4, 0x4b10310e, 0x97cd8aa0,
	0x2fc95fef, 0xc606bf9b, 0xf7e8bfd4, 0xe458b528, 0xf3d22379, 0x745c6f38,
	0x9f060f14, 0x2346d06c, 0x4ed7bd6f, 0xbe7c9c28, 0x5e4ecc20, 0x3a95f06c,
	0x7be2b6f7, 0xecbf8339, 0xc139679c, 0x28b5fc19, 0xf8ebf3be, 0xf34f98a5,
	0x04ea7f85, 0xd6ad4bdc, 0xd3c84229, 0x0fa8cdbb, 0x3bc1f82b, 0x1f0cddeb,
	0xddd99fae, 0x1a791f30, 0x2c1cb2ff, 0x179c6cd5, 0x4ba7c06d, 0x8fe54fd3,
	0xd38373e3, 0xfc98d780, 0x1fef3e6e, 0x37e51f09, 0xf1205619, 0x293fe917,
	0x8afb97cf, 0x6fd379b0, 0x978c78e7, 0xdd6a8cfd, 0xe7cddbef, 0xb8395532,
	0x9ad7d8c0, 0x2bce6fff, 0xe791683c, 0x04b61fe3, 0xb38b3cf7, 0x1775030a,
	0xf230f7f0, 0x3afe79af, 0x33dd4faf, 0x8c9f2bd1, 0x1d14257b, 0x60fa6e2d,
	0x8fb3259f, 0x7fd62a9e, 0xd80ed0fa, 0x820fa4c1, 0x9af5f59f, 0x097eb73c,
	0x3aac7b3a, 0xb1e5f99a, 0xee58396f, 0x5e3a3a96, 0xc1f46672, 0x7fa6bdf3,
	0x19394bb7, 0x60fdc1ca, 0xf8ba35b7, 0x6160dcbe, 0x1be63a49, 0xbc63ef93,
	0x2e2e479c, 0xd38f9fd5, 0x42060b33, 0x9238efff, 0xb7f13f0c, 0x687be75f,
	0xf0640e1b, 0xfb657cfd, 0x3ee1d68b, 0x3ea16091, 0xb997df1c, 0x17e80e3d,
	0x78126bf5, 0xd8345dbf, 0xba296f38, 0xf0a6ee39, 0xf4817d71, 0xb58a7db7,
	0x0af9c40c, 0x6882bce3, 0xb532cfb5, 0x97ebf4b3, 0x20dfbdeb, 0xe7d5afc2,
	0x1ebed95f, 0x031dd5e7, 0x36b7bc84, 0xff105e12, 0x26f2c3a3, 0xbd1ffc22,
	0x9f30eafc, 0x63655427, 0x1ba76181, 0xaf656a76, 0x6d3f9a9d, 0x8df9f430,
	0xeefe079a, 0xd6f7b70a, 0x715ea8ab, 0x4b0c8ed4, 0x2bd12331, 0x9ef8f3ef,
	0xf163cfbc, 0xb72c45dd, 0xd193814a, 0x81307738, 0x4822b6f9, 0xf9a5d265,
	0x878df6fb, 0xbac39ed3, 0x273e7e42, 0x3bf1e15e, 0x2eb1efc2, 0xe74cd56f,
	0x2f5d55fc, 0x52c47e90, 0xbf001f32, 0x70ceee3b, 0x529d2ee0, 0xcf907b52,
	0x89d068d7, 0x71da8efa, 0x4c8cc7be, 0xb3de4471, 0x90cef344, 0xeb0e8de3,
	0xf9ab717f, 0xcf6a02be, 0x41755afa, 0x037dfcac, 0x033bad0f, 0x49e787a5,
	0x75386070, 0x79fd47df, 0x7b861c79, 0xc7682879, 0x229478ef, 0xb7ea84cf,
	0x8c768279, 0xbc8d78b3, 0x20df4437, 0x27d7d1c7, 0xcfa00a38, 0xb48e3cd9,
	0x8d6f3d70, 0xd4b6f7bc, 0x9a00fdf8, 0x15c1eb2f, 0xaf9c2704, 0xec3639c2,
	0x2af09169, 0xd15fe633, 0x1bd6609a, 0x81da375b, 0xb897859f, 0x8351e0cf,
	0x99af160e, 0x2bcfe7c4, 0xaf3e7e6c, 0xfef01ba0, 0x5eebb970, 0xb61633c4,
	0x5067b26d, 0x3d0607fd, 0x79c06a3f, 0x87286646, 0xee5a09ef, 0x85e27ce2,
	0x6f5e569e, 0x201fbc2f, 0xf12f40f8, 0x89bc3094, 0xcfc8024e, 0xe33368ab,
	0xb13e6fb7, 0xb6a9def2, 0x25bfe632, 0x09e1dd36, 0x83e6c79f, 0xb5373839,
	0xf71ef890, 0xce8f0920, 0x7a3f20e7, 0x9dfe56e0, 0x7013cc2e, 0xa779f58e,
	0xa21fdee1, 0x456ba61b, 0xb4fcea3f, 0x815f6f1a, 0x5dd3de4d, 0xe03c7fd0,
	0x62b4f8ab, 0xcbdf1943, 0x7c2c9e52, 0x7cd5f69a, 0xf153f8aa, 0x4fc342eb,
	0x1661be59, 0xe4a39ddf, 0x8ddfed0d, 0x3e07eb3f, 0xdff80de7, 0xe093e066,
	0xf308a2f9, 0x90d1fdd7, 0x6699a54b, 0xe87f47be, 0xfdea97f7, 0xce0e50e4,
	0x6af6aa57, 0xf944d2dc, 0x741fe81d, 0x3c634bf6, 0xedc15fb4, 0x2673a62d,
	0x6372bde5, 0x9041daf7, 0x8e347b1b, 0x4fb8ad93, 0x9e2b75ea, 0x4face794,
	0x8df678ad, 0xe4eed4f9, 0x85175b83, 0x08a87b9f, 0x49513949, 0xc6e414fa,
	0x5fdf6312, 0xaeffa392, 0x2b8f8c20, 0x2e64f87e, 0xf6b6e2f8, 0x97708fa2,
	0xef9bad18, 0x93c3f9ff, 0xb57dbfcf, 0x557f6fb7, 0xfebc58eb, 0x7732f657,
	0xe334dc38, 0x9cc5907e, 0xc17c05af, 0xa35f2afe, 0x9348b8c9, 0x854ff583,
	0x283a48ef, 0x772dfe23, 0xcecf7c5f, 0x5ea6f4a5, 0x57f81b3c, 0x17bdeef8,
	0xc2b7c0c7, 0x4507ba93, 0xde6aabed, 0xbef31b9f, 0xf043c94d, 0x1955ea1d,
	0xefcc258e, 0xd0728e19, 0x617ef1bd, 0x2f79f985, 0xf2bd3c9e, 0x02f81d7d,
	0xa78081e7, 0xe9760d9e, 0x117ddc87, 0xefb1d29e, 0x352c79ab, 0x86958dfc,
	0xa18970df, 0xe29e1307, 0xb4f0c30a, 0xa78931f4, 0xff5ea7f2, 0x2ae7ee23,
	0xd8e434cd, 0xfe7cf27d, 0x8c3df6e2, 0x37eb85af, 0x5da833da, 0x4986617a,
	0x1637975e, 0xbf3fe079, 0x3b56fd6d, 0xd0bd3ff8, 0x97bd2fdb, 0x035f3caa,
	0xb47fd8ae, 0xb54f7db0, 0x43dbdc87, 0xdcbddce3, 0x3bfe1715, 0x4a14376a,
	0x4c6f2e3a, 0xe578c448, 0x803f658d, 0x7ee4a55d, 0xe07ddf24, 0x98b0fc92,
	0x7e5f03fa, 0xe7c7c930, 0xeb971197, 0xaebd7f6f, 0x1fd5ca50, 0x8fbde5d9,
	0x8fed31a9, 0x4345de73, 0xecf10fb4, 0x20ceecec, 0x631d05c6, 0xbc8b0ede,
	0xb6bb3237, 0x83cc53f3, 0xb7ce7454, 0xa77b8941, 0xa20fb2a0, 0x3c8b36fa,
	0x95699557, 0x5ca14565, 0x78685c3f, 0xf274062f, 0x7291743d, 0x857a52eb,
	0x4fd54fa2, 0xd4ba9ca4, 0x250b4afa, 0xfad57e5d, 0xfc30c83e, 0x74be7925,
	0xe8bb8d27, 0xcf7ce1fe, 0xd3ad57e5, 0xd857dc61, 0xf928debb, 0xad17103b,
	0x41da5b37, 0x5b6f5e97, 0xd67ea0f1, 0xd9bc517b, 0xcb9513e0, 0x691f1bde,
	0x0f91f195, 0xe8b7da34, 0xbb960fbb, 0xad4dbf38, 0x2fe7f94b, 0xa041fcf7,
	0xc3c8d130, 0x3e858cee, 0x9efc6a59, 0x3ac90886, 0x7b0acf9e, 0x757bf6ae,
	0xcf929b8f, 0xfd8d1bc7, 0x07de7450, 0x594d167e, 0xb1c87f7c, 0x71620fd6,
	0x9307ca6f, 0x77d4fce4, 0x9bbf1b77, 0x7146d621, 0x4de93abe, 0xaa47e0eb,
	0x7fb0240c, 0x31a68ee6, 0xb9dee11f, 0xcaa4d63b, 0x9e865573, 0x7f90c4bf,
	0xad977731, 0x37ed12bb, 0x81eff067, 0x1c4bba55, 0xb4c5bff0, 0xb26472cd,
	0x00ed2bde, 0x5bbaaf15, 0x1e7c2513, 0x6ad7b8cc, 0x3660e586, 0x9ba59bf6,
	0xc33ffea5, 0xde23d622, 0x64a5ac39, 0xc3e40a5a, 0x97bc9a43, 0x3ef98b62,
	0x929ceeab, 0xaf010b87, 0xeee17b88, 0x61fbb7b6, 0x2fd20a77, 0x07cc1eb0,
	0xd0621970, 0x2eb6b1c7, 0xc15dbfbe, 0xdf3d5ff3, 0xc542e8a3, 0xf7e12acd,
	0x947d0249, 0x547d020e, 0x75b1f118, 0x5eb8536d, 0x9f0e75b9, 0x634169e3,
	0x362b23b2, 0x28183f16, 0x095bf9c0, 0x29ba8a8f, 0x5517a133, 0x804a8b6d,
	0x0f6e935d, 0xa1eb87a4, 0xe1ef5b15, 0x6c9f3d73, 0x9eb9f175, 0x53599ea9,
	0x3df00613, 0xf7e145c8, 0xe4351f20, 0x14dd754b, 0x4a9cf9d3, 0xc1f913ea,
	0xe18f697f, 0xee75297c, 0x3f53a166, 0xfce2380c, 0x795e55cd, 0xdb8526ee,
	0xcff5fb7b, 0x66a3f2ab, 0xec238e79, 0x85ccd11c, 0xdd6d7df4, 0xa7e871d3,
	0xc6b781e6, 0xd7e08413, 0x40fb137a, 0xcda239ef, 0xe5511cf2, 0xe79ffd03,
	0x5431f751, 0xf8a617ed, 0x78c11de2, 0x90f543d6, 0xadde2070, 0xb9eb047b,
	0x1345589f, 0x97a575f6, 0x865de7a8, 0xbe24fa1c, 0x5ff81d35, 0xdf1373b6,
	0x56227677, 0xde774bd6, 0x21c84bfa, 0xd4947b7d, 0xf5826dbf, 0xd480f2db,
	0x30f9d597, 0x1d87739c, 0x4630aa7e, 0x9c647bde, 0x52f35233, 0xb09edff7,
	0x7071fbc9, 0xfcf4087e, 0x09542d9e, 0xfa47be7c, 0x471de228, 0xaf7bfa0d,
	0xcfbfcad5, 0x80462012, 0xeb5ef15e, 0x2388b1d3, 0xd8ac3d2a, 0xce3f07fa,
	0x27d8af57, 0xbee2f1cf, 0xd413be78, 0x7bd497f0, 0x78adbd24, 0xf70d3ece,
	0xc55e9317, 0x216d6a4f, 0xaaf87f47, 0xdea6f436, 0x6c3ddefa, 0x96eed597,
	0x7b6d417a, 0x4a05eb17, 0x04e750cf, 0xb177766b, 0xabbea09e, 0x52e12bdf,
	0x2f3e57b7, 0xf4bf1e43, 0x6cb5f8b7, 0xd71acbd8, 0xe7bc9ff3, 0xf0b655d6,
	0x575bbafa, 0x02fcfbd1, 0xe90fe18f, 0xdefcbd66, 0x3db35fbc, 0xe8c6b753,
	0xb0f6ea97, 0x0c573cf1, 0xd08ef794, 0xbe372cf3, 0x81f49af7, 0x1ed2bdba,
	0xaf45d50a, 0x7adc3ce7, 0x877f8db7, 0xfbcdcea5, 0x4b4696f9, 0x262c6d9e,
	0xdcfacd17, 0x6c7f2301, 0x2e3bcd60, 0x445209f8, 0xbbdc61f7, 0x9e9c48fb,
	0xfc38c575, 0xf38063e4, 0xa0f9d4c8, 0x3c7c2f73, 0x375ffd06, 0xee3cf3ac,
	0x3f6bb0c4, 0x91f115bc, 0xeb185751, 0xdfe4efc8, 0x48781855, 0xec47ddca,
	0x63df3d62, 0x88112b63, 0x48b01c1b, 0x37f026fd, 0xc21a7bf9, 0xbce3271d,
	0xbde53217, 0xefe94e0e, 0xf796e9ef, 0x8fb0843c, 0x4ea7fda0, 0xc7891f6e,
	0xbe485725, 0x177e312e, 0x3d9a6be2, 0x9ba83fed, 0x1afd0c8a, 0xd324aa80,
	0x8594505a, 0xf7993afc, 0x469f7ead, 0x0d93abe9, 0xd8669d79, 0xc9218e59,
	0xe6bfd06e, 0xceb9f3f7, 0xca87f9d5, 0xbbf7fe31, 0xcd3bfc9d, 0x72716f2a,
	0x6bb4b477, 0xfde74c86, 0x44daf34d, 0x943fb529, 0x6f21096f, 0xc9c2fbff,
	0x8ce15d71, 0x2e2d73d0, 0x0ed6bfce, 0xc857fcbc, 0xa7eb54f9, 0xfd69e387,
	0xf9a6ffa9, 0xf5170320, 0x9bc8f47c, 0xd85e9654, 0x38eb07b6, 0xc5cfa71e,
	0x4cf58e3a, 0xd509d2ef, 0x3bb4f7df, 0x10ff727d, 0xf03ff3e1, 0x25c6bfcd,
	0x75e6fa5a, 0x7923fbae, 0x93b7463f, 0x0f93c2fd, 0x461ff718, 0xb25ce7cc,
	0xa9c0f397, 0x9cfdc31d, 0xbdf7c2db, 0x98703e4d, 0xac9c33ef, 0x9a743bee,
	0xde143bef, 0xadf804b4, 0x48beba21, 0xf543e3ed, 0xc63da67b, 0x74f761ef,
	0x352fd9bb, 0xbf7fa5a8, 0x07d05bca, 0x2ebf9f68, 0xde676cde, 0x2fb4857d,
	0xbbf036ef, 0x2564b32f, 0xc16c20e0, 0xdb2f2334, 0x6a247bf4, 0xe31ab5ff,
	0x30e033cf, 0xeb916dcf, 0x123df88e, 0xcf0a0745, 0xfceaaf0a, 0xf88fc296,
	0x384bc756, 0x2978455f, 0x63e25fb8, 0xafe3e31d, 0x7625adaf, 0x7efe4312,
	0xffe5e313, 0x6f7c1f00, 0xa3e365f7, 0x418f8cc3, 0x70d7212d, 0xc80f09e8,
	0xcc8b2ddf, 0x827914bb, 0x6b22c0e5, 0x7503fb34, 0xe276dee3, 0xffc097ff,
	0x4d87ef8a, 0x7ec02cef, 0x47884c79, 0x4b4eaf31, 0xe97f3f3b, 0x43964c8a,
	0x8a474543, 0xcea73dfc, 0x5ac7d071, 0x5ba9fb8c, 0x9f27ceb4, 0x3f77d01d,
	0xbaa0b9f5, 0xd0f83a9f, 0x6db71a12, 0x9e7dfc9e, 0xee144273, 0x8aafdc87,
	0x47177e36, 0xcbfbf088, 0x3587f99f, 0xf7587a1d, 0x4b8e68c2, 0xde7515b6,
	0x2daabd07, 0x080bebc7, 0x173a9fbe, 0x9660587a, 0xbbe9c793, 0xe64d3cdf,
	0xe3e089c5, 0x5c3c8f88, 0x2ef1cd15, 0xd0f55f75, 0x213ffd38, 0xadef22df,
	0x592b507e, 0x0afe8958, 0x173bbce4, 0x93b53f46, 0x9365717a, 0xc7e7a228,
	0x0e39629a, 0xf954e8a9, 0xba058761, 0xd49c021e, 0x193fd8f9, 0xaee0a5f4,
	0x40f9e5f9, 0x67457f05, 0x6d7cbeea, 0xdeb7a4a5, 0xc17ade3c, 0x8543bc79,
	0x51749fbc, 0x380bcf94, 0xfebc5bff, 0xb2dde60e, 0xc562f09c, 0x8ffc25fc,
	0x115bbf19, 0x065d5fc9, 0x1ce3091f, 0xf92122c3, 0xb73a9163, 0xb73e64d0,
	0xe97f7910, 0x71fadc5f, 0xb45d7bd0, 0x9ecefe5b, 0xbc78d6f6, 0xadbfed7c,
	0x9cb9e6fd, 0xdb35f831, 0x3cc69fa5, 0xa50e79d5, 0xf456be3f, 0xf0e41a71,
	0x3cbe6fb1, 0xb8d8e514, 0xf7687392, 0xa6cfc2e0, 0x53f86b61, 0x439f274a,
	0xbfc2d3f9, 0x793fb1a5, 0xf57fbca5, 0xf17be772, 0x0f4964b9, 0xf3ca5577,
	0x91a2a964, 0xefb937e9, 0xf20babbc, 0xf25cf224, 0x3fc303ff, 0x80000177,
	0x00008000, 0x00088b1f, 0x00000000, 0x3cb5ff00, 0x6594580b, 0xff3fdfba,
	0x6018185c, 0x8a22e440, 0x86888a3f, 0xb880c034, 0x102a3b59, 0x93b4174a,
	0x98e9abab, 0x18665ca6, 0x939e2ed4, 0xaea18c3d, 0x4f47bb9a, 0x356b696e,
	0xee1598a8, 0x0c0d1219, 0xb324b46a, 0x44e710f2, 0xc1eace9e, 0x19b51532,
	0x39eb6cc4, 0xdf79eeed, 0xe67ffbf7, 0x7bbb6622, 0x9f3d3d0e, 0xdeff77ef,
	0xdf7efbfb, 0x2eff3f3f, 0x63092d8c, 0xf817f7f4, 0x098b0a7f, 0x2585a782,
	0x7e1925b1, 0x1a98c8b8, 0xe2777ed4, 0xe9f6a0b8, 0x5c107652, 0xa829319a,
	0x29a6bdff, 0x05fdf041, 0xcffa83d3, 0x820cccb4, 0x66a8cc2d, 0xab6b19a3,
	0x973dc92d, 0xb5dbd8c6, 0xd4e7b965, 0x3f7f86d0, 0x759397f7, 0x26480f47,
	0x31ddd2c6, 0x0093d473, 0x32ba3e8e, 0xa609e015, 0x24ea39f8, 0x5e8f9380,
	0x7632354b, 0xc38129bb, 0x36bd1db7, 0x536ce00a, 0x80ef8722, 0x963186c5,
	0xe39a4a6b, 0x67ec64cc, 0x69b356a9, 0xbfb36328, 0x0d1639ab, 0x99ae9f4d,
	0xc8aa48f5, 0x733619d8, 0x27ec0644, 0x1e3ad539, 0x7f8c1fdb, 0xc0b45d78,
	0xa87fcfd8, 0xdc6158d1, 0xd999534c, 0xef98c794, 0xbb16546a, 0xd0b3b19d,
	0xedfe86c6, 0xc61e6325, 0xca9b19f2, 0x86a6c251, 0x14623c19, 0x734c23fc,
	0xe3c147a5, 0x0b04c628, 0x1162ab63, 0x512d8c4f, 0xa8c29e23, 0xa91ad4f4,
	0x489b5a3c, 0x12b57be5, 0xec78025b, 0xf2a0cda8, 0xea89ad78, 0x5016d44f,
	0x85ad51f9, 0x25b593ca, 0x96d67654, 0x71482951, 0xcfcc3e6c, 0x68369af6,
	0xa9cc0f00, 0xeb0f398e, 0xe9033fe3, 0xa6325a10, 0x7a15e766, 0xd17fe742,
	0xd137ee5b, 0xcf1b86b9, 0x8febf847, 0xa9267fb5, 0xe60e80e2, 0xce0e9330,
	0x29d0d93e, 0xec399985, 0x55cf7804, 0xf14551e6, 0x7ec0ea7e, 0x236cee71,
	0xa819b3f6, 0xf43f5a5f, 0xef7ec2cb, 0xbeb1a927, 0xa5d26b46, 0x86bcf632,
	0xffb0f539, 0x1111d548, 0x67ec89d7, 0x0ffa0eac, 0x732a01d7, 0x32d04b18,
	0x8fd0ed86, 0xa7b94185, 0x2237af9f, 0x833966b6, 0x302c4679, 0x7152ea98,
	0x80c62eb7, 0x3c43c9be, 0xe4bfb849, 0x8faa5a95, 0x35497554, 0xb5bcc606,
	0xa7c8199e, 0xfe9ce185, 0x81965a85, 0x70aa60fb, 0x57ac0353, 0x91d0fe24,
	0x568af00c, 0x66961b21, 0x9db2ba85, 0x80d5dfc8, 0xff871663, 0xb80d5deb,
	0xe2b3ba8e, 0x15d7e815, 0x84da6c9f, 0xc43c4ad8, 0xbc6172d2, 0x019324a3,
	0x16d8bbbd, 0x18bdc701, 0xf88d5d65, 0x46b3207c, 0x49992a60, 0x92c49e60,
	0x609b5d88, 0xd8fb5f3d, 0x59cbe43c, 0x0320e93a, 0x4f73a879, 0x1598f921,
	0x4609e52d, 0x70e6ef84, 0x80507482, 0xca73a376, 0x8790429c, 0xe37a7daa,
	0xb53900b9, 0x608263bb, 0xf1924b47, 0x569c805c, 0x1c603fe1, 0xb35047bb,
	0xf26cc678, 0xd60ace56, 0xb079467f, 0xe5ad7c97, 0x96d3ebfb, 0x9b6c604d,
	0x0e3c2249, 0x86780a3d, 0x8f4df673, 0xfd82ed74, 0xc9a90c26, 0x65fb015e,
	0xf61e5299, 0x45f4d14b, 0xbeaf0119, 0x2e25d41f, 0xfa8f8d03, 0xfe7e0987,
	0xa44da97a, 0xfbbe50fa, 0xf240b645, 0x6c3348e3, 0x27543a46, 0xd9518586,
	0xe198b576, 0xb4b2ea3c, 0x458f3059, 0x659616cb, 0x7a7e38de, 0xa7c68ab6,
	0x5e92d7ae, 0x5b045520, 0x053384b6, 0xc602b276, 0x8a871fea, 0x4076f19f,
	0x518ed327, 0xdb23f0c9, 0xfd41d50b, 0xdfdfd82d, 0x4e882cce, 0xd331fc65,
	0xd56beddc, 0x2fc87af2, 0x0c6b994b, 0x0199211c, 0x123e415d, 0x1de88799,
	0x784b1395, 0x62fce853, 0xe91ebe9c, 0x7f02269c, 0x8cc950e7, 0xc0472650,
	0xfc9ed07a, 0xfc85de8e, 0xf9cf47b9, 0xcbc54d3f, 0x5fde2a3d, 0xc89cce1b,
	0x660023ef, 0xb1c84e50, 0xa3cec99e, 0x8f343c79, 0x7c8d94d8, 0xb4dcc49d,
	0xd273027e, 0xc37e947e, 0x949ea759, 0x1d2fba80, 0x545935e9, 0x474f8a0d,
	0xe45e94f6, 0x97e82f03, 0xb7f402af, 0x556a2237, 0x71aafd20, 0xdc7021bc,
	0x8ca71a54, 0xb152afb7, 0x5e9086af, 0xa7b23e24, 0x4cae2ca9, 0x13dec71c,
	0x53beb072, 0x1fe9165b, 0xf07a0dd7, 0xffc7902b, 0xe588bd00, 0xb887d029,
	0x0fa0e7fe, 0xe803fcb1, 0x033fac43, 0x1ecb10fa, 0xff5887d0, 0x2c43e805,
	0x348bcf67, 0x5a38fca3, 0x82afb0a6, 0xed6341e4, 0xa7bb8009, 0xd147ce0c,
	0x8fb847c8, 0x33dbc1d4, 0x38bbf694, 0x308f7d3d, 0xe254aed7, 0xd8c6b5cb,
	0xe70fe91b, 0x7cf9e3d3, 0x1b8e6c91, 0x8f2934f0, 0x892fb9f3, 0x0d6cfac3,
	0xdb1516c1, 0xe527e38e, 0xa3fcf969, 0x6ed8e554, 0x76f3e589, 0xfb0c03a7,
	0x45305d39, 0xe3fd8d97, 0x0fc73ea1, 0xede78f77, 0x5ebc6196, 0x7ed2afd9,
	0xf9c8db26, 0x4fbba650, 0x1267eb03, 0x4afcd3bf, 0xf91395ff, 0xbbfb42fe,
	0xae2554d2, 0x4361f041, 0xe593cdb9, 0x44e1f002, 0x900d4839, 0xe4896a8b,
	0x8543e142, 0xb872a2ff, 0x64e9a6bc, 0x42db073e, 0x831b43f8, 0xe4013a7a,
	0x58bc2040, 0x8f679c18, 0xa84bcb20, 0xf689403c, 0x45079140, 0x4f7e140e,
	0x62133906, 0x33b8e7fd, 0x32955f84, 0x9d3fd65b, 0x118f91f1, 0x4634db5d,
	0x207f6026, 0xd54bee24, 0xca1e727f, 0x54a47c67, 0xfd15d307, 0x983350ca,
	0x7bf8ab1e, 0x85e8a1f1, 0x06e3e09b, 0xf979683c, 0xf481e2d7, 0xe471ea1c,
	0xd6f441df, 0xd958ecec, 0xebfce19f, 0x2194b6c8, 0xbd04f91f, 0xcb07005a,
	0x13fce7a7, 0x7949fe7a, 0x1f0a1cfc, 0xe38ca145, 0xd1ce78fa, 0xe53dea37,
	0x5ce7033c, 0xa5ff48c6, 0x50faf385, 0x0ae72b3a, 0xf14b7fd0, 0x193e0a7c,
	0x70c5fee3, 0xa5362ff0, 0xbb731f22, 0x617a1be5, 0x3fe656c1, 0x9ed955ff,
	0x12254efd, 0x65f6283f, 0x17105ea0, 0xb20cccce, 0xf408cc3b, 0x91d76bec,
	0xac547bbc, 0xd7180dfc, 0xf24e7380, 0x6c8f7f9f, 0x8ce7fa87, 0xe77fa151,
	0x44e0d6fd, 0xd61de63b, 0xf1804677, 0xd8e0edde, 0xb9625f90, 0xfbbb0047,
	0xb418d808, 0xef405753, 0x2ec674b1, 0x8251a2d5, 0x67abee7e, 0x63873804,
	0x00c2c887, 0xeb8ee295, 0x969f91b3, 0xe88c6bb6, 0x7f6dd51f, 0xe3f238f6,
	0x424166f9, 0x0cdbc4bf, 0xf6fe87c7, 0x3d2e916d, 0x18062ff4, 0x68332ffb,
	0x8f5f125d, 0xd7979d91, 0x3d5f4afb, 0x35df818a, 0xf086876d, 0xd155f4be,
	0xbbd9fe85, 0x11aa57db, 0x5812ef3e, 0x162b8c02, 0x01247757, 0x60a2f95c,
	0x9b38c1d2, 0x0057b8a1, 0x55f2ab3f, 0xfcc0f266, 0x26914d95, 0x6dbf9a27,
	0x027a2f9a, 0xd7728bfc, 0x3dfa2d56, 0xeb833be5, 0xc304f72b, 0xffd22f40,
	0x0fa846b6, 0x672fcfd0, 0xbf91c647, 0xa3658e39, 0xc5b6c9bf, 0xe8a2bf92,
	0x56fd1bf7, 0x2ba3d727, 0xec66deb8, 0x3059f89b, 0x3d7ed8af, 0x87030be5,
	0x59f0ca67, 0xcebebf80, 0xa5e0a2e9, 0xebfb5e5a, 0xc3766624, 0xf5dbab79,
	0xb79c2746, 0x28cbf5ba, 0x8477f406, 0xf247dcf7, 0xa234587b, 0x45b1b7bf,
	0xed7e2274, 0x2addfa6d, 0xc1f55bc0, 0x2452b44f, 0xf9397de2, 0xe733772b,
	0xf226637a, 0x12758a89, 0xc96a751f, 0x2df4b18f, 0xadbc79c5, 0x01fa237a,
	0xeb3f87d5, 0x41f08798, 0x8e91e981, 0x4f887a23, 0x8140ee96, 0x23dd2da5,
	0x44f9fbe4, 0x9d22ba44, 0xaf44d1dd, 0xa4774865, 0xe91dd033, 0x713d222c,
	0xc5d6a47c, 0xf82444f9, 0x5f4e3efc, 0xe2c5ee85, 0x57d62d66, 0x4f3a73d6,
	0x5cf0d1db, 0x8681f138, 0x74407cc9, 0xd393bf3f, 0x4ebedb5d, 0xb7f90c3b,
	0x5a0f843e, 0x807c0375, 0x0f81bbfb, 0x015fe842, 0x103d46f4, 0xf4a107ca,
	0xeb9b2c7f, 0xcfbff00d, 0xeffd0eff, 0xd00b8848, 0xfa7ecae4, 0x63eeaad0,
	0x82deb071, 0xe5f6cbd8, 0xf1263f50, 0x7e06960d, 0xeb28b9c6, 0x6707d405,
	0x0ebc7fa6, 0xe335d5c9, 0x97e46cf5, 0xc34f4d3a, 0x8ce150f3, 0xcca13089,
	0xee6752fa, 0x5dce137c, 0x4a7dfb18, 0xf1dfec13, 0x6c88ceb6, 0xefb64d76,
	0x7c0617f8, 0xef1c6761, 0x78b3e740, 0xce9b7b5e, 0xb1fc03a3, 0x604b22e6,
	0xe24be73c, 0xf6d22ae7, 0x718e582d, 0xeb87cc01, 0xe71e1608, 0x7fbdb555,
	0xc7f2c84a, 0x17185565, 0x108d3ce2, 0xe7f86617, 0x531f8c11, 0x28ce433f,
	0x09d1e7e2, 0x87e84a77, 0xd665cdd7, 0x663fd1f0, 0x87d9181f, 0xe9b8e517,
	0x4de3fea6, 0x37e284ec, 0x18f0e732, 0x4e253b94, 0xb2d4f454, 0x63c7be02,
	0x0f509f8f, 0x7b7cf581, 0x4547a204, 0x3827e81b, 0xe34b856f, 0x79008492,
	0x405ffb92, 0x5dbc037e, 0x521cd674, 0x0677c889, 0xe64dafda, 0x23e46acf,
	0xf9a56f38, 0xd39e1448, 0x5b15eb26, 0xc015e82b, 0x52db257b, 0x09577c8c,
	0xe10679eb, 0x4d7dcaa7, 0x8adca714, 0xb33f149f, 0x5fb839ba, 0x99e80e66,
	0x4ccf48db, 0x77e00bf8, 0xe993017c, 0x9149f5cf, 0x03dd1998, 0xa4cfd3fc,
	0x01e79468, 0xff7027fb, 0x633fd14d, 0x078883b7, 0x15ce3bcc, 0xeb01d4c6,
	0x18cfb6df, 0x27704f04, 0xbdbff506, 0xcf6a0a45, 0xb50464f6, 0x05371ee7,
	0x059d79c1, 0x9e27fd41, 0x93c104b2, 0xfa824a7a, 0x2cb171df, 0x84cfee08,
	0xbfe20cf3, 0x89dde528, 0xe9ff5042, 0xfe683e92, 0x20988cd2, 0xe320dfb8,
	0x152bf647, 0x3997f77f, 0x2d0a1fdc, 0x6bdefc15, 0x89475e0a, 0x082fefd7,
	0x25a66f5e, 0x4a9fbd78, 0x4f60bd97, 0xec2710d5, 0xe58afb03, 0xa84f106b,
	0x84684e21, 0xdfe10278, 0xa5813c43, 0xac09e21b, 0x09e2037f, 0x9e219b84,
	0xc410f840, 0xd4b7083f, 0xb8795096, 0x6fea8cb6, 0x790ebf85, 0xbaf2e3dd,
	0xff75e427, 0x247d3c56, 0x9e5277cf, 0x4be713af, 0x4bdbb7f3, 0x03bea8c6,
	0xdb129e79, 0xb8c1edab, 0x314f4561, 0x3efa2de6, 0x902ed910, 0x1d756623,
	0x7b438daf, 0x5fa18436, 0x3efacac4, 0xf54abcc4, 0x4dc6d1c1, 0x7fb3da12,
	0xdeed893f, 0xb9425166, 0x65f2da3c, 0xe573ce14, 0x7314703b, 0xb0083b65,
	0xf0467bed, 0x00976826, 0x0a04de9e, 0x9b9bec84, 0x3495dbec, 0x19697605,
	0x4d8d6594, 0x1553a45a, 0x7fb429ca, 0xb704d6e0, 0x6a0fabef, 0x287f6237,
	0xca2ed4ab, 0x516a5c23, 0x7f50f3e6, 0x41609a5b, 0xbed2fbbf, 0x81dfd777,
	0xd169b7f6, 0x5ff61110, 0xfc49f8d5, 0xc7a11fe2, 0xcf5e87d7, 0x6f603b44,
	0xfe0cf985, 0x1aadecf9, 0xb7fbe619, 0xc71535a5, 0x1468e1a2, 0xae2818d8,
	0x156c2db0, 0x96aac7e8, 0xadea1b06, 0x1a798caa, 0xb9f1f806, 0x01bf3945,
	0x2afd07da, 0x9c7ee323, 0x62d45afb, 0xf71df798, 0x482cfbb1, 0xa377b6df,
	0xb35f5d70, 0x793f1418, 0x727afa64, 0x2bbf44b4, 0x4946efcd, 0xfdd1bed0,
	0xdabbc72e, 0x2a3fe743, 0x09283ec3, 0x9d222ddf, 0x153be2bf, 0xef9941d1,
	0xe6911cc3, 0x2632de9b, 0xe5d5cf12, 0x9a7debe6, 0xd3fcd123, 0xc12d16d3,
	0x9c489ffd, 0x3f92279b, 0xf51a8a08, 0x06d2f8f8, 0xdcaa43f4, 0xf8b065a2,
	0x0bce02ee, 0x9c343be3, 0x3b483f4f, 0xf8fa81d0, 0x6c90c944, 0xbf7211b2,
	0x97e396ff, 0x0d35ad62, 0x419748ed, 0x7f3e448a, 0x247464ba, 0x9628f7d2,
	0x5bb25f58, 0xb2b2856b, 0x65d7af99, 0xbe428cec, 0x15ce6aeb, 0xe651dfd1,
	0x3cf94ffb, 0x403dfc03, 0xa9d12737, 0xc06f55dc, 0xe3f4fc79, 0x18e69ff5,
	0xd709ffa9, 0xafd1b327, 0x2088caea, 0xcb43a4bf, 0x6aae9e28, 0x57717ee4,
	0xe23d725b, 0xd3ef5941, 0xcf2e391c, 0xbd5d1150, 0xdfb91a2d, 0xd41606bc,
	0xbafb434f, 0x3f7827b2, 0xdfd9d746, 0x7b6e3fa0, 0x17686451, 0x789a9a6d,
	0x9d85ff3c, 0x972bfbc1, 0x78d36cf1, 0xf803e3e2, 0x203ad6d5, 0xf3e20637,
	0x244e4556, 0xc742a7a2, 0xcfee0cae, 0x5cea2575, 0x9ada9f18, 0x6faf881a,
	0xa67527cc, 0xfc90fc62, 0x3be51844, 0x2b3f156f, 0x7c40437e, 0xd45e30c5,
	0x53ce8c94, 0x07fbf28d, 0x312c728b, 0xee3143b9, 0xb2b8a32a, 0x0b3f818b,
	0x9fd1da6b, 0xfcbd468e, 0xdd70e787, 0x23f066fe, 0x587b5d61, 0xe0738ccb,
	0x409bf597, 0xfddf6050, 0x392e353b, 0x5fa031fe, 0x6bf654bb, 0x7cd6482f,
	0x7dafec11, 0x67ce8a8d, 0x38a70ccb, 0xbdeb2bc6, 0xef529baf, 0xb8e1bf27,
	0x6878c468, 0xc1fb9b9a, 0xd7ee46b6, 0xff53bb56, 0xedfa3279, 0xe08c1a8d,
	0xd887e298, 0xbce43f65, 0x5f9ef7ec, 0xf8a5a7d3, 0xcf605da6, 0x5bca3ec2,
	0x432476b6, 0x06733dbb, 0xb176b3f9, 0x6589fc91, 0x07fd83db, 0xe0826ff0,
	0xfea17daa, 0x72df9c85, 0xf12bd707, 0x01dca4e1, 0xc61c633f, 0xe4e24533,
	0xfb879404, 0x955d3972, 0x04e566f8, 0xfdca0253, 0x4334b546, 0xbe2043c9,
	0x2a07ed1c, 0x5b2edf70, 0x8de289b8, 0xaf098755, 0x1c786fbe, 0x84644be3,
	0xf8e31f0f, 0x3e70b5f5, 0x57046877, 0xb6078e18, 0x04c2f9a5, 0x33cc1ad7,
	0x48a3fb3b, 0x8256313f, 0x2e62b172, 0x982d578f, 0x487285f3, 0xa14fd72e,
	0x752ef576, 0xa013188f, 0x72e5e627, 0xcb50b53f, 0x56cf68ac, 0xbec89a46,
	0x7ee30c8d, 0x776ad17a, 0x48c3f236, 0x0175c788, 0x8691f8f9, 0xedfb013e,
	0xffe78a79, 0x4cc27c95, 0x131351b5, 0x5b191f60, 0xf995fd43, 0xf1f0a341,
	0x08df9ab7, 0xf3fc1bf3, 0x11a3be03, 0x26ccd7df, 0x3329dbb2, 0x5c9286c1,
	0x2a5c90d6, 0xfc02b9e7, 0x86fc0856, 0x9ba41a39, 0x8a11e76d, 0x73acece7,
	0x8e2b8e3d, 0xc628fbe2, 0xce1c20fd, 0xb97227cb, 0xf05568fe, 0xbf6c1b96,
	0xab2d9a27, 0xcde26e50, 0x94b9d5d6, 0x7f123157, 0x057994ae, 0x9e8499fc,
	0x8aeff441, 0xeba2458f, 0x94079035, 0x046a87f7, 0x5fc82d29, 0xe0ee7ce2,
	0x7332ec55, 0x3c464f77, 0x199d2d38, 0xb8ce5f50, 0xa55c2d7c, 0xef02d297,
	0x31df9003, 0xff8328fe, 0xe32e31f2, 0x8ac6e57f, 0xb75fd07b, 0xf0978aae,
	0xf281c2fe, 0xfcd6ea30, 0xf0f7ca1f, 0xadf913b7, 0x684ce99a, 0xa12d1c5f,
	0xfa3526ed, 0xe4433be3, 0xd3e64522, 0x42e0ab7a, 0x83ff507b, 0xe6d1e79a,
	0x7b37940b, 0x4f912a10, 0x95fb0fe9, 0xfce1714f, 0xf748020f, 0xf8e2db5d,
	0xc23606bd, 0x3e41feb9, 0xcf6a83ff, 0x63ef9411, 0xe62a771a, 0xf9d98e71,
	0x065cd53d, 0x9de8090e, 0xca93acf9, 0x83ea88ee, 0x39dc9a1e, 0xcff0e302,
	0x23ca3aac, 0x15ddafd5, 0x8b367a89, 0xfde235ad, 0xbec98818, 0xdcdee4bf,
	0x47bd08df, 0xf047e063, 0x39d39678, 0x56f65cde, 0x8117c02e, 0x37398946,
	0xf4faaf8e, 0xfde21460, 0x6607a3f2, 0x1c6182ff, 0xe60b7a04, 0xca69aca9,
	0x27197ba0, 0xf7c8cceb, 0xa7a157d3, 0x93a83f42, 0x670ae882, 0x99f80e19,
	0x3df2fac3, 0xa9e9adc2, 0xd34539e0, 0x12a200f7, 0xa1e918ec, 0x782b3a50,
	0x1a3566af, 0x39ab7f9e, 0xfffa1739, 0x424aad72, 0xba06f2bf, 0x1e3e82df,
	0x44f26f3d, 0xdecf140a, 0x9d0a5e8c, 0x821e621e, 0x71f0c54f, 0x29121ea7,
	0x4d7ff87f, 0xeb6689af, 0x67925cb5, 0x1b72a0e3, 0x9337a72a, 0x42ab85cb,
	0x4e4437e4, 0x04d2e407, 0xcfd005ff, 0xe48a2aba, 0x4dafa151, 0xed193882,
	0xc9a45b5f, 0x27a46ec5, 0x9fb8bbc6, 0xbd8166ca, 0x7914fc20, 0x30f7e1ed,
	0x5e02f421, 0x883da0b1, 0xe3e40f31, 0x1c7cf1c6, 0xf4cde3a7, 0x4ef7a296,
	0xa331cf33, 0x5c19f740, 0xb9d71f8e, 0xb9555ef0, 0x2dee50cf, 0x7f5ccdb2,
	0xc1a79686, 0xa27bc16f, 0x435d194d, 0xd6ebdfd1, 0x7bf0f32a, 0x3a6bd3d7,
	0xf1872c47, 0xb2f0a7a7, 0x00bcfd1b, 0xf3ce12d8, 0x7493a781, 0x69dbc44e,
	0xf454dc61, 0x4f0b4e03, 0x04e1c7dc, 0xdcf084ad, 0x8046a984, 0xfe4a35bb,
	0x7f5969f0, 0x3d3ca8bb, 0xf5216277, 0x887bd813, 0x6560490f, 0xc4208eb4,
	0x4e7ec096, 0x0726363f, 0xf39405ef, 0x0fee664b, 0x1db998a7, 0xffb7c818,
	0xf6f940a3, 0x8c3a6085, 0xf5302f78, 0x505192f9, 0x469fe67f, 0xe57dd367,
	0xd1f5e08a, 0x9e52a6fe, 0x77cd2b72, 0x9a7d77d7, 0x7dfe9945, 0xc2cdd80d,
	0xc97ebcab, 0xca478a18, 0x625a1a65, 0xd938f1c7, 0xed1a3a35, 0xfad76298,
	0x04301f8f, 0xe57b51e6, 0x3c00f3bc, 0x8129d7ee, 0xdec8f176, 0x9e71d267,
	0xcb33ad72, 0xeb17f504, 0xfe82977f, 0x5fdef943, 0xbb5f93a5, 0xc63a6377,
	0x9ebbe527, 0x1c10b749, 0x48f8a561, 0x797dcfcd, 0x9bdda4ff, 0xdee8fc02,
	0xcc571e3c, 0x84523b0f, 0xdb8cedfe, 0x79875ebe, 0x24ff31fb, 0x21ee1e50,
	0xed0eb9d6, 0x2e0c82ed, 0x185b6c57, 0x8f987fe9, 0xc61b49ee, 0xf507bbdd,
	0x2f8c89fe, 0xfed04b35, 0x8f84d59a, 0x39b5cc05, 0x1b6ff301, 0xf9bfca04,
	0x7ba08ffb, 0x056b45d7, 0xda1c626d, 0x8c6c98d1, 0xc7309f1b, 0xde1e3ed0,
	0xf581dd90, 0xfaf3560b, 0x73573a19, 0xbcf3ce17, 0xe120d4d6, 0xcaa36544,
	0x9fb1ee02, 0x6db8f330, 0xfc8166e1, 0x319d6579, 0x07d7c5cf, 0x9909f39e,
	0x4f9becfe, 0x2fdc1f48, 0xd59ee5d3, 0x0897bc9f, 0xb6ae7ef3, 0x7986653e,
	0x7cf6fe4e, 0xc2b3ea1a, 0xe44cded8, 0xeb5a31f3, 0xee78150b, 0x57ca3a5d,
	0xc592b39a, 0xf39fe804, 0xb16794e8, 0xd17ab85c, 0xf798150b, 0x71461edd,
	0x15bfb298, 0x78c2a482, 0x5ffaddf5, 0xbb788c3c, 0xf230dbf8, 0x8fd457c3,
	0xc883604d, 0x02be52a9, 0x19d297f4, 0x8c36b57b, 0x8d6bd7ca, 0xee23824c,
	0xf8244daf, 0x2a256b5f, 0x5fce1cd9, 0x5f5c8c2b, 0xdcbe6cdd, 0x0499c2ef,
	0x01bccafa, 0xf53f03e6, 0x76cb5acf, 0xcc61e033, 0x8daefb78, 0xc0c6b9f2,
	0xea676cf8, 0x7983c434, 0x740ef2e3, 0xf99ad761, 0x5d87e87d, 0x0fc8521b,
	0xa5f67d5f, 0x37ff680a, 0xe23d5973, 0x55e76c29, 0xdbbc17ca, 0x8805abfa,
	0x3a5df2ef, 0xdcf93e7e, 0x9e9b7f17, 0x79e602f0, 0xfc50d03f, 0xf679d8ee,
	0x2e508da5, 0x1b5cbcde, 0xf53fefc8, 0xfbcb2fbc, 0xdd5c95b9, 0xbd7f0f0c,
	0x42933d5c, 0xe40bb3f2, 0x976ff32a, 0x35eac72b, 0xe6ebbf84, 0xb788e3b2,
	0x0a671a8b, 0x71c5d3ca, 0x3b9f1277, 0xbfc205db, 0xf195c7a2, 0xab79f21d,
	0xe4cdee54, 0xfc7aca47, 0x888e443a, 0x17ad23df, 0xbe8fd1d2, 0x47f732de,
	0x16a87dcf, 0x9bcc2223, 0xda195185, 0x8eb5af9e, 0xf2f9c136, 0x0e7fdc55,
	0x2b33ef6d, 0xb79e7879, 0xe0213fc5, 0x361d8a9d, 0xf68b1d16, 0x8384f04f,
	0xdcb7b65e, 0xf8c6abdd, 0x2fc2e20d, 0xf650fd82, 0xbf5d8045, 0x556f7ed9,
	0x6a3ce356, 0x789ddebf, 0x013cc54a, 0x4f527c76, 0xac04f338, 0x40af103b,
	0x7bee969d, 0x202f4892, 0x943df0dd, 0x2edc75b7, 0x9cb57b84, 0x1043de8e,
	0x0cbcf197, 0xe7fdf313, 0x9cbd6dec, 0xf4367a85, 0x2f87d5bc, 0x5ad87f13,
	0xa055757e, 0x55ef4ff3, 0xfcfadd67, 0xce5ef647, 0x6af5fa42, 0xfe31f27a,
	0xb27b6af2, 0x6fd50e90, 0xd7fe7d71, 0xafa941e2, 0x79e5a0d8, 0x7148c142,
	0x85789164, 0xe3de00f2, 0xdd500f3c, 0x69f49bba, 0xc7cf1b7f, 0xc59d5438,
	0xa8bf9809, 0xfa81db39, 0xc7913fac, 0x05bf3065, 0xb47936f1, 0x7dd5076c,
	0xaf413329, 0x657be499, 0x88bc1e25, 0x79c5abf2, 0x877a36dc, 0xd0c11595,
	0xf284b8af, 0x560bf50c, 0x3e47aea5, 0x8a1ae8bf, 0x61f62499, 0x5354ffd6,
	0x089deefe, 0x2c7e48a3, 0x6fd006d4, 0x912e1ce0, 0x8a61f43f, 0x2cc11c5f,
	0x5a1cfd01, 0xab8a7ee9, 0x39fbf04f, 0x4f2e78c7, 0x279730ec, 0xda23dafb,
	0x86f980c4, 0x43fac9e7, 0xbc6727f6, 0x97243ff3, 0x9f963959, 0x811c01e5,
	0x4be710ba, 0x8209768c, 0x7fdf2fdc, 0x9368691f, 0x9112f8e3, 0x222d1dda,
	0x96397bc3, 0x0aef4918, 0x7a16d84a, 0xb983396f, 0x3d77f327, 0x03b9bf3d,
	0x11df4bda, 0x1a1df173, 0xbf74d3f8, 0x4d6e1c5d, 0xdd5a77c3, 0xabc6412a,
	0xc0333cdb, 0xdf92ad9e, 0x05164ca5, 0x497d63b2, 0x4ca7e411, 0x8f9f639f,
	0xe9fa55fb, 0xcc1fbc54, 0x73167e43, 0xbde165f5, 0x65f4f32a, 0xd2ab7de1,
	0x113bf66f, 0x99176435, 0x603b3cdb, 0xdc798d9d, 0xfbc35e6e, 0x0e27d071,
	0x48b61ef9, 0x8c39e1fc, 0xf3b456b7, 0x556ec7fb, 0xcef867ea, 0x467809cc,
	0xba065eba, 0x58fed05a, 0xf282c599, 0x0ba86133, 0x5fb1c7e5, 0xaf5ef860,
	0x0bb755ba, 0x9ad542f3, 0xe7e4789e, 0x6a9f2d8d, 0x781d9f91, 0xc7013b2f,
	0x6e5f3933, 0x1d7e2154, 0xf5efc646, 0x867ec65a, 0x71fb3b79, 0xeaed456e,
	0x801f284f, 0xabd71b7a, 0xf8a26e6a, 0x143cc6df, 0x831adbff, 0x913fa6f9,
	0xe543f3e7, 0x149e6364, 0xb7d31f24, 0x2d98f973, 0x77d41ab2, 0x4ebfce4c,
	0xbf204c4f, 0xf64e3fc4, 0xebcbc517, 0x8df18fd0, 0x4c024c12, 0xae770be5,
	0x99c8ff45, 0xdf1afdce, 0x979bafdb, 0x99717e92, 0x3cf7c01f, 0x7d3bdfb2,
	0x18b556c3, 0x6de99fb0, 0x0be8df3c, 0x8887e567, 0x48e1d6ee, 0xb29cba8f,
	0x7cff9067, 0x7793beda, 0xc5483e60, 0xe7a1a3f3, 0xc6bce510, 0x6513cc09,
	0x9a5df7fa, 0x19f5cc9c, 0x751f1173, 0xcafaf8a8, 0x7c651d7b, 0x819e7c8f,
	0xf9e04938, 0x17e99bad, 0x77c1afbc, 0x835f78ae, 0x7bf26be5, 0x41afbc58,
	0x7bf2f7f8, 0xc1afbc58, 0x41afbc7a, 0x0f7e59b8, 0x0835f78b, 0x960d7de3,
	0xb0f7e587, 0xf8ab7027, 0xf9f9cf8e, 0x1d17c80b, 0xfcc36b28, 0x086c7770,
	0x7fb82c3c, 0x0c10ac77, 0xffa8130f, 0xbf9f8381, 0x3e6034e0, 0x2bdb28d4,
	0xb0fd1229, 0x16d611c3, 0xde2f6fc4, 0x1e834757, 0x10f6792a, 0xec6151ca,
	0x5f28f9dc, 0x863a71fd, 0x6797c87a, 0x1dfb077d, 0x6d2d3e3f, 0x3d47e92b,
	0xff77afdd, 0xca68b6f2, 0x32207de7, 0x929a9611, 0x0cd6bb91, 0x408314f0,
	0xe27a0b7c, 0xbe2532f6, 0xb5a67984, 0xb9ab322d, 0x9fa2305e, 0x96da245c,
	0x922b3ae0, 0x7fa8b9f4, 0x4f5ae597, 0xe3f50de4, 0xb2d878b9, 0x3a87f434,
	0x9867d234, 0xac7e7597, 0x294f1861, 0xdfa53bf9, 0x4e53b99d, 0x19e9b8e1,
	0xe0e6d7a3, 0xa86420fc, 0xd65a2ce7, 0xa8b3fb88, 0xd23a8422, 0xf51a925b,
	0x8f5929c0, 0x5fb8954c, 0xea4ad1ec, 0xc3e78c58, 0x7de1c4a7, 0xdf4c876e,
	0x4f7d32e3, 0xfbc5f4c8, 0x897f7c2d, 0xe2585bf7, 0xa19616fd, 0xf2e2d0ef,
	0x23c8beca, 0x04a5f73c, 0x819b63be, 0x4df5c572, 0x460bfa0a, 0xbcf6ff39,
	0xcd0a6fac, 0x9c7cbd65, 0x92a9e69b, 0x359777f3, 0xca85f7c1, 0x4678ff38,
	0xcedd67e3, 0xd68b34f5, 0xc3bef7f2, 0x13df1399, 0x89337acf, 0x975e4ff2,
	0x3a01a9ca, 0x471902cf, 0xe4dec63d, 0xe44b2e71, 0x40eb32f2, 0x93abf502,
	0xd8f6a8f3, 0xb458f4ce, 0x295cb2bf, 0xf33fa1f0, 0x1cf648f7, 0x4b7ca180,
	0xcfb3e7e0, 0x018f4cea, 0x55e82bd8, 0x5df64fc8, 0x964bbdbc, 0x7928fb3b,
	0x2c3cf93e, 0xf4829dcc, 0x99bfb5f0, 0x9bc030f2, 0x5ca59e0c, 0x49d27bef,
	0x3a4f335f, 0x2cba6bbe, 0x3be0cfb8, 0x2b43dee3, 0xfabbe1e7, 0x4bf71acb,
	0xe87d7f08, 0xcef879b1, 0x74d0b2f8, 0x3ed818c6, 0xef829dd4, 0x3d0f7b90,
	0x3687dbca, 0x0a6314bd, 0x9c6f3580, 0xd3ed76c1, 0x042bcd8f, 0x3ae754b8,
	0xf37c8b5e, 0xf4bf9caf, 0x479e0ffb, 0x72b554fc, 0xfeea7dbf, 0x40de5783,
	0x92307cbb, 0xcd8c13de, 0xd7bc254f, 0x19b2beb5, 0xa4dbcdf9, 0xd4d87921,
	0x4f4be9f8, 0xa51d3f52, 0x6e754a57, 0xfa62a633, 0x7da10d0f, 0xbfb84695,
	0xe89c5841, 0x0e947da4, 0x361cf2e1, 0x7e1e6eb1, 0xb83de01f, 0xbf9471ff,
	0x687068d2, 0xebaf3f71, 0x07953e89, 0x3e6215c6, 0xb9d91bc0, 0x7eafe700,
	0x1ddfc74d, 0x8a98481c, 0x3e7301f9, 0x8c576fcf, 0x768292df, 0xd5f87556,
	0x5e624fbd, 0xdd3d35f3, 0xb96238f3, 0xd629579f, 0xfa272fe7, 0xef8bdeed,
	0xeaafbc55, 0x02b5dee9, 0x57007173, 0x79431dec, 0xf4feb7f9, 0x43a402e5,
	0x2f73b891, 0x47b37fd6, 0x743c42af, 0x77d12d69, 0x69761ca2, 0x90acde28,
	0x21ee8ae1, 0x3d113f7c, 0xb8bf44c5, 0x6768292d, 0xe3fc872b, 0x52efb87d,
	0x184bcb71, 0x7457b0ef, 0xfbd0d774, 0xc60de02a, 0xf06836f5, 0x23ec1de5,
	0x72fc8d52, 0xe0b2d859, 0x81bf9c05, 0xdfacbbf7, 0x3674f842, 0x1eb8658c,
	0x876863f4, 0x835b0b2f, 0x5e1b7bea, 0xf478c2c9, 0x14a56bd2, 0xae7c2a97,
	0x1ee54bc8, 0x243d905d, 0xf98f104d, 0xe8cff94a, 0x3c808664, 0x3b43a5d6,
	0xff302fbc, 0x1a8d4bf8, 0x5470168f, 0xf16b63a1, 0x0f22b35d, 0x9777c995,
	0x552af9e0, 0xb7e8e9f5, 0x2cf6e454, 0xd5e8b940, 0xe844b0b3, 0xaf6ca1f7,
	0xccd79b2a, 0x66f7ff44, 0x9f2a79fb, 0xb2eba3eb, 0xd16f5e1c, 0x19ef02bb,
	0xd43fcb43, 0xb523e932, 0x46a87e1f, 0x32bc3e47, 0xb75a87df, 0xeab4e30d,
	0xce3fae58, 0xd046ff40, 0xebca4f63, 0xdc155c2c, 0xbf9f26bf, 0xf6d6aca3,
	0x53dda3a4, 0x2be7b7e6, 0x1d27ad7a, 0xb8e855f5, 0x37d65152, 0x6fa40baf,
	0xb3859b2a, 0xa2091df4, 0xcf8fde34, 0x0ba730ca, 0x460d11df, 0x997cc487,
	0x7e97300e, 0xa3ed2a62, 0xd16f51b2, 0xe1553cc3, 0x27e8513d, 0xa27b22d9,
	0x1ef1ffd0, 0x992ed916, 0xfcca717c, 0x29ebfca3, 0xb70ac9f9, 0x6c1fa2c6,
	0xc60e383d, 0xdff0cbc7, 0x89948a80, 0x5bca6e5c, 0x663d6822, 0xbe47c9ec,
	0x3c19df2d, 0x0c69cf0e, 0xcb6f4790, 0x38c0f8ee, 0xdf3e577d, 0x4b384fb7,
	0xd3fbe372, 0x07c82917, 0x16b62a95, 0x092f27ef, 0x80103bfc, 0x4b903be9,
	0xe5673df2, 0xe47086b7, 0x6dd74b9f, 0xa15ec724, 0xd95cf487, 0x5f495b9b,
	0xa43d3578, 0x3e268ae7, 0x9e98e1cf, 0xcab7a805, 0xfd23ee26, 0x59ea4de1,
	0x6527df80, 0x4608f029, 0x9bc17ff6, 0xf6879fbf, 0xefe454be, 0x8d6ed827,
	0x3887e791, 0x78c997be, 0x77436c62, 0x1a1fc52d, 0x85a4fd09, 0x20fb9513,
	0xa2fcffad, 0x4cbc9e5f, 0xf28cdfda, 0x7ca06e59, 0x8d55f80f, 0x37ffa06f,
	0x7984de37, 0x29bc50f4, 0xb1718af7, 0x3a452fdf, 0x7d6915dd, 0xc9ef1f3f,
	0xbe287b33, 0x3f276e00, 0x1d6dfabe, 0x4d3e99c5, 0x5fd45edf, 0x0fd69131,
	0x361f61f3, 0x4c7ae76d, 0xf4d15d4d, 0x3f4ba074, 0xf48df903, 0x6f37e708,
	0xfdfe6ee6, 0xf92f7c87, 0x065eb25f, 0x91eac67b, 0xe74e043f, 0x7c0e5b77,
	0xdbc6fa84, 0x74f49a39, 0xb6f53ca8, 0x7a851b3c, 0x77d814e3, 0xe01e4067,
	0xe857a2d4, 0x7c1cc01d, 0xc3e501ff, 0xd7cf836b, 0x1403c3ff, 0x01cdb20f,
	0xdb8fc8f5, 0xbc50e182, 0x827a5f20, 0xfc49c0e4, 0x5bcb2f13, 0x6aced4d5,
	0x3c00c3c4, 0x0031600b, 0x87021a3e, 0xdc6567f4, 0x5a07887f, 0x11b6bce3,
	0xdf8a6e9e, 0xbd77f3f7, 0x08d76075, 0xf741183e, 0x60fdaad2, 0xddb8e2b7,
	0x15517b42, 0x2b7949d5, 0xdd1d41ef, 0x7add3ca7, 0x0fcf0521, 0x99f948fc,
	0xe337d6aa, 0x9b1fae31, 0x6a3f712f, 0x7a78c1ff, 0x35b0730f, 0xa510e31e,
	0xa772a6de, 0x6417dfcb, 0xea50fea1, 0x1d27a2ed, 0x74255ff7, 0x58fb6166,
	0x07f537dc, 0xd1984458, 0x97026c39, 0x922ad67b, 0xdba50f9e, 0x36fdf930,
	0x7a2c87e8, 0xe79871c7, 0x507d140d, 0xa395eb21, 0xe5c99f58, 0x47dca8df,
	0xca12fde1, 0x627a20fd, 0x564782bb, 0xf89d7943, 0xcadf7c89, 0xe7979a78,
	0xbd7bf89d, 0x8d672eb7, 0xd271c4ca, 0x01ccbbc0, 0xafda347d, 0x240f505f,
	0x5a781e92, 0xaae70f13, 0xd530497c, 0xf98a90c1, 0x3ba18a6b, 0x5e5ea65b,
	0x7c34f94c, 0x71b86b97, 0xd47ca15f, 0x52a9e324, 0xcaefe3c5, 0x2bdd02bd,
	0xfbf0d25d, 0xf437d03a, 0xc2b2c05d, 0x7f28c535, 0xb5d9c48f, 0xadf27181,
	0x2dba5fe6, 0xb3565e18, 0x106138a6, 0xb55caf39, 0xbb2863b5, 0x6b0abe71,
	0x74bc717d, 0xefb2bd63, 0x9f657a4b, 0x03433553, 0x4d6731f1, 0x972850f1,
	0xf8adfd85, 0xd4bee7e0, 0xdda0f3aa, 0xfdd2fc05, 0xd5df5df0, 0x6f57e504,
	0x73055f35, 0xcdc7fdd1, 0xda5a1ff6, 0xe6374f04, 0x57c81893, 0xc819c903,
	0x877ac04d, 0x1d7eb9f3, 0x2f944bc8, 0x2971891a, 0x191a2eb3, 0x2d089798,
	0x15198bf1, 0x527111bd, 0xc0b87209, 0x943e0834, 0xf226cbfe, 0x65874977,
	0x5a561e3e, 0x460de3b5, 0x27479cf9, 0xf7f9bd0e, 0xfac94f25, 0x5f7f27ff,
	0xf7822d32, 0x311bd76b, 0xff6be3ef, 0xbec2f29e, 0xfc398675, 0x92c0c1be,
	0x7123bda0, 0xfcc0aec2, 0x2e02b0ef, 0xee6611b7, 0x343238ef, 0xca579e3f,
	0x2bc81c8c, 0x1991bf91, 0xde2cf741, 0xdf646b96, 0x46796d7c, 0x76f10fbc,
	0x6f280cba, 0x31fd3f8e, 0xb7b0ed1e, 0x8f7a2bed, 0x02e1fde6, 0x28db53bd,
	0xda3c17bf, 0xeaf3bf22, 0xdeb12294, 0x3165f257, 0x9724dbf6, 0x8682bcfe,
	0x4a94a1f0, 0x978940de, 0x21767e21, 0x1b8c1b3e, 0xf586637f, 0x7c96d859,
	0x3f1007d4, 0xf0dda2c7, 0x84a413e7, 0x812ff2c1, 0x353484f9, 0x896027cf,
	0x34b484f9, 0x18404f9e, 0x625809f3, 0x31eb013e, 0xe630809f, 0x7cc61013,
	0x4f98c202, 0x09f312c0, 0xfc8dff58, 0x140f877d, 0x1a77cf17, 0xc4afef48,
	0xbf80cd77, 0xdefced95, 0x4883656a, 0x7df8c1f7, 0x1bbfda07, 0xcb34ebde,
	0x5bdc75ef, 0x71d01ee9, 0x89213450, 0x67103bf0, 0xe9dbbe3a, 0x2079863b,
	0x5a609347, 0x1cfd6123, 0xb6c6c7da, 0x63e6cfbc, 0xa4c6837d, 0x389f8892,
	0x9705eb3d, 0xadaae51e, 0x8556f281, 0xcef4ed09, 0x3028d1df, 0xd6ceb7cc,
	0x2ed938f1, 0xdd0e6d42, 0x6d1f92a7, 0xfc5275d7, 0x904fb552, 0x76f7bf02,
	0x3d255c14, 0x2f53dca1, 0xeecc4de5, 0x824b4bd6, 0xbf85acec, 0xc27fc2b7,
	0xbbf2ec7e, 0x0243f26e, 0x78a5a2fc, 0xe2f58d7f, 0x899df40f, 0x21dc021d,
	0x5bdfadc2, 0xad35b655, 0x3f5a77c7, 0x85d5ddf5, 0x757df289, 0xa47eff36,
	0xf64bb7e4, 0xfaf5841f, 0x4fc8e8b7, 0xbd59e5f1, 0x7df0f313, 0x2ef28581,
	0x14f5dac7, 0x3adb9d67, 0x52ef2836, 0xbca70e24, 0x408d0ac7, 0xae597bf6,
	0xcbe41bf5, 0x298b2569, 0x312d32df, 0xe158e492, 0xcb733bc3, 0x5779c5be,
	0xcf28904c, 0x8f63a455, 0x3bf27cd1, 0x454e852e, 0x054b8275, 0xa26622f0,
	0x021606ef, 0xea1f30fa, 0xe03618d3, 0x8c85ab7b, 0xf850abbf, 0x8156c56a,
	0x0f130af8, 0x3205e788, 0xbdb6173e, 0x9bbe3dff, 0xfee3ac58, 0xdf8ab26f,
	0xe26f278f, 0x611e27ef, 0xb2377a56, 0x244fb90c, 0x0f76fafb, 0x86235bd4,
	0x5eff70a7, 0x17f9c04a, 0xbbd0d09d, 0x7b84a2e0, 0xe764add3, 0x84dde90b,
	0xfe2799e0, 0xd31fb6e5, 0x26efc19f, 0xdeb8698e, 0x9c527c01, 0x4afc81d5,
	0x952b1ef9, 0xa9cb6a27, 0x06cd933c, 0xd7cddefd, 0x8e1366fe, 0x4c18722f,
	0x7e9bff88, 0xe3fe17ff, 0xf119bddf, 0xe21e5d5d, 0x42572ba3, 0x306b7c7c,
	0x128a3e21, 0xb0fbe9da, 0x59fcf2d1, 0x05996539, 0x144b0fb0, 0x78fae273,
	0xf005b33f, 0x12078c5b, 0xb6ee7f30, 0x7d35f7e0, 0xde9182ed, 0x47a0df51,
	0xf7c3aeb7, 0xc1348e29, 0xe2da7988, 0xf1452df0, 0xa8f17f30, 0x71ea1354,
	0xbfcf0b47, 0x7ce4a17a, 0x144b8770, 0x3c7558f8, 0x1d39ede6, 0x3fac72eb,
	0xafea182f, 0xcce5952f, 0xbf8d76d7, 0x7e75be1f, 0xefce0f76, 0x6efa7a64,
	0x5f60fe9d, 0xa08db7a5, 0x47c2ad3c, 0xbb098dfd, 0x281e8f90, 0xfe68f6e0,
	0xe8344ffc, 0xad9a1447, 0xfde015f7, 0xebab92f9, 0x839ce9e2, 0x7794c9e7,
	0xb279a1f7, 0xfffb7d40, 0xa3fedef1, 0x4f2a1ada, 0xb2a2aed6, 0xdbc9d6b3,
	0x208fac23, 0x9e427ede, 0x483056d5, 0x4985959e, 0x416764d1, 0x3b3e79de,
	0x720aaf24, 0xf3900aae, 0x0f316d69, 0x643f406f, 0xf784d69b, 0x79def8cb,
	0xc2f481a5, 0xe68305e3, 0x19bc1557, 0xcfdb1f28, 0xff8839f4, 0xd5a319a9,
	0xca77682a, 0x6fc95af6, 0xf9e0bca2, 0x44b05e50, 0xfdab5179, 0x16a2f2f2,
	0xfdccda44, 0x05f92702, 0xfaeba27a, 0x004fa035, 0x418ccc5e, 0x884ae4fa,
	0xe600813e, 0x587df497, 0x126d8e9b, 0xa73deffc, 0xce5df142, 0xcdc5fa20,
	0x7088cbf5, 0xbbf4abf7, 0xf4e1d50a, 0x9ce4189e, 0x46d8ebf8, 0x096f4efe,
	0x0775a32b, 0x5df433d1, 0x7d21e2cf, 0xfd077e67, 0x20633f17, 0xd27d66ff,
	0x47bffcd2, 0xc0593ccf, 0xfe3cf1f1, 0xc7fa837e, 0xb361bf7e, 0x2baff780,
	0x48d9621e, 0x1bf7e56f, 0xc50c6012, 0xeffd7fbb, 0x9d233437, 0x0674c81f,
	0xc2437efd, 0xe1bf7e4d, 0xe68796ad, 0xc37efe07, 0xe78b2d5b, 0xffc1be63,
	0xcd0f0dfb, 0xfdfe3fff, 0x7f71f786, 0xf0dfbfa1, 0x93f48151, 0xfc01bf7e,
	0x4e518fd8, 0x9396d91c, 0xe7cb2658, 0xf95efd0e, 0xd8ef7c84, 0xc7ceb2a1,
	0xa9ca38b2, 0xcb957aa6, 0x2a87e58c, 0x0fc4a3f7, 0xc4ffd6b9, 0x9b3f14fd,
	0x877e9e3d, 0x77a6e745, 0x5ae677e4, 0x17f9c73e, 0x0bfe58e5, 0x7f3cd0cb,
	0xd83e7c9d, 0x7b637fcf, 0x85317be8, 0xf595be2f, 0x39651fd8, 0xf8375c9a,
	0x2c7ffb77, 0xf27ac950, 0xfb0df7c7, 0x957ee1f5, 0x8b2db3fd, 0x78ddf4cc,
	0xeb0fa5ae, 0x4957bf61, 0x83621b4f, 0x91bdfbbe, 0xdeb49d5f, 0xc9efe51f,
	0x9e962f40, 0x95287ee3, 0x0c576ae9, 0x9ec30bfa, 0x7ee0c572, 0xe9f7d587,
	0x978ffbf1, 0xf47a7d9d, 0xdd5e5e1b, 0x97fac7a7, 0x767dfc2d, 0x2693fce8,
	0x7d2438f1, 0x1f8d1f72, 0x52756b09, 0x8317d05c, 0xf97a5afe, 0x28e75a7b,
	0xf4ad2efa, 0x24bf905c, 0x948f7c91, 0xa53e46eb, 0x230fc862, 0x6efe3077,
	0xec8e30b1, 0xef18655b, 0xa3d4f95a, 0x71a3e42a, 0x0077d82e, 0xaedd8dff,
	0x8efe0fee, 0xaae343d7, 0x4fc025e4, 0x33b76a0b, 0x98749efe, 0x4fd08fac,
	0xc6fa0f9c, 0xf7defe5e, 0xadc17ef4, 0x7e8f9909, 0xfde060e3, 0xf5987564,
	0xde891eed, 0x5bf50627, 0xf5c9ef3a, 0xcf96cf18, 0x78a5aadf, 0x7ad34978,
	0x4fb66d2c, 0xfc8c09b4, 0xe0fea0ca, 0x37c10657, 0x1f6433ec, 0x5d5e8fd5,
	0xbac8309f, 0x933907c0, 0x707cfcf2, 0x871ee34c, 0x7b31e9f1, 0xdf7f89b8,
	0xa1dfa6e0, 0x877f25d9, 0xa65ffbbe, 0x58fbf99a, 0xfe3017ce, 0x127e9367,
	0x7f51d51f, 0x819654e7, 0x52ab7372, 0xbf0383d1, 0x4e65a36b, 0x88ce53ca,
	0x90e73d24, 0x25eabee3, 0x1443f246, 0xbb56aeb9, 0x7ec7aecf, 0xbdfc9171,
	0x68f41a9b, 0x0d2fde1c, 0xf4dbf7a3, 0xd18cf087, 0x5f158f74, 0xbce0f6e7,
	0x260af77d, 0x46171bcc, 0xa45abd70, 0x02bdb32a, 0xf8a9efed, 0x88bc08ef,
	0x77c443fa, 0x05f7fc13, 0xbcf364ce, 0x3efe2270, 0x9057bd09, 0xaf3e30f2,
	0xc23b2c13, 0x3ce52c44, 0xf6818568, 0x9ca973e1, 0xb6cf381a, 0xa58ed718,
	0x0f6dcf80, 0xee9f9266, 0xbfa0fdc3, 0xc7df8733, 0x9b298b6d, 0xe7db1cbf,
	0x43f6a78e, 0x6bfd1e7f, 0x22afee33, 0xdb7e84dc, 0xe7ee6cb6, 0x41999b6f,
	0xd2096fed, 0xce13b41a, 0xb3ad18a7, 0xdf3f266d, 0x908f5fb6, 0xe9714fbf,
	0xea6f77e9, 0xcf78492d, 0xbaca3c36, 0x4c3de902, 0x96dc67be, 0x3e50f50a,
	0x7dcd9427, 0xc099e704, 0xdefcabf7, 0xe3b9b1c0, 0xe397bd7f, 0x5df783d1,
	0x1491198e, 0x922fffa7, 0xc06a0a3a, 0x00c06a0a
};

static const u32 tsem_int_table_data_e1h[] = {
	0x00088b1f, 0x00000000, 0x51fbff00, 0x03f0c0cf, 0x3373f78a, 0x45e6fc30,
	0x5e0287f0, 0xb0c0ceca, 0x0257881c, 0x56204bf1, 0x50606364, 0xff5e2362,
	0x5b04290a, 0xc181825c, 0x8aa78805, 0x0812f901, 0x06696171, 0x06495486,
	0x08497506, 0x76900b7f, 0xeddca294, 0x2b1b0183, 0xc9098a60, 0x5826d821,
	0x29b191e4, 0x1c917c9a, 0x808cdf2a, 0xf3c681fe, 0xfbf951d4, 0x16b42155,
	0x9a3e7c54, 0x7ca801fc, 0x0b5fd428, 0x1b9bb1d4, 0x27bfa646, 0x006840b0,
	0xf4f4f7fd, 0x00000398
};

static const u32 tsem_pram_data_e1h[] = {
	0x00088b1f, 0x00000000, 0x7dedff00, 0xd554780b, 0x733ef0b5, 0x7993331e,
	0x31e424e4, 0x09261081, 0x83086820, 0x3ac54440, 0xbde311e1, 0x1a5e1db4,
	0x15e18fad, 0xa0484842, 0xdeb787e8, 0x2409033f, 0x88b06220, 0xf0ed6bd8,
	0xed160b48, 0x16850348, 0xd22d00e9, 0xb15ab077, 0x5ac17eda, 0xa4490850,
	0xcb6ad457, 0xfbdad6bf, 0x13267324, 0x5fafdb40, 0x4fc5ef7b, 0xfd9f6b36,
	0xd6bdaf5c, 0xb4518fda, 0x84319674, 0xe7f84bb1, 0x5ac6c656, 0xbde96319,
	0x65166ce9, 0xc6d4864c, 0x8cd18e42, 0x7e9acca5, 0xc634a2f7, 0xdf35139c,
	0x7324506d, 0x6bb9f4d6, 0xd13d9e01, 0x8f2ac3e6, 0x6fb3fe6d, 0x0db19791,
	0xeef1df1b, 0x0bbd7802, 0xebef82fe, 0x578593ff, 0x1e1d8c49, 0xba7871a3,
	0x42e6b614, 0xe1cadb3a, 0xe0cc2cc1, 0xe59eabfb, 0xcea0598c, 0x229e3027,
	0x27f874c6, 0x061847cb, 0x10d8c199, 0x57f8bd84, 0x7df06325, 0xb3dd8096,
	0x2b3d5297, 0xde38480b, 0x63aa34de, 0x337426ca, 0x0bda8d25, 0x2d7ea8b9,
	0xa6fab80b, 0xef1f3f0e, 0xe3466cec, 0x38f08d9b, 0x3f082b0e, 0x601d61cc,
	0xb6778c0b, 0x77ea41ef, 0x94677436, 0xcc3079c3, 0x6def198d, 0xad8fc0fe,
	0x59aceed0, 0xc2e9e112, 0x1e6f182c, 0x95a9e3d6, 0x734707f9, 0x71a6ed31,
	0x85075e3f, 0xa571deb4, 0x5c6892ce, 0x37bed0a9, 0x877df317, 0x34eb3db1,
	0x68c6bec6, 0xbc03eabe, 0xc24561fe, 0xbc4767d4, 0x87dda6f5, 0xf9df52ad,
	0x97d678fe, 0x844eed6d, 0x973e1297, 0x5378f8d9, 0x906a034b, 0x2ccefdf2,
	0x989cffc8, 0x47c180c7, 0xe98ba726, 0x16ff2059, 0x5f39ff91, 0x085634f9,
	0xe83087f0, 0x5d805411, 0x44fdbfa2, 0x1b945d37, 0x6ddf0dd2, 0x40f5dfbd,
	0xd4327be3, 0x5ccb301b, 0x9c95f74f, 0x92a0f6c1, 0x70051814, 0xcd1eb9a9,
	0xeec646e5, 0xd3b4ae66, 0x07bfc1d7, 0x9097c1b3, 0x3e3f80ce, 0x4bd7f63f,
	0xac2cefd0, 0xb7f2f723, 0x787e1e91, 0x80bdab86, 0x3359c6b1, 0xf9e60c5d,
	0x0ba6606a, 0xaceafbe7, 0xf8ef3499, 0xe567b3f2, 0xfa0b0726, 0xe3e91be6,
	0x70d1d075, 0x16e82fa8, 0xcc807dff, 0x2805236a, 0x8e1fcc27, 0x4e196769,
	0x30fa100a, 0xc078cd32, 0xe92dd28f, 0x2f10ffd0, 0x8c1247f3, 0x6cc84be3,
	0x03658e50, 0x1ffab3f1, 0xb539b00f, 0x96099bfb, 0x718270d2, 0xe076c32f,
	0x1a34bbbb, 0xc69dfe20, 0x1a7b3be5, 0x8cdc3a8b, 0x6cd771dd, 0x3486c3c2,
	0x0dfd6125, 0x84625e38, 0xbef84ea8, 0xb3b8f1ca, 0x4f6c012c, 0xc2072d9b,
	0x126bf331, 0x165231e3, 0xdb3ff2e5, 0x7b97e9c3, 0x7f414bc7, 0x15ac7c02,
	0x1c8b5b78, 0x3c77be36, 0xf80d77c6, 0xd21ff91c, 0xd3097ee3, 0xa7b63b6e,
	0x155db6b1, 0x86414724, 0x27f905fc, 0xfe17a924, 0x1c554d67, 0x7e4c5663,
	0x41c91a5a, 0xa3c2f5bf, 0x81eb9415, 0x4320fe42, 0x6c0589e0, 0xf0831f20,
	0xf5b1b95f, 0xd3abff7c, 0x77e0667a, 0xf41a7e8a, 0xb2ffe491, 0xcbbae974,
	0x4ec2b5f1, 0xf50b7a1b, 0xe895338f, 0x48392571, 0xe89e9fc0, 0xfdff00bf,
	0x3140d2dd, 0x471a37ad, 0x43b2d31d, 0xfbe8126d, 0x3ee5c1c6, 0x403ceebe,
	0x1eb186eb, 0xa04f9fe1, 0xd87183bc, 0x94f5cb51, 0x56f416b5, 0x302fd432,
	0x298d0faf, 0xb4249bfb, 0xd30ad823, 0x472f16ba, 0xf4449f8d, 0xd2bd0240,
	0x76b89f43, 0xdeb04847, 0x166ea838, 0xd87e5bd1, 0xd7cbc7c6, 0x02cb0d1b,
	0xaca71b3d, 0x6f1ea1b0, 0xe1b32cf4, 0xbd98d1ba, 0xc86a618c, 0x35bed1ab,
	0x75d97bdb, 0x1d8f4d65, 0xedb92610, 0x363acfc9, 0x630deb06, 0xe8651bed,
	0xc4bd25af, 0xf81fedc2, 0xdd1eec9b, 0x4968e382, 0xd5f63d61, 0x52f39436,
	0xf60ce70e, 0xdc01d786, 0xcf7f3762, 0xb25be511, 0xd910e1bd, 0xb08b5e11,
	0x3ebb4423, 0x6d864fb2, 0x86476dea, 0xb1c6c372, 0xc7eb0690, 0x85cb15d0,
	0x7895e33d, 0xb0ec263d, 0x4b4bc26e, 0x91a4a4f3, 0x1b852760, 0x87a221a0,
	0x63b61d7f, 0xebe8b26d, 0x75b10f48, 0x0137840e, 0x33b7fd4c, 0xde31c761,
	0x46ddbb5e, 0xdbb76df9, 0xfd8a1d21, 0x7d356326, 0xc7af0a5d, 0xe41d91d6,
	0xb18b68db, 0x3e407677, 0xb02167da, 0xb025869f, 0xa78c4083, 0xf6b14548,
	0x4e10c4a5, 0x6952f017, 0x36f90128, 0x988d6fce, 0xd1dc740f, 0x0bc92934,
	0xf5e1de74, 0x1e80f927, 0x419c6c0f, 0x20764b70, 0xf3805029, 0x2ec4919d,
	0x3627df43, 0x0923a605, 0xfcf74876, 0x6bf53274, 0x6d8ec3b6, 0xc3f36a2c,
	0x989a5bb8, 0xca700acf, 0xda1240fa, 0x9f30f9b1, 0x76dea4db, 0xdb361fd2,
	0xf29adb4f, 0x61cbe424, 0xc5bf7c9b, 0xaa3f2779, 0xa94e9179, 0xbcfcccd3,
	0xd2f1c435, 0xaddb8d32, 0xbaef5e2d, 0x32970811, 0x9ef84adf, 0x779737ec,
	0x8bbff7ae, 0xeafcea72, 0x80f3a245, 0x1e56a027, 0x453fcfe2, 0xbdcfb58a,
	0xfe0c5ff0, 0xedcc139c, 0x9b7c4cb4, 0x78db1fea, 0x9fda1247, 0x9240c12d,
	0xfe77d05e, 0x14e8fd86, 0x3fe8c27a, 0x6fa889f9, 0xef3beb11, 0xf819f9f8,
	0xb88f33e9, 0xe4376cf1, 0x1ae4193a, 0x54ec8dfd, 0xa3be0fd2, 0x64498e6f,
	0x1c7a1a0f, 0x89d990f8, 0x7b7e22df, 0x5ffabe22, 0xe6eb1a92, 0x73f02904,
	0x5d92f109, 0x614efa4b, 0xe3495fc1, 0xf919cb7b, 0x1205894e, 0x97bfb7d9,
	0x34f73db8, 0x5cc6fe0b, 0x0e90c82f, 0x7af82cdd, 0xdd637ca2, 0x7fd80a65,
	0x97a7faa3, 0x0b286e51, 0x66cb5e90, 0x72a7a46d, 0x47caefd0, 0x337ae396,
	0x3e5df50f, 0x94b5f49a, 0x94cd608e, 0x9422cb5e, 0x4a36b016, 0xc85cbd0d,
	0x3a1e09ba, 0x02c4702e, 0x774b7b7c, 0x9e61f984, 0x0b08828e, 0x0bd338c2,
	0xafda1202, 0x3976a5e3, 0x8d97e419, 0x2816de62, 0xa5edceb7, 0x9b96c571,
	0xbdeaf504, 0x7a0a9096, 0x9b6b2f66, 0xab7a8c9c, 0xfcb04580, 0x74a5a75e,
	0xb96f415b, 0xe38f02f1, 0xe600965d, 0xee7ded1b, 0xe07b7343, 0x5728cb4f,
	0xc25721b2, 0x14f5a6bf, 0x7d42adc6, 0x02b5c7b4, 0x409adfe6, 0xdc2db95f,
	0xd4771f2e, 0xed7d47ee, 0xc8c2d328, 0xcd05e9f7, 0xcfa708c5, 0xe0193e67,
	0xfde1de9b, 0xc638e036, 0xbd3bcef7, 0xdd212023, 0x5a163cdb, 0xc0e31c37,
	0x3c7b46bf, 0x8c5fd5ab, 0x26f804f1, 0xa20ab8e3, 0x9760197e, 0xd3fbd3f0,
	0xc64fae9b, 0xf6dd717a, 0x9136800c, 0x132f8afe, 0xb6eaacf5, 0xaf8081b1,
	0xe4add7fa, 0x95745fbf, 0x7c31610f, 0x745d4ef6, 0x8c61fccc, 0x4e3bad9d,
	0x1b5d4769, 0x27759da5, 0x6edfed29, 0x7c085583, 0xf9fff911, 0xfd6fd83c,
	0x3bcc03e1, 0xc21dc68a, 0x969d38f9, 0xbfc91e70, 0x7a32d64d, 0x001014ed,
	0xb3c60dbf, 0xad1e4c79, 0xc45f88b7, 0x12c63ab3, 0xd9673c40, 0x05a5a59a,
	0x9e2ef931, 0x53e8ee3f, 0x3b2f512b, 0xa831b3e6, 0xacab3657, 0xf88ce90c,
	0xab69039c, 0x203fb964, 0x4e90b9e0, 0xef07ef68, 0x1d68076f, 0xf0097ac8,
	0x78a07c84, 0xf532b993, 0x9fcd5e93, 0x209fc4c0, 0x00d95de9, 0x6d9fdf85,
	0x7f7983cc, 0xdad9e385, 0x0875b0a0, 0x56af357b, 0xff376e84, 0x98ac1d93,
	0xdb1ec0c6, 0x18ed3e5e, 0xf97ce7ea, 0xe42ac393, 0xde55ae0f, 0xb3d18f6a,
	0x9f606539, 0xb21fde80, 0x1b9f9cc2, 0x81d0c332, 0xbf38e505, 0x665f9cc9,
	0x8bbefe11, 0x8afed0b9, 0x05b2d79f, 0xefe8483f, 0x5163aeaf, 0x4b031aa7,
	0x2c069f1c, 0x57059465, 0x8d96fcc2, 0x599f1464, 0x6dfee16b, 0xbe03d633,
	0xf5d220d8, 0xa918ed71, 0x8169c13c, 0x4ebb03b5, 0x653fb7e8, 0x00b1ae29,
	0x265a0e5d, 0xde5058d5, 0xfb430895, 0xf9a691d0, 0xafca09c3, 0x7fd428b5,
	0x97e6d292, 0x37dd5c61, 0xc036df32, 0x3bb532fb, 0xacb1f28a, 0xa10bebd8,
	0xfd85f33a, 0x58149748, 0x3efe5103, 0x8a5678c5, 0x50b4acf1, 0xa76a113f,
	0x4dbe701b, 0xbb787ec2, 0x197a46cb, 0x8dfd81da, 0x2545be73, 0x22d47b7e,
	0x0907e429, 0xc8a9acba, 0xc004ac7b, 0x8cdfdd76, 0x8253b8fd, 0x9ef91a94,
	0xd45e65b9, 0xcc435907, 0xd5b72bf4, 0x547f20e6, 0xc8252206, 0x7e32673f,
	0x798546b4, 0x3e63ab6f, 0x72eff005, 0x78e0b606, 0x1da9efab, 0x0daef68e,
	0x971d3979, 0xb64d3f72, 0x9f2aca69, 0x14caf902, 0x1f02aa25, 0x9c8e132a,
	0x8698dd54, 0xed3f918a, 0xec02dfc2, 0x29619286, 0xbff08db0, 0xc4d1bb2b,
	0x187d51f6, 0x3627ad2e, 0x8adef730, 0xdb2d3be1, 0x19bacb0c, 0x5c6f4fee,
	0x750f9d29, 0xf8861adf, 0x75876467, 0x2e1db8bb, 0xe215f04f, 0x74dc3778,
	0xfbe9e113, 0xeaf6ff42, 0x1fc9b0a3, 0x32fc5790, 0xcc58e863, 0x797ca66f,
	0x8633cfc5, 0x34bc400e, 0x936d7cd3, 0xf71e3197, 0xaa78f3f0, 0xfa8d77f0,
	0xd1fe1e06, 0x87f78ef3, 0x181f486d, 0xd9d84da7, 0x178e5e29, 0xb7c2ceab,
	0x05325e01, 0xfaf9d36c, 0x6968b0a1, 0x5c034f1e, 0xc49ed6ff, 0xe6b64aef,
	0x787b7d45, 0x1be546b0, 0xf8797853, 0x469b99ee, 0x298f49df, 0xfec36c2c,
	0xc47fd414, 0xf6910117, 0x5cb487e4, 0xd46a8fca, 0xf919844f, 0xbf01c112,
	0x166fca64, 0xfb0bf5f8, 0xca94efe8, 0xc4c13cd3, 0x69e931f6, 0x43700a2a,
	0xafb21aca, 0x0c437aa6, 0x76576aed, 0xe765e939, 0xabbdb338, 0x7376cc7a,
	0xce9b7793, 0xbad3f7db, 0xd9ed1360, 0x9f1435f4, 0x9c9765b5, 0xe29276c1,
	0x50db61fc, 0xb888ac33, 0xf6164bac, 0x06ec0df4, 0xabf593f2, 0x3f0a0f8c,
	0x7fd06dcf, 0x13b7a702, 0x77f405ec, 0x2eec0532, 0xf7c9e830, 0xdff98c01,
	0xfb718536, 0xcf47f042, 0xdc4a43fe, 0x8f0a43fe, 0x91bfafef, 0xe8c207f3,
	0x257db8ff, 0xc7b897e4, 0x686e7af1, 0x78c7c787, 0x27e8df3c, 0xddea3bf6,
	0x68da130b, 0xe05dc01f, 0x6911f4a7, 0xa0a3b51a, 0x1e7cc29c, 0xc2bc7e13,
	0x263f8a74, 0xeb24798b, 0x8baf9e3c, 0x318074f6, 0xe89ae94e, 0x28d1fee7,
	0x3a0dde3e, 0xa7b62f1f, 0x9bda78d0, 0x09f3e454, 0x7685dfdc, 0xf6e7e637,
	0x93992fd2, 0xfd61f204, 0x0b92f680, 0xaa6e8e80, 0x7d48b21f, 0xfe1148f9,
	0x75fc22ba, 0x165a6768, 0xf58033b4, 0x47e099f0, 0xec37f71e, 0xee22019b,
	0x4c777c6f, 0xc7ff1beb, 0xfe38a4fc, 0x4a53f233, 0x7d93e5cd, 0xef8ccf9c,
	0x035b7ef1, 0x9775fce3, 0x7480ec2c, 0x57f38c36, 0x57f155ea, 0xca13ce0a,
	0x59fb18a7, 0x27525f82, 0xe022fd0a, 0x7f06a194, 0x7bdbba71, 0xf3f9c9f0,
	0x8f57c171, 0xbb757c1b, 0x9d2303d6, 0xe1ca9f1e, 0xfd8c52c7, 0x29a7ce20,
	0x89d49da2, 0xa927c425, 0x2f3aff46, 0x17b43a97, 0x285dba46, 0x5b707ce5,
	0xf677cf1a, 0x925781f0, 0x417a5ea5, 0xedcd159a, 0x228f43d5, 0xbe270dbf,
	0x4ababa20, 0x90b9bf39, 0x7f5e24df, 0x2a9f943e, 0xfa3d1df2, 0x5ff42c34,
	0xccb24fd4, 0xf10afdda, 0xc267df19, 0x5fd41cf6, 0x6e5e78f8, 0x049a9d2f,
	0x3ae87a5d, 0x72e43825, 0xa2c62d71, 0x7443c592, 0x83642c91, 0x28ca45fa,
	0x552fb0ff, 0xc7dfa092, 0x2e563f01, 0xb35f147f, 0xe3daf88b, 0x0fc84705,
	0x3587dc79, 0xef5e2f00, 0x432879ed, 0xfa1f16a5, 0xf2978f49, 0xbf7c47f8,
	0x8f97a5a9, 0x71d969b7, 0x6dcd2cfa, 0x6447cfe2, 0x27113fb1, 0x73596b3f,
	0x213fad33, 0x26279b7f, 0x2f2f115e, 0x1f5c89ce, 0xe57d7c3b, 0x114cf901,
	0x7d6092e5, 0x47dafa41, 0xf143e598, 0x1d6c7d73, 0xe8be2017, 0x7c89de33,
	0x33494cdf, 0x5e30ffe7, 0x4eaf7b1f, 0x21f97a5e, 0x80b7d622, 0xe77f1fd0,
	0x2d9fedf5, 0x3ec9f90d, 0x9e201a42, 0xce04b65e, 0x9d0f88c8, 0xb60e87db,
	0x84cff09e, 0x36e8307e, 0xf0bc6295, 0x93cb9b3d, 0x7ad08f43, 0x3cb828ec,
	0xfb17addf, 0x74eb6b87, 0xadf11f4a, 0x25e79b2a, 0x0dd685bf, 0xc553515b,
	0x4367f876, 0x5bbe879d, 0xe76a8547, 0x6c38dc02, 0xf61b7045, 0xd279fc2d,
	0xb15f4853, 0x4b8c6e5f, 0xe5057b45, 0xb7e43b28, 0x10b951a4, 0xc11d534e,
	0x4f68e8e3, 0x041c5c52, 0xe1ac0adf, 0x04eb0a18, 0xdc1185ea, 0x8d0c721f,
	0xe6820c60, 0xaa657e83, 0x10524c1c, 0x51cd051f, 0xba28778c, 0x20d6f24e,
	0x1f239845, 0xf9257be7, 0xbcb8590f, 0xabfb4e27, 0xa8fb8497, 0x48bae409,
	0xdbdd91b1, 0x049846a0, 0xc5186bf3, 0xc8696fc8, 0x4679fb35, 0x1cb850ea,
	0x0f69de2f, 0x5f231dbf, 0x131491d5, 0x2b3fb35c, 0x1c8c76fc, 0x1f9c662d,
	0xf68972d8, 0x27f8aad5, 0x73dacd56, 0x0c2eef10, 0x4bbb42d2, 0x0819ed2c,
	0x3beeb177, 0x6794644a, 0xe6e51fbf, 0x0638393e, 0x223496f1, 0xe8a47c40,
	0x4abf1101, 0xa37daabb, 0x0bd5e12b, 0x484cb3dd, 0x3a8a45b3, 0xd34806f6,
	0x8e331a78, 0xcff8ca49, 0xee030e3e, 0x228397b5, 0x84f435ad, 0xa91ffa5f,
	0xf5e38a27, 0xd1e22542, 0xae4c0bd0, 0x883f6262, 0xc85582f4, 0x904f54df,
	0xe30d71ec, 0xf1ef1895, 0x1fd07d70, 0xfac51bbe, 0x85e846bd, 0x5a0bd406,
	0xd437fcaf, 0x0ab60979, 0xd0f1593b, 0xc94b3e36, 0x5cf0860e, 0x2d766643,
	0x27c04f6b, 0x8a415c6b, 0x2ace1d5f, 0x35f7e0f7, 0x8c3dcb83, 0x9f6e7eec,
	0x935de318, 0xd762ce55, 0x2f371c4f, 0xfc579e67, 0x9be3fa7c, 0xe0c8f5f8,
	0x46f91523, 0x5873d4a6, 0x52afd4c2, 0xc3cf123c, 0x046bfb70, 0x4b2a1fda,
	0xefa3adf2, 0x3e5e72d1, 0x9cd2285a, 0x405ca807, 0x6bfe2fec, 0x093e6ba4,
	0x860e90d8, 0x06b7eb3d, 0xd85ea3f7, 0x69ca48ab, 0xa75893c4, 0xecbda757,
	0xdf183a46, 0xf6bfa63b, 0x55e35405, 0xe209745a, 0x07739669, 0x8c6c875f,
	0x676191f4, 0xe3981524, 0x67817666, 0x54cbe05b, 0x1be0967e, 0x397350db,
	0x7dc54f3a, 0x2e4b7091, 0x2e3e37d2, 0x4940e5c7, 0xb8abe733, 0xf3e30aa1,
	0x83c7bbcc, 0x1b3d5de3, 0xc3f02ef4, 0xfd66e9ea, 0x40e58d9b, 0xf0af7e5e,
	0x7fa11ff4, 0xbe77b975, 0xea290139, 0x33c8fb00, 0xc21ed7d9, 0x92b4ce79,
	0xc18488bd, 0x3c4610f3, 0x2b273593, 0xfc46e7c8, 0xa5e07073, 0x39ae308f,
	0xb927de64, 0x0ade6828, 0xcb6e08fd, 0x319d15fe, 0xa437c798, 0x5fd891ee,
	0xe7a2638e, 0x06e78601, 0xeb015b18, 0xde71ee28, 0x77d62983, 0x3cfc0923,
	0x61e82ede, 0x91903945, 0x1d4a613e, 0x8970bfc2, 0xb464cf7d, 0xfd7bf36e,
	0xc2c7f016, 0x1ecff216, 0x5b9ec9d6, 0x84f9d32b, 0x607ff5ab, 0x4dfa3a34,
	0x97975812, 0xcf5f571c, 0xc62e6813, 0xb2c0dc78, 0xe375c508, 0xf32679cb,
	0xf9f14df3, 0xfe2f82b9, 0x9cde7401, 0xa57c8f96, 0x7a0c3d13, 0x0e0e48ff,
	0xf0c7c751, 0x7d27eead, 0x54ae5f15, 0xa1550e09, 0x628159bd, 0x4fd56fbe,
	0x7f87e939, 0x5df68d39, 0x8bd55efd, 0xbde4c97e, 0x8056f46a, 0xf3f2b7ab,
	0x7643968c, 0xa7ce9f92, 0x69751c39, 0xdf9ca7e4, 0x583d9121, 0x70db6d63,
	0xf6f9c633, 0xb6ec8cca, 0xe7059970, 0x9dcc5a77, 0xb970e7ed, 0xb7ab3870,
	0xeb0fbe1e, 0xd2b7ec57, 0x81f5633e, 0x19b85f85, 0x55c785e0, 0x5baaf5b2,
	0x01036a56, 0x2296145e, 0xe24d7708, 0x27da1bf2, 0xb976fc93, 0x3b6632db,
	0xc6c3bf71, 0xb8c0d7bc, 0xb3196d5d, 0xe1955e60, 0x5eb04a17, 0x87c96ee5,
	0xbde4c6eb, 0xa0b2c72d, 0x892ef55e, 0xef1799f6, 0x0c6f3074, 0xcab74e7d,
	0x1e315bd1, 0x78c4f30c, 0x5cd642c8, 0x6eaf7882, 0x5d79a8d9, 0x5b3ef4bd,
	0xad798237, 0x2ef570bd, 0x2dea07e8, 0xe1f25e79, 0x58589714, 0xf3a4f910,
	0xbb6cbd80, 0x52b7e713, 0x79c2ee1b, 0x6e586a35, 0x3ece7861, 0xb7c717bb,
	0xef812b55, 0xd56f4f95, 0x6af863ca, 0x98ebcef1, 0x4e4f8637, 0xbccfc96f,
	0x1673badc, 0xf1d8d1d6, 0x38788a54, 0xf4dac253, 0xb267f898, 0x91f42296,
	0xe0df6a6c, 0x8cabd0ff, 0x8bd0faec, 0x41abc22e, 0xd73a65b7, 0x2edd060f,
	0x4a8e82e8, 0xfb6c5177, 0xe901ba46, 0x057dc560, 0x61c7d29d, 0x1374c73d,
	0x9f48e7ac, 0x6bbf88cd, 0xf2819f68, 0x315913dd, 0xfdbbf7ee, 0xfee3c8e8,
	0xc558bfb6, 0xc38040f8, 0x2504f719, 0x6fe665ef, 0xe0d59ba4, 0xb7223c1c,
	0x9274756e, 0x59b57202, 0x90c52e0b, 0x3f0de3f7, 0xe0053499, 0x01b06a03,
	0x0a41bff9, 0x4ff8f056, 0xb2f283c4, 0x3c93ec46, 0x8c78418c, 0xb46967df,
	0xdef9b02f, 0x24b2eda2, 0x70869ae6, 0x0e3137f9, 0x4a3ced05, 0x4ed0a8ed,
	0xc9db95fe, 0xa9826fb8, 0x2afb8c9d, 0x5336768c, 0x6babf63b, 0x377df367,
	0x5f73c799, 0x37ced1a5, 0xd5d71da8, 0xfee32bcd, 0xdcf1e689, 0x64ed455f,
	0x7b23e3de, 0x614fd8c8, 0x78c35718, 0xeb94eecc, 0x3e58b1d7, 0xec6df49a,
	0x155205cf, 0x13c947cb, 0x94f24c92, 0xc1354fe2, 0x9a074a03, 0xf207a7ca,
	0xcb33df4c, 0x4be38dae, 0x8271e927, 0x14d15061, 0x06d26f1e, 0x8a77a46a,
	0x7e08da07, 0xf493a070, 0x053783ce, 0x26fdc1af, 0xd5ea2b1c, 0x68e0b507,
	0x30df013d, 0xb8a70fdc, 0x6982d78c, 0xec54bb1f, 0xf41a4e43, 0x5053f0c9,
	0x3dd2c6bf, 0xe3e0053c, 0x50cff15a, 0xb9509ecf, 0x69f8655f, 0xfa465649,
	0x68b731af, 0xaf06287b, 0x5f81834d, 0x9b76dea4, 0xf907a0d4, 0xdcf555f1,
	0xb446e52a, 0xb43a354b, 0x67d59bf8, 0x3a14848f, 0x85764617, 0x11fd0355,
	0xfd06bfdb, 0x6fff5017, 0xf54fde20, 0x6f35bfd3, 0x5b7fa982, 0x7fa9854e,
	0x83fd069b, 0xfd51fc7c, 0xf01fe893, 0x97e81377, 0x7fa817d5, 0xf5054e6b,
	0x0ab1a8df, 0x3d49ff53, 0xfec39ffd, 0xf9f953df, 0xcff33edc, 0xff3cc9bb,
	0xfcf34a9c, 0xf7ff3e35, 0xff458fd5, 0x8bff3449, 0xe7ccffab, 0xe7c9539f,
	0xf6ede56f, 0xc1eeeff4, 0x7f88c7ff, 0xbfdc4b49, 0x79a27f35, 0xccaa43fe,
	0xfef2b7f3, 0xe7ae4d55, 0x7fa93bfd, 0x28e58d6d, 0x15487fcd, 0x8359aff5,
	0x6d23e43e, 0x9e2d5250, 0xc90305e3, 0xfc267e8b, 0x0474a7ed, 0x55115f3f,
	0x0f1c68f3, 0xbbbe7126, 0xe6fc0498, 0x2ca7d5ec, 0xfa08120c, 0xe9e08972,
	0x358bbbc5, 0xa210ffbe, 0x3102c5b8, 0x65fbf9d4, 0xb26e8f6e, 0xceadb9d2,
	0xe10872fd, 0xa16e9bf9, 0x958d68f8, 0xfda01fdd, 0x209c3043, 0x8c4f8fff,
	0xaf3b16da, 0xb34174f8, 0x14ddba7a, 0x09e3e69f, 0x6a23624d, 0x540b7c61,
	0x469f04dd, 0xf0f40bbf, 0x418fe85b, 0xb465467a, 0xfa36feef, 0xcac4d765,
	0xae7e4acd, 0x295ec436, 0x21dd7980, 0xe15a7fc6, 0x5cbd3ef8, 0x1774f3a2,
	0x50d52e37, 0x76682d9f, 0x1aa1fc98, 0x03eea741, 0xbfee30d6, 0xeea7e71a,
	0xec645124, 0x7f3e8777, 0x85c7ed0c, 0xea98065b, 0xabc2c3dd, 0xde7e503d,
	0x718339fa, 0x654be10f, 0x3f71ebd6, 0x20d4d402, 0x83655f1e, 0xd6529e30,
	0xb3c551ba, 0xa99677be, 0xaefdbb26, 0x52fe19a0, 0x54ee1985, 0x81c62ac3,
	0x6c49173a, 0x6f7bb42b, 0x0fef1aad, 0x68b73f50, 0xe4bec2a9, 0x3401ddfd,
	0x7bac82cc, 0xb31ebd31, 0x7deba275, 0x8c6baf3a, 0xe02be6a7, 0xdc7ad1c1,
	0x65fe4e9e, 0xd0fc9d28, 0x1de7cea0, 0x54fbde3f, 0xe3003f9b, 0x9921efb9,
	0xfe3f19f0, 0xbf0e43f6, 0xf6f4ec05, 0xd1527f2d, 0x4f9f89cf, 0x5feff8fc,
	0x5d1f3f11, 0x4e61f5c3, 0x643f3e28, 0x69187b8a, 0xede2fecd, 0xf6f6bb66,
	0x763b26ed, 0xbc1374e7, 0xa9977c28, 0x732dc2fc, 0x3417df4c, 0x9f7d322f,
	0x04d4b4d7, 0x643d09cf, 0x8aff7f2a, 0xf7efa695, 0x7d35aed6, 0x46c552ff,
	0xf0577c13, 0x3bf95329, 0xbe9ab6cb, 0xfc8d0e5b, 0xfd51ca22, 0xb1dd32ab,
	0x7a79df78, 0xef9bda03, 0xd21f153b, 0x3f8c1de3, 0xf2aed158, 0x7fb9da52,
	0x056f9d2c, 0x9b8e583d, 0x94d71b1b, 0x444d37d4, 0x7f48ccbd, 0x5a66b13e,
	0xa7e0087d, 0x4fe12f35, 0xe8b1a2de, 0x526a7400, 0x5bb8f87b, 0x7edef98e,
	0x405bef85, 0xfdf6c7d0, 0xce27b72e, 0x6736d9af, 0xfe209e88, 0x6cb72bd7,
	0x5d73ae10, 0x6138e252, 0x3539dc55, 0x9c9156c6, 0x3af8d50f, 0x7d71a553,
	0x6b27b550, 0xc1f5c612, 0x7b5e1f2f, 0x1222feb9, 0x5a18e5c5, 0x0fc8e9ff,
	0xfdf14c83, 0x4df33bc5, 0x5871ddf2, 0x412d71a6, 0x757a009d, 0xafd81ab8,
	0xa388fdd1, 0xe1473339, 0x3407fc38, 0xd3fb3bd4, 0xa8ef5d69, 0xb6fedd2b,
	0x5009f48a, 0x195d4efa, 0x82eba7a5, 0x575dbe94, 0x755be941, 0xd7b694b5,
	0xf7f4a0ad, 0xdf4a2175, 0xf4a26bac, 0x94cd75b7, 0x42dbac9e, 0xc2ea6fe9,
	0xf9d67694, 0xa1e43529, 0x8406ff47, 0x946c6c3d, 0x8b0f6131, 0xf7a434b9,
	0x78a2d39c, 0xc5e705d3, 0x5fef68e1, 0xfba56938, 0x2be1fd07, 0xa7fadf9e,
	0x95ec9fa3, 0x7200f0f2, 0xdbbfe392, 0xec9d3893, 0x40ca5616, 0xf61dad1f,
	0x02dcdf4d, 0x19641582, 0xd37c9058, 0xc5da095d, 0x2bccb8fd, 0xbbf989d3,
	0x3d00670b, 0xe3ed7f4e, 0xa8776c22, 0xa4bfd7c6, 0xc3ad32a3, 0x37ddba2c,
	0xc7a7d473, 0xdfc3f49b, 0xee9c60e5, 0xdafe0f7c, 0x8c9ce872, 0x173b53a6,
	0xe30cad5a, 0x3a0e1763, 0xc2f0ff68, 0x946eedf1, 0x391e65c7, 0xfed8f6fc,
	0xc91d55f1, 0xfe4d3b0d, 0xd0be19b7, 0x6846952c, 0xcf26f63d, 0xa57c851a,
	0x73a6df87, 0x8d4a1e72, 0x34799676, 0xceece7ea, 0x34cf1e7c, 0x4eec97ee,
	0xbf057e21, 0xbdffca93, 0x3b5fd3c7, 0x6b1878c6, 0xd1b07f65, 0xf3c320d6,
	0xef95fdbc, 0xff949f97, 0x775e28d6, 0xf688bd50, 0xbffe1582, 0x1409f744,
	0x6b768d82, 0x3ac87222, 0x9b77f31a, 0x5e7a83fa, 0x94bfa7c3, 0x35be3977,
	0x1eb91fdf, 0x4b7fab03, 0xa256ac5c, 0x2f1195b8, 0x4d9c52e9, 0x78dee8d2,
	0x5b888d49, 0xb5dadb57, 0x6f9d6420, 0xdc6cbfcd, 0x71dd6cf6, 0x555dcf1d,
	0x74359ad8, 0x23222a7e, 0x3b9ea0a7, 0x819f5adf, 0xf962e0f6, 0x048183c2,
	0x795a67f5, 0x58516f7c, 0xa3af36ed, 0xb4183f82, 0x43f3e46b, 0x31d3ce87,
	0xdb858770, 0xceedf1d9, 0x3c5d5eb7, 0x13eec969, 0xfb7b3725, 0xfec969e2,
	0xcf8a34f7, 0x5714cc2b, 0xb2e7f032, 0x615be606, 0x4f3b957c, 0x8efa3d91,
	0x95fe1a1a, 0xbea7e8cb, 0x287a73f3, 0x2bcc672e, 0x9fb0dac4, 0x474413b9,
	0x1be77bcc, 0xfbbe9eb0, 0xa39f9533, 0x8d72e714, 0xc5fb1871, 0xb73404f3,
	0x17ed3175, 0xdfefbbbf, 0xcf9bfec9, 0x03a26e02, 0x3b422e6b, 0x94b33cf2,
	0xb3ce9e22, 0x6363dd97, 0x8e04d0e8, 0x5e69e212, 0x018ed993, 0x2f04d7fb,
	0xcb8662dc, 0xd40c8cd9, 0x549be527, 0x7e689616, 0xac2befa6, 0x216fd13a,
	0xeb835dab, 0xe3cabd6a, 0xa67573bc, 0x5abd020c, 0x17afbdfd, 0x31f801cd,
	0x8d1f5f2b, 0x54a2cbf8, 0x4656076e, 0x2e786ab6, 0x63ad0ffa, 0x6199b8ef,
	0x5c1af0fd, 0x257b4207, 0xe3c6c38a, 0x3f8ed3f7, 0x7ac6bc7e, 0x240e27dd,
	0x53bd51c6, 0xf1ae784a, 0x0ccf82eb, 0xcc4e7d7d, 0x3e0bf0db, 0x4fc63840,
	0xdc455888, 0xd232665e, 0x0b6ebcfd, 0xbbe99259, 0xdbf38a2f, 0x7bd5f563,
	0x681f8e31, 0xc0dd92b5, 0x728c2ff7, 0xf2906b7e, 0x979fa43b, 0xd114fbf3,
	0x126fda42, 0x9ee37d71, 0x2ee49c94, 0x62cf2864, 0xeedead9f, 0x1af086de,
	0xc39d0557, 0x877941a9, 0x97751ef6, 0xb578c71c, 0xfd47358d, 0x4f56bfc0,
	0xd7807edc, 0x3ec43b0c, 0xe0660d7f, 0xc78fa15e, 0xcc231dff, 0x333e5ce5,
	0x3c1ecbfc, 0x698f8945, 0xe78bd92b, 0x3c519cb7, 0x2826c0a7, 0x56fe3d1d,
	0x7c7bfa1e, 0xd9cf0cfc, 0x3ae5f943, 0xe304bf2f, 0xe58f402a, 0x4cca4faf,
	0xaa3e8cbd, 0xe16250f9, 0x46a47598, 0x0f90d6e9, 0x28543e6b, 0x4deb33ff,
	0x31aaac2f, 0x5acff37a, 0x01ea34f0, 0x3e3893d4, 0xdd89fa09, 0x57c7030f,
	0xd973958f, 0xcf8fe666, 0x66348e3c, 0x6b2edfd2, 0xe34483f0, 0x7bedccf8,
	0xdb2fb4fa, 0xed8effd2, 0x7ed3ed0f, 0xabf6a272, 0xbedcf7bf, 0x95afac10,
	0x8dc279df, 0x55deea87, 0xfef0339a, 0x6acb5554, 0x3be5ca37, 0x748dc84a,
	0x272c377d, 0x625c7fbc, 0xefcef833, 0x4b5a7bc4, 0x7d9ddf04, 0xa02f91f6,
	0x45b172ff, 0xb03e29d5, 0x02b51ad3, 0x5d692e53, 0xa763e5c4, 0xf98714f5,
	0xfd9af3bd, 0xf9517d66, 0xbc3227ad, 0x121bcfb4, 0xfc9473fe, 0xfe3b2583,
	0x57768258, 0xbd26eb0d, 0xfb0f5f17, 0xec9530ff, 0x1f783981, 0x71bbfe2d,
	0xe046a7be, 0x11f5a6a5, 0xd3578f3a, 0xef38bb7a, 0x677e4ed6, 0x610abd7c,
	0x1360dff7, 0xbec4dde7, 0x161781a0, 0xfd7f76e6, 0x4f0b27ae, 0x763ab8c1,
	0x152dccfc, 0xd729f2c4, 0xf322177f, 0x6f7df1be, 0x09d572ff, 0xbed631fa,
	0xef69d636, 0x1cafe17e, 0x1a9569e4, 0x583fa375, 0xf3a555b5, 0x6dcf55e7,
	0x30d7e6ff, 0xd5baf33e, 0x5fda0c37, 0x7f8fdcfc, 0x8bc01373, 0xa6d3505f,
	0xf13869f1, 0x9f41985e, 0xc57ff81a, 0xa8f4bdf5, 0x358feefc, 0xf98147bc,
	0xd2f6a70f, 0x870bf165, 0x2faa3635, 0x0e47263e, 0x82bdfc6b, 0x4e44fa38,
	0x515fa095, 0x0d03ebbf, 0x87bbd7f5, 0x9b999624, 0x7f5b9f00, 0xe231f64c,
	0xe829e889, 0xb8bf43d5, 0x174035f2, 0xf4718bd2, 0x11e72f8a, 0x62ed8ff2,
	0xfbf81e3c, 0xbee3eff9, 0x3ead6fcd, 0xf3c543c4, 0x7ce3765f, 0x9cb528ce,
	0x3abebfcf, 0x54d1cf03, 0x9d0ca1a8, 0xf15f9e52, 0x7fc403cc, 0x903c4f0b,
	0xfddbf7c1, 0x4c5ce259, 0xc173ce16, 0x9e69b3d3, 0x7c482ce5, 0x7e75f158,
	0x857dfe8f, 0x4090be95, 0xb8d90e4e, 0x9b66761d, 0xcf133695, 0xfb8242e0,
	0xe1cb2f18, 0x2e078a16, 0x03cb78a5, 0x5b13fec6, 0x36fbf046, 0x364daf4e,
	0x2c1bbce3, 0xbbfcb125, 0xe90db1a3, 0x3fb07674, 0x35c8e313, 0x7c09094c,
	0x5da09748, 0x4cd4c4f9, 0x55e6274e, 0xd03d448a, 0x1f3193ff, 0x7ea9b7cb,
	0x1ea9a17b, 0xdbdb94bb, 0x3fd172ff, 0xed093b8c, 0x601933d7, 0xdf98260f,
	0xf83f3139, 0xf862c6d3, 0xb9de462c, 0xcb58effc, 0xff90dde5, 0xfc52f4f0,
	0x70afdffe, 0x687ac239, 0xa2b8c0bf, 0xf0fdf499, 0x83f4892c, 0xc9134595,
	0xc8550ef9, 0x3c7bf9b9, 0x15f8c0bf, 0xf87b8f5c, 0x2549fb06, 0x5b7d903a,
	0xc7ea09be, 0xd7ec55ea, 0x435db7dd, 0x7d0a178e, 0x1f4e2070, 0xafd3a7b0,
	0x4ab71f6a, 0x6bf37f0d, 0xaf20bf28, 0xafca2f21, 0x9c31ef4a, 0x37f47ddb,
	0x9edc8377, 0x6b72188b, 0x72f1abd6, 0x3c67b15b, 0xe7b7244b, 0x50963e9c,
	0xa13f216e, 0x89db3adc, 0x7ad1ff9f, 0x5be3c0d5, 0x48b9f336, 0x87f64f43,
	0xf93d78cf, 0x426f369f, 0x5e7f093d, 0xf97d4561, 0x8343e0d1, 0x5dbf2aff,
	0x7ab9e74d, 0xc3e0d4f8, 0xf8353e1e, 0xd23c4fb0, 0xeff8c784, 0x61bfe2cf,
	0x2a03810a, 0x0eabcfc5, 0x733ce24a, 0x71a0d8e8, 0x2d3f2f84, 0xd8f9ac73,
	0x3858b4a0, 0xe247071c, 0xe0e3fbca, 0x60f95c40, 0x2a6b5c1c, 0xa8ffb55f,
	0x46c70fc6, 0x15e4e54d, 0x90fec5ff, 0xac603e20, 0xefad3543, 0x0fe42169,
	0x57d53767, 0x0b90b157, 0xca2fe5e3, 0x02ef2f14, 0x7e81af1c, 0x86e776ba,
	0x5647a043, 0xa57c79db, 0x835b5d3b, 0xef4baf7a, 0xd95da376, 0xbe71e76d,
	0x3bb740ae, 0x3b9ec625, 0xbd265075, 0xa5661edd, 0xba4efc89, 0x6cf80ae1,
	0xe77dfd67, 0xb42efff1, 0xa9bfa1cf, 0x056733b2, 0x659a65c6, 0x7f393f3a,
	0x3c6e9de5, 0x3075d237, 0x90658bff, 0x3227e0bf, 0xf90c8edf, 0x7f18ac95,
	0xda161def, 0x7dc2513c, 0x27c4f5ea, 0xff720ef3, 0xc4fafe6f, 0xea295f7c,
	0x6b973b95, 0x6fc15fa8, 0x7f762b7b, 0xe2a768c3, 0x83fcb8e9, 0xa3e42eff,
	0x951ce299, 0x83dfcc3b, 0x62504e22, 0x8631f217, 0xba7e118d, 0x865df625,
	0x17c172a9, 0x5d0e80cb, 0x218665c7, 0x65070b86, 0xdd85c3a2, 0xc5009cfc,
	0xbe446ff3, 0x68bd26ee, 0xe503abe0, 0xf5fe9ae8, 0xdfdec755, 0xf9057d15,
	0x851bdf65, 0xc76905ff, 0xff87d7be, 0xbdefe100, 0xeb06f396, 0x21f27e5b,
	0x749fed3b, 0x9f11721d, 0x8bf8bd77, 0x7c20af9c, 0xeb714ac0, 0x141f43ae,
	0xad74df22, 0xbea056b2, 0xfdcc1aeb, 0x3f17fad6, 0x75a76c28, 0xb7e881b6,
	0x7b71aed4, 0xbfc7e0e9, 0x17a473c7, 0xd0acc20e, 0x20e4388e, 0xbef9aa39,
	0x5d6ce29d, 0x14507e2f, 0xadfc0feb, 0xf62259f3, 0xac5cbb35, 0x2f8e0f6c,
	0xd507ef85, 0xedc6e0fc, 0x47dcf12b, 0x1e6d61eb, 0xc3fc9f7c, 0x1ea214bf,
	0xedc3daed, 0xfdb54ea3, 0x7bb7dc19, 0x1bb7ed78, 0x2757a054, 0xb040d30a,
	0x4c75d647, 0x7dbaf3c1, 0x8a17f2f1, 0x3e2d5e1f, 0x832ffabe, 0xf5cfc90f,
	0x268c2b9c, 0x1f43e4c1, 0xd40dfefd, 0xc4ac8707, 0xcf7cc697, 0xdd925645,
	0xef79a572, 0x6f371ff9, 0xf3357a29, 0x3e4ff13e, 0x70f13bef, 0x72bef8d0,
	0x5fcf97d0, 0xe7e0907c, 0xef1a3e5c, 0x7bfbf255, 0xfb371e76, 0xa7ff9d67,
	0xa01efba6, 0xf3cafbbb, 0xb9fe93d6, 0xdd3fdde7, 0xa09f727f, 0x5ee78ebb,
	0x17f87e6a, 0xd5a7df1a, 0x7fa4be73, 0xec37be4d, 0x5f1675fa, 0x72c7de33,
	0xeb00d7a0, 0xa335d3b4, 0xeb88c309, 0x7ba0cc46, 0xef3f729d, 0xe249cc6d,
	0xf12c93fe, 0x60d81977, 0xc263f71e, 0x0be3c29f, 0xc9d03f74, 0x4e29f9ef,
	0x29908f7e, 0x66977a3e, 0x7d73b5dd, 0x5d88a674, 0x7088327f, 0xc51f44f6,
	0xcafce3b5, 0x25f98906, 0x6b956bb0, 0xfa38edff, 0x4b08ea37, 0xe9485ad4,
	0x451b4c29, 0x35d552bc, 0x2ce3df93, 0xaf76c330, 0xf68ab619, 0xdf8f8c6c,
	0x8c6161e6, 0x8f23cb5b, 0x4e6e78e8, 0xbc30a31e, 0xcd676087, 0xac2ff421,
	0x5bfd731e, 0xce299892, 0xd3f4ed9b, 0xd85579b9, 0x6fd053a3, 0xc03b3841,
	0xd84ebf68, 0x9f9a4aa3, 0xbac8c3ee, 0xa289ce8f, 0x4305105f, 0xdbdda5ef,
	0xfe713e29, 0xc05f53d9, 0x81fe2cf1, 0xcf806ccc, 0x162eddce, 0x584afac5,
	0xb2a77f43, 0x0077a655, 0x9a2d1299, 0x68efb319, 0xbf8b99d8, 0x54f9a2e3,
	0xa786b1ee, 0x7dcafd41, 0xf5a4287f, 0xd937557e, 0x2567a1cd, 0xbb0d0b5f,
	0x15f710bd, 0xef6e152b, 0x5577d3c6, 0x3bdff712, 0x30ca380e, 0xe4ed204e,
	0x232b49e7, 0x98d6aa77, 0x250f3273, 0xe23946a9, 0x892ed0bf, 0xe30493bf,
	0x68c73d8b, 0xbb1db9d8, 0xfdbe3e24, 0x5203bd2a, 0x4e85f3b9, 0x9e54778c,
	0x5cd0fab4, 0x1ef9d9ac, 0x7f27d7c5, 0x3b7739e7, 0xc9b275f9, 0x5fe3edcf,
	0x1f8994ee, 0x9356b496, 0xf1300bbd, 0xf08892c5, 0xffa53ee7, 0x2f3bf8b3,
	0x4e0bc3ee, 0x2dfbbf8b, 0xce53c637, 0xc9b8b5b6, 0xf979dccf, 0x7f1f4f78,
	0xf856b232, 0xef179f93, 0x27f62651, 0xc03fe2cf, 0x149ddafe, 0x1cef97e7,
	0x4645ee20, 0x2ef72e8b, 0xdee7e2cd, 0xa1e3067f, 0x3dce7b1d, 0xfaaee383,
	0x419e9feb, 0xb21d95fb, 0x522fb8eb, 0x14abecf3, 0x1dea323f, 0xcff1e24b,
	0xa2df5dce, 0xf8275bf8, 0xe75ad8f3, 0xd072678b, 0xe17ce98f, 0xcff40ca3,
	0x9538bf97, 0xbe5945de, 0x4b267277, 0x8a46ff20, 0x8abe1bfc, 0xdd3c5ff8,
	0x251eb68e, 0xd03cfb3b, 0x9e9cfd1d, 0x9aa44138, 0x22bc5fc7, 0x713bb03e,
	0x3c4fb5bc, 0x17e675a0, 0xc2f3c16f, 0xd50faaad, 0x02e315c8, 0x473d00af,
	0x771d055f, 0xe44ff88b, 0x0b8d97f3, 0x007fc79c, 0x6498febd, 0xdfbc0b8e,
	0x781be0ba, 0x0eb595ff, 0x102e37e8, 0x19fc0abd, 0x9217dcf1, 0x2849ddfc,
	0x4dbe7b6f, 0xdfa418f1, 0xe7709834, 0x60e7ef73, 0xb51dfc3c, 0x0f7a3efb,
	0x8eab45e2, 0x8be56dfe, 0x753c91af, 0xf1413dee, 0xaae22652, 0x0fe7ac9d,
	0x33897f8f, 0x5c3b357e, 0xe8209e3c, 0xaf06f180, 0x5c45f29b, 0x11b5f381,
	0xce2fe86f, 0x2791c230, 0x78f1ebce, 0x378ef548, 0x4bdeff84, 0xd2026937,
	0xe365d4eb, 0x741e06e3, 0xb10dc3c4, 0x71c4b471, 0x5a389e9d, 0xf88cdd1c,
	0x0c9c4f59, 0x978c6ce0, 0x12d7a584, 0xb73b65c5, 0xa75bf8f2, 0x8f7cf89a,
	0x77cb5711, 0xf86dc9c4, 0x5769e2ea, 0xc5a7c79a, 0x978700d3, 0x57c78dda,
	0xf58927c7, 0xeae3897b, 0xddfbc3f6, 0xdf32a9af, 0x835970af, 0xdfb81d53,
	0xa34a7ad4, 0xb7e0650b, 0x8cec6207, 0xb19e710e, 0xe29959e3, 0x47226b2c,
	0xebc7bf49, 0x2f3f630f, 0x6265bc7e, 0xf3f64bbc, 0x8f63a3f5, 0x7684ec2b,
	0x201c8e3a, 0xfbb25ebe, 0x8e79c514, 0xd6aefced, 0xe2deb31e, 0x998e11fa,
	0x87f3c74f, 0x30dc790b, 0xe536fbf1, 0xd4d76e0e, 0x4fdc4c1c, 0x4cf7eecd,
	0x450e2cfd, 0xf53e7e34, 0x559dfdf2, 0x7b6277fc, 0xba54db67, 0x22367a5f,
	0x3fda2697, 0x8aa1ddbe, 0x4f3374b8, 0x73a51d61, 0x7df827e7, 0x272f7190,
	0xe5ed39d1, 0xc0df4a27, 0x8396c0f7, 0xd97da358, 0x69f392ba, 0x07fa7feb,
	0x4f5bbd21, 0xfae32ddc, 0x1bf10fb5, 0xbd166763, 0x05d93b52, 0xcde8a1fa,
	0xd76438c0, 0xc373bd78, 0xfc698b49, 0xae264fd0, 0x0ed00d0b, 0x73c02fde,
	0xd91e3858, 0xe38a525d, 0x6e8b7591, 0x566e704f, 0xa17b8a75, 0x37555da2,
	0xf8676b9f, 0xd3b4170e, 0x9f38d239, 0x3c464814, 0x9b36dfbd, 0xf240b6a7,
	0xbddfcee5, 0x4766f423, 0xaf458f9d, 0x1054f7e1, 0x97e711ae, 0x2d1e0e2b,
	0x11583d41, 0x93be1891, 0x933588b1, 0xa4736cdc, 0x6625f388, 0xe0f2a2bb,
	0x657ca9af, 0x98bf2f2b, 0xde3ca845, 0xfbb58967, 0xe36323aa, 0xdfce11ec,
	0x49dce25d, 0x744587d5, 0xe718d10e, 0x1d4fc11e, 0xcf49ba75, 0x9cf8e157,
	0x8da92f78, 0x0c8ea9fa, 0x9463f530, 0x66f0feab, 0x4ad57b53, 0xf55bf11b,
	0xfca39f87, 0xf3aaf91e, 0x6ffa1e10, 0xdc69907f, 0x48dfedbd, 0xb6fb1fe7,
	0xe3f2913f, 0x667aafcf, 0xd66538f0, 0x09cd234c, 0x190cfea3, 0x93ca87f7,
	0xbf80f5c2, 0x12f83d36, 0x6b8f03ea, 0x198fee53, 0x8134dbbe, 0xd2ff81ce,
	0xb83bce21, 0x779f9b99, 0xb02c8670, 0xb7cd7f0e, 0x4644e36d, 0x765e19e7,
	0x60679ec4, 0x23d442d1, 0xdf3eb946, 0x643bcee3, 0x85501563, 0xbe6718b2,
	0x7eafa778, 0xc21b7bba, 0x7bf8bb4f, 0xfbac3963, 0xd86f9e30, 0x5c87fc2e,
	0xf7e64f8c, 0xb3ec777d, 0x369637be, 0x10e978b9, 0xeb39ac1f, 0xdef04b53,
	0xc59dda4c, 0xc1d20c2f, 0x4af8b06f, 0xda7c9cf0, 0x64c78ab7, 0xfcecdc01,
	0x557f8729, 0xe007263c, 0x72af5d67, 0xe744b178, 0x591f3b60, 0xc2fe825d,
	0xb3d3d667, 0x3d663300, 0xdfc467fd, 0x779bc0f9, 0xb9e2f02c, 0xbc4d6e8a,
	0x72c01047, 0xfc702783, 0x7cdf3b65, 0x21c1fd01, 0xa895f696, 0xe2f1be5f,
	0x7f742907, 0xa873bc51, 0xe91d06b3, 0x2e135908, 0x5e7ce65d, 0x058e779f,
	0x094e8d3f, 0x1fc09c3a, 0xa08ce76b, 0x56bebd77, 0xcfc6c331, 0x47cf9a01,
	0xe88d3d30, 0x95d05f3a, 0x0b96fb89, 0xca167cc4, 0xc4078d21, 0x237ac59b,
	0x550e5fde, 0xfdea9fc9, 0x21ae3165, 0x23df7ece, 0xd3a673cb, 0xc694647b,
	0x67f647bf, 0xe6286047, 0x987f9567, 0xbc6e7c83, 0x4eff162f, 0x2dba5319,
	0x6df9ec89, 0xfeb29de2, 0x3389fbc6, 0x9fb63d78, 0x9eef43f7, 0xa36720e3,
	0x3c3e6be7, 0xc57a39fa, 0x7a429f38, 0xa89f9f80, 0xe7c3f411, 0xc3fee912,
	0x6bf68c83, 0x1f92acbb, 0x2faeeefd, 0x66feb4eb, 0xfe469fcf, 0x3723976f,
	0xba8ce782, 0x7da5e2be, 0xfc1de33d, 0xa39307c1, 0xc3c93776, 0xb87938c5,
	0x737fe668, 0xbc975dbf, 0x3da9dbfb, 0x0607b45d, 0xd8fdcc75, 0xabaf992e,
	0x1a5e755d, 0x3a1660c7, 0xd5da768c, 0x29dd37f6, 0x1f416bec, 0x58ccfbc0,
	0x3fd9dfbc, 0xf416eefd, 0xfd113bbb, 0x738fdfe2, 0x63f78339, 0xc7e533b9,
	0xf8b91de8, 0xe9e2e377, 0x3f34a35a, 0x33565785, 0x7647be0e, 0xd1b74182,
	0x7d10c62b, 0x8958e862, 0xe0fa3f7c, 0xaf1c167b, 0xfb27bf41, 0xa0fe4739,
	0xf11faf93, 0xb59465fd, 0x28260c0f, 0x35e9d2bf, 0x5b42ebe9, 0xf9014f91,
	0x78f0b4cc, 0x52f2df51, 0xfb40f9c2, 0xdf3b9779, 0x76f3a859, 0x38f5ff01,
	0x8dff031f, 0xfbdfa14e, 0x961d7fe2, 0x7a53fc03, 0x0c7ff815, 0x7f87f5cb,
	0x2c5b4fc3, 0xdc62c2f4, 0xf9fe02af, 0x464677a3, 0x225bf41e, 0x17ff893b,
	0xff62c8b5, 0x654bbf92, 0x374591e8, 0xfbc61ed6, 0x2ebe8b90, 0x17ce9f11,
	0x139e50ef, 0x9fc650ef, 0x0b2f2c17, 0xf2bc9e91, 0xe930c1b9, 0xcd3bc5a1,
	0xf97b3bf9, 0xf9ce8736, 0xf46684a2, 0x8f199bbe, 0xa14e0bff, 0x2ddbe62f,
	0xc66befb1, 0xad7061d3, 0x3cbe74c5, 0x3b4f726b, 0x2c7bb7e4, 0x3e28d7de,
	0x619553f7, 0xa4afc7dc, 0x11f7a38d, 0xb05349c6, 0xb72162dd, 0x56437b46,
	0xdcb4ed98, 0x61fef990, 0xfef9937e, 0xf366b0e1, 0xb66bc3fd, 0x8e1fef98,
	0x1fef9b0c, 0x7af3b75e, 0x722a3c13, 0xe8fca993, 0xf04c93fd, 0x99bfe898,
	0x3e3d8fca, 0x6f8f04c3, 0xfe54dbbb, 0x4d739386, 0xaf6c6fdf, 0xf9bf7d34,
	0xf826659d, 0x30ffee96, 0xe02e8f95, 0xdd48f17a, 0xafbc228a, 0xc8e5e060,
	0x63a2cd52, 0x16e1d2fe, 0x3f3630bd, 0xc42defc3, 0x7e8fc8b4, 0x32f27f72,
	0x5150f6d9, 0xcc5cfaec, 0x9b5e9354, 0x9dc3336c, 0xe657e14e, 0xf100bf00,
	0x572714ff, 0x9aab6a83, 0x70380386, 0x873a50d1, 0x5175f20d, 0x578bb7e8,
	0x263edfa9, 0x5d125af9, 0x7cbc7083, 0x400def19, 0xd8efe21a, 0x9f1f77f1,
	0xd4f99bb2, 0xb15e8fd3, 0x3ff38cb9, 0xac4e3ccd, 0x4c558d97, 0xbfe46272,
	0x5f362e33, 0xce8d385a, 0xaed7f4ff, 0xdd7799ea, 0x6a97d00e, 0x8d4a1cd6,
	0x8965d5fc, 0xcf24af7f, 0xe76dfd25, 0xb1f4b7e2, 0x685cf29f, 0xbcbda53f,
	0x2dadcf19, 0xfc9ba7b9, 0x19ab2cdd, 0x7f30bd2f, 0xcf18d85f, 0x00ac75d3,
	0x5ee379d7, 0xc44802db, 0x5df34d7a, 0x0c8cfaf0, 0xdd906f3c, 0xc73c1f8f,
	0x33f5f5c5, 0xe6eba175, 0xcd98e123, 0x273c9f74, 0xf682535a, 0xce7110fb,
	0xf125b37a, 0x055ba7f9, 0x9151325e, 0xd4e09da2, 0xbe7f7e28, 0x3e374dfc,
	0x0d655471, 0xef82eade, 0x15b74773, 0x3d3f7789, 0xe3bd5c33, 0x8e51f436,
	0xde99b033, 0x8d3307f3, 0x7990beff, 0x04f7993c, 0x7be1734a, 0xe7c5aa43,
	0xc25bb824, 0x1987b4fe, 0x1be5001b, 0xf8d32afe, 0x48dc8e1a, 0x673482e7,
	0xc6e3e290, 0x3738993c, 0xbc07ec60, 0xfc8b369f, 0x7b6b86c3, 0xfbd105ee,
	0x033bef32, 0xfbeed86d, 0x9efe549b, 0xf4c924e5, 0xbcd9c73d, 0xa38c18f4,
	0xf141d5bc, 0x17cb6541, 0x3cd1bfc8, 0xcf0d3c7c, 0xa25b2c48, 0xb638f0f1,
	0xf003e39b, 0xdbd13b70, 0x62d17b9f, 0x57be1a4c, 0x5f746b27, 0x713f7074,
	0xf18c8784, 0xe89847fb, 0x798d759c, 0x27a6f2dc, 0x73c31e96, 0x3e1d7b1d,
	0x175c3a6c, 0xcf357415, 0x8cda757b, 0xf785de2f, 0xe9915eeb, 0x3b6f6bbd,
	0x1f34a963, 0x804e1c39, 0x306e8377, 0xfc7087fe, 0x9a1296f2, 0xf7a0ae6f,
	0xae37a042, 0xa04b1e03, 0x619fe894, 0xf8df3861, 0x1c848479, 0xdce974af,
	0x7394f78f, 0xbfccf3f9, 0xb7b4076e, 0x7aefd5da, 0xebe2e4df, 0xf69fa53d,
	0xb2aadefd, 0xca9863b6, 0x0cec997e, 0xc7876ac6, 0xbfa0cdda, 0x1aed8abe,
	0x70fc9cb0, 0xbfdbb621, 0x1a6c167d, 0xfb657b9e, 0xe432ed0c, 0xdb2ec33f,
	0x18bf371a, 0xc5c3bb7d, 0x57a52df5, 0xe1776fa1, 0x1ddccf78, 0xa4cf684d,
	0x5df5896b, 0x8d7fc0bb, 0x0f3a31ae, 0xcd7ecfd8, 0xed895daf, 0xa3d6feb8,
	0x791bf92b, 0x0d4f830e, 0x0efdcf3d, 0xfed1ae56, 0xe1e385d1, 0xbf71c3b5,
	0xe74793d3, 0x676bfb79, 0x8d2f8ad0, 0x7819fa45, 0x6ccba9fb, 0x7f1e039f,
	0x8bf8f021, 0x02ac7884, 0x784c5a3c, 0x1975d97c, 0xeb33f0bb, 0xbdf30af9,
	0x6f814e9e, 0xc5dff7d0, 0xfccfcefe, 0x31c6117d, 0x48becc96, 0xf733fefa,
	0x4f5e6653, 0xfa1c3f0c, 0xe9fb1e79, 0x1157f99c, 0xb8a76d3f, 0x6bdefd5f,
	0x58ce3192, 0x6f47a93d, 0x987db8d8, 0xfcf07a47, 0xc71fab3e, 0xc7953e79,
	0xbbefce9f, 0x39c618e1, 0x4f1dd5ce, 0xf9efa58d, 0xa9144fe7, 0x3df9ded0,
	0xd2148a27, 0x3bd361e3, 0x7e97d5d0, 0xf670145d, 0xe1e843de, 0x875f1b37,
	0x3c79d936, 0x173c49e5, 0x55b19a37, 0x3be10a7a, 0x81b2c333, 0xfdb70bde,
	0x78dbe07a, 0xafb8fcc5, 0x2f564018, 0xa016b3f9, 0x24e39d1e, 0xb3e4f17e,
	0x4f50b911, 0xf1e2d68b, 0x79ff6665, 0xfd3be198, 0xf4a2578e, 0xcdebbf5e,
	0x495eda76, 0xc4ad9b7e, 0xf4dbe8a7, 0xda1bb260, 0x4af0e94f, 0x757f00c9,
	0xfa0f58e8, 0xae64cafc, 0xb2efbb7f, 0xd2d77bd1, 0xf2db9fbc, 0xccb72f81,
	0xe3eff850, 0x82979f1d, 0x9d2ec87e, 0x19e067bf, 0x64c7c3d2, 0xf02acf0f,
	0x984c5ede, 0x023bd3f7, 0x90e9ceba, 0x5b59659a, 0x82b4fd0c, 0xbc050c5c,
	0x3f16bcb9, 0xe8987dff, 0x78866b25, 0xadee5397, 0x5cf510e7, 0xf893d1d9,
	0xcd38f85e, 0xb8a193f7, 0xe2ca32ef, 0xc479f7a3, 0x46c98abb, 0xcb5f713d,
	0x97a2e7b8, 0x76c3df9a, 0xc52cd605, 0x27e716fd, 0x52cadab7, 0xf316fde9,
	0xb8eef177, 0xdf399c73, 0x5bd89011, 0x5f177c31, 0xe1bcbe2f, 0x7cea6477,
	0x6ceafb1c, 0x75fddf34, 0x08286fba, 0x3cebf7d8, 0xf3ac1e94, 0xbaa1fe52,
	0xeb469411, 0x83a6947c, 0x81edc01d, 0x00f78dda, 0xe3eed21d, 0x7c1bfaef,
	0x7f1d48f4, 0x5607bb9f, 0xddf12723, 0xc85feeec, 0x3f959784, 0xbcfc4b1f,
	0x3ef41479, 0xf357bf9a, 0xfd9d8c56, 0x659f8ad4, 0x917d014c, 0x324fd0f5,
	0x6d3f00a6, 0x0bb9f896, 0xd8a517b0, 0x5af5e4fd, 0xc14bebc0, 0xda98addf,
	0x78458368, 0x8bbc1ab5, 0xa162818d, 0xe47ffabf, 0x7839dfc1, 0xdf02cb3c,
	0x1a9b944b, 0x71c39f6d, 0xf9ec9ad5, 0x663ce2f5, 0xbf7e24cb, 0xd7bfc8d7,
	0x4eedf5cd, 0x775ef8a9, 0x37c1fe02, 0x9a9fc9fc, 0x30779c6d, 0x802993e3,
	0x23f9c017, 0x24bc72f7, 0xf87d63eb, 0xdc8ffa9e, 0xdfc33d86, 0xfbfa3191,
	0x8dddf891, 0xb88b23e4, 0xbfe1e3fd, 0xf1a69177, 0x30588ef7, 0xdfcef4d5,
	0x084ed13a, 0xff7c6919, 0xda24377a, 0x00f4771d, 0xfc007dc3, 0x7f58875d,
	0xff08eb3e, 0x422d8a1d, 0x03d02d2f, 0xa35f3855, 0xbe3df19c, 0x4bd6919e,
	0x473c7ac1, 0x22c51a1b, 0xae58df28, 0xbfa5ca18, 0xc2677fc9, 0x57bb4738,
	0xbdf8d9e0, 0x5c493f91, 0xb489cf2e, 0x5de7a453, 0xdf094781, 0xcf669ef3,
	0xf7aafe01, 0x3628bd59, 0x447e8ee3, 0x09fd75eb, 0xf9e786cd, 0xa29e0fd3,
	0xa97accfd, 0xf453435d, 0xb79df779, 0x5eb4bc61, 0xf0e2cdad, 0x6f184d5d,
	0xfb55d27d, 0xc8f1ff14, 0x7e436f3b, 0x0aef14c8, 0xdea08720, 0xf01bb56c,
	0xc83f46ac, 0xe1caab4c, 0x1b33dde7, 0xd708d943, 0x0977c1ce, 0xf6806e10,
	0x83fc535b, 0xd29c9f90, 0xb7e3c6f4, 0x9f946c20, 0x14ef88de, 0x7ceb72ec,
	0xcc19c6bf, 0x07a53b45, 0xc57601d6, 0x99870ac0, 0xfcc6a78d, 0x447e8faa,
	0x1c979de7, 0xa571efe4, 0xe12e9c1f, 0x4ff7d33c, 0xd05ffc27, 0x7a57ba4f,
	0x9c3dee29, 0x2e3c0faf, 0xb8c3d06e, 0x1ad53b6f, 0x263b81fc, 0xb73df3fe,
	0xcc9d6f58, 0xd0bf7b19, 0xb4f5ca2f, 0xaae8e227, 0xd29bbf85, 0xf9d194bd,
	0x9dacc1e8, 0x221b8fde, 0x172c1f7e, 0xd191f7df, 0x1aaff435, 0x70efdf08,
	0x61de7df3, 0x9b5f73bb, 0x3bf97aca, 0x1fbb50ad, 0x9c7a70f5, 0xd093731f,
	0xc5eab7cb, 0xba43271f, 0xbbd00a49, 0xfc03a154, 0x99db271e, 0x21d4f245,
	0x66b9d674, 0xae9dff0b, 0x5f9481da, 0xabbbee25, 0xe81b22ab, 0x539e2df7,
	0x717b9f69, 0x7ae3246e, 0x643aef67, 0x14e2dff0, 0x37dc6f9e, 0xb38c7845,
	0xc9719f77, 0x78398dfe, 0xc3dde26e, 0x9e1d13af, 0x41a5ce4c, 0xd09eb757,
	0x77da2e82, 0x7ac170d5, 0xfeb3ded7, 0xdabbbad2, 0x99be4bee, 0x8f7a35eb,
	0x85f3476d, 0xe76f11db, 0x7e98b61e, 0x8f48c34f, 0x41ce21d4, 0x4160ebde,
	0xa8e01f05, 0x019feeca, 0x23d39ced, 0x0edf1c6e, 0x745ae07f, 0xffc92c09,
	0xf41d9b71, 0x5f9e4b59, 0xcb3e80b7, 0xd1b1ac7e, 0xa2d6fc06, 0x1f9123e9,
	0x343793b3, 0xb62fbf22, 0x19c7e2cb, 0x1fe4bc37, 0x0055ce2a, 0xcfc3727c,
	0xc9fdc36e, 0xcc9f6ccf, 0x3541db37, 0x0bbef89b, 0x325227d8, 0xd20965e0,
	0xad8b6003, 0x6739ee8d, 0xaf486d23, 0x6e65ef99, 0x0c9eb892, 0xe7f1e6cd,
	0xaccfdd2b, 0xc2c1d0f8, 0x93f87631, 0x7f03e8b8, 0xda212854, 0xd0f8aa8f,
	0xf6ffdf4d, 0x7ba6ec7e, 0x71fb7da0, 0x9fa377d2, 0x287edeaa, 0xfaf55b3e,
	0x8fcff211, 0xd9d86b5c, 0x96175a7e, 0xcbce20bf, 0xd899fdd8, 0x132a93ce,
	0x0b7f01f4, 0xef6f4cf0, 0x80a43873, 0xa3da3a3e, 0x4e36b68f, 0xc6fa46c9,
	0x2609a7e8, 0x8057e57d, 0x0493476e, 0xb895da1c, 0xf95c527c, 0xd3de033c,
	0xdf626538, 0xef693cf1, 0x5e506d85, 0x07b58bf9, 0xb46df1c6, 0x6a97b5c4,
	0x6a7dfff4, 0x93bfe0cf, 0xe12fa3ee, 0x53474f3b, 0xbe78c502, 0xf3367bac,
	0x437c3ca2, 0x62fbb6e9, 0xcdd270e8, 0x1f150de3, 0x7fc2675e, 0x4d0bde2f,
	0xbcea67f9, 0x85eb7da6, 0xf74cbfbb, 0xdf8a4e7d, 0x2160aa29, 0xe9ed8f7e,
	0xf57ed37c, 0xb3e38dff, 0x9fb8a38e, 0x07f94c71, 0x49a4638f, 0xa38ef40f,
	0x59ff94c0, 0xcca721c7, 0xfdc5cd2a, 0x7a1695a9, 0x12c332af, 0x3da1e5b2,
	0xfc85a0f7, 0xf16d3414, 0xce1819dc, 0xf5bfdfa6, 0x41ceb41e, 0xb0abdcfb,
	0xca2a4ae3, 0xbf8bdf93, 0x407a14fb, 0xf20b75a1, 0xa8f5ea6d, 0xf8fd9b0a,
	0xc15b15ee, 0xfcef3da8, 0xfa373560, 0x17377e63, 0xb159d1fb, 0xf4d3f902,
	0x7a0eb439, 0xc1ac1ecb, 0x699d5b72, 0x2666aecf, 0x657b2579, 0x0e74b4b5,
	0x4bdfb7da, 0xed11a37e, 0x6e24cc9b, 0x8dec48df, 0x2637e3c6, 0x75e5cefa,
	0xdc6f63df, 0xf08cf186, 0xfa2d762a, 0x387b6175, 0xb0e90472, 0x78f649da,
	0x26e123ee, 0xd6bcbf9c, 0x28dbbf42, 0x6e7784a7, 0xe1d1f843, 0xc237b43e,
	0x76bf5c29, 0x3d9274af, 0x542ea6b0, 0xd4b2ef84, 0x6075f337, 0x1d44c35b,
	0xc1a16f7f, 0xefc15809, 0x785ded6a, 0x8f4fe4af, 0xbb68d47d, 0xaf98f511,
	0x61ce8069, 0x6bae164f, 0x4636cf2c, 0x2e75877c, 0x440d92bc, 0xf380d257,
	0x0a5602ff, 0xc88f99e9, 0xce706b2e, 0xfebc64a8, 0xbc1f784b, 0xf10f47a5,
	0x0473f8ef, 0x51802784, 0x7b2bca0f, 0x79814fbf, 0xd73aff6f, 0xfb41af53,
	0x7cc1a768, 0x0c376442, 0xf63e6853, 0x2c9bfe14, 0xb47991f6, 0x73b6191f,
	0xff247bb8, 0x6923ec6e, 0x8fb42cc3, 0xb0f81764, 0xdaf2f167, 0x0a2f99e7,
	0x5272e6b0, 0x3df8c41c, 0xfe33274b, 0x54bc79f8, 0xe124b3ec, 0xfc31083b,
	0x46586b68, 0xeff1e89b, 0x9fbfc729, 0x5cdf30ac, 0xdd64bbb4, 0xb271ff9c,
	0xe54a57d8, 0x6f993fbf, 0xfcfed209, 0x76442c35, 0xa513481a, 0xe528b1d7,
	0x04ed628f, 0x34af468f, 0x7967af1f, 0x9f3285c5, 0xc664f68c, 0x2b7c465d,
	0xaeb8eb28, 0x147ec2eb, 0x369b5bbf, 0xd3ed3e7d, 0x22587fff, 0x80000e1f,
	0x00008000, 0x00088b1f, 0x00000000, 0x7dbdff00, 0x55547809, 0xb57df096,
	0x542aaa57, 0x646caa92, 0x280810a9, 0x89212b01, 0x849520a0, 0x152da8b0,
	0xb16406c4, 0x4d900d58, 0x65ba6da5, 0xe90414be, 0xba1b4c80, 0xe9569719,
	0x5b1bb102, 0x9d1a09da, 0x558b51a8, 0x8ffa1dfc, 0x88f4ad0c, 0xb20bb576,
	0x3dd38327, 0x7fcb8cf4, 0xa6f7b9ce, 0x8154bdea, 0xe5e9fcdb, 0xefbbdf72,
	0xe7bf672e, 0x392b7b9c, 0x9677a025, 0x3fc1b633, 0x0f1ac1f4, 0x7f6b5b63,
	0x331409e8, 0xd7cc66e6, 0x8556e501, 0x33b0eecd, 0xe96576c6, 0x4b633a58,
	0xb6fe8c2c, 0xc46a1539, 0x2ac75398, 0x84e55b18, 0xacf7c27f, 0xb3b79b39,
	0x32ef7af2, 0x30d76313, 0xe50194d6, 0x2fb7a820, 0xe7846c9a, 0x9554feab,
	0x2ffd0a91, 0xffa071c3, 0xa6548f65, 0xddf01d07, 0x0f2639de, 0x02cee594,
	0xd6e97fea, 0x1460535a, 0xd0badfbc, 0xfde62be4, 0x0c7ce0f6, 0xea0c41de,
	0x83bd5bf7, 0xd63195c6, 0x76cf4477, 0xf0afe3c0, 0x72c0e26f, 0x640c0b5f,
	0x8b40ec66, 0x3386f985, 0x5e1e4a16, 0xd4a192c5, 0x654b1f31, 0xb3d1bf6c,
	0x7e82ebd9, 0x62f50e36, 0x9f24a13f, 0xa1ea0521, 0x56de3dbb, 0xf56a3fa8,
	0xfbe0f674, 0xeef2487f, 0x5377d0f0, 0x7fae2959, 0x08e4f392, 0x2fdf14c6,
	0x896caf95, 0x330987c7, 0x5f7f876c, 0x14bc61e9, 0x1edf8776, 0xa4beff5d,
	0x770879b3, 0x46eb80a7, 0x93b9655b, 0xcb139f4a, 0x6302526b, 0x445b5ea9,
	0xced57278, 0xc67b60b4, 0x6d279c72, 0x3a5d7ed1, 0xb4fec016, 0x20cfffe3,
	0x4b1cb7e8, 0x126f1716, 0xf22f12cf, 0x2f8a55bb, 0x789c59c3, 0xf4974d5d,
	0x5316942c, 0x9c99f437, 0xa26e7c76, 0x969c17e7, 0x3cc60ea0, 0x7ad81994,
	0x0a74a03d, 0x983031eb, 0x79293ea7, 0xab45d234, 0x96077935, 0x7d8d3253,
	0x5f5b4111, 0x0059ffe1, 0xc9bf3060, 0x48efcf8c, 0x4ac3e4f2, 0xa41f7e32,
	0x3bd9a7ef, 0xf4086c0d, 0x19bba8eb, 0x0b2378f1, 0xfced73d3, 0x630fdfa0,
	0x51e69dfb, 0xa11a6fd7, 0xabc0ffae, 0x241633ae, 0xd2d03d78, 0x31b1f15c,
	0x8c03efda, 0x0388ed4d, 0x58031f97, 0x772bce11, 0x8f1f4359, 0xd0d3f688,
	0x37aaa291, 0x3e856575, 0x2567198e, 0xf90b23fe, 0x9ebbaf87, 0x730e62bf,
	0xf788c7e0, 0xe1311606, 0x4d0280fa, 0x9b07e07e, 0x5f11f995, 0x1f56bde1,
	0xb26cba03, 0x015bb69b, 0xb5dd4dc5, 0x6e7842ca, 0xe47bc073, 0x6943ac63,
	0x40f6f233, 0xf83f34b9, 0x1be031f3, 0xfb733fb7, 0x29f88526, 0x37d476b3,
	0xfc23779f, 0x4ff00d6f, 0x8a3d81a3, 0x475fe9f8, 0x3d23ac3d, 0xb6f38eba,
	0x8e982a0f, 0x2e4ba3d6, 0x3130ba47, 0x3d745065, 0x4b5e1adf, 0xda6af0d4,
	0xaeea0f6a, 0x419471a1, 0x76c6b700, 0x7504d05d, 0x84c7a59d, 0xd200f2fc,
	0x95bc1c79, 0x687f393b, 0xf119bcf1, 0xf69f871c, 0x885dcab1, 0xe7277297,
	0x07eafb27, 0x831e3e2a, 0x494373f2, 0x0ddbda00, 0xe01a7e5c, 0x139066bf,
	0xe5e4ff16, 0x69a1a329, 0x67efe732, 0x3e543d93, 0xc415f8a4, 0x57ceba6b,
	0x7b190ac0, 0xd966c618, 0xbd60f082, 0x7d655b0f, 0x1526cfd6, 0x8f78bf23,
	0x9fc72733, 0x29ea1321, 0xc9b3fdfc, 0x5106a74b, 0x17d7f61e, 0xa3c705b5,
	0x3bf5947c, 0xd03982da, 0x2b6580be, 0x8ef38f00, 0x8788d3c0, 0xc2878e03,
	0xd69fa07a, 0x331ecc17, 0xe7ab81d2, 0x45d00083, 0xb6668bfa, 0xb9adaa09,
	0xa99f6857, 0x3ac05f69, 0xb613df91, 0xaef681cf, 0xc8167b68, 0x37743922,
	0xd24016e2, 0xb9f8e46a, 0x2833d438, 0x65dc0e25, 0x80047fa9, 0x5a772316,
	0xca0b5e0d, 0x3efb569d, 0xb9518b92, 0xfa3de9cb, 0x1dfd499d, 0x1c3605e8,
	0x43334dc5, 0x7ec7ac3c, 0x1bd7be62, 0x57ec4ebd, 0x56da559f, 0x98cc65e0,
	0x01aa75b2, 0x4006d8e4, 0xb18ebb2c, 0x11f7edd3, 0xf78c379c, 0x5b0f91f9,
	0x0eb6069d, 0x0ed6b9d6, 0x69700ec4, 0x708434cd, 0x205326dd, 0xed105c33,
	0xd03110d7, 0x87da2e3c, 0xb44b1e90, 0x6025d34e, 0x0eb831aa, 0x9cac667b,
	0xcf1bdfff, 0xe3b4ed4e, 0xdbcbfdb1, 0x8b3c600a, 0x02b5e753, 0x3b1ecc9e,
	0x1f8628fb, 0x1e18fdb5, 0x47edc431, 0x3fc24edb, 0x918d9e21, 0x85c7c464,
	0x50d4dd4c, 0x4f0f799c, 0xadf4fce1, 0x8d3cc7e5, 0x2f1f729c, 0x4af7e30a,
	0x80a0b924, 0x14f0c8e4, 0xc7469fa0, 0x3cf83fc5, 0xfdd2af24, 0x389ece0e,
	0x2acc86ee, 0x2ae4804b, 0xfd949fb3, 0x9fd313eb, 0x4de98b84, 0xf8742ab0,
	0x7f6199be, 0x41838257, 0x99be12f1, 0x2a9ec0c3, 0xb19ef818, 0xfe9f34ed,
	0x310f48f6, 0xe0dfbfeb, 0x4e363a27, 0x00fc5a08, 0x459eb5c7, 0xdbd40896,
	0x0b079e0c, 0x137a7ed0, 0xae0f27ec, 0x7f8a8667, 0xec09b964, 0xd3f60626,
	0x6a9d14cc, 0x4a4cb23d, 0x27dc7760, 0xef69b3f0, 0x65e57f1c, 0x99c407e8,
	0x2937e91f, 0x7d44e0d5, 0xf9f23464, 0x38dfb0da, 0x26fd91f3, 0x7b03d782,
	0x960fc4ad, 0xf5084b62, 0x0dbc76a2, 0x67cd3f06, 0x8827cc03, 0xfe3e1cf5,
	0xb9c1a706, 0x46dbda03, 0x0c4b3124, 0x33594cfc, 0x5d17fe09, 0xf787a62e,
	0x8f405c1b, 0xe12bd671, 0xf4e10534, 0xa032e85d, 0xef61cba1, 0xc4bd2114,
	0x534fe5d0, 0x72e903dc, 0x72ffca0a, 0x89667f3e, 0x41d0ff9d, 0x803af0f1,
	0x5374353e, 0x90f99e31, 0xdca032ef, 0xab05eb0e, 0x629eea6b, 0x1cbc079c,
	0x659bf307, 0xf7904e67, 0x4dcab4de, 0x3d1527c8, 0xf90c4cfb, 0xeb4dd3a1,
	0x6bdf17a8, 0xc0bbfdc7, 0x9c53dfdf, 0xee3a0e54, 0xc022667b, 0xc927b3b7,
	0xceabc0a3, 0x6b1f6e54, 0x45397bbf, 0x3b4bf611, 0xd1910d2f, 0xf6c83f68,
	0x6f98f315, 0x93079407, 0xf4059b58, 0x722993ee, 0x5e0bf29f, 0x6171801a,
	0x8cafe99c, 0x8f7641dc, 0x5041ff58, 0x3d3ed80b, 0xd15a323d, 0xedbc077f,
	0xe0c7d582, 0x2912c1ad, 0xbff53b42, 0xc40e814d, 0x48f1d357, 0x8f3bd63a,
	0xdf7b219e, 0xb0edcadd, 0x216c97be, 0xf881bba4, 0xabf34b59, 0x059834bf,
	0x5bc40cc7, 0xf64c21bd, 0x3ca5fd76, 0x0eeb0f7a, 0xefa3525a, 0x8e2d03a7,
	0x858a7dc5, 0x13e109c3, 0x14bf1f0f, 0x01f12af4, 0x21d238fc, 0xfa7081f0,
	0xfdebd850, 0x369b7778, 0x9cee7ee0, 0xbe673f85, 0x213f7c11, 0x4987f8f4,
	0xf6062179, 0x724587ce, 0x8f49e6bf, 0x56f53bd5, 0x61b383df, 0x3d6decdd,
	0xc58a0a7b, 0xb436f6d5, 0x7d9b1707, 0xbe781483, 0xcaf4dff8, 0x210202da,
	0x0152c1f1, 0x7bcc73cf, 0xb82fe22f, 0x8a7cead9, 0xc7dea7f0, 0x39543c14,
	0xbf7c08e6, 0x45ef4bb4, 0xb55167d3, 0x56fd883d, 0xe33d54f4, 0xdacbe780,
	0xfd061e6c, 0x3de89e2e, 0x1e71c7a9, 0x15d67ab4, 0x4867bee0, 0xbbf41665,
	0x9c0a9fea, 0xab6c0f28, 0x2f1699fd, 0x8617e280, 0xc7803669, 0x85c2cafd,
	0xf8a0094a, 0x068db617, 0x8be1b3c0, 0xa856b3ea, 0xce45fe0f, 0x632e4b46,
	0x472ca0af, 0x3b982d3b, 0xbfa9f70d, 0x475da9c3, 0xee3b2653, 0xa2758777,
	0xd271bc5e, 0x76aec650, 0x30ecea77, 0xc5a9d9e7, 0x7e302d1b, 0x44afaa7a,
	0x492de307, 0xfd86992d, 0xd4707a2d, 0xf7811edf, 0xa693a96d, 0x7801bda1,
	0x9b4fdf13, 0x642a0d56, 0xbf5978d9, 0x97758ac5, 0xc6ed458d, 0x873f20b1,
	0x3b47c744, 0xd65533b1, 0x049b4c67, 0xd5587edf, 0xfe806d5c, 0xdecea4f7,
	0x63157c58, 0x74ad6ed7, 0x17fc60fa, 0xf5a76f53, 0xfb649a76, 0xd07d1b79,
	0xf60593be, 0x91fde11b, 0x669d2c5f, 0xd2bac001, 0x584e25fc, 0x81e59a7f,
	0x7c27538d, 0xa1197e07, 0xee3bf768, 0xcdf13754, 0xde690421, 0xd7133eea,
	0x73df82af, 0xd7f71d38, 0x11dd4047, 0xf5e4cf53, 0xe5f175ce, 0x5c69bbc7,
	0xc526757f, 0xca9a5f7f, 0x3bc00be5, 0xecfa43ac, 0x158685b2, 0xf009e544,
	0xf12c6593, 0x27ce16d7, 0x1c3357c0, 0xfb71c7c4, 0x0bfca6fb, 0x3a7ea770,
	0xee1b3e0d, 0x035ca5c3, 0x38e1b306, 0x2a3c53a7, 0xb3d15d79, 0xcbede488,
	0x3d6f8269, 0x6aee3e1c, 0x96615cb5, 0x8b84229e, 0x58ba6efc, 0xe048c167,
	0xc023f44f, 0x573f903c, 0x8fbf6159, 0x953d807e, 0xf632ec19, 0x4aa5fd77,
	0xba3fbed5, 0x7cf4498e, 0x9fd0bf40, 0x2deff447, 0x4af03afe, 0x5cbc02b9,
	0xeb4afef4, 0xf6a7f68c, 0x8fec0c53, 0xe8062bfb, 0x79fc5315, 0x04e92bde,
	0x918bafe0, 0x7c84cb6b, 0xfb45a905, 0x5e2f0bf2, 0x415363b5, 0x38ebb8ec,
	0xdf4019fd, 0x2083bcc1, 0x558e515f, 0x61377c18, 0x549e8afb, 0x7a215067,
	0xcde82f5b, 0xf126f480, 0x5cda99dc, 0xa2ddeb49, 0xb1c47738, 0x9521ff03,
	0x768abbeb, 0x49f687c5, 0x7e80bcc6, 0xa4fccc61, 0x3bfe87fc, 0x9c65ff45,
	0xa7e89f9e, 0x3fc8f9e7, 0xbcc1bfc2, 0x06a3df40, 0x6133ffce, 0xafebf467,
	0x9c21ac17, 0xb7db848f, 0x3f697fa5, 0x53d427d4, 0x8ccf34c9, 0x3064e1e3,
	0x097fd8e9, 0xf8ece87e, 0xd47af928, 0xa67a5d57, 0x51baf878, 0x3948546e,
	0x70f37c19, 0x63b250d5, 0x43d972a2, 0x9b948cf6, 0xda258b61, 0x3796fd7e,
	0xb947aea7, 0xc3fc066a, 0x907a5c3c, 0x79d1a5e2, 0xfae54eec, 0xf9806c72,
	0x2f81d9e2, 0x1ca438a7, 0xba3c75a1, 0x847d9aba, 0x75fa17eb, 0x7e48246c,
	0x1c054799, 0xa110edfb, 0x239ba7bf, 0x8f7f72cf, 0x1d651e9a, 0x5d4694ec,
	0x7c7fb461, 0xee86233f, 0xd03a090f, 0xcabbe7e2, 0x10438027, 0xf54c60e1,
	0xaea1fef0, 0x00617da0, 0x3ff005fd, 0x6ef76b5f, 0xb799882a, 0xb763cb9d,
	0xd8e5c75e, 0x95c2f815, 0xbdf7dfc6, 0x8e7e20e4, 0x31db83c2, 0x7e5ca9bd,
	0x3ab1d76f, 0xd41c6fdc, 0xfd209f01, 0x2f3af9da, 0xfd4598bc, 0x7dda227e,
	0xbb79725f, 0x7ce3c609, 0xc363f64d, 0xabb783cb, 0x9bfbcfe7, 0x52e1c69c,
	0x8257dc71, 0xbf30cc76, 0x85fb8bdd, 0xfb199e8a, 0xea2f508c, 0x5ad89c56,
	0x075179d2, 0x2ea053e7, 0x77379701, 0x65fbf6c7, 0x5d7be3aa, 0x2671d147,
	0x2e7ce3c6, 0xb34a0fdb, 0xfac27c73, 0x834f08cc, 0xf2ca8e5a, 0x7f879bfb,
	0x5bd6119f, 0xb140f00f, 0xd9d6e12d, 0x159d70b1, 0xf338f8f9, 0xe85f1f22,
	0x851ba858, 0x91847d78, 0x1f2fd77d, 0x4875f2b6, 0xb2e8147b, 0x20b2e903,
	0x19fa972d, 0x2b67dc76, 0xd0c3f786, 0x9bef826e, 0xdc211c3a, 0x02d37857,
	0x9d70d393, 0xd1aafb33, 0x6b68dc6f, 0x798d6b5e, 0x0bbedfde, 0x071d13da,
	0x9e70a3f4, 0xcedec077, 0x340f5d13, 0xaf5fa20d, 0x5a7c04c1, 0xc230f548,
	0xdbc4d3ad, 0x1467cdf7, 0xf7d4688f, 0xe83df099, 0x3e889bef, 0x1152ea8f,
	0x426fb8bf, 0xef5eb9bb, 0x5f7051cf, 0xa2f6619f, 0x087d801e, 0x2b41fbd1,
	0xffa15833, 0x3944a037, 0x6bbfa35d, 0xa6abc22f, 0x8478a150, 0xdca3efdc,
	0xf4d37dc2, 0x47a23689, 0x433df9f6, 0xb6eb8fd1, 0x3f413c71, 0xc58fd116,
	0xbfe51a52, 0x15779bff, 0x7ea47fed, 0xd428a83b, 0x2309c1cf, 0xecc6b477,
	0x943fb08b, 0xda9507ff, 0xfe90bb9c, 0xec8ebec5, 0xef545743, 0x6a52bda2,
	0x507bc58f, 0x87922fcc, 0x8f6b1474, 0x6fda7da2, 0xde9f06cf, 0xf2e40538,
	0xc23b53b5, 0xd152273a, 0x863f69ee, 0x9ec06afe, 0x6a1c02b5, 0x2c1c5d05,
	0x7193ea08, 0xfd60c37e, 0x5250e8f0, 0x1ed9b8a0, 0xf85d271d, 0xdc4dd209,
	0xc49e910f, 0x5c69b3cb, 0xf171af4f, 0xa6512df2, 0x2bf7c727, 0xc7ef149c,
	0xd8fcb998, 0xbfe5c954, 0xd12addb6, 0x7bb6b7ef, 0xfed5158b, 0x55deec1e,
	0x35eedc69, 0xf710bf71, 0xed149f8b, 0x3c21cec1, 0x3f2aed45, 0x1da4f1f9,
	0xdb9ed7fa, 0xe490dea8, 0x44fc907f, 0x2abec0ef, 0x24327ece, 0x05ba7de6,
	0x63386708, 0x8178b69f, 0xb8fb1970, 0xe5f542c5, 0x3269fe6b, 0x160ad7f2,
	0xbafc80da, 0x141ea762, 0x4bfe7463, 0x193fdcd6, 0x52125ffb, 0x7dc14798,
	0x35da9f99, 0x69dff808, 0x40a53668, 0xa6ddb4b9, 0xf1eeaefa, 0x94baaa31,
	0xfededf17, 0x18a166ac, 0x2f951339, 0xb6b9e993, 0x5acf495f, 0x16c3f43b,
	0xf65bad0f, 0x30cd68b3, 0xbf6cbf5a, 0x7d697998, 0xd50adb8b, 0x8d247ff3,
	0xf9a24ee4, 0xbb44ba49, 0x9e771833, 0x0ff3d526, 0x7341fe01, 0x0d4e3ccc,
	0x28fc79a5, 0x7485d02d, 0x8d879d11, 0xc2c44705, 0x24f3bc71, 0x9ec195ac,
	0x408efd0c, 0xe9cbc127, 0x71a43ffb, 0xc3dbe0bb, 0xbb02647d, 0x57fff47f,
	0x1e62bfbb, 0x5dacb397, 0x2e90c361, 0xb0eda9e7, 0x2b3ea33f, 0xe426d2c7,
	0x8ecabb50, 0x8b16bf42, 0x9c0ddfd9, 0xeefa66cf, 0x5fbc49da, 0x0b7643b0,
	0xdb98b97b, 0xdbf58fcb, 0xf66373cb, 0x2997689f, 0xf8cf2885, 0x3f428d77,
	0x6a399c15, 0x23b8c0f2, 0x2d7edc5c, 0xd2fafb74, 0x6b66fda0, 0xa3f468f2,
	0x85e6b66c, 0x8ff51f50, 0xece5c5df, 0xbc7f6366, 0xb9e1033b, 0x5a7b8bfd,
	0x3ddf880d, 0x1c83ff60, 0x00e27cac, 0xa7c8c48b, 0x7c56ac1f, 0x5f0f004b,
	0x7bd73c0a, 0xef587db9, 0x42869b0d, 0x7cf5d93f, 0x7b1d395e, 0x77cc4315,
	0x9dbc7539, 0xf95465c5, 0x9ea21d55, 0x3872e2e4, 0x0cac2ea7, 0x8fd97685,
	0xd80c54ef, 0xfa42875f, 0x1019bb32, 0xecc70315, 0xfcd76e32, 0xb2bb6ca0,
	0x870a38b8, 0xb16d5d36, 0x96d6f013, 0x9ea2f36e, 0xd2077069, 0x13cf385c,
	0xf18230e1, 0x063d13da, 0xdc5bdbb4, 0x973e173e, 0x9de8f070, 0x6d47a8d9,
	0xdb3cf827, 0x5cc5f7fb, 0x964450bf, 0xd21de8ec, 0xb8cc3d2e, 0x2a7a485d,
	0xd208dd7d, 0xe97e7277, 0xa44f42a9, 0x7673c0b3, 0xf146df6a, 0x8c71e47c,
	0xda2bad67, 0x4e58edc1, 0xfe85357f, 0x26bcf89d, 0x56d2aae3, 0x39b85e78,
	0xfb84586c, 0xfbe3c7ee, 0x1e854b81, 0x8a8c7581, 0xe495c75d, 0x4c676c85,
	0x7c909fe0, 0x7f1a9b62, 0xcfd8c1df, 0x13e57de9, 0xbe71dbae, 0x0c4debf5,
	0xfe1241e3, 0x0fbf6e2d, 0xb1dd93e7, 0x48d8415d, 0x571c9ebf, 0x3df0edfa,
	0x2687edf2, 0xfe9ccfc9, 0xd585ca12, 0x5892df7a, 0x44deb739, 0x73769278,
	0xcedc7e74, 0xfae2eb9f, 0x7fb759f5, 0xb1a7ce06, 0x79f90b6b, 0x8bfcef96,
	0x5a9f9e29, 0x825717cb, 0xf9c752a3, 0x85b67ebb, 0x4f9561e2, 0x560e8818,
	0xcc8537ae, 0xdeed7f68, 0x6b3bfdc3, 0x47e51798, 0x651ec77d, 0x72bb8c09,
	0x69651ef7, 0xd7075c0c, 0xcf9c1487, 0x43e48770, 0x74b4d72e, 0xb463fe8f,
	0xb9590e57, 0xd2ae76fd, 0xe9b8c41e, 0x1ea06339, 0xb2cb9ddb, 0x51058379,
	0x67b1bc3c, 0x3833e50a, 0xb187339e, 0xc8edd36c, 0xb6bb40b4, 0xa45e4dab,
	0xe07716af, 0x4f802ec7, 0x89dfc1aa, 0x1cb8a7df, 0xadf0b5de, 0x514accc7,
	0x385d7e0e, 0x93a1ab5c, 0xfe70d76b, 0x21c85a79, 0xfe452bf8, 0xfbe2e2d9,
	0x68a3b00c, 0xc8c8759f, 0xe31cf1d7, 0xe69b3df3, 0x7c7440db, 0xcdc69538,
	0xe82b0fae, 0xf3382ec7, 0xd935c91c, 0x7cce947f, 0x5ffe719b, 0x261d9e7f,
	0x4295b7a4, 0xb13e550e, 0x6628f953, 0xf4b98fde, 0x377b2ed4, 0xde9da5d0,
	0xa2e69def, 0xc1ecccf6, 0xb77d0ae7, 0x8d2fde12, 0x1d723791, 0x0ecee471,
	0x44fd8f5c, 0x772e01cf, 0x28cfdcc2, 0xe7c5abe6, 0x70ff28b3, 0x9b6a077f,
	0x23829b9e, 0xa1dfd03c, 0x9fd44921, 0xbe5a0394, 0x39d0567d, 0x9d9d4bca,
	0x4f64b4fc, 0x76c9f9ca, 0xe7aaee85, 0x4ed75e10, 0x343821ed, 0xf5a06e3c,
	0x43fc98d4, 0x87e18aef, 0x1dfb8bb0, 0xc0facdf6, 0xeb7f7284, 0xf44dbcbf,
	0x50aed0d8, 0x7f6b111e, 0xfa1b74db, 0xeb4f8209, 0x89bcbed1, 0xa1ec0a9b,
	0x3c26de17, 0xe5c9d4dd, 0x1ee74372, 0x947b62c3, 0xecce0b4e, 0xd674805b,
	0xb86661d0, 0x3bfa021f, 0xd2d1f384, 0x948f84a9, 0x09f089bb, 0x83f889f2,
	0x5fa44d05, 0x80551f61, 0xb72909fe, 0x2c3f0acf, 0x1fe7f3b3, 0xe9453809,
	0xa5dc7027, 0xe256bb92, 0xa533828b, 0xffb82cfb, 0xdfe42af6, 0x78735577,
	0x76abcec6, 0xe9b96254, 0xc37a134e, 0xe19bc910, 0x7ef7ca88, 0x3fbe2ff9,
	0xcf0df029, 0x1b39fcc3, 0x9c837682, 0xa97f16bf, 0xe3ef2e6e, 0x3c6f59d0,
	0x01ed26fd, 0x7dbf3749, 0x23d2a0dc, 0x044cba5f, 0x065d2fc7, 0x4aa1f7ea,
	0xc878c71e, 0x43d9f5c8, 0x94212d6b, 0x99cc6f27, 0x7901587c, 0x14ddb8ed,
	0x6ea0f2c6, 0x3fbe3d51, 0x6fc7cd98, 0xc6eee9d3, 0x3b3adb7a, 0xfabc256b,
	0xfd1172be, 0x1f2e3324, 0xfadc3cb9, 0xf567973c, 0xc1887b41, 0x3303eb3f,
	0xc23ed097, 0xbc62f565, 0x980e0599, 0xa40c736e, 0x7b73cf2b, 0xa6ef5f29,
	0x127fce0e, 0x894f200f, 0x483f24be, 0x19e146b8, 0xc493f152, 0x63f459c7,
	0xf97a7397, 0x3b41794e, 0xffb871d5, 0xee3c0536, 0xc0571e72, 0xe38ac3fc,
	0x8890ae3c, 0x7eae577e, 0xb063fb2b, 0xbe6456a3, 0x5be4a549, 0xf8aac7d8,
	0xbbc0947b, 0x6e65944b, 0xacbeff0f, 0xe572f883, 0xcfc4cdc7, 0xae5ca9f6,
	0xe5a84fd9, 0x28ff6331, 0xcdedcbd6, 0x64c75b1a, 0xf9a997cc, 0x7dc4e2b5,
	0x79b9227e, 0xbbf3c2a7, 0x7f7c7d3e, 0xb17be632, 0xc7fac1cf, 0xaf958a38,
	0xe5cdc6b7, 0x005db9c4, 0x66f7a270, 0xfaece5d3, 0xc2c7f52b, 0xe78414c7,
	0x73eb014a, 0x7dc7abbb, 0x5debfe82, 0x60c3bc83, 0xdf7767c9, 0x604f93fa,
	0x4e76e7de, 0xd2dba2f4, 0xfa27ead5, 0xbd5b73e9, 0xf1010fb8, 0x84fd153d,
	0x27f63b6b, 0x9ddf0f5f, 0x529ae67e, 0xdcf3db94, 0x3ccfef9c, 0x708d5faf,
	0x7fdbf759, 0xafdf01be, 0x6669290c, 0xafd7671c, 0x7e86ccbf, 0x913676ea,
	0x99f5a89f, 0xb7984dd7, 0xe76d0ba0, 0x720d77cf, 0x4fd3bb62, 0xe101b96e,
	0x4ad1dadd, 0xb93ccfef, 0x7efbea9d, 0xfdafcffb, 0xfc6ffa37, 0x776c5ec9,
	0x84bdf9e6, 0x8180fa97, 0xd112b3f2, 0xf67b43f5, 0x7a897972, 0x3660f91e,
	0xae926397, 0xfe9efd25, 0x62e31ded, 0xde7c86f5, 0x6d38fc26, 0x9c8f5c49,
	0xb2bbfc15, 0xcf39c78a, 0x9b3adefe, 0x48a607f6, 0xeb97ee11, 0xac5d398b,
	0xefa8f010, 0x68d8cbb8, 0x9fa9efa7, 0xb1ef8077, 0x89f4051c, 0x6ad0a479,
	0x179457e7, 0x19e12cf4, 0x3f458dda, 0x7f79accf, 0xb63e7051, 0x4ae366e2,
	0xfc33e79a, 0xf63aac3d, 0xf8aac57d, 0x6ef5f5fe, 0x380bb0bb, 0xd677641f,
	0x0e4878e6, 0x62c3bd98, 0xbaece1ec, 0x87c62b40, 0xf0155c6f, 0x2f8f01ea,
	0x793a3a9f, 0x3b7fd430, 0xf8431942, 0xcf5c2bd7, 0x4e34ed05, 0x81bffa03,
	0xf8297e8f, 0x0cc9dd24, 0xe01c91d7, 0x031aac7e, 0x3fc9d833, 0xa27247d5,
	0xc1e84da1, 0x6dbfc29d, 0xd5bbcbe9, 0xafd9df41, 0xc36f898b, 0xd53b7677,
	0x887ef2fb, 0x83539179, 0x78ef49b3, 0x33df344c, 0xe0b01e52, 0xa2a3f9e8,
	0x17f5a6fc, 0x75a9bca1, 0xf95a3da0, 0x2d1ddbb4, 0x0b491fa5, 0xfbc48fa7,
	0x951f748c, 0xf3d7d76c, 0xfc0a3407, 0x9644a43f, 0x25fb1c51, 0xbc6ec71e,
	0x2b145221, 0xe6ecfe57, 0x820bb7fb, 0xc4bc2e6e, 0x4ea0e5e9, 0x83fbfb47,
	0x6f6e463b, 0x37ea0655, 0xf84fcea5, 0x717c046a, 0x51d577bb, 0xea1a93b4,
	0xadf91798, 0x33d053b1, 0x9f08add8, 0x25daaec6, 0xd760dfd8, 0x8353f234,
	0x3079315d, 0x59eb1bd4, 0xf64bf239, 0x212f55e3, 0xdf17595e, 0x81d76767,
	0x77788a3d, 0x05f57835, 0xddb8b7a8, 0x0a88e37a, 0x5ca1fefa, 0x82a7c50f,
	0xf5d68c35, 0xa8bfda10, 0x7246b2af, 0x9eb037fb, 0x49e626ec, 0x0b277f22,
	0xf6c6ee18, 0x8c79c18d, 0x7cb431f2, 0x764292f8, 0x16c8637c, 0x37f7c2b2,
	0xa5fb7175, 0xe1f38bb1, 0x591f0979, 0x90167b1a, 0x3305fd1f, 0x31f8c60b,
	0x0a6978df, 0x9a2f93d7, 0x6d9e4f49, 0x868fb1f1, 0xa3d33ba1, 0xdcaea78a,
	0xf1e3a05d, 0x38cd5be6, 0x1e62c58f, 0xf72e46ed, 0x2f1c8453, 0x71e7ccdc,
	0x79f3d05e, 0xdde7b7c1, 0xc1bfb526, 0xc37f2419, 0xfe1e3179, 0x9e85d279,
	0x961ba182, 0xebce8984, 0x5cfef377, 0x3dc95f66, 0xed207431, 0xd93d2d1b,
	0x576115d3, 0x1850501e, 0x433e3f64, 0xd637a7c5, 0xac1370b1, 0x75c7c6f3,
	0xc9a389e1, 0xe49db9ee, 0x8b135af1, 0x4ce26797, 0x26a2fae7, 0xfe825fcd,
	0x76599ae8, 0xb81fac6f, 0xb3a7c926, 0x2a561da2, 0x32fecffd, 0x4a9cf78c,
	0x6f117877, 0xb89ee919, 0xfdc0d2f6, 0x6ee3b733, 0xc68e0f6e, 0x6d6843fd,
	0x478a6cd2, 0xff227682, 0xc7be13b4, 0xeb8ef7fd, 0xeffbe49f, 0x0e979a56,
	0xafcc5f18, 0xeebefd0c, 0xae2aff42, 0x78de1c5f, 0x2dd679eb, 0x2505e4ed,
	0x9c6bcfb8, 0xd87e2769, 0x88b28afa, 0x32281bd3, 0xe700bbe4, 0xf1fc060f,
	0x91e88794, 0x66c6a0ec, 0x3d3e287f, 0x04697e72, 0x64ed08bb, 0x7dca3d2d,
	0x589bca39, 0xa7f2543b, 0xfb947fe4, 0x74930fe8, 0xebfff92b, 0x2305f9f2,
	0xb00bc3e7, 0x7ef3a47e, 0xd3997efa, 0xc0b5a6f7, 0x137ef087, 0x8c6b61f0,
	0x5beed6dc, 0x50e4c83c, 0x0b693cf7, 0x5e523f61, 0x35fdb836, 0x1ddf38e9,
	0xabaa526f, 0x2f8d6f94, 0x9cba2c6f, 0xf03164dd, 0xafc02cfe, 0xb183f4b1,
	0x95294755, 0xb6f39441, 0x17fdf1d5, 0xbfdba477, 0xc0dcde5b, 0xd23b927c,
	0x49f303dd, 0xa06751d2, 0x0b61d89e, 0xfd2b7da1, 0xdcf9da40, 0xfdc8ae98,
	0xda57cd0c, 0xc03f18ff, 0x8ba5f7f6, 0xb7688b7d, 0xcc65f05e, 0xc1f882be,
	0x85fc0ba3, 0xe813bcf2, 0xf7ddf913, 0xe39297e5, 0xa5a6bd48, 0xc0ff191f,
	0x2716d4f5, 0x57bed76e, 0xf434afec, 0xef212bfc, 0x703780aa, 0xf0c6eddd,
	0xef1f895f, 0x03ca3072, 0x1a5f3208, 0x1b5ed1c6, 0x4468f9ce, 0xdf7e115f,
	0x81381197, 0xaafd2574, 0x4be31cf8, 0x71dc452b, 0x28632ee5, 0x7d45fcf6,
	0x7a71a306, 0x1ea0961d, 0x199744f8, 0x1f7e15f8, 0x30de62ac, 0x5a9f99ea,
	0x06041e29, 0x9bca396a, 0x46491626, 0x094c1f38, 0xd5fa236c, 0xdfa114f7,
	0x1912bcf0, 0xb61fcf8d, 0xdf4f7df1, 0x70d0fa9b, 0x4b45e798, 0x3798e7e4,
	0xa1557170, 0xbcfd0837, 0x2f7bf2ff, 0x7dbd07bc, 0xc17982f0, 0xafc62c63,
	0x0dfbd161, 0x0bef7e31, 0x7411ce09, 0x12683a08, 0x60665071, 0x37be4fb4,
	0xe8c7cb83, 0x071e18f9, 0xf6a75f7d, 0x2532c98f, 0xceafcb83, 0xd24ce704,
	0x74bd3833, 0xd6fce10e, 0x38a15db7, 0xb5eadd5c, 0xfe07a1ff, 0x08e55baf,
	0xd1af0953, 0x0673aace, 0x28d1bac3, 0x5cfe4037, 0x699de043, 0x37ea88a9,
	0x8f186768, 0x5274113c, 0xd0916a5c, 0xdebb8b4f, 0x93ca3bf8, 0x8cb3033a,
	0x5ff3c52f, 0xe18343fe, 0x25f6a7d5, 0x97de28c9, 0x749ee8fd, 0xf3193fd4,
	0x969e45da, 0xb3750f3c, 0x879c9bfe, 0xff8669fa, 0xde6be218, 0x9bb7ee20,
	0x47970f77, 0xa116fdb2, 0xf1f4b49f, 0x9c3c0241, 0x88daa8c8, 0x9a737f7c,
	0xe72c03ff, 0x255e73dd, 0x91282eb7, 0xf4863cdf, 0xfbc39773, 0x2f2eef14,
	0x7fe56f36, 0xbf1878e4, 0x96f7bc01, 0x2ead14f4, 0xcbed3a40, 0x4efd177b,
	0xd22766dd, 0xe38c4acb, 0xa245d0c4, 0xf8e24e38, 0xf484c78d, 0x214978d1,
	0xfdd4587a, 0x778471c6, 0x744221a3, 0x2762c8b2, 0x325e363c, 0x336a7a70,
	0xefc88b9e, 0xd24bf701, 0x7e277f7c, 0x14f8d9f8, 0xbf01038a, 0xa342f870,
	0x27157398, 0xc32c0232, 0x077ff44d, 0x5a2e8fee, 0xbf30833c, 0x4fd4c9ac,
	0x8c4b7e0f, 0x1c72c3bd, 0x7ee83a6a, 0x8960e893, 0xbd426025, 0x4cd7d4bd,
	0x0de691e7, 0x8b3b970a, 0x5e3ef163, 0xafc8d5ff, 0x858ff78f, 0xc4df78fc,
	0xd20639f3, 0xf7339739, 0xd9768866, 0xcfde5f9c, 0x61cf7563, 0xf0943579,
	0x4443fbdd, 0x8bd454bd, 0x5e74bb44, 0xf9c1991f, 0xbcd1fdf2, 0x299c769d,
	0x644edf82, 0x4e110af8, 0x84d85df0, 0x359af1f4, 0x196a7644, 0x679437c8,
	0x9d92e777, 0x646c720a, 0x138d3946, 0x6676a14e, 0x19ac23d2, 0xb3e01ce4,
	0xf043dcb7, 0xf40954d9, 0x55e6f282, 0x246bc533, 0xb55e257e, 0xe6289cf8,
	0x95c63df9, 0x0f946627, 0x36332b8c, 0xf445f094, 0x465ce712, 0xee7d7c22,
	0x7e0078e0, 0x7a41969d, 0x962a3c2e, 0x3808566f, 0x7ef6b94a, 0xc7af1a92,
	0x219b9e85, 0xda31faf0, 0xb78fd875, 0xfdeff88f, 0x55dede54, 0xb48ef5c8,
	0x790917bb, 0x57c84277, 0xa23d4a59, 0x109f73f5, 0x3d227bfc, 0x0175e259,
	0x1fea55e2, 0x3c613390, 0x75ef39df, 0xb619c933, 0x5df28fbe, 0x5c62dda0,
	0xdf733cd7, 0x1bd03482, 0xc67b043f, 0x7ddf4a54, 0xc064728c, 0xd258bbfe,
	0x5ea18385, 0xeb10c86e, 0x71e3eb29, 0x5d7c11a9, 0x0fc8188b, 0x47f8cae5,
	0xc8167f1f, 0xf798dde1, 0xcc39fb80, 0x76254ab7, 0x007f60f6, 0xee19d5f7,
	0xe3b5dc28, 0xb074109d, 0xd031432e, 0x56129479, 0xf05b7882, 0xf98e67f6,
	0x7179e5d0, 0x0e67d31e, 0xce7ec06c, 0xb24de4fd, 0xc2984fc3, 0x38f6ed45,
	0x6de14def, 0xf7d12b0f, 0xa7ad3c77, 0x3d9d74f3, 0x1669fee7, 0x8f517bac,
	0x2e438bde, 0x23d7f35a, 0xdd1da2d7, 0x0a78a463, 0x06cdf3e8, 0xb733779c,
	0xd4e84f1b, 0x5ef67074, 0xa766bef5, 0xee7907a0, 0x139dca53, 0x9cba3e22,
	0x49bcb979, 0xf581de4a, 0xf3baef0f, 0x2d538c66, 0x3e43fe61, 0xbbe9fb80,
	0x7bfd91a7, 0xbe500b27, 0xf536e2cd, 0xeda5ce39, 0x8f9dfaea, 0x49e7380c,
	0x48797872, 0x8df85cfb, 0xe3c7e3ab, 0xe5d04dfe, 0xbb889359, 0x8dc735af,
	0xf826bfbb, 0xef1f1a3a, 0x5fddc753, 0xbddc7cbd, 0x8f771349, 0xb8da11da,
	0x2df7ef3b, 0xbf606f61, 0xb3f7f1b1, 0xf1d7f155, 0xd3475886, 0xaf2a9b25,
	0x7601ade2, 0x6fbd324b, 0x304d64ba, 0x3f3d3b1f, 0x38fe2cbb, 0x471fec7f,
	0x7e8fe71d, 0x72fbe3cf, 0xa4e92cff, 0xe91652e9, 0xf6975959, 0x1cbbf46f,
	0x0f3daf7a, 0x92cffd2d, 0x98523e2f, 0x45fc8b25, 0xdd3ec45b, 0x1f93794b,
	0x7c845da1, 0x5af3c539, 0xf8b8a604, 0x864571be, 0xd1be5121, 0xebe803ae,
	0x1e46244c, 0xb870cd9f, 0x997aff48, 0x09cbce97, 0x93f05fba, 0xf3773a1a,
	0x19d535e7, 0x418973ea, 0xf1320fee, 0x189d20fd, 0x4cb7d18d, 0x77178fa3,
	0x264dfe81, 0x01ce8bfb, 0x4feaf27d, 0x632f0f48, 0xf7a474fe, 0xe78757de,
	0x1e83be05, 0x35b9f396, 0xf3c8d0b8, 0x3f645d4e, 0xb9f310cc, 0x1a0dfbb5,
	0x19f1675f, 0xf31f1c69, 0x0b69d338, 0x420be7cd, 0x09f500d4, 0xe747f3fd,
	0xc5e3631a, 0x6e6e95fc, 0x25104e47, 0xc4c8145b, 0x5c719b79, 0x84afa63d,
	0x1d6cb132, 0x3960f5e7, 0xf81bf151, 0x279e383c, 0x6c1ce6b3, 0xf444b3af,
	0x83309d7c, 0x256a3a74, 0x877545e1, 0x799fafa8, 0x7c52c171, 0x3c90776e,
	0x14798931, 0xc45c8267, 0x05985b75, 0x87b66dd7, 0x4b7c534f, 0x0f2ac194,
	0x087071f1, 0x12473f23, 0xae3860eb, 0x883e7edd, 0xa732758b, 0xf3ab7582,
	0x863ef862, 0x379f92f2, 0xcde97906, 0x539e7984, 0xe21975fe, 0xf733e405,
	0x6f7a24fb, 0x0b73f308, 0x8aa5de42, 0x790ab5f9, 0x8abcc597, 0xf24f2738,
	0x658e17ee, 0xc5ddce74, 0xde517bfc, 0x953c9a3d, 0x2c1972e2, 0x9b49f340,
	0x2dc9506a, 0xcf5d5fb7, 0xcad06d98, 0x97e7053b, 0xb73f5015, 0x4f9413b0,
	0x99fd84a4, 0x3ed1a55f, 0x5bfa046b, 0x79f12566, 0x90fc8519, 0x3c4959f5,
	0xa676656f, 0xc3e5bbee, 0xf6fbd579, 0x3e7e54c6, 0xc5ba42fc, 0x6009f982,
	0xe4ceccc7, 0x820ff8fb, 0x59579a2c, 0x16b3d132, 0xd43661f3, 0x8075de2a,
	0xe70e0def, 0xabf47adc, 0x7f71b7ce, 0x6ad3c18e, 0x97dbf787, 0xbcf178a5,
	0xc3c89371, 0xae7560de, 0x9e788ddc, 0x58ede0ef, 0x2b8c06df, 0x74e4df6e,
	0xaba79e62, 0x09b26fba, 0x994b55f7, 0x438b0773, 0x1f039fef, 0xc49f7cc1,
	0x1149e03a, 0xef9f23f4, 0xbc85e7c4, 0xf702b13e, 0xb0affca5, 0xe712a53b,
	0x142a66cb, 0xdeea6937, 0x5a3f4613, 0xf212ece1, 0xfc2bbfa3, 0xfff04c41,
	0xc13c72b5, 0xe947d75f, 0x8897de9d, 0xfd7d8f7a, 0x43943b41, 0xd77f85bb,
	0xd7711665, 0xc9c13e18, 0x8541e13b, 0xfd881a38, 0x787f38b8, 0x7ce3fc99,
	0xfe8b1d7b, 0xd1d538e1, 0x4d4e4971, 0x35aeef12, 0x3f22f784, 0x12ca2f5f,
	0xcf9c1e51, 0x3a3dc6e3, 0xe3a4c7bb, 0xc4296dfc, 0x8f5fb7ad, 0x6e70a970,
	0x4cf9c56c, 0xe654c250, 0x51e8b7f9, 0x405a971c, 0x8c7f202e, 0x79d0d5f5,
	0xce8c49e6, 0x9496da83, 0xfcf09d78, 0x73ff05dd, 0x63d1fd08, 0x19c519da,
	0x5e649966, 0xcf106f86, 0xfcd0f3db, 0xcd8d056b, 0xbd395d9c, 0x3d12ec8c,
	0x5d57ee13, 0x9cfffbec, 0xf2e83d54, 0xbf9d577a, 0x5af224d7, 0xa654fd64,
	0x0ffee89d, 0xc99f9399, 0xe3c27d24, 0x85327b96, 0x8d8235fd, 0x23133940,
	0x76c05e07, 0x4adf2ae7, 0xefd42724, 0xcdb89c85, 0xf648c637, 0x521790bb,
	0xfe45fb2e, 0x33e61cce, 0xc47b5c22, 0x2b471a7d, 0x98bc9397, 0xfcf402c5,
	0x1f1c554f, 0xec464840, 0x6aa9d6ef, 0xbf36e73b, 0xb66b3eba, 0x70e20ed6,
	0x09cee393, 0x90cfdfa8, 0xb554ecf6, 0xc7ef3b3d, 0x3e90a79f, 0xc34df8ce,
	0xbcd1f957, 0x5e4d269c, 0xcbc8a34e, 0x785aea69, 0x2f263bbf, 0xf283f807,
	0xaebb1a72, 0xedc39794, 0xa18d779e, 0x78bf18bd, 0x14ac3977, 0xe45fb9e6,
	0x3cc01c71, 0x5d28d28e, 0x3f70163a, 0xf29c4029, 0x369c7273, 0xa6d0b73a,
	0x6abf252b, 0xe543b25b, 0x96b4deff, 0xa7f4a3d3, 0x599c3cca, 0xc1dcd666,
	0x780774fd, 0xa3f719be, 0xe25f8485, 0xfa454c99, 0x1f93d701, 0xdc0f234f,
	0x746edc69, 0xfe411dcf, 0x25ddd9d2, 0x64979465, 0xff1f9077, 0x7d0f4c99,
	0x42503b3f, 0xed1bbe7e, 0xd2ce2873, 0xb0ddbdd4, 0x9ba51ec4, 0xd9bd24af,
	0xade90d98, 0x9cf63fdf, 0x3e63fc99, 0x059f5fb3, 0x0a6f5574, 0x862c1f93,
	0x2279e8de, 0xc0a774bd, 0x3fcab1b7, 0xa5c02967, 0xee8988f7, 0x9bc301bf,
	0xbfcf68fc, 0x3dfe4294, 0xfa460cc3, 0x23257d60, 0x3fa2f67c, 0x69ffe60a,
	0xe9d91d4a, 0xe9196beb, 0xfca90bb1, 0x2ce5971e, 0xfe87c874, 0x8e81c7aa,
	0x8ac3f462, 0x3d7aea9d, 0x5f3920eb, 0x3d007bbf, 0xf2935c92, 0xf47981af,
	0x752f8c46, 0x4367bfaa, 0x44adf2d5, 0xb731e9c8, 0x3cc56a4d, 0x2e3a3180,
	0xef12d88f, 0x2fb419e0, 0x693ce79e, 0x1bf95145, 0x53f672e5, 0x9e94e3af,
	0xc3972ff3, 0xad7fa2e5, 0x7617289e, 0xe6060dd3, 0xb4a47dc3, 0xd53da083,
	0xf5bae80f, 0x3ce53aa8, 0xd277c4cb, 0x587292fe, 0x2c72abe2, 0xb3a04688,
	0x8ec259a9, 0x2086c219, 0xa27fa1be, 0x32370573, 0x107fd4a9, 0x8bd75ff7,
	0x821e80f1, 0x9d415748, 0xbbf48425, 0xfd266941, 0x1b3b4164, 0x804a4dca,
	0xd4bff0e4, 0x1f48f505, 0xadf358e3, 0xf1bb4337, 0xca1b1e96, 0x9b93a01d,
	0xf4a3cab3, 0x79c2cad3, 0x1d15147b, 0x2973fbd1, 0x23a5c56f, 0x7fc22fa9,
	0x4dc376e2, 0x183bec0c, 0xdceff7d7, 0xf0a039be, 0x79d81cfd, 0x79bed007,
	0xe88d374b, 0xf7de1a64, 0x9c6aed03, 0xe95ffc6a, 0x5a861f5e, 0x21d102b9,
	0xe03219e1, 0xfdf7b47c, 0x62dca4f8, 0xc055b96a, 0xd579e73e, 0x08fd0f1b,
	0xd5b6f9f7, 0xf501846c, 0x0ef24b08, 0xba6f138b, 0xddfecb37, 0x71819fec,
	0xcab37b8b, 0x7a2dc607, 0x70bf7c8d, 0xdb2c8b1d, 0xb7a40cad, 0xeb57070b,
	0x52e86333, 0x46cbc7f2, 0xbca03f9e, 0x6344e3ce, 0x8c38ac2d, 0x7ee32970,
	0xd71fc93e, 0x46a69d21, 0x3c42afe9, 0xc84b387f, 0x8f967c97, 0xcba136f4,
	0x7e03d61a, 0xd77f444a, 0x4695fd21, 0xdf6901ed, 0x401d8eb7, 0x1f980567,
	0x16f16a5d, 0x7b495d22, 0xd1d28c60, 0x9f9ce78a, 0xad67e97f, 0xba18df38,
	0x4ae88c7a, 0xff22ba01, 0xa97d00d5, 0x3ba1af7e, 0x5663ff89, 0x592b27ae,
	0x662bed33, 0x193d7126, 0xf493bdae, 0xa24b8824, 0x706637bb, 0x3e61abba,
	0xa64abba2, 0x8b6a97a6, 0x4ba5aeba, 0xa6a75118, 0x9dd100bb, 0xd1135e96,
	0x9dd23e5d, 0x576997d4, 0x5983bba6, 0xecbc7bdf, 0x789c5660, 0x2d3ba499,
	0xb67949bd, 0xb6aceac7, 0xea9b3cc3, 0x630fd214, 0xc56d0c8e, 0x0286f0fa,
	0xa4f76bb2, 0xfbd3f778, 0xacbefe66, 0xfcc7a7c7, 0xe255c291, 0x1abf817d,
	0x15ab4deb, 0xfcad7fba, 0x192fcf18, 0x2fbf86ba, 0x1fbcd759, 0x0537efcf,
	0x9f2ff7f9, 0x81e740de, 0xf7c41b42, 0x58d5ed95, 0xdfe36a6f, 0xa2f18a7f,
	0x2bcf306b, 0xafcf8ad4, 0xe5e05cda, 0x476e5cdb, 0xddeb144f, 0x9fb73ca3,
	0xdfe76bbe, 0x92c879dd, 0xe6fec8c4, 0x620df076, 0xe71f139d, 0x747d74eb,
	0xd00f54e3, 0x20bed2c7, 0x752763d9, 0xef2415f5, 0x2b67ec12, 0x2c1cf695,
	0x3e65bde5, 0x3f4db78b, 0x7713c784, 0x364a10c0, 0x38c90bf7, 0x6bfbc61c,
	0x251cec63, 0x6531fb9b, 0x4654f4bb, 0xafd8b7e7, 0x9697e41c, 0xc3f0c271,
	0xc4fe414c, 0x8977e235, 0x0a5386e2, 0x988ec99b, 0x85e32f92, 0x1822c311,
	0xcfabe4b7, 0xd7f3c726, 0xa7b8c458, 0x7c82fe44, 0x79e2175e, 0x48907b12,
	0xedacfce8, 0x9853d508, 0x9ed79cea, 0xcf4f5e02, 0x5b63ff36, 0xd757c00e,
	0x92a2086c, 0xff2853cb, 0x161e96e3, 0x703c941e, 0x2c0c53fe, 0x207ca26c,
	0xad65ff3e, 0x075f7126, 0x09b76b97, 0xc3f1b1fc, 0x0a677e88, 0x0b66153c,
	0x8d863539, 0x9b753941, 0x2d0fdbc0, 0xafae46cd, 0xf91a8ddb, 0xed1b3c31,
	0xda13479f, 0x1af7eae3, 0xc62752f9, 0xf0ec265d, 0xfc8face5, 0x1d852794,
	0x6e51ea7e, 0x1d60af87, 0xfdeca7e4, 0x1b3fb715, 0x2f487960, 0xcae37f5a,
	0x437aea5d, 0x08deba87, 0x6ffb1dea, 0x9dc8d2ea, 0xedffee62, 0x02a1b47d,
	0x8f757dfd, 0x733f211c, 0x2133949d, 0x03019cb5, 0x8799cb9b, 0xd13f26af,
	0xbb1f96b7, 0xa154f761, 0x05bcb3ca, 0x47efd5e1, 0x8be79179, 0x5fbe3234,
	0x6eac75ef, 0xf144f7a8, 0xf493f528, 0x4be56827, 0xf22f9089, 0x253794bd,
	0xd829eb8c, 0x61f11e5f, 0xb79d8d5b, 0xffbd5b32, 0x690a7e92, 0x7da0951f,
	0x7575f484, 0xfd05be7c, 0x487996f4, 0x539a7e8c, 0xebfc2166, 0x7602a3ed,
	0x65347d15, 0xa73f7e5f, 0x1fa1af7e, 0x5dba9fb9, 0x18adcfd0, 0xfff180f1,
	0x96e3ee5d, 0xc999fa73, 0x7e9107fc, 0xd382b4fe, 0x7dd7dc8f, 0x4f9c7df3,
	0x938fbb1f, 0xbbafc1fb, 0x1ba7eb9f, 0xbee86feb, 0xfd7959cb, 0x3ed0bbf7,
	0x74e149ba, 0x4fe0b0d1, 0x4a9ef0db, 0xb68e2f29, 0x18c1af30, 0x334eb7ad,
	0x28ee305b, 0x719b7bef, 0x8b15fbd3, 0x79cfe462, 0x8456e547, 0x9376eb1b,
	0x26c1b51f, 0x9c7cdbfd, 0x7b9eba59, 0xb83943df, 0xdbf146cd, 0x9919878b,
	0x1f1f172c, 0x67d1794e, 0xce5b9c45, 0xbb43cee7, 0x7cc08b5e, 0x3b9ead96,
	0xdcf600c6, 0xb7f4254a, 0xfbf41417, 0x46cc9e05, 0x16174dbb, 0x50f62bf7,
	0x9b8e401c, 0x241a7fd8, 0xc7da68b9, 0x929f73f5, 0xf0ae7944, 0x1e3628bc,
	0xee60ecf6, 0x3d7e9317, 0x28ff47a9, 0xdce2adea, 0xed55ab57, 0xfa65d0c7,
	0x7ffd713a, 0x82baf854, 0xde491b6f, 0xe31f1fa3, 0xd9b5a0b6, 0xf381d4e0,
	0x9d853cc2, 0x614f235f, 0x5feb90af, 0xf986eca0, 0xedf74f4d, 0x894ef1c3,
	0x1129ec38, 0xcc953bb7, 0xfa4778e3, 0xcff2f3db, 0x38882f52, 0x7554a9df,
	0xfbb6477c, 0xffdf364b, 0xf162dc7e, 0x7c6237af, 0x83d7f99c, 0x6c3cf11e,
	0x8ffca66e, 0xbd7d7c79, 0xcea8a52f, 0xaecb9fd3, 0xf2f102fc, 0x0effdb80,
	0xbb496bce, 0xaf505cfa, 0x57b4afb8, 0x95af4fd0, 0x73dc7297, 0xe05fb5d9,
	0xf873bd77, 0xf5fd99bd, 0xa7eeb271, 0x44277bfe, 0xd7f52e48, 0xe711147f,
	0x43bfb9b5, 0xc513e3fa, 0x39f1b4eb, 0x6d4c79ed, 0xe4be7d7c, 0x9f5f113b,
	0xfcd5e427, 0x5fdfee6e, 0x061b6160, 0xba3bfbc3, 0x5b5e2833, 0x522c1c97,
	0xb683d7c5, 0x2157946f, 0xb737b4e9, 0xfd1e3fa7, 0x747898ab, 0x36478883,
	0xaa75f5c8, 0xf83297d7, 0xa7478f7b, 0x8f138e0c, 0xbc2fe6d6, 0x3186f688,
	0x9dbb878a, 0xfa356e1c, 0xcbf46afa, 0x28c25c5e, 0x37eefbef, 0xdfa2b717,
	0xe28deef6, 0x7f614c56, 0x27380837, 0xafdb975a, 0x7f951e63, 0x6279893c,
	0x481593d6, 0xa2c9d555, 0x1cdbc98f, 0xfaad975c, 0x8879b73e, 0xeafe7daa,
	0x0bef55ab, 0x7aaaa582, 0xaa75db61, 0xabdac3f6, 0x8fe1f554, 0x5f6aa8dc,
	0x220c86c2, 0x3d61d9bf, 0x55d896fa, 0xf7aa19a1, 0xaedd7723, 0xd653fefa,
	0x6878d0fc, 0xdf5569d7, 0xbe82cbb3, 0xee0ae29e, 0x8c75c1be, 0xeaa458ea,
	0xb0958587, 0x6fbd1152, 0x3f326ceb, 0x87a4b25f, 0xe9ae1fc7, 0x671aa15a,
	0xf09ebea5, 0x96af8da8, 0x9443beb2, 0xbc521c47, 0xde303661, 0x3b6bbcba,
	0xfb25777d, 0x30fe3fa7, 0xc93ae1d8, 0xe6cab8ef, 0x0ba5ad74, 0x1789d93b,
	0x1f93d71f, 0x3d1584b1, 0x65e09e3c, 0x40cf2164, 0xdc645dfc, 0xb771763f,
	0xeebef283, 0xcd31737c, 0xa6a99cc7, 0x4d47ab0b, 0x6a11b617, 0xd57870ba,
	0xac683074, 0xf0b40e9a, 0xe9a9f14e, 0x3fe04582, 0xda778197, 0xfcdd3554,
	0x55b9c16f, 0x0731df03, 0x8276ad7c, 0x9313cf1b, 0xd8599a76, 0x81b8da43,
	0x397e77b4, 0xa25dd858, 0xd80f191f, 0xff6904a0, 0x1be71fdf, 0xfbc3ce1b,
	0xcd2d4b49, 0xfc97fb8c, 0xef8e0f0f, 0x89e7a49f, 0xae1293fc, 0xb87d8533,
	0x7e49f992, 0xbf72b31f, 0xcbb5c7d2, 0x8cb4afc9, 0x7dfd9335, 0xe114c676,
	0xbb520c7f, 0x0c05e52b, 0xfb0007c8, 0x6ff8c594, 0xe055e057, 0xa9e10385,
	0x07612b74, 0xdd65a39e, 0x28041f52, 0xd0c8045f, 0xaf8aa152, 0x6860eca8,
	0x2fcac4a0, 0xf1cb0f69, 0x5ca53c24, 0x5998e393, 0xf9133eb3, 0xd8e72342,
	0x477c6d08, 0x7e91d7ed, 0x91371921, 0x1fad2271, 0x81bfea27, 0x25c62bfd,
	0xf15a0bf3, 0xa718ebdc, 0xe585fc8f, 0x3e2e67ac, 0x68e96b1f, 0x1f847835,
	0xefd62ae3, 0xafa848c7, 0xbe4710ae, 0x1e44a835, 0x3f18182b, 0x5868f196,
	0xc1ef47fe, 0x4f15e3c7, 0xc663ce2e, 0x48ddc3cb, 0x9bfd034f, 0x40afe3de,
	0x5f5d7a3f, 0xc1abb61a, 0xf898ef44, 0x844a1bf2, 0xe643f3d6, 0x1cf63fbb,
	0x98eb237b, 0xcafc973c, 0xbef127a0, 0xf7ee4e98, 0xbb5a5d62, 0x677e40d8,
	0xe904ac1d, 0x898b257e, 0xdf4416ab, 0xb03f5d53, 0xae7ef32e, 0xe4b44f64,
	0x02de4538, 0x426257cf, 0x687dca0e, 0xcc9efda2, 0x5cf7907f, 0x631f3cca,
	0x8f23f08e, 0x7fb1a366, 0x0e6b37e0, 0x3f8019f9, 0xec7e5895, 0xf7a20bcf,
	0xb351f803, 0xa0ff997e, 0xff919477, 0x7aec7168, 0xa43c06bf, 0x0e4b72dd,
	0x3423f2a3, 0x486ed08a, 0x0f8ef13a, 0xa8f5975f, 0x4c9b35f2, 0xbf41b1b0,
	0x0f228bc2, 0xbf6d43af, 0xf911ce8f, 0x73ff6245, 0xc6257825, 0x139bc887,
	0x76baf8f8, 0x939bcc98, 0x11cb2c70, 0xf70a3272, 0xf37139b1, 0xaee1fa07,
	0x2ee02f7e, 0xbcbe72e1, 0x2f8837e7, 0x3a58e3bd, 0x34e6fbc2, 0x9f6c04ff,
	0x52723c7b, 0x55e745d1, 0x79473fa3, 0xf4bb17af, 0x71ae1e74, 0x8d839702,
	0x3449e92f, 0xd336e85c, 0x5d75493d, 0x3c2ec9fb, 0x168202d7, 0x1699c464,
	0x65d87218, 0x781a09fc, 0xc92fda27, 0xa1a6dcf5, 0x0367993b, 0xa2a39ceb,
	0x987081af, 0x6afe8f13, 0xf083c5f4, 0x7e7f743c, 0x2f2fa190, 0xed3adef6,
	0xdc39dc3a, 0xf56196af, 0xfd38422f, 0x21e727a5, 0xdf46afec, 0xe11b287d,
	0xf3a14ab3, 0xfccd1352, 0x26566a7c, 0x3636bf3f, 0xf3c5ecd2, 0xfc3999bd,
	0x3fe1af5e, 0x22b4e5fa, 0x8ca5bba4, 0xafeff9e2, 0xef1527ba, 0x0ce390bb,
	0xae747457, 0x3ee7b192, 0xc61969f8, 0x1e51e72b, 0xb8b37cc2, 0x5b5ee7cf,
	0xc9e410b8, 0x3f7e26eb, 0x33487193, 0x4be9479d, 0xd39f93d1, 0x909367a5,
	0xe5fce4fe, 0x1cf95439, 0x3e63c9cf, 0xb13e7caf, 0xddcc6fb5, 0xe39f5e50,
	0x31e3dd51, 0x4c6fbab1, 0x078a3db3, 0x88d75799, 0x9e82b8f7, 0xfe9160bd,
	0xae3df517, 0xf4fec427, 0x7bfeb0c4, 0xf1b11c5d, 0x6fab46f2, 0x7eb8b5d0,
	0x7feb8f71, 0x52837d3a, 0x7beabd68, 0x3c882f59, 0x12fbf976, 0xd981ee89,
	0x2f7ca396, 0xca24e6f7, 0xf4f996b7, 0x14c8fa5a, 0xc531a1f2, 0xd0d70cc0,
	0xe5ff6ef9, 0xa5f2bdda, 0xacb9ee3e, 0xfaae82c3, 0x357ca5ef, 0xebe03e7e,
	0xc07cda39, 0xedcf9d08, 0xa97c07cf, 0x6df7b2f2, 0x9bfde234, 0xf9907031,
	0xff788de2, 0xfd3898e6, 0xfb1e7f42, 0xc9e1ef95, 0xf5fbe1cc, 0x4bcfcc46,
	0xe5ce7d8b, 0x971c744c, 0x248bb7c8, 0xaefe7f23, 0xd7e74f4b, 0x3758777f,
	0x799c4775, 0xbb70179f, 0x63f06dda, 0x30c8c4fe, 0x513a4fbf, 0x460e793b,
	0xced5079e, 0xb22ab3af, 0xf98fe700, 0x8bc6f1bf, 0x79caf808, 0x7c72a677,
	0xe666be34, 0x781a84f7, 0x6a67769e, 0x0bc91964, 0x97cf1aa7, 0xf3a6df84,
	0x9d1e48c6, 0xfdc69acb, 0xc1e8890b, 0xa170169b, 0xbaf7911c, 0x159a1855,
	0x5dbf0c67, 0x70a21e89, 0x3af0abd7, 0x7a26ee10, 0x7d3dfb2f, 0xe9edf394,
	0xe54f9ca3, 0x23f4e83e, 0x00afca7a, 0x7ee3b686, 0x77d0a16e, 0xa38f19a7,
	0x68576e9c, 0xc028b3df, 0x3b906ad8, 0xe4ae770b, 0x6353f276, 0xc2aaa036,
	0x1ebbf8e7, 0xbb19330b, 0xeb45ca01, 0xb1757135, 0x747a929f, 0xfdb566c9,
	0xff36c75b, 0x4b49da07, 0x97e93359, 0xdfd55b65, 0xe9bcedd7, 0x1b4f1c53,
	0x315f47ff, 0x2b9677dd, 0xac1523f6, 0xddc3f502, 0xc2667d4f, 0xc448cc9f,
	0xde40a70f, 0x72861d0e, 0xb9e542d7, 0x57952716, 0x7372fae5, 0x73637e01,
	0x7b2c1e03, 0xbaf0e6df, 0xeb917f58, 0x0c3c3c0f, 0xe7accb7a, 0xb9e65379,
	0x33fe3e3c, 0xe00097bc, 0x7b733662, 0xcd683f49, 0x96685b8c, 0xb5c7c221,
	0x1482e711, 0x4cde4fd2, 0x33d77fa4, 0xfc22a653, 0x7cd8cfdd, 0x954daeb8,
	0x4bf412be, 0xe7e5aa6c, 0x1e662d28, 0x6efd0f9f, 0xb9743edc, 0x52d8ed0d,
	0x9c68e785, 0xa8c37bdd, 0xff74dbc2, 0x6d4d7941, 0xc3bcf037, 0xef645d74,
	0x78e882e0, 0x13285b6e, 0x91eef7e3, 0x97187efc, 0xcb84b2be, 0x35ff6e73,
	0x2af7d80a, 0xfcf1079e, 0x904df07c, 0x45efd0c7, 0x71e73f03, 0x9678e335,
	0x763869f9, 0x0e7b9dac, 0xfbfb17e0, 0x28775703, 0xdd326361, 0x9e714213,
	0xf4e175fa, 0x9e97a8b9, 0x4c9c5036, 0x7af5cbce, 0xc3c61556, 0xab9a3ea4,
	0x4cffb938, 0x9873f1d8, 0xb4f1e3fc, 0xe65e82d9, 0xae7dfb08, 0x1179c38d,
	0x77e1e6f3, 0xb2585bb7, 0x6e6a580e, 0xad394775, 0x0531a56f, 0x171904ed,
	0xc45f6c4a, 0xfe357bf7, 0x05cfc1c6, 0xd8457d2b, 0x29f419c9, 0x1b0f865d,
	0x161f0573, 0x6c71f3f1, 0x1c61f328, 0xe1b5f1b2, 0xe6393bf4, 0x06e71e24,
	0x7bc164f9, 0xdea20e72, 0x7f2f7586, 0x47efcac5, 0x3a26f791, 0x4da87df9,
	0xe94a7233, 0x3ef1debc, 0x82e2dfba, 0x7c479231, 0x6f07720c, 0xe27b6d02,
	0x780c5bd5, 0xec1b32ae, 0xf8bfa834, 0x3ebc5bc4, 0xef0cb224, 0x13f3fc43,
	0xd5faf09f, 0x3f589391, 0x2ddf44fd, 0x6378ff78, 0x1e996469, 0x5f6d86ea,
	0xa1b8f7f2, 0xd94ac204, 0x441e9c66, 0xd84523fb, 0x9d08de41, 0x797c6e87,
	0xbfd62eb8, 0x972e45fa, 0xbcac675b, 0x760299dd, 0xf7840cc7, 0xffedf888,
	0x9d53ab92, 0x95eb966b, 0xf8ccb3df, 0xc62c3ddf, 0x31ce2e59, 0x36b1b44f,
	0x05eb8f2b, 0x070f0193, 0x5c5387ba, 0x54dcbef2, 0xdd08b701, 0xd1fb2343,
	0x1c813efe, 0x7fc28577, 0x9182e8cf, 0xfbe581fb, 0x307f029d, 0x671a7ace,
	0xff9f8fa8, 0x8253919d, 0x19bc03f8, 0x7c0cde04, 0xd69dbbdf, 0xefe2fd85,
	0x181e80f3, 0x03fcfe83, 0x82fb439f, 0x74b5bce8, 0xeb9727b2, 0x3cade597,
	0x5297db1e, 0xd134f448, 0x2933ee26, 0x90c3af53, 0x45f0e1c7, 0x63870a6e,
	0x14325e3f, 0xc055a71a, 0x34522731, 0x5f37d463, 0x9f317ef7, 0x31dd7bef,
	0xbde1f2f8, 0xf8ba0724, 0xbc86bdbd, 0x013f7e54, 0xd92a73d0, 0xfd545b7b,
	0xf9ab599d, 0x7ba32c7e, 0x0b531b73, 0x899ffbe9, 0x7de5497b, 0xc15df86d,
	0xa2a76e68, 0x8bef2afd, 0x581bc160, 0xffb17c6c, 0x710e885e, 0x3aff6e6f,
	0xeb132e6f, 0x3a758a74, 0xa1077f63, 0xf58f3f9f, 0xb98ccde5, 0xef3e4faf,
	0x7f7f7f87, 0x3fa2a5c5, 0xebc79f15, 0x113af90f, 0x7df6fe5e, 0x53ce45e3,
	0x387ecf03, 0xe127e66b, 0xdf4dfc89, 0x52e9ab15, 0xae74f3ce, 0xf86b1fdc,
	0x8e5be0bb, 0x6d4dee27, 0xb7cf09f8, 0x5d351e66, 0xe8167437, 0x7e40ef30,
	0x68cdc0e7, 0x97efd479, 0x87f62795, 0x41272c39, 0x5e6e633e, 0x217f5c79,
	0x0feed73d, 0xefe4537b, 0x14fda98d, 0x8f6f6ebd, 0xe76be30f, 0xebfff9f9,
	0x8c1b7e35, 0x8f673d2f, 0x2fd5177e, 0xc14afaea, 0x4efd03df, 0xbf38797d,
	0xf3d57332, 0x0dd82f1e, 0x474f06db, 0xa8365d79, 0x3dfc1eea, 0x797909a9,
	0x979e51d3, 0xacfaae0d, 0xc4f9e400, 0x1f5e7cbc, 0x10d9f559, 0xe7cb6fac,
	0x9efa27ed, 0x82cf7947, 0x6527d3f9, 0x5f09ed45, 0xd5c6879e, 0xdee8eb57,
	0xe63b7eb6, 0x31d93375, 0xca89ae12, 0x39aeb332, 0x5a707c5e, 0x84bfbf5e,
	0xf16371f6, 0xeff41e9f, 0xc47ffd89, 0xf7ffdaa0, 0xd9f3f326, 0x17feafbd,
	0x99994f9d, 0x0f25b817, 0x76c9b8e8, 0xd401416e, 0xa03ed9d7, 0x03e29df8,
	0x2afd043b, 0x079b271e, 0x6dce55f3, 0xc4dda3f2, 0x062d7856, 0x77f0ab82,
	0x00719de1, 0x7b5e57bf, 0x7cc1befa, 0x63ce3f18, 0x4d03909c, 0x6ffdfdaf,
	0x3a6dff18, 0x99a2f763, 0xd1fbae38, 0x1aeed07b, 0xdfd6fdd7, 0xe7e61eb9,
	0xc7bce469, 0x9e133fa1, 0xd332ed8f, 0x5f75c7fc, 0x5fdb14b5, 0x85dd6fff,
	0x4e132748, 0x2c515b84, 0x2ffabef4, 0x68e75583, 0xcd97a7d8, 0x6f184d03,
	0xc4f8f093, 0x097bbf44, 0xba4668f0, 0x4e7db26c, 0xdc176a79, 0xc8443747,
	0x579f573e, 0xe29dfb02, 0x925917c9, 0xf218e317, 0x4fd6bbdc, 0xd616bc7a,
	0xf427cf07, 0xec620cc1, 0x2c9789e7, 0xf5a24820, 0xaaa2964a, 0x54b25b57,
	0x059c6bed, 0x3253f7aa, 0x9fbd52af, 0xd55129e6, 0x4e311a6f, 0xde07fed5,
	0xfa7d554a, 0xf6aa69d8, 0x555abeb5, 0xa1dc24bd, 0x70e63f6a, 0x31fdfa97,
	0x943c47a6, 0xc7eef71e, 0x1f63fcb2, 0x4e2b5bb9, 0x72c7ef35, 0x70727fdc,
	0xd7c4fd68, 0x8fd8ea5d, 0x589fa5cf, 0xfa48fe7b, 0xede9678d, 0xff7c5321,
	0x30a1a670, 0x5e804f7a, 0x1d1fcfc7, 0x16fc094c, 0x3f9e58e9, 0x627e889a,
	0x1dcd4240, 0x01bdf9e7, 0xed1fb8f3, 0xe5062238, 0xf9071cd3, 0x9b1b8f1f,
	0xcf1eff7f, 0xb945c807, 0xb66fa137, 0x2f13dd6a, 0xaeeb5405, 0x7835cb64,
	0xaf554bba, 0xd544fe71, 0x5ae64a7e, 0x9e69fbd5, 0x6d3c1a8d, 0xe07fd551,
	0xa783547d, 0x3d3c1aed, 0xe92f7aad, 0xb1f85bbb, 0x13ff435e, 0x3d23e394,
	0x1b8788d5, 0x3e11f54e, 0x57b4f6c6, 0x3bae9e23, 0x2af841de, 0x51abfb0b,
	0x6e1c565c, 0x18658fde, 0xddf861f6, 0x2a4c96be, 0xc878b40f, 0x65a8758f,
	0x5b879504, 0xfffcf4bc, 0xf2a58cb4, 0x547c5b5f, 0x2a65a1fe, 0x7e2d3d95,
	0x3a5a3b2a, 0x2d73fda8, 0x960fdc5d, 0x452f7fd6, 0x2e07fa2e, 0x188d22e8,
	0x5b7f7e01, 0x0bcbc933, 0x580b9149, 0x489ac75f, 0x9f39fe5e, 0xbdc33c91,
	0xf2c5f916, 0xa8f98d7d, 0x5d78f227, 0xe87465e6, 0x8768257c, 0xf35bca5f,
	0xb19721a0, 0x33fad7fb, 0x8ebc299d, 0xc843cbbf, 0x35b77ca6, 0x1872fa0f,
	0x12aa3dfb, 0x99ace60a, 0xf15ef58e, 0xf2e78b7b, 0xda0f4cd6, 0xdcdc43bf,
	0x7e6e2037, 0x1b50e909, 0x29fdff37, 0x3afd038f, 0xee1f3f47, 0x151c7840,
	0x2b1f2dfe, 0x4befe231, 0x8c4a1a54, 0x6b8f67a8, 0x8e5912ec, 0xf92a5731,
	0xf7b75c6e, 0xbf0fca36, 0x2fbf48d1, 0xfbe14337, 0x83eed95e, 0x7a0fae7c,
	0xfda6607f, 0x6f9d31d4, 0xaf47f229, 0xe10db7d2, 0x276fc9ec, 0xfa3af7b8,
	0x797e10f2, 0xbaf20ff9, 0xe29b6fbb, 0x391ba98d, 0x3ff99c7c, 0x93e1beff,
	0xc2d4f883, 0xc9df20a7, 0x97d858f5, 0xac80768b, 0x35f5ab1f, 0xd2b09c50,
	0x71d70c37, 0xfce66fd4, 0x868477eb, 0x57c87f91, 0x9f8c5b7e, 0x237c89e7,
	0x0f13377d, 0xf3bfa212, 0xde287d76, 0x92bdf0ef, 0x441ff7cf, 0x9ccfb827,
	0xc17da363, 0x87bf1d31, 0xdffedb40, 0xeabef9f3, 0x7efb826c, 0xaf7013df,
	0xf7e1b5ba, 0xbd7f402f, 0x75d4acab, 0xd9387faf, 0x00cdbd63, 0xdee9a05d,
	0xf9e7cd53, 0x8057b37b, 0x73b6e284, 0xfef05ff1, 0xfcf7ddf7, 0xfed08ff5,
	0x2f365583, 0xd5e710e9, 0x45dbbf04, 0x1669f9e3, 0xcfe69fb2, 0xbd42adc8,
	0xffc45738, 0xe90c3816, 0xa4340614, 0xcfd09c98, 0x06c97b12, 0xe65b2080,
	0x4fe135aa, 0xdce5d4af, 0x15cb01b5, 0xf098b743, 0x8bea4127, 0x33406cf7,
	0xb85801b6, 0xe45fe49c, 0xebcc0b48, 0x0f7ad58e, 0xf3c9cfdf, 0x51bf2ba9,
	0xdfa48b1e, 0x08df2263, 0xd5fb4080, 0xca8af913, 0xc0427dcf, 0x88be6173,
	0xa3628caf, 0xafc752be, 0x9fbd2296, 0x28a47f9b, 0xfd417c41, 0xef8fd85e,
	0xb58c7b88, 0x71c88ff7, 0x3f7817df, 0x44ca0266, 0xae76f27b, 0xfecf4607,
	0xac395d6c, 0x53b7747f, 0x770a7947, 0x7880bc34, 0xf025d8b8, 0xc85d6468,
	0x1706b74f, 0x5eb9407e, 0x57b7739a, 0x1ede97d2, 0xbeac7567, 0xabf88b2c,
	0xd8e5f563, 0xd46af6be, 0x863f528b, 0x3c84ea5b, 0x7a39266e, 0xd53565a0,
	0xa904b50f, 0x26d2dc3c, 0xbd3b71e4, 0x4796d7ff, 0x090e3c84, 0x9e8bbc79,
	0xa6ccb777, 0x0096b5f2, 0x05a73795, 0xc9ff2336, 0x4b4cecb8, 0x0f6df280,
	0x18666a3e, 0x6dd8bb97, 0xe00cbca6, 0xb98f6d88, 0x4cc8ef30, 0xf9b52ce7,
	0xdf395a47, 0x039d0f4f, 0x04793dee, 0x379fd4f1, 0x7e62f684, 0xca3a7a62,
	0x4b940e3c, 0x463ebf1d, 0x8f51f5f6, 0xf4f681c7, 0x923ffc9e, 0xf3ea3a5c,
	0x7f508c38, 0xe47fd7ee, 0x871e03ef, 0xe7cfea19, 0x41ebc3bf, 0xf50ac38f,
	0x7a8b5fce, 0xff105188, 0x47bf5fa5, 0xa64a96fe, 0xa8fe401c, 0x024c14b6,
	0xbafa0175, 0xc5f200f2, 0x9385cc94, 0xf28a2f90, 0xd397443d, 0x600f6b3c,
	0xdb11a6fd, 0x83c5780d, 0x1eb25ecf, 0xd572abbf, 0x49bbf01a, 0xc7ad7739,
	0xdd0f26ef, 0x6efd8862, 0xf59ef16a, 0xbbd9bf58, 0x69f680dd, 0x7731ca11,
	0x97591fb4, 0x969ca5ef, 0x74d771f9, 0x8c1f49fb, 0x3e93f2ee, 0x9aa97090,
	0xc63f7b59, 0x14ba9ab3, 0x4adefe27, 0x3fa54cd5, 0x0c730139, 0x501ef11b,
	0xf387d790, 0x0b5a0ccf, 0xfd6135df, 0xb83faa3a, 0xdf95fbf6, 0xe8e3f2c7,
	0xbf0577b7, 0xbcc7bea3, 0xfc4d77f8, 0x089196fe, 0xbba7b417, 0xbee83a17,
	0xa0701652, 0xf422559d, 0xd096397c, 0xae5152df, 0xb318e510, 0xe71c03ef,
	0xe1f2c493, 0xf305d934, 0x9bce688f, 0xe42f7824, 0x67a959c3, 0x0d1c3dc4,
	0xa0fc9dac, 0xd3afca57, 0xf36b91e6, 0xb8de644d, 0x9ea4bf36, 0x07fef0f5,
	0x3cf387e4, 0xe1f901eb, 0xc4955f72, 0x946ce9e5, 0xfff74035, 0x20d9c80f,
	0x008000d8, 0x00000000, 0x00088b1f, 0x00000000, 0x3bd5ff00, 0xd554740b,
	0x9dcefbb5, 0x9924c85f, 0x10827c24, 0xc947f9bc, 0x03108067, 0x04243209,
	0x20271115, 0x067cac4f, 0x027e7f94, 0xd7628daf, 0xa02ac60c, 0x2d6ac6be,
	0xa81beab4, 0xc95a5da8, 0x0958d443, 0x5822aa1d, 0x010553aa, 0x1101d29b,
	0x08cf91e1, 0xfac5a556, 0xdee7def6, 0x0249dccc, 0x5eb5d548, 0xdce76158,
	0xbdffdff3, 0x456639cf, 0x05cf1e32, 0xffc87c80, 0xb0e8065a, 0x0486bd5b,
	0xddc5a700, 0xd000194f, 0x0b4ffb3e, 0xe0f580c1, 0x9fe5702f, 0xf588dea7,
	0x60ad0871, 0xc5806284, 0x580145d4, 0xe0333e02, 0xa67c4bb8, 0xf02b41a3,
	0xbbf8d7cf, 0x4ccfb6cc, 0xab3d96fd, 0x1c6e0eff, 0x35403074, 0x0190cd04,
	0x551cd350, 0xad33210f, 0xfa25aea3, 0x68c0137b, 0x1868475a, 0xcbebe3ad,
	0x2c15439d, 0x038dce57, 0xe9c03fb9, 0x259f16ed, 0xb93ffb8d, 0xdb35cb1f,
	0x0a75f62d, 0x4a0eb7c1, 0x36ad0805, 0xbb708cbf, 0x4d182667, 0x6e3c3b00,
	0x62cf7e86, 0xfc016630, 0xe5cf53c1, 0x5c0d3c37, 0x32f1e5de, 0xc359eddc,
	0x134f6df0, 0xacf5efd7, 0x1e3bf2e7, 0xe780c31f, 0xf37efe59, 0x6e619adc,
	0xcdbf4e1b, 0x55cc1ed4, 0x700e9dd7, 0x0473b27b, 0x7f7bd1e1, 0xe1f1e259,
	0xfaff7bc0, 0x43972c72, 0x27adbd6e, 0xd6d932ec, 0xf65c0948, 0xde1f719a,
	0x46be311d, 0x886057dc, 0xdbf68cbb, 0xdcfa1e55, 0xfe86f880, 0x8dc3c641,
	0x69e3dd03, 0x438cc97c, 0xdeacd127, 0x09dfc26c, 0xb005f783, 0x65f14c03,
	0x67388cbb, 0x5d563c67, 0x65815006, 0x03c01e6f, 0xd4955c03, 0x6683720f,
	0x8cfd27c6, 0x9825f1c7, 0x40ebccd9, 0x62baed88, 0x9141bc04, 0x213dff18,
	0x74e3818e, 0x0f9806a5, 0x1d9e36ba, 0xc4f5e4a6, 0xfa5e347b, 0x5ca547c2,
	0x2116f416, 0x1d624b3d, 0x976eac16, 0x448d2fc0, 0x39606138, 0xa9ed38e0,
	0x71c12366, 0x6d056421, 0xff1dfc3c, 0x04663225, 0x44804cbf, 0x3ac2b95d,
	0xd2bed758, 0x6faba69e, 0xf1e6cd4f, 0x42b949af, 0x707daed7, 0x3bcc5589,
	0x2d825ae9, 0x79faf766, 0x18d09748, 0xd613638b, 0x5f131bbf, 0x53008500,
	0x1137e363, 0x9866377c, 0x3d4dda8f, 0xe03fae7a, 0xfecaa73e, 0xaa880581,
	0xfa1194eb, 0x2accf771, 0xf5ddb057, 0xebf463b9, 0xed226090, 0x04c706f7,
	0x4b1bf7dd, 0x77f5d3ae, 0x84490359, 0x95672ad6, 0xc3757bee, 0x064c60e7,
	0x07386d28, 0x230051c6, 0x71bacdfc, 0xd16eed46, 0x0fb11fb5, 0x91eb1264,
	0x13af1d07, 0x29cc7d1c, 0x9f14ab13, 0xe09d7fa8, 0xc302cf98, 0x04e01f68,
	0xf9103ec5, 0xf07b954c, 0xf2c4604a, 0x125cb538, 0x102635f2, 0xae41ce1d,
	0x0a57e911, 0x36321cfd, 0x78fe4a96, 0x9c60f896, 0x3990010a, 0x58995fb0,
	0xd831cc02, 0x5274e67c, 0xa8df282b, 0x8e49d60f, 0x59c22314, 0xca98b072,
	0x202c109d, 0x465c1b28, 0x5049afe2, 0x16ca943f, 0x7c10a770, 0xdffdd133,
	0x521dc7c4, 0x2e2c51b0, 0x5cfc4c94, 0x39a1d779, 0xc42f58ab, 0xbeb82c38,
	0x347cb6df, 0xb7fad680, 0xbf9f80c0, 0xbdf984a6, 0xe339fece, 0x37572b49,
	0x69fc619c, 0x30d5f6e5, 0x6e4b85d7, 0x2adcc132, 0x92ffd584, 0x48d956e7,
	0xa21ac17f, 0xc1fc3553, 0xdc2f3cbc, 0xed3f9a1e, 0xea2177c6, 0xd35a2abf,
	0xe9bd2a58, 0x2abb6272, 0x80439093, 0x8e5c55c9, 0xcddecb51, 0x5b8e272e,
	0xef6d4035, 0xa9f5154d, 0x5130fd5a, 0xbbc6d2ce, 0xac1fb44b, 0xaef1d595,
	0x51ffcad0, 0xda69f5c5, 0x1ca20d7c, 0xf0dfea27, 0x3d22ad8d, 0xb7fbe9a0,
	0x02313b35, 0x409d9046, 0xe90efffd, 0xef69769b, 0x4f7fa642, 0x57afa0fb,
	0xdfdcc3ed, 0x21735ec8, 0xd8baffe1, 0x371c913f, 0x5c72404b, 0xe9c9b77d,
	0x254ff9c3, 0xb0ac1735, 0xea75f185, 0xaebf0287, 0x8ca7388a, 0xce5e6bed,
	0x237c44d9, 0x381bedc7, 0x347fbf1f, 0xa67ac0c4, 0x8139b652, 0xd0a0f9e8,
	0x68ff5af3, 0x35e1b0b8, 0xd47afd1d, 0x07cf12cb, 0xe717f133, 0xd06878eb,
	0xa38475c6, 0xe13640cc, 0x1af49da6, 0xea2060d2, 0x7dfc12d2, 0x15aaf513,
	0x033fdce9, 0xdf6c069c, 0xc7d415ff, 0x0163d344, 0x5f0bbfd6, 0x284bf189,
	0x5e1b3528, 0x5f377b67, 0xfc46a946, 0x9f71cead, 0xc674fc26, 0x4f89b205,
	0xe0ec3617, 0x659e5d75, 0x1ec1f1e7, 0xe7c48bca, 0xffe27a3f, 0xffc0175f,
	0xfc4fbebf, 0x494704e3, 0xc8501b7f, 0x6d4b7d68, 0x977ef06f, 0x9f59dfaa,
	0x71db85a4, 0xee59ee59, 0x230c738c, 0x3a54387c, 0xc528351d, 0xd252be2a,
	0x058e9e70, 0x2c44ec81, 0x8181fc3b, 0x7b07b66e, 0xf7444b47, 0xba2038fa,
	0x82814a77, 0xbfd0bd03, 0x76ccd3d9, 0x85a7ab78, 0x0e708fe1, 0xaf86b3c2,
	0xf81eb4ec, 0xc06d32bd, 0xafabf179, 0x3bf18eff, 0x3b3418c8, 0x41ed5fb0,
	0x038a71e0, 0xa110cd47, 0x09a72657, 0x22d09b7b, 0x9ca57d71, 0xd5d41097,
	0x653a09c7, 0x9f10473a, 0x5bdb4cd6, 0xcb0a4eb6, 0x6858f8c3, 0xbe62498e,
	0xed7ca876, 0xf8d6be20, 0x9471f917, 0xc6fcf111, 0x0bd7ec39, 0x0bfcc37e,
	0xa7868f3c, 0x9d789eaa, 0xbe7e7691, 0xc77fd7d5, 0x0fd6dd78, 0xfd7b2107,
	0x536f8c52, 0x373c4f5a, 0xd77909a4, 0x02f6bdf0, 0x1dfb5e78, 0x9a6d79e1,
	0xe346e3c2, 0x147b2fbb, 0xdd6d1f4d, 0xe8e9c8bd, 0xc1d3914b, 0x329eaa19,
	0xdf999fa2, 0x444dee93, 0xee8eab77, 0x9e405e8f, 0xe53efd1e, 0xd16f1a29,
	0x57025ab0, 0xf7e7adb3, 0xb10669ad, 0x8f08efef, 0x753342e3, 0x2ff8d8fe,
	0x6c7f3add, 0x7a544602, 0x5d0ef5bf, 0xa77ed2b9, 0x2935fdae, 0xd7f575ab,
	0xf5756b29, 0xac3ee7d7, 0xd8e0df2b, 0x6e57e510, 0x3957d5d4, 0x9faba37f,
	0x5753bf5d, 0x8f61b73f, 0xf79e7eae, 0x86b2bacf, 0xe01eedc7, 0xc78768f8,
	0xd74bc6aa, 0x060b2c32, 0xae0c482a, 0xff62113e, 0x54d024b2, 0xc1c92ec1,
	0x8b3ff666, 0x0a0aaefc, 0xd7778aa3, 0xefd04ebf, 0x59f1abb1, 0x3c37c30a,
	0x5df7eb0a, 0xbb865c9e, 0x3e350e3d, 0xd7b8612b, 0x32e354e3, 0xbb68c317,
	0x6dc33ab0, 0x4c7a474b, 0x0191717d, 0xfe370170, 0x03bcabee, 0xc3a0f8b4,
	0x0aed7140, 0xca672f75, 0x0abc38be, 0xbd4cebf9, 0xb6e541c5, 0x4a4d279d,
	0x997e4f7e, 0xce0ca5fd, 0xdd9b3e08, 0xf91367f0, 0xe591b359, 0xd3917b9b,
	0x5fc174c4, 0xea007ee4, 0x30569985, 0x307d47f5, 0x68e4a673, 0x85eefe04,
	0x377e8624, 0x82354fd6, 0x2ae582df, 0x896fd19b, 0xacb9a5e7, 0x10cf3fe8,
	0x118b04cb, 0xfd0f54bc, 0xbf2e3993, 0x282a3e89, 0xae194e0f, 0xc833efc6,
	0x3f7ec6ef, 0xc89b35b0, 0xfbb2deee, 0x58558e9e, 0x477af70f, 0x130f3c73,
	0x25bfa4ed, 0xaf8687ef, 0x2f2df787, 0x1e384d48, 0x2489d7c1, 0x4a8f14c3,
	0xe293808e, 0x8e4c3bd4, 0x7ecf4acd, 0x7909a71f, 0xec4b2a9c, 0xb55e85bf,
	0x614936f8, 0xedfdc4f9, 0xeb3ee0b6, 0x9f680788, 0x4e7f26f5, 0x3bd5f901,
	0x2baeafd9, 0x74405d59, 0x1d289baa, 0xe38414b1, 0xcf86ba9b, 0xd68f6fd8,
	0x42f0d1cf, 0x60238ff1, 0xec3bfe67, 0xa2fccdd9, 0x1e6d41c5, 0x828b973f,
	0x78c88aae, 0x07f8d668, 0xc6738a64, 0x9de2267c, 0x03ce73d2, 0x83bee157,
	0x95bfc09e, 0x08f2d04f, 0x3a215e5a, 0x91e9a14f, 0x26567739, 0x57bf71b8,
	0xbe85dba7, 0x65484eb7, 0xd4051a3a, 0xf4c4edf4, 0xdaf9fa1e, 0x65dbf3f4,
	0xac77fd7d, 0xff962f9f, 0x5d8453ab, 0x83fbe68d, 0xd1319ed3, 0x8efe353a,
	0xd459ffe6, 0x559fe707, 0xa8bcf927, 0x6a2e67a7, 0x974a9532, 0x6d4befce,
	0x1c1c44c7, 0xb1be176d, 0x8e98503d, 0xf1cc8572, 0xc3be4585, 0x8d0f7941,
	0xd27aab0e, 0x7e7e93cd, 0xffafaabb, 0x6380e3de, 0x2ecd2e73, 0xf89fce82,
	0x3f7dcf65, 0x3f7d8179, 0xfbee7df9, 0xc30a21a3, 0x736d7e9a, 0x17a88364,
	0x0c0d89f1, 0x3e5dbfc8, 0xc5d2e399, 0x14f14d69, 0x284940cf, 0x92ddf49e,
	0x3fc81956, 0x38d3a304, 0x9173f918, 0xe0ed9fca, 0xb1f880ff, 0x94fc1e16,
	0xca8b2e12, 0x3d214d16, 0x5371f8b7, 0xbffc4f18, 0xb525f393, 0xb6a5bf6a,
	0xefda666d, 0xedf4a7d2, 0x9faa71b4, 0x6b4de7d7, 0x04f9aecb, 0x38046ed8,
	0x4dbb57cf, 0x7a576fdf, 0xc3ce7f5c, 0x8491848d, 0xd3e90bf7, 0xa6ebb24e,
	0x0f39f288, 0x49de17e7, 0x3bd8786f, 0x7d9f4c34, 0xf079e93d, 0xe0e7fa02,
	0xa27fa9f7, 0x7b8e58f9, 0xfcf44cca, 0x9bfc7ca6, 0xad07672c, 0xddcfd35b,
	0x0b35e77a, 0xd1ae9deb, 0xde8bc88a, 0x78c6dbf1, 0xe0b393e2, 0xaf987620,
	0x6be747e6, 0xfa35d1f9, 0x76f8e8fc, 0xc6e1e73f, 0xc635f31d, 0xdb4bdd21,
	0x1ba79cbc, 0x68ddcfb3, 0x7b55f2c3, 0x47f9329d, 0xc970de23, 0xbfcd6eb4,
	0xb09dfcd1, 0x7d64cb1e, 0x8cd679c7, 0x9a77d78b, 0x61ecd45d, 0x092c1db4,
	0xfd905535, 0xf365fb1b, 0xadbf04eb, 0xddb47a3c, 0x2393473b, 0xfe4d3b5e,
	0xcfc807d1, 0xb1c63578, 0x3fae7a19, 0x75d04333, 0x899e77ba, 0x0f848fe5,
	0x2a9a6de5, 0xdd925337, 0xce381999, 0x185ed574, 0xd9134eac, 0xfdb94ad1,
	0x5f1337e7, 0x13ce6405, 0xfbf1fcae, 0xb94afc2f, 0xcea17e70, 0x8ffd867e,
	0x3a8ce2be, 0xbe29b803, 0x8ca15918, 0xe2863f22, 0x6a1bca36, 0xf6e8c479,
	0x8bcab28b, 0x72957d69, 0xeb49c059, 0xd3d62f59, 0x1aeabd17, 0x2de5d53e,
	0xaebf9afb, 0x7e7db475, 0x28fc7c84, 0xb44e3ba3, 0xe986b71f, 0xf17cb17d,
	0x997e2dff, 0x4257832a, 0xf92f9b3b, 0xc20bff84, 0x01059e0f, 0xc4207386,
	0x3e760dd0, 0x0e0f9a8f, 0x8b83b786, 0xf74c99e1, 0x73f20cb2, 0xc481a14d,
	0xff2f1d57, 0xa6f88f33, 0xa6d2eae3, 0x9dedf031, 0x7ffb4527, 0x9e14235d,
	0x7fa5ebbf, 0xecfe27ee, 0xa2e9b1fa, 0xc9edc6f4, 0x51f10f4e, 0x3bcaf9f4,
	0xc73e6413, 0x961ac701, 0xe8bb2a8b, 0x70071303, 0xa4868f9b, 0xf5859cb1,
	0x9a8da0e6, 0xfd879cde, 0x58188ff2, 0xc912c1af, 0x5b4d8597, 0xb1160682,
	0x3e6905fc, 0x44dbca99, 0xa24d7e7d, 0xfe72c24f, 0x7f511898, 0xd20fa247,
	0xb20a1e28, 0x6005ce5c, 0x840f387d, 0x9c0dbc5e, 0x0c8c4fbc, 0xbfec25d2,
	0x2475bb60, 0x982163e7, 0x80bffa49, 0xe25ea8e2, 0xf2a8bff4, 0xf42e985e,
	0x3eb9617d, 0x4331b22f, 0xacf659c4, 0x7e88aff2, 0x26e74c96, 0x81498582,
	0x51148f75, 0x9b00c83e, 0x193ebe50, 0x6f9f2773, 0xcaaefd6a, 0xda867f2a,
	0xe380916d, 0xc5ab6f15, 0x2b9c59b7, 0x273c8c0e, 0xf159933b, 0x36f3c25b,
	0x17d8cf35, 0xc71fb15e, 0xcae53dfd, 0x290afdcb, 0x3cfce376, 0x79e1287e,
	0x4666fcb9, 0x79bdd55b, 0x25e0867c, 0x2caaf93f, 0xaf9a0ef7, 0xa3600cd0,
	0xe2213ff5, 0x61fa8028, 0xf45d1f94, 0x7e40c5a4, 0xc73421c6, 0xc1f88390,
	0x5fe09bb8, 0xf8267e31, 0x099f8c37, 0x99f8c11e, 0x3f1847e0, 0xe5f05c13,
	0x908a0c08, 0x03ce990e, 0x79c5cf82, 0x037af45f, 0xe7bb3e2a, 0xfcf3356f,
	0xe3372cf6, 0xafde9bb7, 0x61ce8f82, 0x2e8624b6, 0xbf0f3a4b, 0xc17eb575,
	0xe17da5e7, 0x8c873b45, 0xd2a5dfae, 0x919b60bd, 0x4b417fed, 0x44617e30,
	0xcc338fbb, 0xd2ff9f5c, 0xbf1a78b1, 0x5f8dded3, 0x9e5b84a7, 0x8fe5106a,
	0xdd574e33, 0x3bf5a36b, 0xa2bc22bf, 0x7da49f9c, 0xffbcb414, 0x1e22d2b3,
	0xb4292edf, 0x1c63d08e, 0x23ed4437, 0xbeda0f1a, 0xd60624b6, 0x2f2dff51,
	0x504ed3a5, 0x1b9080ef, 0xb7a923e2, 0xf5e6aefd, 0x150968de, 0x373d71d9,
	0xf7d72d7e, 0xd67b7f86, 0x7af3c604, 0x3eee6fd5, 0x4bf9570f, 0xcaa5dba3,
	0x4078f477, 0x9dfa11ae, 0x2a9749cb, 0xc5ce9764, 0xe7c85f93, 0xde486359,
	0x7da5df33, 0x90cb777a, 0xeb1f30a5, 0x2991cfe4, 0xf98345f8, 0xd11766ad,
	0xf1eb4b6b, 0x4c6ddbcc, 0xd805cc9f, 0xd2ccc95e, 0xc7f33de5, 0x23e5fd9c,
	0x9dbdb9fd, 0x3605baa6, 0xfc71da56, 0xdf3bad5b, 0xb6cd2da4, 0xc44ca91f,
	0x6914dcf2, 0x4a79c117, 0x8524a4da, 0x71e3eb96, 0xb09dcb6e, 0x8a6a448b,
	0xb9fd8aa3, 0x2264a409, 0x358543ec, 0xbb1b0e96, 0x64f695cb, 0x949af95d,
	0xd7f6ba21, 0xfaba1929, 0xeb8773eb, 0xa779b5ea, 0xdae94638, 0xd2852615,
	0x7dc3ae29, 0x66c05cb0, 0xd12597d9, 0x1e4df7be, 0x4fa9e58e, 0x9b9070cf,
	0x9fad45b2, 0x47c2b5ba, 0x7c42e8f4, 0x3aa1d19a, 0xb1f6b251, 0xa8b06847,
	0xf5baa1b8, 0xca9cbbd7, 0x7d0dc425, 0x40cb0bc4, 0x15f7db9c, 0x0bc74437,
	0x467f3fa8, 0xe5f0b3fa, 0x388dec9b, 0x673196ee, 0x6f88532f, 0x408e3133,
	0x44716ad4, 0x2dd3fc5f, 0xf8229227, 0x9b0c8f67, 0x801fe17b, 0x147e547b,
	0xe87bea70, 0x737de4cf, 0xe931f6fd, 0x781fce37, 0x0aaebcd5, 0x857df2a3,
	0x2bbbc766, 0x27f53f28, 0x1f5ce819, 0xb03ae1ce, 0x2dfd217e, 0x6e1ef987,
	0xc193f8df, 0x97bbf9fd, 0x355ad35c, 0x532eb7ff, 0x77aaabf5, 0x517064fe,
	0x1e561eb8, 0xbb87b5d1, 0xe574fba5, 0xe5f4d37b, 0x17dc2707, 0xbf2fbfd9,
	0x79fae16c, 0xe9ca3766, 0xa72547c2, 0xd17d17af, 0xaafe9ebd, 0xc45d687e,
	0xcef8f6fa, 0xae256625, 0x1c5afb67, 0x0b96f28f, 0x9ab7b0fb, 0x8645ba9e,
	0xd7eadefa, 0xbe39f36b, 0x210ef9dd, 0x79bec9ee, 0xf876115f, 0x1cdb8250,
	0xcebf27c9, 0x1d37e714, 0xf1fe1e1b, 0xfb9e74e7, 0x3aaf88aa, 0x28fd8512,
	0xc189f6d8, 0x9fb0b080, 0x7b02afe0, 0xa97640d0, 0x17ac716b, 0x96eace50,
	0x850d79c4, 0x3e8447e4, 0x3cab22b0, 0x3fadd4f7, 0x7e7f22b3, 0xece83068,
	0x5b051772, 0xf3257e58, 0x376469d6, 0x43dc4f20, 0xf9f6b6fa, 0x7f08264a,
	0x8de85ca6, 0xaa7fc439, 0xab9402dd, 0xb7409fba, 0x433d231d, 0xa7f2a178,
	0xef79cd4f, 0xf7f3f251, 0x7941bd08, 0x2fd95b85, 0xf9f4da70, 0x73966686,
	0xbc895bfc, 0xfad175bf, 0xb3268de3, 0x23d45bed, 0x2fac2ffb, 0xe91ebbde,
	0xccaaf759, 0x6f4e80f7, 0x08804acf, 0xc78d11fd, 0xcb32f5ba, 0xdcee56b9,
	0x724b5f2e, 0xaac5f741, 0x1be27bf2, 0x97fe429c, 0xcb7cc5db, 0x8d317dc7,
	0x56f2f4ec, 0xd2e4b8a3, 0x646b3cd7, 0xd9e62250, 0x98b2c3b2, 0xfeb69aec,
	0x4faabb2e, 0x349eff5a, 0xd5c04f21, 0xf457d8bd, 0xc9fd4c0b, 0x3892a82f,
	0x3adfdd9e, 0xb4f09ca8, 0x32bf025f, 0xc9b88792, 0x2e9beb8a, 0x36efa386,
	0x4a428bca, 0xd1e691ae, 0x9e2d5ae2, 0x233ad19d, 0x0fd8fc8b, 0x8fdfcdb6,
	0x566b0394, 0xcdc5cb06, 0x7bbf65e0, 0x952ba27f, 0xd55324f2, 0x13fb0ffb,
	0x6fe4ed43, 0x2b171fef, 0x1c067dd1, 0x5f1a5eff, 0x937ed7db, 0xf79eb52b,
	0x9d4be6a5, 0xc75fca57, 0xa89c7c5e, 0xf94ad9e9, 0xd3d709ee, 0xb02cfdf9,
	0xa37b3c53, 0xf86afc2c, 0x4d6790bd, 0x8149d6af, 0x99e75a24, 0x659769cc,
	0x0d41bf61, 0x7de6a5ff, 0xfef7749b, 0xeeafd62e, 0x959fa38e, 0x1d6a7f98,
	0x2da8de22, 0x9bf3f53b, 0x8c5afe71, 0x9bbfc9f7, 0x20f3b2df, 0xbe3a2fe1,
	0xfeaf8eef, 0xcf6f7ccd, 0x9455ccf8, 0x0cf29a35, 0x0cdff667, 0xeeb4e33d,
	0x2ff340b8, 0xb9f2c737, 0x21562a35, 0x9ebf2a1f, 0x607d91dc, 0x7c9fd605,
	0xfaecc4db, 0x745fb8fa, 0x95e589de, 0xcf19639b, 0x4bc09327, 0xa6e4e476,
	0x1b179f1c, 0xda84322c, 0xd6c1bec8, 0xf9a73e38, 0xe79c89e4, 0xe4fca79e,
	0x87ec5973, 0xe828fc90, 0xf7427cc2, 0x8bfbe88d, 0xb81fb983, 0x550bbcc5,
	0xc99f94b9, 0xd51969ff, 0xf9cc933f, 0x277e8d09, 0x5271889e, 0xf077f6b0,
	0xf591d817, 0xe3de494e, 0x99714f74, 0x12c3f9e1, 0x3f6765f2, 0xeba20cf7,
	0xcffe5fd2, 0x9fb8a507, 0xf86e678a, 0xdf5c18c5, 0x0007f792, 0x6ba6138d,
	0xe9c37eef, 0xfe4219ed, 0x7b2cfc55, 0x2c77c636, 0x34d49f42, 0x75caea27,
	0xc77d832d, 0x32d0f422, 0x6a863810, 0xaa09cf89, 0xb38ab955, 0x7a256fb8,
	0x547dd0d4, 0x7fb89fa6, 0xabce923a, 0x590fff08, 0x7cd1ff18, 0xf84b22b6,
	0x9e5ad5b5, 0x29ac1927, 0x816eb724, 0x7287aebf, 0xf63c5136, 0xea925640,
	0xa7b28477, 0x67f247e5, 0x9c6bed5b, 0x7b88b1e7, 0x9fbd318e, 0x12b27beb,
	0x5a17ff99, 0x99e5d33f, 0xeace1b6a, 0x79b53ff2, 0xc8c07ec0, 0x1dd46546,
	0x74a85708, 0xbaea9599, 0xfcdef187, 0x197bcbf0, 0xf0ff8f9f, 0xb7779a43,
	0x7b07e98d, 0x2a2c78d5, 0xfd685ade, 0x8dbf9554, 0xfbed5ebc, 0x0a070df1,
	0xfc71ff28, 0x9405e1a5, 0x072f9da7, 0x8d2aff8e, 0x5e1d39ef, 0xeeeb7085,
	0x1e2f38f7, 0xf71edebd, 0x87a12418, 0xc91f69aa, 0xb5c7ff74, 0x5ce58b3e,
	0xeba387e8, 0x5a7f19f2, 0x64ebba3e, 0xb6a0f1ef, 0x6d7c6d4e, 0x5af8da7d,
	0x44b3a7bb, 0x0e61d8dc, 0x2ffd9014, 0x889873a6, 0x3e23a3b8, 0xa3689050,
	0x2ed176ef, 0xfc11cb09, 0x579eeff6, 0x754f9f45, 0xf9aacb9f, 0xd58683a8,
	0xfe4669ff, 0xc47e6f6b, 0xbbd48ee4, 0x4a9cf0df, 0x9f76af5b, 0x636ec3b6,
	0x2cade6ff, 0x0a9f1f35, 0xeb0ed4a9, 0xbff27e1d, 0xe41c5ab7, 0xae2d3bc7,
	0xabfe123f, 0xbfbe7ecd, 0x5a73f5a6, 0x3a3dfcdc, 0x6895df2f, 0xdca7ba06,
	0xff3d4035, 0x5eb03bfd, 0x2b7438a1, 0x61545bce, 0x0b6adfa8, 0x7f4d43eb,
	0xefc70d16, 0xd46f7479, 0x9013f618, 0xf50a8a6f, 0xd1fbc3ed, 0x0b669797,
	0x1b25163a, 0xbf938d7a, 0x11b2e552, 0xcf21659a, 0xaa968ec2, 0xc91dc778,
	0xad4d7e91, 0xe2bbe7aa, 0xd83a5ead, 0xee2edd2d, 0xfd1a96a9, 0x16a2093b,
	0xba248680, 0xe317e932, 0x39f5e8b5, 0x6c5990d9, 0x5db38797, 0xfb92ab1e,
	0xef9ea93e, 0xb5ef86b3, 0x57826406, 0x13a18843, 0x488246ec, 0xc1138606,
	0xd41270c5, 0x9a16bc33, 0x66864e18, 0xc0205386, 0x37f4ae10, 0xbb83db02,
	0x5d3feced, 0x7640c8b7, 0xdee6e8b9, 0xfb2572fd, 0x2d40f842, 0xf8e97c5f,
	0xc3dea498, 0x432f13ed, 0x35ef9973, 0x3f8858bc, 0xf80c5fb1, 0x838e0852,
	0x9e338f20, 0xe2833918, 0xf9ef8575, 0xcb938056, 0x8f891795, 0xe8dba092,
	0x2f05ebce, 0xc9f3bd15, 0x5e5e2a15, 0x27e606cd, 0x6cee5e8d, 0xba3417a1,
	0x429f7c61, 0x3d27a0f6, 0xb3ad1861, 0x8cfcb628, 0x9ae32a82, 0xd3a6cbec,
	0x51a2fb3d, 0x85482be5, 0x70f4f2dc, 0x7f2d2e51, 0x6fea8e91, 0xe517cecd,
	0x2651f2c2, 0xa93bea07, 0x2c44fa60, 0xe3fbd5bb, 0x74023456, 0x10ce4c6f,
	0xf56ec2e7, 0x4e45b91e, 0xc5f74d5b, 0xf580ab2c, 0x20063b8d, 0x722d7ec0,
	0x4f8bc91b, 0x7695e7d8, 0xb1d1bf41, 0x64d909ee, 0x78feaccf, 0x72b0e905,
	0xb220e575, 0xc59bf79b, 0x280647f8, 0x7c435fc3, 0x5ee22c59, 0xac5fb6ab,
	0x3960c6f7, 0x1a2b2928, 0xd2ebc2d2, 0xf31171d6, 0xef37ceba, 0x33dd4397,
	0x2a0ec9b2, 0x862b8e0e, 0xeb7df6a8, 0x8e0752d6, 0xf3b0eb84, 0xd971823a,
	0x6ab01a2b, 0x4dcbaa72, 0x09c575e3, 0x9d13743e, 0x1f0df406, 0xa1ce76c8,
	0xbbdfd1f6, 0xb2f17f56, 0xc7d2f49f, 0x671c10b8, 0x017bb665, 0x0433abb5,
	0xfa428d87, 0xd87b13dd, 0xf1a37c4c, 0x9cc484b5, 0x74687885, 0xf2cccf82,
	0xf6ef6652, 0x72c232cf, 0xc700b5d1, 0xb914fc43, 0x2ee8155c, 0xfaccf142,
	0xb89609d7, 0x86b02a9b, 0xf3ce59e6, 0xc485a1c8, 0xef899d27, 0xb9663f9b,
	0x53f82a1d, 0x3bad67d5, 0x221aacf6, 0x90882e8a, 0x671dbacb, 0xd20bff3f,
	0xcdb4eebd, 0xb74bcd41, 0xf141586f, 0xe88f2681, 0x8df4ea1d, 0x5b639f26,
	0x58707c2c, 0x058afdba, 0xfbdc7ed4, 0xb7a4196d, 0x1b05b7c7, 0x6aee7dc9,
	0xc844303d, 0x7fd7e689, 0x7d8a5d21, 0xfc8ac4f9, 0xbfce2091, 0x497a6e39,
	0x572f7f9c, 0xf6549df3, 0x1c457ef2, 0x359bc5aa, 0x7be4de7b, 0x978c38c3,
	0x5d44bbf6, 0x6fc7e2ff, 0x167c429b, 0x8b488efd, 0x76d4eb43, 0xf77cdacb,
	0xdfa23ed1, 0x1c51d515, 0xbbf7d05a, 0x2bc7baa2, 0x7e8d0e38, 0xb674f457,
	0x76aa871a, 0x73ff5411, 0xf686da91, 0xd0b8e367, 0xdee0b3ec, 0xc2b13f96,
	0xaa72a761, 0xb87ac1cd, 0x5be70361, 0x78f0f6b5, 0x268af332, 0x48d64bc7,
	0xf86b57ec, 0xe2da7c2c, 0x3e1475a4, 0x65fd883d, 0x7dc5f3f4, 0x488f3574,
	0x5de8066f, 0x50c496c1, 0xdd2fdd3a, 0x20eb9ad2, 0x1e77fc3f, 0x0a647c27,
	0x038b4faf, 0x2be7e52a, 0xe9d09de8, 0xc2be31db, 0xfcf7cb4f, 0xe58ad1ba,
	0xf5e96be5, 0x372d2d0f, 0xd1a9fc81, 0xd1f065bb, 0xa47be038, 0xfdbef28c,
	0x525b7c84, 0xe044a00c, 0x07e94623, 0x00792f4a, 0xd8bf4a8b, 0x7d5d24dc,
	0x5d32e39c, 0x749284ff, 0x8c637d5d, 0x5e031778, 0x38af2067, 0xd1245efc,
	0x1faea579, 0x715ff104, 0xfdc85df8, 0xf37693f1, 0x62db11bb, 0x5f244fce,
	0xded7523b, 0x89976f22, 0x333ecbaf, 0x1579e8ea, 0x6f11b865, 0xbfd0fb25,
	0xb6c679c1, 0x8263ebeb, 0x317ea05e, 0x7cba8cfb, 0x97d14584, 0xf7ab664f,
	0x50c28622, 0x1ba27e5d, 0x4fef82ef, 0x5f30309f, 0x2fe64314, 0xcf088aca,
	0x3d29f026, 0x841a76f1, 0xa87a75bf, 0x75a5e1cd, 0x265179ed, 0xd2e01839,
	0x4cd07fe3, 0xbb07fe3d, 0xb21ef8f5, 0xd4ef8f58, 0x2fbe3d7a, 0x35e3d06f,
	0x5bc7abcd, 0xbab19ac6, 0xe54d59f6, 0xface72ba, 0x57f6bac9, 0xcae9a6f8,
	0x81fd9fc3, 0xf37e7dae, 0x617d5d7c, 0xbd5d52cb, 0xf17d67c6, 0xf2ff08c1,
	0x80337e28, 0x307c3ce1, 0xba5df76a, 0xfa2bbef9, 0xeaa3915f, 0x59fe9505,
	0x4ef09faa, 0x490789fc, 0x6ac6a75c, 0x33cd4ffa, 0x8e389994, 0xae49577b,
	0xa0bd2388, 0x6a9739da, 0x13ca60e7, 0x765c27ac, 0xc4047651, 0x07918abd,
	0x0af1155d, 0xf710afdd, 0x344f8a2a, 0xfb502455, 0x3756f7a8, 0x73ba4896,
	0x57f7e8ee, 0xe5abbdd3, 0x23ee8904, 0xd1897b8a, 0x77b41ff7, 0x18ce5558,
	0x5f78f9dd, 0xbcb4b2ef, 0x6009c612, 0x60c138a6, 0x3d8877e5, 0x7ac720fd,
	0x3734fd99, 0x496f6dfb, 0xdd37ce6e, 0x230c0d64, 0x887cfefe, 0xe20e7a7b,
	0x50e0d3ad, 0xdf53cfd8, 0xc6d17569, 0x0bd39df8, 0x52dde9d3, 0x94b98617,
	0xff751ccf, 0x36bdd373, 0x583dbe5e, 0xfa69c22c, 0x67b8e771, 0x254738d1,
	0xb0a37dfb, 0x4f633bef, 0x663b230d, 0x91fdf3a1, 0x873dee7c, 0x29f3bbea,
	0xa87f7083, 0xc506836f, 0x77b8e7cb, 0x9c9f1c49, 0x44c6c1a2, 0x931aefc8,
	0xc4546efa, 0x7c55b36b, 0x2cdaf169, 0x38a3fe75, 0xe7d462c4, 0x62de5bb3,
	0x694b2cbc, 0x7abce357, 0xbfc71d87, 0x246da86d, 0x8e72f3df, 0x5f388872,
	0xc886df8b, 0x5ebec4df, 0xb2d5fee8, 0x38ba9394, 0xee4f9e1a, 0x9d194f35,
	0x5bef0b0f, 0x6d747f8c, 0xa3a1db2c, 0xef39536b, 0x93bf1e18, 0xebb30af3,
	0xe7baf7f5, 0xf1d21c36, 0x11ef3cdf, 0x7fb07d5d, 0xf70434c8, 0xf0797c1f,
	0x7f115ba4, 0x8a592f1d, 0xba458e29, 0x1113923d, 0xca1f0767, 0x5df34899,
	0x78a79f78, 0xbdea6d1d, 0x879f6d5a, 0x1cb9073d, 0xeea304f4, 0x71757939,
	0x7fcd06af, 0x9ff25c80, 0x473f5243, 0xcb9c796f, 0xd93c4573, 0x6d2fbea6,
	0xb697df53, 0xdb41efa9, 0x6d9ff7d4, 0xed4ffbea, 0x049b6e7d, 0x3257ba4e,
	0x985e524b, 0x73efc697, 0x759f699b, 0xf405434b, 0x30aeb17e, 0xf9924738,
	0x398bee7d, 0x9f7d7a03, 0x2ea1205b, 0x76739d38, 0x67f291ba, 0x649dbcfd,
	0x99f7ffb1, 0x2cd944cf, 0xcf1fe3e4, 0xef174db4, 0x34addd75, 0xec8351ce,
	0xfef5be27, 0x64f3e24e, 0xd3cd0670, 0xeefde22e, 0x9ce2399b, 0xfc145764,
	0x6bd08e6b, 0xa56150ff, 0xbf3660fc, 0xe16f5ab7, 0x1f3856f7, 0xeef37bbf,
	0xe8daf910, 0x7f237177, 0xfe93f16f, 0x873df2d0, 0x3339c472, 0xb92397bd,
	0x8b53ffeb, 0x0c172f78, 0x75f7a30c, 0x45c9ff74, 0x9c0fbdf2, 0xce5dfde2,
	0x3077c8a6, 0xfbd47287, 0xee83b779, 0x9ecd5e7d, 0x9f4987a3, 0x9f71ceac,
	0xbea03d61, 0xdf89ab1b, 0xb7defec9, 0x493c0f98, 0x06b1ae78, 0xe6aa9f85,
	0x4fc2fb03, 0x63c082c7, 0x77e16979, 0xd9ef116d, 0x5e1a9d78, 0xc78675b4,
	0x6bff3f39, 0x7cad2d79, 0xd9fdc37c, 0x7f884f24, 0xa5946f91, 0xe97ad3b9,
	0x9c57303f, 0x754acdc3, 0xf794b949, 0xbf7917ab, 0xfd347f30, 0x87d243f0,
	0xdebd6c7b, 0x47fad7d7, 0xc766b3ef, 0xee07c61e, 0x2fed0e73, 0xb9099f62,
	0x68ecfb11, 0x9e58f03d, 0xfbfbe972, 0x2dc8efa6, 0x4d6e30fd, 0x8e8f2dea,
	0xffc22656, 0x87fd68b2, 0xd1fdf51a, 0x753ca6f1, 0xfa35c90b, 0xb8d4db27,
	0xf12fec86, 0xb77f6685, 0x460e3159, 0x770525bd, 0x79a7feb1, 0x93efff89,
	0xb5076cbc, 0x84a3467c, 0x06f28e76, 0x176c15ee, 0x0e6dcbe4, 0xc86ddfe2,
	0x7be2017b, 0xf39633a3, 0x73f151d8, 0x84bbac6d, 0xcff2b5e8, 0xbe2883e5,
	0x64f6fade, 0x76134e35, 0x9fcab469, 0xda7e69a3, 0xf3025e47, 0xbeba916d,
	0xfb3d6b62, 0x2bc063c3, 0x9a85bc8b, 0x4bbb5907, 0x1ffddf17, 0x0f9284da,
	0x00004210
};

static const u32 usem_int_table_data_e1h[] = {
	0x00088b1f, 0x00000000, 0x51fbff00, 0x03f0c0cf, 0x022aa78a, 0xc3033ab1,
	0x06060d6e, 0x06064d03, 0x1c840631, 0x373fb0ad, 0xb177fa65, 0x01ec3030,
	0x7c407de2, 0x980b8800, 0x990a1818, 0x242fd788, 0x0afb608a, 0x03083032,
	0xfa40a2f9, 0x4c50108b, 0x04418184, 0xf2064fc8, 0x1bb881eb, 0x6281a388,
	0x21f4804b, 0xc40d5e20, 0xcdf8a2a2, 0x7f202317, 0xff951854, 0x577f8d11,
	0x037ebf08, 0x76f2fc11, 0x61b1e404, 0xe3f22b66, 0xbd0283c3, 0x2ad78103,
	0xcafff2a0, 0x00f03031, 0x211542c5, 0xf24875fc, 0x7fb140e9, 0x39f61072,
	0x015c6009, 0x602bd6e5, 0x503cf737, 0xae5013fe, 0xf7349158, 0xf2a0e914,
	0x34208c5b, 0x711dda00, 0x0003a8d3, 0x00000000
};

static const u32 usem_pram_data_e1h[] = {
	0x00088b1f, 0x00000000, 0x7de5ff00, 0x45547c09, 0xbedd77b6, 0xee92774b,
	0x1090274e, 0x5849d0b6, 0x05b36035, 0x2aced050, 0x4056904a, 0x2c3b1151,
	0x19176421, 0xbaf2ce1f, 0xd14112c3, 0x8be33b89, 0x1330a363, 0x5180d419,
	0x206c06a3, 0x13383a20, 0x19705066, 0x9b6459a7, 0x36e09a40, 0x757c3833,
	0xdcedd54e, 0xb898e9db, 0xfbcdefbc, 0x4ac3f8be, 0xcb5baadd, 0xea73ff39,
	0x2b73a9d4, 0x6c409292, 0x04b90883, 0x3210d73f, 0x24842255, 0x7603a474,
	0x8fb28dae, 0xebbac424, 0xbda1a8de, 0xd737e909, 0x45a288e0, 0xc7133deb,
	0x7909971c, 0xea732046, 0x2a4909d3, 0xc652a9aa, 0x6da174d1, 0xa427688c,
	0xc33dd24f, 0xd212c79a, 0x99eb4dd7, 0xa25cfe08, 0xab657eff, 0x90692389,
	0x91ae0af3, 0x69aafd1d, 0x1fe942d2, 0xf9fd4d01, 0x4a9d15c4, 0x2fccf1c7,
	0xcdbafbaa, 0xfd003c84, 0xa752810e, 0x71d06481, 0x2cdebaf1, 0xbfda3ffa,
	0x56f8aad7, 0x0688840a, 0x09112c7b, 0x120f4989, 0x9fbc2f78, 0xc3953d27,
	0xacde1924, 0xe859728c, 0xeb94e87c, 0x21cbd423, 0xcd41d202, 0x26764ec7,
	0x57b8e979, 0xbce2237d, 0xa425f557, 0x2447be85, 0xf4d08d87, 0xc847125a,
	0x321e4278, 0xf903ee0f, 0x243f3b55, 0xec7eda76, 0x6af120b8, 0x21eb5fda,
	0xe4246ec4, 0xd3098f3e, 0x4f1b1e55, 0x187d8893, 0x763dab21, 0x8679574c,
	0x80ff7a63, 0x29325a47, 0x06bec5fd, 0x59111d1b, 0x66c9bf6b, 0x4f68ef4f,
	0xca6f9b8e, 0xc5321074, 0x484cec9b, 0x0c12f5a1, 0xa9495c84, 0x9455f344,
	0x1d884397, 0xbceca5c7, 0xa4f3c70e, 0x9dca32ad, 0x345cf1de, 0x3fcc3710,
	0x29df9c66, 0x38c63a52, 0xbd92596c, 0xf4fe39e3, 0xdecfe7c6, 0x717c029f,
	0x3cba034f, 0x2f011c49, 0x38adddd0, 0x2bfad136, 0x52d24765, 0xd0a8aeda,
	0x0e19d2f7, 0xe31db1a4, 0xa4f4059c, 0x593991fd, 0x840dfe3a, 0x7bc02471,
	0x37c019f6, 0x6df183b3, 0x022be025, 0x76f1e65f, 0x369cd956, 0x89072786,
	0xa6d12784, 0x5d3993c7, 0xc4fa478f, 0x9e72e276, 0x17aefda7, 0xa5c9df2a,
	0x312ef4f3, 0x67d13638, 0x011a84fd, 0x2bdb57da, 0x57ec0621, 0x922df7cd,
	0xdae181fc, 0x0f38bcf6, 0x6025bcfa, 0x2dbcfcea, 0xe802782b, 0xb6557de8,
	0x1053a26f, 0xaff8b2de, 0xbfdbf4a1, 0x6919f041, 0x0623bfde, 0xf6b67c71,
	0xd2919f46, 0xa368e779, 0xdd9fea13, 0xecf98998, 0x4ab7de57, 0x15ecbcb4,
	0x61bc8251, 0x806b69c7, 0xd8c2a7d2, 0xf455d0f2, 0x9115f079, 0x4ddd8b3c,
	0xe09efa43, 0xb35f2063, 0xcb14617c, 0x39d86d96, 0x6a2dda0f, 0xda289234,
	0x8bebd94e, 0xe68ab86f, 0x0993ef17, 0x54db2954, 0xf9a3f4a5, 0x1ea13e25,
	0x7c762bf2, 0x65b4fd8c, 0xebe02291, 0xc52dc019, 0x25b59b65, 0x5e7d3671,
	0x079adbec, 0x08b78bf5, 0x52214a0e, 0x13f3bb5c, 0x41b8bf68, 0xf6d22c1e,
	0x8862ea4b, 0xeca7435d, 0x00dd1657, 0x477b2de3, 0xa4f61426, 0x0adde2e8,
	0x35489df0, 0xd963c80a, 0xc01587a6, 0x3ecf19e9, 0x77a547ec, 0x1fb4f3d9,
	0x8bf95efa, 0x56a60382, 0x3b38606e, 0x9cd47af7, 0xaf30cce7, 0xbc28652a,
	0x0a7dfaff, 0x2bec5bd4, 0x0eca3578, 0xe4a0dbe3, 0x376b38c1, 0xb91a8528,
	0xbdfba929, 0xd6275c6e, 0xa771f5a7, 0x9a91c677, 0xab72e19e, 0x88a98be6,
	0x3e487ca1, 0xfe0d46e5, 0x1e9819e6, 0x8913a928, 0xbc0e023d, 0xf27933ef,
	0x36f8b76e, 0x6bf074a5, 0x6efe8da9, 0xbb57e0ef, 0x0a4ff38d, 0x0118dc66,
	0xfd710fdf, 0xc7f5c351, 0x683fa023, 0x1fd718fa, 0xb1fd704f, 0xe7c0e3de,
	0x6226794f, 0x6271eb5a, 0x54cf6bfa, 0x171e7d4c, 0x33d67bd6, 0x1e8dd307,
	0x8dff3e37, 0x3ad308a7, 0xdf3e254f, 0xe98e59ec, 0x9f178f16, 0x8359e8bf,
	0x06a7bd69, 0xf59e6dd3, 0x7c783698, 0x4f55ef58, 0x9e8da61d, 0x86fe7c7a,
	0x26d311a7, 0x1dd31f8f, 0xfa9a5fc0, 0xee982d3d, 0xb4c61cf2, 0xf7c013d9,
	0x614e7af6, 0xddd38eba, 0x4a64993a, 0x27566e94, 0x9f183d41, 0x6994ccef,
	0xf2c5de3e, 0x99bd7389, 0xba27cd0a, 0xb1d29e69, 0xd33fa95f, 0x2556eb08,
	0x39fe4f2b, 0x7cd132c9, 0xa79597b2, 0x456673ae, 0x0d6a7cd1, 0xeb5a1f2b,
	0xf9a68acd, 0x7e563ea1, 0x567f16d9, 0x565fcd0c, 0x3547cacf, 0xcd336c91,
	0xfcb3f28f, 0x6ccefd98, 0x698fcd0b, 0x4f8cf961, 0x9a56d9bc, 0xf7b008cf,
	0x67f56caf, 0x95fcd2c7, 0xf57e5641, 0xa3639245, 0x8089abf9, 0x66732cf9,
	0x67cd1c4e, 0x6f3e58d9, 0x8f648140, 0x721dbf80, 0x58a10160, 0xe55aaf88,
	0xbcd12694, 0xaa9bb812, 0xeab8323c, 0x65fbcc41, 0x33ca10b2, 0x79609eaa,
	0xf2832c85, 0x60cf55a9, 0xc76c977e, 0xeaaadbf2, 0xb35d129c, 0x2c762976,
	0x8adaad2f, 0x13b2cde5, 0xeab3ffcb, 0x566f2c0d, 0x535e589c, 0xf7cb1bb5,
	0x7f2c6eca, 0x963f6ab6, 0x58dc55ef, 0xf7aac8fe, 0x2f34399d, 0x6166dc1b,
	0x776be83c, 0xa963ea11, 0x71f4093e, 0x9fdfd735, 0xbaa675f3, 0xfd04e2af,
	0x8c9be3b6, 0x63a144e7, 0x4df1d95d, 0x5d606fe1, 0x0824eda1, 0xd08eb009,
	0xdbeec476, 0x135ffab9, 0xfd5ced75, 0x9db522af, 0x544f1c64, 0xf1d9dacf,
	0xe3f52baf, 0xdab157f9, 0xc76c30ce, 0x5d79b3d2, 0x7eb2697d, 0xd54a973c,
	0x4ed81c76, 0xe3c6cf5c, 0xdae82797, 0xd58bcbf1, 0x3b612676, 0x8f1b3d09,
	0x6ba49953, 0x512ca9c7, 0x76c2c9db, 0x1dacf6fa, 0x7e9572bf, 0xda894a3c,
	0x676c34ce, 0xe5e6cf60, 0x8fd14e34, 0xb6a658c7, 0x9ef90b33, 0x7676b3d2,
	0xd9f4f459, 0xe7d10965, 0x48676c0e, 0x6595e6cf, 0xcb27d3d5, 0x214fa21a,
	0xcf446bce, 0xd565d9da, 0x359767d3, 0x6c0a9f44, 0xe6cf6467, 0xa7ab1595,
	0x886c564f, 0x9db1cb3e, 0x4f1b3dd1, 0x3e9e8273, 0xfa2109cd, 0xe33b6154,
	0x9c9e367b, 0x727d3d44, 0xb9f44312, 0xa93ce91f, 0x2734ed67, 0x9cd3e9ea,
	0xa3cfa218, 0x3d299e38, 0x1f4e579b, 0xfa727d3d, 0x8b53e884, 0xebba64ed,
	0xb6843c70, 0x9dbae963, 0xf4f503bd, 0x44303bd9, 0x4ed84d9f, 0xad276d2e,
	0x92f276fb, 0x4bc9f4f5, 0x45e7d10e, 0x3d75cfa4, 0xb26f676b, 0x937b3e9e,
	0x0d79f443, 0x67bd33c7, 0xa41bcaf3, 0x20de4fa7, 0xa46b9f46, 0xd0ceb8d1,
	0xfb01d3b5, 0x64076bb3, 0x6071853a, 0x68bcb31f, 0x7bb01073, 0x219ed544,
	0xd6914e2d, 0x1b896f37, 0xdad13f73, 0xc36f5935, 0xcad42c78, 0xb135dad3,
	0x7675a313, 0x5e339c54, 0xb535ef97, 0x827eae9f, 0xde57552b, 0xba65ce67,
	0x31eebef2, 0xa2ff7cba, 0x07f5752b, 0xf2e96656, 0xaf5f9683, 0xbde29fab,
	0x5b4f9749, 0xfeae9b73, 0xbaf99a90, 0x8beb61f2, 0x7c23e575, 0xcbf9754b,
	0xabaa7eeb, 0x857eb23f, 0xc68afcae, 0xa3e575fb, 0xf2e88ffd, 0xa53df763,
	0xe5be3fab, 0x84f95d59, 0xe5759bc3, 0x74db0293, 0xbd4eabf9, 0x253faba1,
	0xbf974bb8, 0x7577ebe6, 0x9fc933f5, 0xe9b6f6f5, 0x5cfd5d63, 0xf95d31db,
	0x0b7f49b5, 0xfbf553b3, 0x849995a2, 0x2afbafed, 0x2dfaaf68, 0x7e95e60a,
	0xb14fb666, 0x538fda14, 0x16bb28fc, 0xfc537bd8, 0xb5086600, 0x15fb320b,
	0xe7d00b0d, 0x1ee95cf7, 0xefcfa366, 0xd857dc51, 0x1437d822, 0x8249026f,
	0x34806ed4, 0x993efcbc, 0xffab3de1, 0xe847a1c5, 0xe08615fb, 0x7f9a38d0,
	0x67eccc46, 0x196f0f18, 0x168eaed0, 0x8bd42549, 0x37dc1236, 0xf19297dd,
	0x0f23579c, 0x3b52066b, 0x7768e843, 0x424eec8d, 0x7c456a3b, 0xd535d815,
	0xfabce903, 0xe2187c51, 0xd3077a77, 0x261607f7, 0xa8d43ec1, 0xa8707db0,
	0x9ff6857f, 0x065ffd8e, 0x6c0c3bfd, 0xbfde185f, 0xaea27531, 0x9172537f,
	0x42937fae, 0x5251b7fb, 0xfbc7e8ae, 0x7dbee137, 0xf61fa1bc, 0xc22e4c6f,
	0xe853effe, 0x7fdb4bbe, 0x2bffa874, 0x0de0090d, 0xa9fe62e9, 0x9fe7ea57,
	0xbf9fac5c, 0xb39fe6c2, 0x1ff79522, 0x35cff38d, 0x27f9b2a4, 0x1bf9b317,
	0xfea1bb59, 0x5ffa21ad, 0x7577f30f, 0xc9b4ff35, 0x2a0ff9fa, 0xc8dfcfd5,
	0xe2b59ffa, 0x19bfde32, 0xb86d9ffb, 0x507fcd8c, 0x18aff629, 0x8fc00edd,
	0xd2ba3fd2, 0x0327fb47, 0x03ebe2a8, 0x40fda170, 0x0a9e3c3a, 0x8643d50d,
	0x3dc3a454, 0x5f6f0cd1, 0xa1bc5346, 0x73e2f33e, 0x939aa3e2, 0x39caabee,
	0x64b64bd6, 0xb0f7a02a, 0x4590913c, 0x1b0ba87c, 0x7937c445, 0x421be8cc,
	0x51ae7bc7, 0xe17e42f4, 0xa07c5363, 0xe48c2b5f, 0x27bc174e, 0xff3c3f11,
	0xcf91f1ec, 0x9e15e76a, 0x4f91aa2e, 0x7813f244, 0x4af0c8b3, 0x0097be3a,
	0x51fc9a04, 0x8d838fba, 0xdf7427f1, 0xe7fee843, 0xfbfacc98, 0x20f7ee94,
	0x3dfba01f, 0x2a9338dc, 0x3af14fe6, 0xc74c1fdf, 0x8fea22ef, 0x0b79e713,
	0x4f6d148a, 0x747bf262, 0x7e03e09d, 0x863cb9dc, 0x3c63bf12, 0xba5ede05,
	0xd591857c, 0xf8275e0f, 0x0db0159e, 0x46e7d037, 0xf1811ede, 0x1b1cfcd2,
	0x8ed0e77b, 0x2b057be9, 0xf4d60b21, 0x68e8bca7, 0xca712667, 0xb3fbe87d,
	0xe0c81597, 0x8411693a, 0xaa1fe081, 0x3f132058, 0x09bd9bee, 0x83839d24,
	0x1b36f78e, 0xa746ff6b, 0x3feb5c7c, 0x9c9b2399, 0x399e3a2e, 0x7f8e2205,
	0xf97d54e6, 0x9c623b47, 0x5d345186, 0x33f628f3, 0xbf2fa5db, 0x7f3e8e65,
	0xa79f5bab, 0xeb0caaeb, 0xe145edea, 0xe85929cf, 0xe886e73c, 0xc74a074a,
	0xc3a70779, 0x57b2951d, 0xedba57c7, 0x7072d456, 0xce09b884, 0x3b17df0b,
	0xb973bfd7, 0xd5e05f3e, 0x09ac17e7, 0xe6e39f6b, 0x51ffe704, 0x4f4d07c0,
	0x3d283e02, 0x747c738f, 0x3e3d55e8, 0x834d0e6e, 0xc79d43e1, 0xe0b18909,
	0xc7c32d44, 0xc8989aa2, 0xe1082878, 0x97c5a9c1, 0x1c79878a, 0x78e17f0f,
	0x8f5ebc58, 0x6f895bab, 0xff7d1275, 0x913b75f6, 0x05081f4f, 0x533f0f0c,
	0xe1d010f1, 0x10f1cdc1, 0x1c79bfce, 0x65eef30f, 0x67e70878, 0xb021e380,
	0x524c82fe, 0xf295f33b, 0x7ca79741, 0x0dbbe308, 0x1f9450fd, 0x3f30f111,
	0x713a6f34, 0xcbc05f9a, 0xe38bf13a, 0x8153cb01, 0x84e904ec, 0xae75a7ef,
	0x2e84f54f, 0x647d78bf, 0x6e3457fe, 0xf35c7758, 0xf9feacbc, 0x66bf5a75,
	0x5d56dd49, 0x75ef897e, 0xebc5fd5d, 0x8bf2ea77, 0xd5d1de6a, 0x80e6b05f,
	0xfde05f2e, 0xceff5750, 0xe57447e5, 0xd69e5477, 0x745edf95, 0xd5bf975e,
	0xfd5d77fd, 0x0f08e65b, 0x5db3f36a, 0xeb6a0f51, 0xa71a9ccf, 0xece8dfcb,
	0xd86fabab, 0xe0066231, 0x22fbff71, 0x0be3fb01, 0x7ff449c7, 0x1d90e17e,
	0xc7b8e750, 0xc270728e, 0x53d31c33, 0xc9ca071e, 0x4c44cf19, 0x36ee35cf,
	0xd742bac3, 0xd97042d1, 0xa91f170f, 0xd600335a, 0x6feb8275, 0xcabeb8ba,
	0xc163f34b, 0xcef4a638, 0xff10af5f, 0x58044258, 0x82b8f89c, 0xd03ca6a2,
	0xba7af94d, 0x5ceaf450, 0xfc881f9e, 0x8291e2bc, 0x7e08b641, 0x26b90eef,
	0x6a4ec1fd, 0x5e3fc2eb, 0xf697102a, 0x502b2139, 0xedcddc0f, 0xe9855284,
	0x7d6dd28b, 0xf21588b3, 0xdf95a1fe, 0x153d5fd6, 0x93803eb2, 0x2f3c9d34,
	0x4eb97f5e, 0x3ef013df, 0xc6de0027, 0xd4979eea, 0xaf7ba55d, 0xe388a775,
	0x425d072e, 0xe272edd7, 0xfac2299a, 0x3c9ddfec, 0xd38c2473, 0xbd044b39,
	0x768098d5, 0x6ea7ab64, 0x9d379c1d, 0x7a63d4f1, 0xe988d3ca, 0x1d7f8f09,
	0xf71d079c, 0xa8f4c3ec, 0x80d305a7, 0x9fa630e7, 0x7e98027a, 0xe98539e2,
	0xa6209e47, 0x635f3d87, 0x3c8781fa, 0xf41ced08, 0x93fd3098, 0x8b6986c7,
	0x73d30927, 0xa3f61f1e, 0xb8775dca, 0xedd7c53b, 0x08bf8033, 0x6567bb38,
	0xc99ad563, 0xa9fb381d, 0x4ce216f8, 0x7afe73a5, 0xa243c723, 0xb0550f0e,
	0x780f1bf7, 0xbd7ca6e9, 0xd5d871cc, 0x2bcb91fb, 0xc1effd9e, 0x2edc6bdb,
	0xeb78befc, 0x30ff53c0, 0x8775a53c, 0x3f11a7a7, 0x19af4f1c, 0xe41d6c6c,
	0x9f807a78, 0xfbf7865b, 0xfbcec8ae, 0xf39df642, 0x6a90033a, 0x21373f29,
	0xdbe62a64, 0x692bdf79, 0x03b416dd, 0xdd61c37d, 0x8ffe1f6a, 0xd0ee70a1,
	0x3f32987e, 0x85f9eba5, 0xba6ba4e3, 0x543f713b, 0xef4ca3e8, 0x2a3cb9d5,
	0xca35d19a, 0x3192a640, 0xf21dac84, 0x74fcc71b, 0x1e244bcc, 0x6e39f7de,
	0x976844b4, 0xdf40d6da, 0xd2bae8ee, 0x6828e5f2, 0xff53c4ef, 0x35f480cc,
	0xef475f6e, 0x27ced116, 0x401ce7fe, 0x64bad0df, 0x7f812474, 0xb144383e,
	0xa6409da1, 0xbde7e9e9, 0xb5bf475e, 0x69f9ea29, 0x6fd2124d, 0xfb4397f0,
	0xdd7e80f6, 0xe8eef7e9, 0xfde61f39, 0xeecf40df, 0x7a7763f4, 0x2fed3891,
	0xb7f9d236, 0xe63918ed, 0xc1e83b7e, 0xeaafb654, 0x79eade82, 0x6478f85c,
	0x7af7c249, 0x44b6e38a, 0xc92dc715, 0x285d6e70, 0xf6fdb0da, 0xc0b16186,
	0xdd3b5097, 0xeb7853f0, 0xdfb0c92f, 0x6fa29b3f, 0xbe832bef, 0xcf7df6bd,
	0xb5df6159, 0xdac16934, 0xa0f811e3, 0x55f565a6, 0x3b5acd6b, 0x6f9f51b4,
	0xd6a611af, 0xb1ecb8e3, 0x3ac246b3, 0xe996b951, 0xaa98e5ed, 0x2a4d2ced,
	0xd4ce7ec4, 0xfdb2c5a5, 0x83e98f9e, 0x2fa8712d, 0xb08a78ce, 0x9e3d8ffe,
	0xc751daae, 0x39034843, 0x4c7d0266, 0xaebad2cb, 0xa59e25df, 0x97f015cf,
	0x4bf92692, 0xf44d13b0, 0x77d825df, 0x6af30910, 0xa2f515bb, 0x3c0578d7,
	0x8feba2df, 0xcf5767be, 0x7ea52f88, 0xe448dc9b, 0xba5b8a84, 0xe3cb5c5e,
	0x96ea4a43, 0x65dad5ac, 0xe977f565, 0xf78d15f2, 0x71dad5ae, 0xd50bf025,
	0x9052a4bf, 0x1ca53700, 0x79926d46, 0x97c7408d, 0x8007410a, 0x2bd5815b,
	0x37140533, 0x81b6747d, 0xf1abadf1, 0x5298f19d, 0xc8a39e20, 0xc8e78354,
	0x7223f545, 0xdb399d60, 0xd61132b0, 0xfdb112df, 0xf784571e, 0xaf81248b,
	0x6f50722f, 0x107c73e7, 0xde66aeda, 0xa21cc7f4, 0x1ab7cd17, 0xbc265f98,
	0xbb797bdd, 0x7ca7d1dd, 0xabbc81cb, 0x54e99dec, 0x715e78de, 0xffa45ea3,
	0x49d07465, 0xe4aa5fa5, 0xeda257ba, 0x411dd717, 0xd929c5ff, 0xdf67f43b,
	0xcf3b2fa2, 0x22749ccf, 0x2f2f3346, 0xe67e8169, 0x111de44f, 0x531f2dfb,
	0xf7fa7e3d, 0x443d0132, 0x9a5ad22e, 0xd6e6c071, 0xefb1d190, 0x9250df99,
	0xfd3ef40f, 0xf7dc34ea, 0x2b2e242d, 0x64d481f2, 0x2ce73ec0, 0xcd7c6031,
	0xeb27f259, 0x9e1f0d58, 0x33a41496, 0xd51d07dd, 0x83ee8f8e, 0x0fba7974,
	0xc90be5d2, 0x0710894d, 0x4c98f851, 0x4fce027c, 0x64a0fe57, 0x931776c3,
	0x6bb06aca, 0x7ce1ff54, 0x53fa911b, 0xdaf65ebd, 0x740519d3, 0x66251b1c,
	0xfae7ab0f, 0xef8ea84b, 0xeb8bcb4b, 0x5a4e2837, 0xec61ac7e, 0xd34354cd,
	0x10d57df7, 0x457de0df, 0x709738c0, 0xf1d77efa, 0xb5578f87, 0x17c53a97,
	0xd59471f0, 0x045f4e09, 0x78936d9c, 0x0f5f0d3c, 0x35bcc176, 0x843fa47e,
	0xcb0a3fe5, 0x7fcb089f, 0x4dee796f, 0x2a9cf274, 0xf800ffb9, 0x7d85f904,
	0x110520b2, 0xfdbbdfcf, 0x7fed4ea4, 0x3fb6a3f4, 0xb4672f40, 0x6a3f13fd,
	0x8d3b83fb, 0xfb523dbf, 0xf0bdaf65, 0x1597c42a, 0x95b8f4bf, 0xb4e33b50,
	0xa0e89354, 0xb4dd2ffc, 0x38380ada, 0x80ad7925, 0x713ed3e7, 0x3e822faa,
	0x78ab211b, 0xf0059a70, 0xb4afc273, 0x1f9b33fd, 0x2df601b8, 0x6d926e5f,
	0x33acbfe8, 0x4e548dfa, 0xe4961bcb, 0x3f985193, 0x9df7f2c2, 0xa8df2117,
	0x6ff167c7, 0x78844f1f, 0xfe948a1c, 0xfbd3f406, 0xbe503f71, 0x583cb3f1,
	0x10482bdf, 0x3dfc2ce5, 0x78ebffe8, 0x940a7f5c, 0xe8e5ced8, 0xf7844910,
	0xc3454fd9, 0x2b45e703, 0x049dd7a4, 0x7277427d, 0x7f0987e8, 0xf9db88af,
	0x6f4b64fd, 0xc81363d4, 0x2a63d004, 0xd98f885d, 0x7f9f2bf9, 0x3a11d472,
	0xbf8dd6ae, 0x7a1a0ab7, 0x5ed6f2a9, 0x3799e0bf, 0xcdeb5dec, 0xb51e5473,
	0x2ebaa4f6, 0xfef91bd8, 0xa5a589a4, 0xf10adfb2, 0x641ba553, 0x2e3e9787,
	0xdfb9e17d, 0xe3fe053c, 0x218e8d0f, 0x1792fdb4, 0x25707cf6, 0x956c97cd,
	0x69b3e77b, 0x0ec48598, 0x7fd054fe, 0xf074c7cb, 0x3de5f8a3, 0xc25dc40a,
	0x77c79ff3, 0xeb64a5f0, 0xec8c854e, 0xfaec8f4c, 0x1cc04a9d, 0x47f53f81,
	0x5adec0f2, 0x0a57fcf9, 0xef4ed4b8, 0x949f4810, 0xb0dcf408, 0xa031ed07,
	0xf393f213, 0xb0bfc42b, 0x2f9415fa, 0xf9c3d7a0, 0x9fef5e15, 0xbb40bf5c,
	0xf142d710, 0x101be2fd, 0xd191f677, 0x7a287401, 0xcc2b6ef1, 0xc954a4e7,
	0xeaf4fe70, 0xbfed2744, 0xda26f648, 0x8bcf6530, 0xc413fd7e, 0x3f03e2df,
	0x41fe6449, 0xae035f67, 0x30bede55, 0xb3b545cf, 0xc4859e71, 0x7a2c388d,
	0xbe81745a, 0x532242fc, 0x939046b7, 0x4e4e5c0d, 0x4b994b3e, 0xf61279e7,
	0xffdfa0e3, 0xe136fa24, 0xf42ee5be, 0xcf84fe3f, 0x986c5a85, 0xf8c4c2ff,
	0x5b321ff5, 0xef580837, 0xbc6efc5a, 0x74f805af, 0x0fb3a066, 0x1055739c,
	0x21e9cbc9, 0x8aeda25c, 0x30fb7207, 0x94bb113e, 0x76a3dfc1, 0x873c3657,
	0x33b22dfa, 0x3dee946a, 0xa3a52972, 0x7fbc65ff, 0xb068ee3a, 0x46264e97,
	0x10ffffb6, 0x5d7403d2, 0x234ce0d7, 0x37fe4cef, 0xaef265ae, 0xc6efbfca,
	0xf9fe50a9, 0xf0472641, 0x7497ac1e, 0x583efe5c, 0x809673be, 0xfc48c1fa,
	0xa37ce491, 0x5f5ce5cc, 0x3a178e1e, 0xd588497e, 0x89fa06e0, 0x3da03e47,
	0x7d18f855, 0x2b47a35f, 0xe76b5fa0, 0x5e395576, 0x2d41f5cc, 0x3bcb83e8,
	0x65a901f4, 0xbb6ba07a, 0x61fccbd6, 0x4f37efb2, 0x7952fc81, 0x7e41daf5,
	0xffcc1765, 0x7f765b6f, 0xdb951b70, 0x72abd5bf, 0xe1abd7ab, 0xedb45b72,
	0x1b5f1827, 0x1b7fb72e, 0xca224950, 0x511e7d2d, 0xfe04076e, 0x4aaaf447,
	0x74613dc7, 0x5764f554, 0x93d70cf4, 0x748ed96e, 0xf493d70d, 0xe8c920e7,
	0x8715478c, 0x7f8afe2a, 0xf4083657, 0x2aa70851, 0x5538430e, 0x6f3e1871,
	0xcbc31d3d, 0x1e5f041f, 0x2ebe579c, 0x694679e3, 0xa5bb8b13, 0x3fededef,
	0xc4e5e90e, 0xecd48e65, 0x9b5bdfed, 0xebe585f7, 0xc33beac3, 0xfab0aef2,
	0xa57cb0ee, 0xe3697eae, 0x0e20856e, 0xe27abafc, 0xc722fff2, 0xadc246c6,
	0x1a93ed8f, 0x57102bce, 0xe20e615e, 0xe20af2fb, 0xe0c47885, 0x69cf1176,
	0xab8d28da, 0x25b09fc1, 0x7aa5e7c5, 0xdb147564, 0x941307c7, 0x6d7bd06a,
	0x1e35a0b6, 0x3ecc51f2, 0xad05736e, 0xf33b1a71, 0x7a889348, 0x1c8be03b,
	0x16574f1f, 0x8ba073e4, 0xfcf579f8, 0x3ada2da9, 0x15cbfa0a, 0xc1cbc9cd,
	0x3a2353bf, 0x616948e0, 0x38562dd5, 0x4a6b6a07, 0x3e87319b, 0xc88ef45f,
	0x4ebc5cc2, 0x7f66afa9, 0x9f788a71, 0xbc402c98, 0xc9c43aed, 0xdfb62682,
	0x322eb858, 0x7bf98bee, 0x0a65e685, 0x4fba57e8, 0x473daa38, 0xaa29db51,
	0x34de7b0d, 0x0d47cb8d, 0x378babee, 0x7cddcbea, 0xe1423a5f, 0x3268c776,
	0x990bef9a, 0xe7eb845f, 0xc67d315c, 0xb687ca1c, 0xd231227d, 0x88937b7c,
	0x22df687c, 0x45afc0f8, 0x4fdc09bc, 0xf1b45419, 0x4720ade5, 0x57d6bac3,
	0x25fcafad, 0x978067e3, 0xf51e3f57, 0x7d6d345f, 0x6fa1c3f5, 0x43b5fe42,
	0xce931fc9, 0x4477b3f5, 0xdb7c39e1, 0xbce20b0e, 0xc97bfb6d, 0xebfc833f,
	0xb38c0746, 0xa357c76d, 0x2b6d3700, 0xefa0458c, 0xbf3206da, 0x5fedcae8,
	0x3ae00a8d, 0x37f90abb, 0xff98514b, 0x9f9fe9a6, 0xa521bd0a, 0x823b02b3,
	0xbc57abc7, 0xd823e511, 0xda1957fe, 0xe87e2def, 0xdc79ca7c, 0xcc859b45,
	0x8be306d9, 0x15057163, 0xae7a4e6f, 0xd65ff68a, 0x405953b0, 0xfadfb3cb,
	0xa7c61466, 0xd1f6636f, 0x6bf03939, 0x53b82b88, 0xa652b819, 0xc2073afc,
	0x23da8fd4, 0x906cbcca, 0xf974ce97, 0x3d54fd06, 0xff3dc7a5, 0x3821e86b,
	0xf8b39e99, 0xfbcc024c, 0x8c7e9fef, 0xe22345fe, 0xdfef9d52, 0x6ed0abea,
	0x8fde6ee9, 0xfebf6c2b, 0x05bcceff, 0xdde64f7f, 0xef3e6ff0, 0xe23b152b,
	0x3a0e5c31, 0x3dfb7ce3, 0xe2c17f98, 0x10f6f1c0, 0xcdff07ef, 0xf99dffe7,
	0xddf28dbe, 0x2fbcfdda, 0xbbcf9bfc, 0x33bfbe6b, 0x06ddf38f, 0x6f1594e7,
	0xfbe3837d, 0x97ae7aae, 0xfce77ff1, 0x68debb55, 0xd264b570, 0x3521cdf1,
	0x6e2c3016, 0x0fdf684d, 0x81c68ca1, 0xf186f79f, 0x96e761ca, 0x64639a6a,
	0x305927fb, 0xcc90bee0, 0x90bef816, 0xe06ea7ed, 0x030dc5f6, 0xbd7ed10a,
	0x7cecc9c1, 0x995cb922, 0x6f6e20e3, 0xa6fd03a1, 0x3761cc64, 0xe14f67e4,
	0xf2befd79, 0x0a71020f, 0x21bf8ed4, 0xb03eea79, 0x900c6767, 0x1e9646fc,
	0x2b7df481, 0xbf513e7f, 0xadd5b9ef, 0x4732dfcf, 0xdbcd9f9f, 0x2b8c19bb,
	0x2ecdffda, 0x527e07c1, 0x0963e079, 0x179537e0, 0x201044c9, 0x3572a77e,
	0xbb662fec, 0x0f83eff4, 0x1c57eb52, 0xc0127660, 0xd1edcc85, 0xe583b31c,
	0x3b08b807, 0x7d61f217, 0x7893b7a9, 0x89e23bd3, 0x4a0a9897, 0x34c39ce0,
	0xce3a405c, 0x1ea22758, 0x380ba532, 0x1944d72e, 0x333f47e3, 0x3f8032b8,
	0x942763f9, 0xc30d94ff, 0xc25a7401, 0x2a485ce9, 0x17224ed1, 0x9c9a5d2f,
	0x82657e01, 0x2712d676, 0xbee9d321, 0xe0b270a0, 0x2378868f, 0xc7637889,
	0x2055bf80, 0x56fe7547, 0xae7e1e7d, 0xa768ec4e, 0xe15dfabb, 0xff4ec7f8,
	0x28e6e54a, 0x811c9add, 0x2f760874, 0x7771f769, 0x563a3136, 0x54be0a94,
	0xd65fa3c4, 0x96f8f77e, 0xfc3b9d91, 0x5163e7f5, 0x397f331e, 0x2fed9632,
	0x64f7e1c7, 0x6d3edc15, 0xc163daf7, 0x94ded2af, 0xb2e3cfc6, 0x7208eead,
	0xebef8070, 0x65710cfe, 0x11cb6d34, 0x37d8446a, 0x13fa2090, 0x645139bd,
	0xc7b88453, 0x8e068c67, 0x67dc4a9f, 0xdf088fc2, 0x2c79f21f, 0xc6c6afa6,
	0x6eb6f86b, 0x546969fa, 0xcfc03e67, 0xcbf9cd51, 0xec2fa50f, 0x07ae8123,
	0xae7902a2, 0xcaddf308, 0xd77f3ee5, 0xc3fbf1df, 0x64529a9b, 0x394dcba0,
	0xf69ceea2, 0xffb72379, 0x30b192c7, 0xd75dfcae, 0x5f012759, 0xf80e89f6,
	0xe9a2b0de, 0x708ee2bc, 0x4f4e17fe, 0x19cf1f68, 0xd0214764, 0x5183d8f3,
	0xef69f604, 0x74a573f1, 0x474fc788, 0xfc1381d7, 0x99186f58, 0x64d629df,
	0xccce71c3, 0x681394cf, 0xb60de9bf, 0xd46a10d1, 0x358fd78f, 0x3fbcb1d9,
	0xd7ad4f7f, 0x3bd594af, 0x23cad8a2, 0x28daffcd, 0xc4c59f86, 0xe144cf71,
	0x996f8fdf, 0xb3f8b4bf, 0x51ca1d60, 0xb8e1edf7, 0xed1f2826, 0xac1f0553,
	0xc2efb013, 0xeb80be7c, 0x56067bd4, 0xe989bdee, 0xe1f71573, 0xd4693e74,
	0x346be77f, 0x72b7ba31, 0xace952f9, 0xbc7c37d2, 0xafaa7d6a, 0x3bfad1ae,
	0x7e8e3466, 0xf2d1d611, 0xa066c126, 0x014b954d, 0xa2b0e405, 0xfc1961f1,
	0x59dab7fd, 0x191d74bb, 0x8e3f3da5, 0xfcf3b135, 0x9aae63dd, 0xb0b93807,
	0xf433da8e, 0xf3c2e77d, 0xefc3d056, 0x847f1c19, 0x1fef2438, 0x5be9b244,
	0x1ec7d5f4, 0xac8e715b, 0xc705376d, 0x5334b339, 0xedccf706, 0x3ee53ba5,
	0x9ac53c1a, 0x7d5cb1e2, 0x8ed4afde, 0xfed3f7df, 0x87de1c70, 0x07be048c,
	0xc16faf48, 0xaf6f24ef, 0x2c38638c, 0x60a9dfaa, 0xabeb053e, 0x84fda9fd,
	0x7cacd3cb, 0x82e9bc7d, 0xa000c0ec, 0xbfd1be4b, 0xa70111cc, 0xff214cdb,
	0x275b77e6, 0xa3b7149c, 0x275a3ffe, 0x44eba996, 0xd59be300, 0xea6a7ff7,
	0x89f44eb4, 0xad2c4eb4, 0x3e01f7b2, 0xd69edd2c, 0xe9648407, 0x9189b93b,
	0x3df789d6, 0xc43866cc, 0x9b6e47bf, 0x2b89d745, 0xacc4eb34, 0xf849c428,
	0x39550b7b, 0x509d6ee9, 0x597ff6f9, 0xeb0fbcdf, 0xfef90444, 0x9d7e930f,
	0x00a9b9b8, 0x679b89d7, 0x6aefba89, 0x8fdc4dca, 0x913ae5da, 0xe62b7899,
	0x044c4765, 0xedcfbcfc, 0xae3c43e8, 0xf581fa1b, 0xffd005e2, 0x8dd79d09,
	0xccfaf4ae, 0xfff5ea9e, 0x7aab3a21, 0xb3b5297d, 0x7091298d, 0x4bcf1048,
	0x5d7aa56f, 0xbd323c00, 0xee0ef4be, 0xb3d30b4f, 0xe3b3d02e, 0xbd967ab4,
	0xeb66ee5f, 0xca634542, 0xf9697393, 0x03b2356d, 0x3adbca96, 0x56866ef4,
	0x7a00beef, 0xde822137, 0xf77a622d, 0xb458d342, 0xdf9aba9f, 0xa5beb85f,
	0x23b06cfa, 0xcce63e02, 0x777dd18d, 0xdbf46c75, 0xbc832fe9, 0xb9e227bc,
	0x0edc67e1, 0xedfa3fd8, 0xc74f6071, 0xe075b144, 0x39dfc710, 0xa1ce290f,
	0xc85ecbf4, 0x2db2e9ec, 0xbcafd222, 0x797fc981, 0xd3b3e09d, 0xbf98de7c,
	0xc95ff9e3, 0x47fe7676, 0xa99f9067, 0x7bc97fe1, 0x3bf06a81, 0xf0106c97,
	0xd6e212fc, 0x398b9e81, 0x251d0b3d, 0x8f09cfb8, 0x6d1b5863, 0x815c967d,
	0xb5dfa1ed, 0x37cfd78c, 0x9d8fd106, 0xb1c15bff, 0x778e7481, 0xfd7c1b28,
	0x949fd869, 0x773d85d4, 0x0a73c5ac, 0xec18c2f8, 0x7d7ab2da, 0x6f5cd7f9,
	0xe9fd122d, 0xecbec32f, 0xd223a28f, 0x0bd6a77a, 0x07e8a7d1, 0xa500e7d2,
	0x8f1fb8cf, 0x769a4b3e, 0xbbfa5fa2, 0x1e9c25d2, 0x3b7130ff, 0x07190c74,
	0xc199f8f2, 0xfbc5fa89, 0x2a7188ae, 0xa21e1f0b, 0x14c2cfbb, 0x9ef370c5,
	0x17dd5dc1, 0x78b395ea, 0x5bb5c596, 0xfcd224f7, 0x1a327adc, 0xd78bd9dc,
	0xd0e3d7eb, 0xc760dffa, 0xe56e7df5, 0x22e20156, 0xbdeff117, 0xe30f7c8a,
	0x2c771ffd, 0xad3deba7, 0xd18c60bf, 0x07afe70d, 0x3fa882a2, 0xe04efc55,
	0xf5cf1df8, 0xc17eb1d1, 0x1aa75c1c, 0xa5ca1b05, 0x5bad8a3f, 0x2f704f94,
	0x5f49eec9, 0x30be71e5, 0xe323463f, 0x1be50563, 0x135e75c8, 0x7b33d7cf,
	0xf3a6f6f0, 0x69acdcec, 0x37eecca7, 0xd42f4811, 0x77dc0e77, 0x9c23ebab,
	0x6a2665e3, 0x08fdbbf8, 0xc126ffc3, 0xf47c0f81, 0xdfc21fbf, 0xdaaaf82e,
	0xafe53d33, 0x5109a74a, 0x881f3e7a, 0x8b1fc96a, 0x03823ce7, 0x8a697bef,
	0xe38973c3, 0x92feec35, 0x70e7ce5c, 0x87fd80b9, 0x1b953ef6, 0xd710e061,
	0xe30a353a, 0x54dfb102, 0xf5699f66, 0x39fbe854, 0x38d77e9e, 0x82d20a98,
	0xfc475976, 0x11b77b9a, 0x82a9b7ec, 0x0b2b8fa4, 0x08ffdca2, 0xe9a7ffed,
	0x4927da5b, 0xee5f5c26, 0xbba7b1b6, 0xee042a07, 0x46b0ba31, 0x62dd1c46,
	0x19307fb0, 0x32fdcbf4, 0xb0b8f901, 0xb9a1fc7f, 0x445ca1bd, 0x37bc147c,
	0x2b5c1cb6, 0x89f62c05, 0xd6cbdc14, 0xffbc63a5, 0xed7ae88f, 0x04bbc61c,
	0xe713d83b, 0x6703ef83, 0xdae67639, 0xee32dfc1, 0x57386ac0, 0xfb6d999b,
	0xe3e003e0, 0xcf6f765a, 0xb8d935d1, 0x2efbbb4f, 0x30ece501, 0x33b417e5,
	0x07ca567b, 0xddf1d01f, 0xcf0126b1, 0x133ae6c7, 0xb2f3866e, 0x8745fbb9,
	0x305bd69d, 0xf38662c3, 0x45c369b5, 0xe5d0d6e2, 0xfe82d20e, 0x7795b99d,
	0x293906cd, 0xdc21eba2, 0x74d453c7, 0xe40fb720, 0xbf7c056b, 0xe056ebc2,
	0xf596bd3b, 0xb47195e7, 0x0f5a42ff, 0xcb515dc8, 0x146c55ea, 0xc2afdef0,
	0x4f5187a6, 0xf0146e16, 0x6a169342, 0xbb589aff, 0xb44ad83e, 0x69f7d2d4,
	0x0fbc317e, 0xbb8c6eed, 0x2ac1ce19, 0xfdf138e8, 0xee785589, 0xa3df4859,
	0xe365a4c5, 0x92ded85d, 0x77c0815a, 0x53134561, 0xed089a1e, 0x501d97ed,
	0xafe7687e, 0x3cf71814, 0xda5f5fda, 0x903102fe, 0x9fb8fe8b, 0x37bc3609,
	0xe50c31c7, 0x1dcb8dba, 0x93087cf9, 0xdfa88173, 0xf8da4967, 0xb146bf87,
	0xe5c2f5f8, 0xaf30d555, 0xc5213780, 0xaf3a7880, 0x9c7e3ac0, 0xed4ddbd2,
	0x8b0a63d7, 0x3dedd8ab, 0xfa3404a6, 0x1a5462f3, 0x31b0bfbe, 0x22ccf513,
	0x79f3c2e2, 0x47b31577, 0xf28eac8e, 0xc9876009, 0xbe7864b6, 0x9f11b57b,
	0xad817b9f, 0x0606e73b, 0xb27a8fd0, 0xddf02656, 0xb4dacada, 0x278f8027,
	0xf00ec8b7, 0xb34f8b4f, 0x2fc5e973, 0xeed93f30, 0xc9eed65a, 0xb2dfa63a,
	0x079d9e9f, 0xd5317b7a, 0x9f9c4653, 0xda158f5e, 0x3d4f518b, 0x52f4c51d,
	0xd70abeb8, 0x1b354553, 0xcb43af22, 0x43af22f2, 0x9f99aa03, 0xb9f58bb3,
	0x3d559882, 0x56e20635, 0xce06ca0a, 0xbe780f5b, 0xb78c0583, 0xe2ff5ff8,
	0x4b775871, 0x54cf782d, 0x427b64b9, 0xa020f860, 0x6d36e7ff, 0xa1e402fd,
	0xde146e68, 0xf8027523, 0xaeb47201, 0x16979e17, 0xee900afa, 0xe2e75c6a,
	0xabbc7af5, 0xdd5bc87e, 0xd76a7122, 0xe218a2af, 0xf43bd4d4, 0xda5b8a0b,
	0x828d9dcf, 0xa1e5540f, 0xfbd91c5f, 0xb7987193, 0x7396b8e1, 0x059d60fb,
	0xdee87d71, 0xb701abf3, 0x102e7ef3, 0xd789dbb0, 0x61eb0d5d, 0x0ec17af9,
	0x3fc5dd7e, 0xa62fef67, 0x0fb8c3ef, 0x8be18afd, 0x720edce2, 0xf0fb5e50,
	0x51bfac5e, 0x87fb43b0, 0x3da01436, 0x0915e451, 0x823c6f96, 0x5eba08fb,
	0x6ed37c61, 0x720898af, 0x68cabe50, 0x8aac5703, 0x479f1527, 0x312b3c78,
	0xa4cd4639, 0x830f3def, 0x714b808a, 0x4f5a108e, 0x5e153f01, 0x2f23b786,
	0x91100ec8, 0xbec9f1ee, 0x27f15683, 0x75c6fe02, 0x6d776fe0, 0x3c7802b6,
	0x3cf013e9, 0x0bf01b3f, 0xf55e7cf8, 0xd6b310cf, 0x9f0eea8e, 0x84ec38e1,
	0x28d9b83f, 0x2a9f03ad, 0x7871c31e, 0xc3372254, 0x1d5eefb8, 0xaec8f385,
	0xe5e6fd7e, 0x1cf0ce4c, 0xdefabb28, 0x42eb9044, 0xa895c589, 0x58932d74,
	0x71a7521c, 0xf4a5563d, 0xc2f8c9ed, 0x8a3fb1c6, 0x1e40ffef, 0xe3271644,
	0xbdbcfda7, 0xd78c39e5, 0xc8f9bb3b, 0xbcdf680d, 0xf4007149, 0x7e2162df,
	0x50f887dc, 0x8837151f, 0x94678c4e, 0x353319fc, 0xee3577fb, 0x0b25e4a2,
	0x9b78bbd2, 0xdf4f97d1, 0xd8f57e2f, 0x5eff3c28, 0xef6fecc1, 0x63ed0166,
	0x828c0de2, 0x258a46ef, 0x6e11ff16, 0xcd1b5c17, 0xc7af5bfd, 0x4dbb01cc,
	0xc3f763a8, 0x22dfd715, 0xddfe351b, 0xb565a3ab, 0x78c79e1e, 0xfbe19f29,
	0xf69f1878, 0xee35327e, 0x8679f5a3, 0x1946e2bf, 0xbae2b9ed, 0xfe20e7ad,
	0x11b0f8af, 0x7515bbf7, 0x39be31e7, 0xd817a5fb, 0xa28d763d, 0x53abee2e,
	0x889d55bc, 0x0de523e7, 0x41ff1865, 0x524e78f3, 0x9be3cf5e, 0x503c63be,
	0x5fdb4bc9, 0x961252f5, 0x2b5bfcbc, 0xb2d737de, 0xbbdf8ac9, 0xfc7b7dd4,
	0xaaf8a763, 0xbe3cb5fa, 0x8249fa6a, 0x7c7231fa, 0x85f819d5, 0xe8aee902,
	0x3ab538b0, 0x38e8dfa6, 0x63dd2233, 0x5ebbb218, 0x10d7e2f8, 0xedbadc1f,
	0x7186bf6f, 0xc2ebfe97, 0x839e21af, 0x81b288ec, 0xf9b1529d, 0x54a78c7d,
	0x9a207bdf, 0xff9e83ef, 0x9ea3c62d, 0x80e8d0fb, 0x3f6dced6, 0xc7f60c99,
	0x4f7fadb9, 0x65d33884, 0xbfd173db, 0x6c95ecb3, 0xabb2b7bc, 0xd7e02cfd,
	0xd87883d7, 0x6eedbe70, 0x27718dd8, 0x41df2967, 0xe6e2844f, 0x3c58cbea,
	0xcbc79da2, 0x7f1c896d, 0xae3e29dc, 0x298ce661, 0x981b1fa0, 0x9c6dd09d,
	0xcfca41dc, 0xc7c07a2b, 0xb21e3c2d, 0xc6b7fa7e, 0x5f859dc9, 0x8736bf28,
	0x868bf1f1, 0x053ccf45, 0xbabd0d65, 0xf7f3938c, 0x7c6a7e80, 0xced13df3,
	0xde41a257, 0xe30efdb6, 0xf97f8113, 0x5fd7d076, 0xf8bf8324, 0xbf441c94,
	0x11bb7044, 0xde2bb7bf, 0xe9e5087e, 0x30072bdc, 0x38f0987e, 0xf42473e3,
	0xb941e2c3, 0xa362a80f, 0x71d7c585, 0x9dfc403e, 0x79cf8add, 0xb5c31d9c,
	0x55d77f1a, 0x68d9dddc, 0x1a9a9df6, 0xf1b65d77, 0xd6cf1e63, 0x226137c1,
	0xb7c8ebf0, 0x74aa35c6, 0x261d01b0, 0x234ae368, 0xe28639c7, 0x06f8c34a,
	0x1e3d04fc, 0xf9a51b8a, 0xe83f1001, 0x8a450e13, 0x81b73e53, 0x939ea3c5,
	0xaadf7f23, 0x0a9e99c6, 0xcf5f5b97, 0x9bbb4be2, 0xd3a577c7, 0x2ebb68e1,
	0x57a552be, 0xfac8c5eb, 0xf846263d, 0x956bdf61, 0x47dfe10a, 0x878cc744,
	0x0a23f873, 0xeea173de, 0x5b7cf8ab, 0x75adbfb9, 0x877188b3, 0x51bbf5d5,
	0x8feb87bf, 0x128e7e72, 0x3181de3e, 0xde5aff6c, 0xd68fd6c8, 0x999f166d,
	0xebbad3b6, 0xf975c475, 0xf7182396, 0x65eeb7b8, 0x7f39a025, 0xa7c3f586,
	0x8beb7f19, 0x3ea1473b, 0x855af7e7, 0xef3973f7, 0x7229a2a7, 0xce5b153f,
	0xf129faeb, 0x73362bd6, 0x919dfdf7, 0x7b40b79c, 0x1d985a67, 0x9c5ea675,
	0x1dfbe91a, 0xcfcc8c6b, 0x4a586a31, 0xdfbc51d7, 0xf3eec2cb, 0x68d1ad12,
	0x4cb32d97, 0x48f70c3c, 0x1828b32e, 0x8ab2b17f, 0xc2fc6bc7, 0x5efc0491,
	0xc09eb969, 0x7d035778, 0xd97bfb35, 0xcf6026e6, 0x71ae49c9, 0x751873da,
	0x036f4afc, 0xbff869f1, 0x0fb532cc, 0xe4894fec, 0xb8e3001d, 0x092bf521,
	0x0f16c5d6, 0x78b8098f, 0x6f3c306c, 0x7a7b6c91, 0x725b76d1, 0x66b80704,
	0xa7dee33b, 0xe8dc3ff3, 0x0a83dfd4, 0xbf30fe31, 0xed018776, 0x6fc18b44,
	0x258855a3, 0x370925aa, 0x976276b8, 0x1f343112, 0xf7efe3e3, 0xf7c30698,
	0xcd42567d, 0x90e7a856, 0xc462f774, 0xeec2944e, 0x070720c9, 0x399abc53,
	0x9d7f555e, 0xdb4efd85, 0x1bfde00d, 0x0aa4e971, 0xe2cebbe0, 0x51e27b46,
	0x5fbf13ab, 0x21c33fa3, 0x449e224e, 0xfaf7b43b, 0xf7757ed0, 0x757ed081,
	0x3ea738f9, 0x74aa6bdf, 0xd37ad23c, 0x4f238f8b, 0xe21d2334, 0x5edc0d72,
	0x490fe676, 0x5c7718ec, 0xa1f87102, 0xe319ba7c, 0x7978a9d2, 0x9b30f3b5,
	0xe3a6e3f5, 0xd889e9d3, 0xc0d780f4, 0x6e7ba9c6, 0xd7bc7623, 0x68f78e98,
	0xf97578d8, 0xefae18ea, 0xbe812224, 0x085a9b33, 0x8ebb7fa7, 0x5724abde,
	0x4b61227c, 0x0e938c26, 0x886fbe13, 0xfda0f3e5, 0xc0dbeaeb, 0xd7fac07b,
	0xd80643b7, 0x5e25dfb4, 0x19c1d7c1, 0x3193d766, 0x0c64af54, 0xe100c4aa,
	0xf38249c9, 0xd65a58f8, 0x7bf99bd4, 0x5c636796, 0x70c3508a, 0x411d7835,
	0x641c19b9, 0x55642ff1, 0x46a9da34, 0x8d46f113, 0x88adef81, 0xbd031e57,
	0xd9fcb8f8, 0x53681857, 0x358a1ad2, 0x30535efa, 0x3288b0cb, 0x688a1ea1,
	0x38c58ffb, 0xaefa037f, 0x927746fa, 0xfc3c3461, 0x00f37568, 0xe011da94,
	0x1f083431, 0x9037d9ee, 0xbdc10a85, 0xb87c840e, 0x135e3007, 0x7c3f13ca,
	0x1d135df7, 0x544d3bca, 0xb2a4d7df, 0x87cc437c, 0x11fee1ab, 0x00d5cd97,
	0xed9310fd, 0xf30f3c32, 0xbaad7bb3, 0x71d45f5b, 0xc818df0e, 0xfcc71e8b,
	0xecff70a9, 0x3be84b10, 0x378f5c6c, 0x1fbcd599, 0x86ae17f7, 0xcad7a803,
	0xb9600fea, 0x1d34f201, 0xd7902bd4, 0x3f908e3f, 0x373a703f, 0xb5d80469,
	0x3a064905, 0x381e4fcf, 0x5bbe07bd, 0xb9c3a0eb, 0x3b93cdd5, 0x5a1920e8,
	0xfad0e8c3, 0x49f0e89d, 0xb86aeb4c, 0xf3a7a31f, 0x18f8b8a6, 0xd32d35e8,
	0x4d70f780, 0xff466c38, 0xc289fd0b, 0xb3b788f5, 0x74ef8ba1, 0x6d0a7dd5,
	0x5f1698e7, 0xae2a7bea, 0x1a4dc2ba, 0xeec65db1, 0xa7e3d477, 0x0ad9d9b7,
	0x718d9ded, 0x8092cafe, 0xc2efc7f3, 0x5c0bb9a7, 0x703abd39, 0xb1eecc4d,
	0xffa05937, 0x7d405ff9, 0x32d35c75, 0x74a98a97, 0x2c825fbc, 0x27cc7424,
	0x6a37b961, 0x82679d28, 0xdbf180d3, 0x7feecc33, 0x39d67bc2, 0x8f553f41,
	0x8f7004d4, 0x7e8ec415, 0xdea8f954, 0xd5f1f6ce, 0x0adf0605, 0xf78c1e76,
	0x23e077ef, 0x208f8610, 0x11e347c3, 0xd37947c4, 0xc68f8611, 0x7e68acaa,
	0xe8fb06ae, 0x0d1c121a, 0x675b8f7c, 0xdf2893ca, 0xab04c507, 0xc85c53fb,
	0x8fcbc944, 0x9ac6ba42, 0x87f02213, 0x579d4b8f, 0xd9adfc57, 0x3a40fa97,
	0x1bf733ec, 0xa54c3cf0, 0xc32f5a9b, 0x4f13e2cc, 0xa003dc58, 0x81898a9f,
	0x6dbec0bd, 0x7184fefb, 0x37fdd61d, 0xadf784ed, 0xec8728b3, 0xecd6fd1d,
	0x3cf7815f, 0x7bb134d7, 0xd0496397, 0xd77aeb0b, 0x13f260f4, 0x3dd807a2,
	0x238f40e9, 0xf99b2f28, 0xee544b77, 0x41dd3bf0, 0x891eec31, 0x8e2ccc2b,
	0xb22cdb24, 0xb3334538, 0xb7f61237, 0xaaffb02b, 0xfac06558, 0x6ba69009,
	0xbf8abfe7, 0xf0e2e927, 0x78aabe54, 0x06349aa2, 0xc4b0a3ee, 0x759b27bb,
	0x498f89f8, 0xbea7b4d5, 0xb88790f7, 0x4ca05216, 0x377f9e68, 0x3f14abac,
	0x759acd7d, 0x3948da7a, 0xc216e80a, 0x2467c50f, 0xaef7d0fe, 0xfd678f37,
	0xb5b0bd80, 0xf788a979, 0xaf90f42a, 0x209f7019, 0x43119fad, 0xf7d1b72a,
	0x0a696233, 0xdf3c5ef9, 0xb3fbe787, 0x8713ed34, 0x37cfa041, 0x7cecbf70,
	0xd922574e, 0x2469bb2e, 0x275d19e4, 0xbae0c527, 0x5c2dcaa0, 0xdae70183,
	0x4edf3f12, 0x801aa60d, 0x4b1caa6f, 0x62df8341, 0x0c077bc5, 0xaef0e710,
	0xf382edc7, 0xcef4aec2, 0x77d823f5, 0xefcfe185, 0xdef9e3e1, 0x9de7f5f6,
	0x07be3fbe, 0x0a665be8, 0xcd13743c, 0x80b88f97, 0x3115da7e, 0xdb7d57e5,
	0xe3e1083d, 0x49e2f77f, 0xe787d82b, 0x8d4e36be, 0x366f6764, 0x3ec17db3,
	0x2f7c1ccf, 0x46f3df83, 0xaef1a8fa, 0xa117ef9a, 0xc865db8c, 0x8e7c54ca,
	0xa8d5d676, 0x5e9f8102, 0x8fde1e29, 0xc573c149, 0x63bec26b, 0xaecbcf54,
	0x603f33f6, 0x1f2fac46, 0x0d3cbbfb, 0xd7c908e3, 0xd1325ecc, 0x2a1ce0ff,
	0x399b9f97, 0x619adb0f, 0x55e8cc39, 0xc7ed8393, 0x2b5fa0a6, 0x67efe893,
	0x95e3e8cb, 0x969e500c, 0x9b65ed82, 0x08d3cac2, 0xb0c8adfa, 0xb97e70cb,
	0xe19f6344, 0x00e351ba, 0x386d3c7d, 0x7e7f3fc5, 0x641bfe81, 0xa8de7724,
	0x675c67d9, 0xa395d5bf, 0xf06a5bb3, 0x7fdf985e, 0x2919de23, 0x30b442fe,
	0xb8f3ee7c, 0x100f105c, 0xbb2cc74e, 0xef62cab0, 0xfa70ef4c, 0xa55bd385,
	0x32dd3863, 0xc4e4713f, 0x27d33bdb, 0xe71d1e9c, 0xc075be97, 0x22e1dc87,
	0xdd2a5fae, 0xf187d33b, 0x6823f7eb, 0x42f0013d, 0x4cf40de9, 0x47be3013,
	0xf9736fb5, 0x8b7da8f8, 0x82766bf6, 0xe13efd05, 0x474ced74, 0x626e7e67,
	0x02f6fcc7, 0x9ea086bd, 0x4d8cb860, 0xc465be43, 0x7c420e3a, 0xc21d8919,
	0x86bfe370, 0x5e3fe368, 0x2c72ff02, 0x29ef070e, 0x117586bc, 0x5f35d7a2,
	0xdcdcedeb, 0x60d3bca6, 0xaaf4673f, 0x7e838e6c, 0x79bf0c8c, 0x34e9ff7c,
	0x4a41f8b1, 0xbc7aa3cf, 0xf4ec6611, 0xbc71f14a, 0xbc56fd1d, 0xfdf7c2d9,
	0x74e16f0c, 0x12f6f150, 0x99d4983c, 0xfede2a6e, 0x79f6e661, 0xec00323f,
	0x8faf51e5, 0x4dfd058b, 0xfa23e29a, 0x761c2625, 0xfde1da85, 0xe2052e23,
	0xa5b73d0e, 0xb63d00fd, 0x1a92ae9f, 0xb92b163d, 0xf4112d63, 0x29938a98,
	0x88535f9c, 0x99f82777, 0xf3e910a6, 0xa5207ed0, 0x2c7dfe63, 0x3fbbfcfc,
	0xfcf30fe9, 0xd99db30f, 0xa19e7c45, 0x12f35379, 0xfbcc9ffa, 0xe3326c9f,
	0x28241e77, 0x9ee886b5, 0x78dff78a, 0x718ef895, 0x493ebcc8, 0x9ecc24ae,
	0x1ff78b9b, 0x4b90ba53, 0x48e31d31, 0xde1208b7, 0x71c7c2ff, 0x85e4ceb6,
	0x92d9b738, 0x6cf301db, 0xc28ff615, 0xa1fe49f9, 0x9785feb0, 0x2e6c685f,
	0xaf5a7287, 0xf1f1eb10, 0x670c8897, 0xdf46edc1, 0xdb5d29b3, 0x71bc54a9,
	0x63e5509d, 0x79577c32, 0x505bc805, 0xf1377184, 0xe71d9573, 0xe85f708b,
	0x9755b624, 0xb4f6f6d3, 0x00f7e1e7, 0x40ed54d9, 0x87fc70bd, 0xc71c3ae3,
	0x0f382439, 0x5f8cebde, 0x2bf2f7ef, 0x085c76a9, 0xb8f50737, 0xf142f151,
	0xcfd80b73, 0x7b3ee36d, 0xf7eecc02, 0x84485dc6, 0xd3b54ff5, 0xe711ec3b,
	0x2baf506d, 0xd3b55d7b, 0x05dc5b17, 0xe60907c0, 0x1d4fdf43, 0x77c0376e,
	0x9c5b8ffa, 0x6ab9e1f3, 0xefb774bf, 0x1912cd20, 0x877f019e, 0xdea1f188,
	0x607ef040, 0xef0152ef, 0x0483bec7, 0x8eefe865, 0xbfb7594a, 0xfc15179d,
	0x8e7067f4, 0xe30c3558, 0xd5f0dc88, 0xb3ef88a8, 0xbe6ae4b8, 0x0e0f0eee,
	0x9ddffd85, 0x13eff5cb, 0xc7627dc0, 0xd29fab3d, 0xa1e37dba, 0x7c0240dd,
	0xd5e05bc7, 0x5fef0fd7, 0xbb78479d, 0xf055efe1, 0xf704fbbf, 0x76343b5c,
	0x3b0b4ac3, 0xf78d0a27, 0x025f7e5d, 0xbbac37a5, 0x7c234ded, 0xafc047f7,
	0xfd4dba9a, 0x7ee6929d, 0xe376c0ad, 0x98f7489c, 0xf4a8fda8, 0x545a4b9e,
	0x1223fe7a, 0x99bb26fe, 0x98f0c03f, 0xaf5e775f, 0x398383a6, 0xae0df768,
	0x2eced017, 0x2c34cfad, 0x6cfbd9d0, 0xdec9dc3f, 0xa0357b87, 0x664ec37e,
	0xe157d7ef, 0x81b4a1be, 0xc0367fed, 0xf8fd11bd, 0x1f71d240, 0x42d7da10,
	0xdc1954fc, 0xfdcac863, 0x5a55b570, 0xb6ffab0d, 0xad6553e5, 0x7752fb04,
	0xf91cdc12, 0xaac783f6, 0x54ff744d, 0x08a2429d, 0x79ed3fdd, 0xbade58f0,
	0xc73b5489, 0x37b8053b, 0xcdabe692, 0x8fbe7a93, 0xa3c1fb7e, 0xa68fb0d5,
	0x801daffb, 0xba5e556b, 0x307a8f92, 0xdeba123e, 0xae6cbacf, 0x54be41b7,
	0xff3844bf, 0x58f64ddb, 0xbe5adfc0, 0xf97ebecf, 0x443fdc02, 0x0c98bb0d,
	0x39936271, 0x3b720fdf, 0x7d8622a8, 0x93115e0f, 0xf53d03ec, 0x083ee8b5,
	0x75db6ce3, 0x93f82871, 0x0c7e1ddf, 0xfc4d6ff7, 0x9efdc9be, 0x6e369722,
	0x1f1caffd, 0x6dd88fd7, 0xf4c7fd85, 0xefc67ff1, 0xec4acfd4, 0x89d6b5fe,
	0xbddece8a, 0x57fb92ce, 0x529abf18, 0x9fa089f2, 0x3e6b8f27, 0x577eeb0c,
	0x3ac744eb, 0x1d6014e0, 0x240f1720, 0xc35079e2, 0x35f82b1e, 0xef77f95a,
	0x27761b67, 0xd969a7ce, 0x615b3fd6, 0xf3e415df, 0xe0b52b3c, 0xafa53d7d,
	0x049f7888, 0x76f137ed, 0x2c3733f0, 0x759fb8c8, 0x83aed263, 0xddd9be63,
	0x7f9cc5df, 0x6a883f78, 0x79314e1f, 0xa6be307d, 0xe777f62a, 0xbf9090a6,
	0xb915ef13, 0x467441a6, 0x8bdb3b59, 0x72e6558a, 0xa778c764, 0x4fd63665,
	0xf939f257, 0xa7c45eeb, 0xb2606fb9, 0xfc6117e4, 0xc44ebf93, 0xa5f767e7,
	0x7c0f9a3e, 0x0863b227, 0x66912b34, 0x79f947b4, 0x8669fd12, 0xf077a67b,
	0x170d5bcc, 0x60855e66, 0x0090eba5, 0x37bb97f6, 0x7d321273, 0xd789daaf,
	0x93f7ad7c, 0xeaaddb86, 0x34d596ba, 0x027f557a, 0xc4cfb774, 0x49f61def,
	0x6e159f18, 0xf306e6d7, 0x1f5fb0ba, 0x6b6c7a46, 0xbc018b48, 0xafb8e09c,
	0xf780b868, 0xff1394c7, 0x4f8f70cd, 0xf3688379, 0x1a2b8813, 0x8dc83977,
	0x74abfeba, 0xdbb8bc69, 0x6cfc0a34, 0x15b68baf, 0x0be9af50, 0x3fd8e1c4,
	0xe9f5c45e, 0xf78c935c, 0xff6c54a7, 0xb340bacc, 0xc4d7381f, 0x6b6955ee,
	0xde7fa63a, 0x7872ebd8, 0xed81ab6f, 0xfef79b6f, 0xcef40623, 0x7bdb175b,
	0x5d5abee1, 0xd7db3bff, 0x5b671768, 0x58ff90c4, 0x71133f6b, 0xcf8841f2,
	0x89958dca, 0xff6d7428, 0x56427e66, 0x3b674859, 0xe2774420, 0xe10e8094,
	0xce884176, 0x74c17661, 0x06d7b72b, 0xcf703192, 0x5ec5e360, 0x6a3df825,
	0x056d8c53, 0xdd987ffa, 0xe67cd6d3, 0x7cf06991, 0x23eec8bf, 0x3ca228b8,
	0x3251daed, 0x0fa1a028, 0xa7c88cd5, 0x3f9efb2f, 0xffad26f7, 0xe6689ee5,
	0x971c970f, 0xe86bbf6b, 0xf4e3efa8, 0xe763f7f2, 0x707ede6a, 0xb6f7d05f,
	0xed3b5b6b, 0x68ad8bcf, 0x40f306d7, 0x3dad0fbd, 0x4fff00a2, 0x56a55c58,
	0x18fab794, 0x925e2fd0, 0x7ed09fd5, 0x1649a28b, 0x45582ae0, 0xf7e7106c,
	0x01833eca, 0x536e32f8, 0x6ce1c60a, 0x4b8ee7e6, 0x14946bea, 0xc25ade8d,
	0xc94eadcf, 0xcd78e4de, 0xdb2b76f3, 0x53da9fb7, 0xe1ea0cfc, 0x48648d0f,
	0x4ff77584, 0x7897e656, 0xdb4ef159, 0x1a8ef502, 0xe6a0fbf0, 0x85ec6fbd,
	0x1c976a7b, 0x75868fb6, 0x8ed58b6c, 0x6ff71af5, 0x1aee7bc6, 0xdde8213f,
	0x2058d8cd, 0x6fbf681a, 0xc3f33b12, 0x177f641d, 0x24bfe431, 0xcf305ece,
	0xdf4cade7, 0xa0cfb9bd, 0x937ae73b, 0x14faa7df, 0x563543d7, 0xb6db07e6,
	0xde17ab2f, 0x3f716b2b, 0x38aaf40a, 0x2186a81e, 0xd53b7ea8, 0x70749b0e,
	0xf491b4db, 0x06ad49d7, 0x7edbb01b, 0xe61159f0, 0x48453f6b, 0xd93a409c,
	0xa7bdb465, 0x7b6a2f81, 0xf6b2b66f, 0x817638e8, 0xa7f4aabc, 0xe903da2b,
	0x8b66ff34, 0x5bf10f14, 0x79d5fd2a, 0xebdbfda8, 0x19837389, 0xedb9c945,
	0xeac7fc5b, 0x6d63f7fd, 0x1f0fbd44, 0xead83971, 0xfccac17c, 0x3f90c977,
	0xed1a27b5, 0x3af9979d, 0x060a9249, 0x3e54fd01, 0xd6cac1fd, 0x5d3c7535,
	0x1f0efff5, 0x577e9aa7, 0xed966f5c, 0xbf0dc45e, 0xf5eed0cf, 0x4e20d29b,
	0xff0d31ac, 0x8e26901e, 0xff1c1df6, 0x75fdfd29, 0x0183018d, 0xdf2af7be,
	0xf5e1c42e, 0x9bb43d27, 0xea933843, 0x878d7f11, 0x7171ca09, 0x7fcc5ddd,
	0xf9fdfc48, 0x1e785ebd, 0xcfc3f20e, 0x340afbc5, 0x61b4d49d, 0xafa47f65,
	0xd5720adf, 0x372a2741, 0x28d65690, 0xcb25d780, 0x9f98ba58, 0xef592f2f,
	0xac2cf946, 0xc783f165, 0x7d6c29ac, 0x862578e6, 0x57107ee8, 0x5fd38f32,
	0xc731771d, 0x4786e9ed, 0x14bf4377, 0x1e81a75f, 0xfc3e3657, 0xc5570c04,
	0x328de9eb, 0xad1453b6, 0xc73f7f3f, 0x41cafaf9, 0x1b49f786, 0x4fb82ce5,
	0xd897926a, 0xe6fd1fc0, 0xe8224dc6, 0xcf0137ef, 0x61ce4c29, 0xe7b53dbd,
	0xc29f98fe, 0x40c476fa, 0xb2fdefc0, 0x6ab68a42, 0xc379a2e4, 0x2df93a6b,
	0x869aabae, 0xbc40f5fe, 0x955e7a00, 0x2fee955b, 0x50eb8e2b, 0x93086ffe,
	0x7ef61cff, 0xcbe32c5a, 0x1ffe5ca3, 0x9fe54a9d, 0x18db8a3e, 0x2f3b4027,
	0x19ef912b, 0x7efd884b, 0xd5e90bf8, 0x9abd2740, 0x05fccb10, 0x7fda34d6,
	0xf476f4f9, 0xc7c68417, 0x8e68f371, 0x01149b8a, 0x39435fe8, 0x45e81838,
	0xa6780ae9, 0x379df176, 0xee54a3a5, 0x86bcf093, 0x38f1079f, 0x8d28940e,
	0x33e876bc, 0x43dd6e55, 0x39191c61, 0x6ec12b95, 0x45ef95ef, 0xdc169e7c,
	0x7ae9e283, 0x38e41a76, 0x63903e82, 0x52fe5e99, 0x9f777776, 0x73c03f7a,
	0xc201dd11, 0x60ad487c, 0xe5a8be03, 0x4fb65af6, 0x55f4e6c9, 0x50ff679f,
	0xdd3b077a, 0xe8cd9943, 0x0e20541d, 0xad8fa875, 0x42c84463, 0xeb862079,
	0x2d9c81fb, 0x6dd7eba1, 0xb4ebf59a, 0x5538835c, 0x963d30e9, 0x7197cdc9,
	0xf0dfde6c, 0xf072e9f5, 0xd0d78dc1, 0x8124905f, 0x3028b3c9, 0xfda11739,
	0xbcae7bd3, 0x3d3ef10e, 0xb06dde32, 0xbf878a7f, 0xf101b3d7, 0x86d53719,
	0x2a3ca9df, 0x74e2a239, 0xd30f91f6, 0xe24f4de6, 0x0bf00dbe, 0xfe15def2,
	0x24ff008b, 0x147dee02, 0xa9fe1af7, 0x58b8a038, 0x0fd1ab12, 0xcf50b8e1,
	0xbcba550d, 0xd8ee761c, 0xc554e9c0, 0xf1177b53, 0xbe7cea2f, 0x754f9f37,
	0x5c37b3e2, 0xaadf80ae, 0xf204587e, 0x7cb5d095, 0xb1b58b1d, 0x97f733bf,
	0x526f1805, 0xea9fcfc3, 0xb8ea7f79, 0xecf8e11f, 0x8668fcea, 0xac70fdd9,
	0x7329bcf6, 0xef4f68a9, 0xb72e47c0, 0x326e9767, 0x56fdf9e2, 0x35be0128,
	0xdfb4fb47, 0x6a24da8f, 0x6f525290, 0x71c14d88, 0x2fb0f8ab, 0xda60c857,
	0x052997ef, 0x73c710cd, 0x7f378b6d, 0x56c79d24, 0x3a6b3bc5, 0xeb8effda,
	0xf2ebfda0, 0x5ff0360d, 0x026d39c7, 0x64d037f8, 0xcfdc3903, 0xe69b19fa,
	0xc1f71cb8, 0xd058c776, 0xe58bbf07, 0xbf9c4de7, 0x5aba1d2a, 0xebe2bae7,
	0x049f4e31, 0x47ae1e5e, 0x3bf2f356, 0x1ebdda78, 0x4f208af1, 0x015ee256,
	0x4c9bb77f, 0xa42ffa66, 0x3c132647, 0xf5cfdc5f, 0xcd5cfa92, 0x647a88ff,
	0x4845c83f, 0x440c4c8f, 0x27f423d4, 0x6c27fca2, 0x2c76845c, 0x8ed91c39,
	0xad9624fd, 0x7eb009c3, 0x5e097ad2, 0x7f74f7f6, 0x8a05d7c7, 0xac838c48,
	0x73c468d9, 0x590f5509, 0xf82c9167, 0x5856c0fb, 0x2cd6a16f, 0x7029e1f7,
	0xd8a49bee, 0xb4fa1ce1, 0x9fbe441c, 0x1af01ba6, 0x004b87c4, 0x47d0477e,
	0xde21fc04, 0x3f30068f, 0x7284d8be, 0xe09734b2, 0x69bcd9fa, 0x28aae202,
	0xdc00553f, 0x09c5d716, 0x639f1e50, 0x529e8033, 0xb96131e7, 0x72a4f888,
	0x8395aed0, 0x114ade09, 0x97a835e8, 0xc38e493b, 0x5aa99638, 0x7ebfd07f,
	0xfd6aa649, 0xe6bf3441, 0x0483f8bb, 0xc0fba5db, 0xd637d41f, 0x9dfa0979,
	0x36097661, 0x03ffcf4a, 0x1cc8bafb, 0x00008000, 0x00088b1f, 0x00000000,
	0x7dd5ff00, 0xc5547c0b, 0xbddcf0f5, 0x936bc8fb, 0x21213bcd, 0x21e1026c,
	0x10084b88, 0x83cdeb11, 0x05849288, 0x6ea2be29, 0xf23c2402, 0x6b62d102,
	0x023042cb, 0x2d47c622, 0x858bac56, 0x0da229fe, 0xa8d63502, 0x8a8b401b,
	0x9fb4df1a, 0x8790f0d2, 0xfb60a482, 0x77cb16a5, 0xec9999ce, 0x808d9bde,
	0xf7efffda, 0xe64e9f85, 0x67b999de, 0x9cce7bce, 0x6e4d8c99, 0xc640d950,
	0xb18e3f98, 0x873b19cb, 0x2ef5573f, 0x9632f319, 0x4dfcd8c8, 0x0e1e5773,
	0x0e73f463, 0x596dabfe, 0xb7d7aba0, 0xf0f2b5de, 0x3e7d40d0, 0xcf0a92fe,
	0x43b21717, 0x0ef7e1a3, 0x1892c516, 0x584de1ab, 0xade7586d, 0xc58c9c9b,
	0x8e093d98, 0xf5d58c31, 0x0e28f23b, 0x77f6df57, 0x6faa27ab, 0x57f01238,
	0xcc27dffc, 0x5f8151b7, 0x256a0ddd, 0xa9ec9fb4, 0x33c51770, 0x7cc074e6,
	0x4d2360c6, 0x2ea76699, 0xc608cb5a, 0xf49b199a, 0x5fcbb61c, 0x694166a8,
	0x7b5e630b, 0x51f3b61c, 0xe4c7ac7b, 0xeee16810, 0x5d5b194b, 0x1be49a62,
	0xb18e1bd1, 0x85efa88e, 0x998c760f, 0xdac0f183, 0x9fc7fdfe, 0xf8f6858e,
	0x9658cabb, 0xf11633d9, 0x1e89f801, 0xb879f808, 0xe21260e4, 0xd84c7e03,
	0x8df176ef, 0xdeb99727, 0xf0780219, 0x8db2adbe, 0xb3651f50, 0x9c18957a,
	0x4920a036, 0x4a3f078c, 0x8fb7e29b, 0x0ad7fa84, 0xa70e80d3, 0x7ca956be,
	0x49ee17f2, 0xaebfd099, 0x065ae4d5, 0x00daeaed, 0xb98cb999, 0x585f3006,
	0x112d6326, 0x8c1923d1, 0x4a2bbf97, 0x53f3c0b3, 0x96cf984a, 0x08657849,
	0x9fc24587, 0x05b195d7, 0xd9b637de, 0x9ea82ad8, 0x235207ca, 0x0c5766bc,
	0xefc0111b, 0x1e1eb7c8, 0xe780330a, 0xd0372ecd, 0x3e70a9e5, 0x19e153fe,
	0xa58d163e, 0x018ce7ec, 0x8259614e, 0xe066cc6f, 0x1413a011, 0x2c272c5e,
	0x8199a81e, 0x79998ace, 0x09af402d, 0xf1157e5d, 0x34e5d593, 0xf7c0a8b1,
	0xe68c5dcc, 0x9a76659d, 0x8b47005c, 0x3db6ffc0, 0xc066a9cf, 0xe6a2d8eb,
	0x7bca1546, 0x10b33da2, 0x3427e3df, 0xf8f3e234, 0x81eaaf12, 0xc34ab9f6,
	0xd9f23b2e, 0xd1b5cc35, 0xf8939019, 0xe00ed64e, 0x9d7dd8b2, 0x1f3c345a,
	0x1f6b4c7f, 0x718ff301, 0x63c70533, 0x7f7d296c, 0x1ebb944a, 0x9a0965c7,
	0x8ce30a52, 0xfc231bfd, 0xedb671c8, 0x009c5029, 0x9147426f, 0x9bd11ce2,
	0xe732d7cf, 0x77ae387d, 0xf485c9af, 0x6d30b675, 0xf01fb43d, 0x884525f4,
	0x8d7ed92f, 0x5defa143, 0x5a14f1e1, 0x17e7cd19, 0xf97fe80e, 0x165dbe0d,
	0x1cdc6780, 0x33ab2eef, 0x19733e68, 0xe9d6978d, 0xeea479a5, 0xf963e4f3,
	0xbe963d98, 0xbf98fe3b, 0x4bb4047d, 0xc0f9806e, 0x1f1dfef3, 0xfed78828,
	0xd20a1d0d, 0x9d9edb73, 0xc77a6f04, 0xf90a5e6e, 0xabe40e7a, 0x8f1e6825,
	0xd7044dd9, 0x5f0e7663, 0x2999c9d3, 0x90ff786e, 0x3d98f3c3, 0xa68f3031,
	0x034a4f7c, 0x4f76bf8c, 0xb37ccf56, 0xa0cbde01, 0x5a5eb05b, 0x38d2b0ef,
	0x5f9eec47, 0x6feafce3, 0x790d7ce8, 0xef3db9f0, 0xb47c9345, 0x937d1025,
	0x7a241ef6, 0x9c062d24, 0x7bb5e3c1, 0x2fa82a17, 0xcd0396d6, 0x9678de94,
	0xc22d637a, 0x88e3fc4f, 0x69fc0a9c, 0x0ffcf38f, 0x9fb6477e, 0x9917115c,
	0x6497a415, 0x309747bf, 0x64002cf7, 0x6dcaeedc, 0xeee90b2c, 0xdfae95f9,
	0x2384f7a5, 0xb5db653f, 0x9c3f203f, 0xf80dd852, 0xc258cd9d, 0x5e16cdf3,
	0x97faf897, 0x8e43e7a0, 0xc7d98fa9, 0x80393c70, 0xf387378f, 0x747d4676,
	0x39fbc1d2, 0x0eb0bf05, 0x0f382fce, 0xddb263d4, 0x344f9207, 0xf399a14f,
	0x93e22ec9, 0xe42edf3c, 0xbc9371db, 0xfbff90bb, 0x9327c133, 0xf9189f38,
	0x57ea20fd, 0x862e93e2, 0x9855cf78, 0xb2ee983b, 0x42e108fc, 0x4051dd7d,
	0xd0f203fc, 0x9b1bdf81, 0x505aa0d6, 0x64c7336f, 0x1dc73fb4, 0x3a376a4e,
	0xfc85db4f, 0x24dcd0e6, 0x3a445fcf, 0x7264df38, 0x7ffe80fe, 0x7946fec1,
	0x34728eda, 0x09472022, 0xbd518fc8, 0x016df1f9, 0x43c471cf, 0x3df1a862,
	0xaf041c47, 0x90605349, 0x7ca2fb71, 0x5b8e9a0c, 0xe5127604, 0x03ff0194,
	0x1c737180, 0x696728f9, 0xe9052e35, 0x7dd2327a, 0xa135fb02, 0x7e45cc6e,
	0xa11af936, 0x1a31bddf, 0xdb3befd1, 0x8c2cdd89, 0x09d80d8d, 0x12ff0bb0,
	0x054d6176, 0xffdfebea, 0xd4fa8ad3, 0x4f6fe529, 0x1065644e, 0xf2c5c47f,
	0x5bd10679, 0x6f410d89, 0xd2339ea3, 0xf417a03b, 0x15f00e7a, 0xcdfa4b19,
	0x2cf91a33, 0xca9163a1, 0xaf5e83f5, 0x5e8f45f5, 0x21d041fa, 0x404b4a21,
	0x19031f38, 0x0b7aefc4, 0xde7c50d8, 0x1a1e3d97, 0xfffd451b, 0x2878f68b,
	0xc7b463c2, 0xd7aeb0a6, 0x6d47c015, 0x6154ea9b, 0xc7778d0a, 0x27ff4869,
	0x0d97145b, 0x536aedda, 0x6c9e1f89, 0x29bb208a, 0x4772fde1, 0x197648cc,
	0xd9fe4294, 0xa7b258ee, 0xfbe2b1f5, 0xf817e1cb, 0xaf0729fe, 0xf278720e,
	0xffb2cf10, 0x08ff6d93, 0x4f0f3c47, 0xe8c3b451, 0x31ed1957, 0xfd029088,
	0x829bf86d, 0x42b51d78, 0xe19ac145, 0x895366d9, 0x9f38056e, 0xbdf3ac71,
	0xd3d70009, 0xc14c0a5b, 0xd699d6fe, 0x09dd6eaf, 0x7247d7f0, 0xc91f5cfb,
	0x9da9f3ed, 0xbf230767, 0x2678bb5d, 0xd56ebde9, 0x48363933, 0xf431bdcf,
	0xacc3d710, 0x386471dc, 0xce535a7e, 0xa30a0245, 0xd19a86c3, 0x5c2350af,
	0x20afdeaa, 0x06cc68e6, 0xdafe20fc, 0x8d7f0823, 0x997720d9, 0x380de704,
	0x2b76ddef, 0x67e7854b, 0x9db11e40, 0xc03bfb84, 0xc78c115b, 0x8ee9bc00,
	0x2f829123, 0x3d7c00d4, 0xc03a4174, 0x4cddaaf8, 0x22c538f3, 0x16cf485c,
	0xfe90c6ab, 0x3fc2fdde, 0x13ab7410, 0x6daa773c, 0xcc0f3ecc, 0xe97dc9ef,
	0xaa7fec2e, 0x29b84cf5, 0xcf47fd0a, 0xda9bc442, 0xed1a2bbf, 0x33b6aee1,
	0x90473ac3, 0xcf845b7e, 0x143deccf, 0x9df119e7, 0xd0f3f7e6, 0xafcfd0f4,
	0x22b51cde, 0x33444fd8, 0xc0d2864b, 0xfb5b4a47, 0x249194bf, 0xa1f50c7f,
	0x1af98337, 0x974dde61, 0xce9a7e0a, 0x46f7289c, 0xb8720f7a, 0x920d8fef,
	0xfb8764db, 0x7e3bc401, 0xe6872d27, 0xf92c60f9, 0x5b473383, 0x22bf384c,
	0xfa537686, 0xe89e727b, 0x04e7878f, 0xbdfd27e6, 0x9f67f99e, 0xd197b91d,
	0x3d209fbc, 0x4ccb9cc4, 0x183d6700, 0xc1995585, 0x5d13f7f3, 0x6b3cc56a,
	0x2afca2c3, 0xb76d8bcc, 0xfa94e89c, 0x3cf7ab20, 0x709b4e80, 0x6b816f5c,
	0xfce9079f, 0x235728d7, 0xe1dcc9e2, 0xe615ff40, 0xc9e719b5, 0x10522af2,
	0xb4a2530f, 0xdfbea33f, 0x5f1194bc, 0xf9867a9f, 0x6f49829e, 0xbe226ddd,
	0x212ecf59, 0x74c4bffe, 0x147756fa, 0xec76f5c9, 0x6cd1db9f, 0xed9bfd42,
	0xaf509a73, 0x3168eb0e, 0x3c1f8899, 0xc07be3cf, 0xc03319d3, 0x834b7c37,
	0xc2f91dfa, 0x0a72217f, 0xe7cddb74, 0xf126e9cb, 0xc3f04136, 0x1a1bc404,
	0x89f32e86, 0xde00b0ce, 0x2d2c2e80, 0x8c78f7ae, 0x9e206675, 0x3a385fda,
	0xabc613b8, 0xade8f97b, 0x3fba9788, 0x8a1988d9, 0x062c34fe, 0xfccbfef9,
	0x89cd7ed0, 0x336e0d25, 0xb15be330, 0x6a076459, 0xfd158758, 0x6eebd005,
	0x975e9073, 0x4b5edc7e, 0xbf8e0947, 0x96ca8c77, 0xb8cf9e02, 0x10b325c6,
	0x1fc7a2f6, 0x9b2dbf40, 0xec22dfb1, 0xe42f8fc8, 0x323f70c6, 0xb182ec8e,
	0x7325defd, 0xbe9645dc, 0x2a3bdbc7, 0xf41f06fc, 0x43f8312f, 0xf6e589ff,
	0xdb8e252d, 0x1acc5063, 0x8ff279c2, 0x1e179f76, 0x30f9cc9d, 0x4e9e019a,
	0xb47f7f6e, 0x24e8f817, 0x45fdb8eb, 0xa2afb794, 0x32575d68, 0x4bd1c3ea,
	0xbcf901ed, 0xfdcf8f32, 0x8adfe7ca, 0x92fb4276, 0xbc12bbad, 0x92bbf841,
	0xe1eabf99, 0x2efc4ceb, 0x77331f9f, 0xb07a460e, 0x39278f17, 0xe1792ca1,
	0x07ce04d5, 0x3a026eb0, 0xee7a122f, 0xc828f80f, 0x5c592eef, 0x1d1a2ee7,
	0x8776d7a8, 0xdd705f33, 0x25c561dc, 0x14776d71, 0x6b183f3d, 0x603e404f,
	0xd43f58fd, 0xebe27d37, 0x7c69f102, 0x77b9f12e, 0xf40cf1d4, 0xc3ecbe2f,
	0xe05abe2f, 0x97ef87bb, 0xd945dc78, 0xdf9bfa81, 0x43b9b7a8, 0xfa2e1bf4,
	0x9e5d719d, 0x895f7e8c, 0x11c83fd5, 0x23e11e32, 0x7a788c38, 0x24756ce3,
	0x6ec7fb8e, 0x7050a4db, 0x7d338a0d, 0x5ec1f8bf, 0x2fc82a80, 0x267b318c,
	0x64ff71c4, 0xd7a834cd, 0x4c533b0d, 0x2fc96ceb, 0xc95def42, 0xbf28edbc,
	0xf490fe46, 0x74138a2e, 0x4869634b, 0x939c7b37, 0x07908df3, 0x3c461f29,
	0x56c9cb1a, 0x1eb509e6, 0xd783dfe8, 0x7d05e670, 0x0b7afb78, 0xceb7f9d9,
	0x347d3c7e, 0x75d1fbf0, 0xf832c716, 0x76279ce4, 0xef0c3fa5, 0x39b28ce7,
	0x751fa814, 0xdca107fa, 0xbaa13f57, 0xae8e1f91, 0x26693dbb, 0x7e400fae,
	0xea8e006b, 0x3e7a16f5, 0xf41dfd67, 0xeb90b8fc, 0x871227ea, 0x6b7cbea3,
	0xa424aaf7, 0xee6f9ce3, 0xd974819d, 0x1f0c756a, 0x16cd6505, 0x84145dc5,
	0xc21b79ef, 0x26adf575, 0x21e70736, 0x4f14cae9, 0xc0277bcf, 0xe99c4773,
	0x7e9df9fb, 0x7e09dfbd, 0xdc711de6, 0x0ebb2fbf, 0xe6375de6, 0xbbf7f90c,
	0x7b208b5e, 0x4a944af2, 0xd47fa47e, 0x32f37dff, 0x637e17a8, 0x278f9176,
	0xd0513ce8, 0xd2623c19, 0xbc6155db, 0x9982f85e, 0xbb42d0fc, 0x83f6f84a,
	0x23222d5e, 0x844d45af, 0xfd923f76, 0x5c8f09d4, 0xc626ed0e, 0xa1da1858,
	0x95e7f91f, 0x5793b030, 0x760f9b75, 0x80a7cd06, 0x8bf46669, 0xf74599f3,
	0xf444657c, 0xc2d7e853, 0x87b46660, 0xf7fa6185, 0x7b5d0713, 0x8989fd1c,
	0xc973fd0e, 0xff208f7f, 0xc6f40645, 0x7f3ed7ae, 0xb3cc3268, 0xfe4aaf6a,
	0xf2f4f9f4, 0x6caf38db, 0xe51bf7a4, 0x5bdfa05b, 0x9d6f3b02, 0x153cba3d,
	0x614f2bf9, 0x7a3ae718, 0xfe5cb436, 0xc615e855, 0x0343ce80, 0xcd752e74,
	0xd8a3a9ed, 0xd05bc94f, 0x2ff84753, 0xbb7d9f5c, 0x67129abe, 0xda30f925,
	0xfcfca30f, 0xc947ecb7, 0xbc3357a8, 0x877f2a76, 0x5cad89e5, 0x85f51aff,
	0x37f45ed1, 0x9d80d9e8, 0xa2767550, 0xc493ea3f, 0xa5617b60, 0xfae03ff7,
	0x07a953f8, 0xe0c7d783, 0xbcbe10cf, 0x2eb4cd63, 0x20ebbf07, 0xe5111bb6,
	0x9007cf8c, 0x22b23b96, 0xdb65af51, 0x05c59f3d, 0x6f86a5c5, 0xfea13669,
	0x58d789e8, 0xb91b71f4, 0xc7113d7e, 0xa15de6f9, 0x4afd61d7, 0xcfe97eeb,
	0xfa563f4a, 0x197c72af, 0x67ca6b07, 0xcb106e3c, 0xa1acebfd, 0xc603934e,
	0x4524b95f, 0x7cfc0c3b, 0x952712df, 0x5d50e86c, 0x72fd17fc, 0x19dde7ec,
	0x4cfaf341, 0xb9448f71, 0xe684a95c, 0xc1789caf, 0x7e4dcc3f, 0xbb3e7c80,
	0xcebeb420, 0xbcd33788, 0x31bd1ff2, 0xcfb4fd03, 0x40ca6fda, 0x2199fa3d,
	0xbf17dbbe, 0xf1e4283f, 0x622f617e, 0x01e01c45, 0x83a81394, 0x695b6b34,
	0x9b926e9e, 0x40dc96fb, 0x164bc3e5, 0x9f167bd3, 0xf23af049, 0x040f73df,
	0xad5e1dfa, 0x6d983d92, 0x858e0f75, 0x4cc3877e, 0xd4384f14, 0x7b693510,
	0xb4673e14, 0xe8fd9c7e, 0xe0de8de4, 0x47989f38, 0x89ccf35f, 0xb8f66eff,
	0xa3467596, 0xc7e1ea5d, 0xf2ecbd7d, 0xb889f165, 0xc24cec5e, 0xc74af576,
	0xd8b42de0, 0x8e08caea, 0xb5db55cb, 0x62d76c1c, 0x2e51c365, 0xddb8225a,
	0x3e39c231, 0xcad9f39e, 0x5f054325, 0x80c3b4b8, 0x7fa37faf, 0x433ffd07,
	0xee82157b, 0xbf7e8957, 0xc5576bb4, 0xc8a3fd13, 0x0079a74f, 0x68c6a4bf,
	0xd61cf805, 0xd0f14565, 0x8f326c6e, 0x77663dcf, 0xf0a3ecf4, 0x9afb8df5,
	0xb7f110f8, 0x463de2be, 0x3c090e38, 0xb240e31b, 0xe9a07194, 0xf2c166b0,
	0xb507388b, 0x8c217197, 0xff8a877f, 0x7ae78d6c, 0xd4d34533, 0x72df6748,
	0xe839eb97, 0x75ce3155, 0x7b217303, 0x69684f25, 0x6a57f8c7, 0xc6296f91,
	0x8d629ac7, 0xc70de872, 0xc7965975, 0x7685e494, 0x7c9e1d49, 0xbdea146b,
	0x992f8224, 0x7a452c35, 0x344c7ae5, 0x11dddce9, 0xa62e453e, 0xa168c9a1,
	0xc342411f, 0x4506de51, 0x7e10167b, 0x62343567, 0x86ad3e3c, 0x571c33ef,
	0x30e2033c, 0x446afa0e, 0x99777f48, 0x0a531fa0, 0xf814b1fa, 0xe10b06ce,
	0x2fc37721, 0x7378456f, 0x566d5c37, 0xbf21e282, 0xfb50b789, 0x1bceafe3,
	0xbf89f140, 0x667658d8, 0x151f71ef, 0xf029dee3, 0x9a1acdbd, 0x7a121eef,
	0xe9eb3be3, 0xf473f04e, 0xf8a1fa7a, 0x5d5a78a0, 0xd3d269ed, 0x3edcf175,
	0x796e6e3c, 0xf3e01fad, 0x85cc59f1, 0x69b79f78, 0xb759c53d, 0xc1ae5b59,
	0x9d6f267d, 0x65bc6189, 0x7a7f6bf7, 0x89fa1fad, 0xd0a39cb3, 0xbfe9e83f,
	0x3e137377, 0x1b0e7c7f, 0xf54ff885, 0xdc60a83d, 0xcde19fe5, 0x6e7faf84,
	0x30a5b1b4, 0xb6efb9a5, 0xa853f35c, 0x3131adaf, 0x79c62bd4, 0xa62c97c3,
	0x16fd2c14, 0x3fa71e53, 0x77493fea, 0xd22b2c60, 0xf10dd243, 0xddca15b7,
	0xf8279f1b, 0x308b5c25, 0xe7063dbe, 0xe41af5b1, 0x71357e93, 0x2401c60a,
	0x4ed7df5c, 0xf3f680fc, 0xf110f8d5, 0xf3f610e5, 0xb4676c0d, 0x99bb469f,
	0x22ded76d, 0xfb1e77fd, 0xe1f04339, 0xf43f420b, 0xbee063ec, 0x4cba0857,
	0xd715ef8f, 0xb9e104fe, 0x7176b8d8, 0x3627df3c, 0x5b37b5c6, 0x8e6d1eb9,
	0x0d4db763, 0x02f90f21, 0x5d23d35e, 0x098bb456, 0xbd484a6d, 0xeb9d98f4,
	0xa79bd025, 0xdf720f10, 0x4357a8c3, 0x389ff7e0, 0xfc5b619f, 0x4e55b13b,
	0x7448a0ec, 0x07392ebb, 0xdf10d5eb, 0x87c08ff9, 0xfda31173, 0x2303674f,
	0x1f75047d, 0x15f9ee0f, 0x8f403fd4, 0xf9ee3873, 0x756e9ff6, 0xc9bf13e4,
	0x6245a6fd, 0x6f7e48df, 0xd3a70250, 0x3c2d0ead, 0x8bf71121, 0xd8fbeb42,
	0xdfce4504, 0x13fd0091, 0xbedd3116, 0x494fdc8a, 0xd62af068, 0x8c2b345c,
	0xe203a4e2, 0xd02d4b3d, 0xe672ebae, 0x31ea0a7a, 0xd47c8ee5, 0x5c737197,
	0xd2efb8ed, 0xd5c79274, 0xdf30169b, 0x1f282532, 0xdbe593c0, 0x16e9c998,
	0x7697aebc, 0xec0fce45, 0xc381339d, 0x5f658595, 0x9407eef6, 0x85c2572b,
	0xb063a5f9, 0xfdd285dd, 0xaf3e04ca, 0x59fdd1f3, 0x21efd707, 0x109857be,
	0x4f80cf82, 0xcf12128a, 0xb1f127cf, 0xf94fb717, 0xfdf2a445, 0xf1bdcbd6,
	0x0842737a, 0xc4bab57d, 0xf38cd434, 0x50ae1164, 0x212eaf76, 0xbf9dbfea,
	0xbae02751, 0x278dfca8, 0x4569d17f, 0x07fdcb3a, 0x6f31af09, 0x6d1e67a3,
	0xf75c68ca, 0x4b3aefe5, 0xf6a9f9fe, 0xef3fc9af, 0xbfc17f9d, 0x00f910bb,
	0x46a899e0, 0x5e9cfc91, 0x2a09e3c7, 0x026afe73, 0x58f7cdc6, 0xfc49cf98,
	0xcd0bfe4f, 0x19a7ea17, 0xfdb1f973, 0xe3d93b16, 0x1267d7ea, 0x4cf2639e,
	0xaf8419cc, 0x39822d58, 0x3f15f083, 0x4f574e29, 0xb5d3f774, 0x4b21be4f,
	0x73d53ef7, 0xda7dee89, 0xbd5d1c9c, 0x5d78c37f, 0x0b8b01fb, 0xef4cf574,
	0x03f6bab5, 0xd5d34c57, 0xd26f9bb3, 0x1e1cdfb5, 0xf3ed14fd, 0x418eb578,
	0x6259df30, 0x56d643be, 0x1881faea, 0x6d3f71f9, 0x17f720b6, 0x28f78b9b,
	0x89664860, 0xdf30c8f8, 0xb3b8dd3c, 0x0df1f59b, 0x2d7aeb33, 0xe757f00d,
	0xa87e5c53, 0xbfd5af57, 0x9ebadb9f, 0xa7d739f0, 0x937f3e7f, 0xadf23ebe,
	0xfcf386eb, 0x9468f719, 0xe8253feb, 0xa5e725e3, 0x77c877b3, 0x452db3a2,
	0xa770e74f, 0xfc46ce9e, 0x338d0e45, 0xdf7f87bc, 0x4bbb3f82, 0x2dff17cf,
	0xf01a75fc, 0x73ca2535, 0x4cf4e508, 0xf71522eb, 0xbe24d89f, 0xf5a67d8f,
	0x9d7b91ab, 0xb255f621, 0x7cabed7b, 0x5f1c1091, 0xa72afb16, 0x32ed7f70,
	0x6bfb0176, 0x7885febb, 0xb2e581b0, 0x9e5e1e60, 0x3f67ac2b, 0x8fb03c2d,
	0x3d5fd462, 0x39e1d876, 0x16f7df8b, 0x1b21f604, 0x98d8f7a1, 0xa708dc8f,
	0x79928fdc, 0x869f322a, 0xca79f145, 0xe60f0071, 0x8bcc44c4, 0x75c48b8b,
	0x0bddd6dc, 0xf3225d69, 0x87c89869, 0x931fe10b, 0x5fc16d1e, 0x46aec953,
	0xbb218e26, 0xb20c4f6a, 0x49df32ab, 0xc6bed5da, 0x7d4efb91, 0x954eca95,
	0x94bad1f6, 0x2153d708, 0xc490faf4, 0x8e5f69ef, 0x0ec78af5, 0xe3d20c49,
	0x799c7775, 0xe03bf50d, 0x9f9c12fd, 0x53760edd, 0x5fcdd809, 0xbc934645,
	0xfaaebd75, 0xd383c086, 0xb898ce61, 0x31fd8111, 0xc213bc23, 0x4d8f28d2,
	0x710cdbd6, 0xee1ca69b, 0xe44b8cc7, 0x3b3f547e, 0xc4cabbf7, 0xeb0deb3c,
	0x7c15fa86, 0x30d20c7d, 0x5fc82da7, 0x53b44b28, 0xf9910dfb, 0x7af70865,
	0xca685f11, 0x4d7be854, 0xddf6428a, 0xc32828ea, 0x90937ef9, 0xb1658a5f,
	0xae196ef8, 0xe6bfe1f9, 0x538f0e2c, 0xf1c89be4, 0xfb7913c3, 0x2a02c4f0,
	0xc21d12cb, 0x825c728f, 0x52247ef4, 0x6aad71a3, 0xeb96fde8, 0xd13fb912,
	0x31ca3182, 0x28993901, 0xe858a6e4, 0xdb5f8c31, 0x92b49848, 0xb8ba4989,
	0x04d607f5, 0xa856b711, 0xe6fa86bb, 0xbec7412a, 0x50dad8e2, 0xa7546ec7,
	0xeaf638c6, 0x96c71e70, 0x715eee71, 0xc871576c, 0x21d23638, 0x0f202e32,
	0xfb3d8975, 0x6fa8e960, 0x469ead5a, 0xed748f5c, 0x1e16bf00, 0x5275f50f,
	0xbdd2fb7c, 0xeeb85d03, 0x3b64ca68, 0x4b3fc8ed, 0xb7bf4319, 0x2cb4d3b5,
	0xf6afde1c, 0xbfbe0732, 0xcf5f1d7c, 0xba75af54, 0xae529a70, 0x24cc481f,
	0xdd6059bc, 0x7ec1cf68, 0xde31dad3, 0x8b3a7abd, 0xccd0b343, 0xd1a30b9a,
	0x42c758cf, 0x0956a7ae, 0xdfce4f3a, 0x27fca2a9, 0x851f0176, 0x44aad3a0,
	0x57e7f493, 0xeb8d1f22, 0xfbe19cf2, 0x903f5c4c, 0xdb75c38a, 0xe1f9136e,
	0xc6f7fec6, 0xfd803e14, 0x8e85f52e, 0x39d8b4e3, 0xba442f1c, 0xb6ed497f,
	0x0f515a77, 0x3a7d4b55, 0x40ccc4cb, 0x5d04ebf7, 0xf3c75baf, 0x73d9d813,
	0x7fe954e7, 0xa19f1a31, 0x6e9ea89e, 0xa45c61f7, 0x4bd32dba, 0x8a15b970,
	0xbdb7d4fb, 0x757ac6eb, 0xd703ae6e, 0x995fdae1, 0xb9286472, 0x23eb8c6e,
	0xf5223b33, 0x04d5d903, 0x26994fda, 0xeec5adf8, 0x6f413824, 0x7c048eaf,
	0xba5baf57, 0x3e53f313, 0x7da32dfc, 0xd76a7d93, 0xc7ec1c58, 0x39c59c80,
	0x39599a58, 0xd0a715e5, 0x38c5d338, 0xbbe1afde, 0xfeef8161, 0x9a75edb8,
	0xf30b3ecf, 0x9d1f0186, 0x277ae97a, 0x894db1fa, 0x6be22e61, 0x5fb8dfb1,
	0x4643dcf5, 0x8755dcc5, 0x16d8dda0, 0x877cc0e9, 0xdc7d2f53, 0x9fffe31f,
	0x1d8cfcfe, 0x99bfc2fd, 0xf798ecbb, 0xf7eeec7a, 0xf3d01aed, 0xca55bbd3,
	0xd855ba9f, 0xb7f78901, 0x92b3fd04, 0xef11bbdc, 0x66f92db7, 0x103e706c,
	0xfc489c5b, 0xd2a7d73c, 0xde8f52d6, 0x49c604dc, 0x75e367a7, 0x6bd7a975,
	0x87d7a1cd, 0xfb97126a, 0x5bd65bb9, 0x7df89cd3, 0xfdf847cf, 0x47ce6663,
	0x3e2bb6c7, 0x9e00666f, 0xaca32dca, 0x6feaf069, 0x47e6366d, 0xb0ee64fb,
	0xad5f7cf0, 0xf0be0144, 0xe11bfa08, 0x48e5ed7c, 0x2ff66f1a, 0x80a8feb9,
	0xfc062d6f, 0x92e6da7a, 0x63ce305e, 0xe2cea7f6, 0xecebc064, 0x3f430a95,
	0x0ddfdb08, 0xbe2cf3f4, 0x7fb8eff7, 0x85679c6a, 0xa407af57, 0x7416aafe,
	0xff42b99e, 0x3eedbabe, 0xf316671a, 0xd1833e50, 0xbb6ea9df, 0x1bfa28e6,
	0xf4e73f46, 0x2861d19e, 0x144aff0f, 0x3658cc7e, 0x6ff41cee, 0xf18aca8c,
	0x59279084, 0x20e2589e, 0x497cfd66, 0x96c79518, 0x27772a30, 0x69ae3e72,
	0xfd18b77b, 0xadd6ba9f, 0x1d176f24, 0x1e3b6f07, 0xd80b137d, 0x27b318d1,
	0xf8f50926, 0x0f17451c, 0xc67f5baf, 0xc0967e4a, 0x5e78b94f, 0x3a00f88e,
	0x2b5cccdc, 0xca7d0026, 0xfd812c6b, 0x392ff826, 0x1c77cc49, 0xf0bd57cc,
	0xd679caf9, 0xe7257b0a, 0xddfbe46f, 0xdacdaf42, 0x1fa9b530, 0xa5f1a4a0,
	0x7c9d19a3, 0xc201f6bd, 0x9aaaf92f, 0x43538bb9, 0x67a48ff0, 0xddb49f0f,
	0x7491f34f, 0x215cd59c, 0x114dede6, 0x8c14c4f1, 0xc6f91a27, 0xbe4627c8,
	0x99d2d2f8, 0xe46cf281, 0xd847990b, 0xe24c3fcb, 0x9cb33379, 0x09c6315a,
	0x13773367, 0x24f12dc5, 0xb39418c4, 0x867ed7e6, 0xf381b672, 0xfd04dff9,
	0x29e4977e, 0x9e7e824e, 0x21d4d765, 0x6d4b9ddc, 0x9e7f2819, 0x026aa965,
	0x51acf7b4, 0x2c166f48, 0x9e22b54b, 0x551f2e66, 0xc398728c, 0x96ff1a34,
	0xced21678, 0xaf790bd7, 0x6b30b06c, 0x1587090c, 0xae4eb5f3, 0x0b5f2850,
	0x814ba3f7, 0xb908e62f, 0x6ef95da9, 0x2717d934, 0x698b1bfc, 0x4e67fceb,
	0xdde13543, 0xbe4befe8, 0x86a07692, 0x615358b5, 0xdbab79dc, 0xf5c6ff09,
	0x4d5b3d40, 0x316daa74, 0x9ab86f3c, 0xb73306e8, 0xbeab3ae2, 0x90deb0d5,
	0x2e62e8fc, 0x9dcf47e4, 0xa7cc30f6, 0xa9f8102b, 0x5038ad58, 0xde5ccccf,
	0xd43d789e, 0x5d51ee67, 0xfc1e9d30, 0xb4eb5eb0, 0x75079411, 0xad364f7a,
	0x9d3b4fd7, 0x13ced8c9, 0x8af1d7cd, 0x9f0e33d9, 0x19ef12df, 0xaeb27187,
	0xe619d8bf, 0x86e81d95, 0x25e63b95, 0x9491b184, 0x2360e3d7, 0xd7f906a7,
	0x12471615, 0xd97993ee, 0xf7c614c2, 0xf182c37c, 0xbab61f53, 0x9eb6f903,
	0x7e62bd99, 0xe88539ca, 0xebaf2647, 0xd7f28505, 0x8bc5ab58, 0xc2c618f2,
	0xd7be6296, 0x52736771, 0xdf773c2b, 0x5abd2163, 0xd69625b9, 0x0bcb9597,
	0x2b0768ad, 0x3f92c7b7, 0x0fc2eb03, 0xd00d8d06, 0xd1f2c0f3, 0xb8c0a5af,
	0x2e992d95, 0xc3c74f55, 0x79c746df, 0xfa480e2b, 0x7e83ee1d, 0x0fd14387,
	0xee7ba6e8, 0xdd8dd033, 0xb0764f1d, 0xd9abc17c, 0xe9d70061, 0xcfca7086,
	0xc27d6beb, 0x7da78d66, 0x99bf196f, 0xce27afd4, 0x6725f942, 0xfa218f56,
	0xe936e919, 0xa1c7333f, 0x6afeca7f, 0xdd17e867, 0x36dd9032, 0xa6df9e0d,
	0xa5bb7970, 0x68499af1, 0xe2485ff7, 0xd01de8fa, 0xc610da5b, 0xa57d05de,
	0x1f7abe81, 0x3fd619f4, 0xf542925c, 0xa938978f, 0xa192cbfc, 0xf1161e54,
	0xc077296a, 0xafb7c408, 0xf6bd7124, 0xf7dc924a, 0x2e82945d, 0xbcffa4c8,
	0xbc04c63f, 0x4cf5e897, 0xf825789e, 0x5ede9a73, 0x6f5d30de, 0x8e2d3b0f,
	0x5f5c14e2, 0x7fc854ae, 0xa15f74ac, 0x4ecccf6b, 0x60979e2b, 0x9e074743,
	0x5a73be93, 0xde3f01a7, 0x6baf1258, 0x9a45633f, 0x9271feae, 0xd4c2f493,
	0xcf750349, 0xae1f2a6f, 0x5b7457ab, 0x777e4319, 0x2cfc91e6, 0xb02df912,
	0x7174e670, 0x355fb6f0, 0x09fe4b8c, 0x5ed5fbc0, 0xd237bd0b, 0xd675d243,
	0x6079955a, 0x416b99bc, 0x878801ff, 0x7c92679b, 0x4ecfb17d, 0x2da688eb,
	0x83cedfa3, 0x162d81fa, 0xb0393fca, 0xfa0d7e3c, 0x24b60757, 0x3d283346,
	0x43f0aa4d, 0xa416561c, 0x2f970aef, 0x0ac73ca5, 0xfe45cd9f, 0x6fef6ec6,
	0xeb89dd64, 0xe5120445, 0xe7d503e4, 0x1a7e8857, 0x387377e1, 0x063b679d,
	0xb11e1ffe, 0xe1c9d998, 0xe5b0a63a, 0xfe1e3f58, 0x009fe0c9, 0x9b4b271c,
	0x2f184cab, 0x9226f750, 0x654e7cfe, 0x0be5b7c8, 0x3dffb42c, 0x3d7543f7,
	0x939299d6, 0x52ade9c6, 0x6cdb2efe, 0x1759f1a3, 0x5bb40870, 0x53db7bf4,
	0x338e14ab, 0xd4b8efaa, 0x27f04ab7, 0x58b1d1f2, 0xb012c5a6, 0xf9fbc10a,
	0xf1eb89bb, 0xbe9f007d, 0x32ef3891, 0x19323b8b, 0x2af3ebf8, 0x6fd248df,
	0x5c922777, 0xd87ef119, 0x1797f5ca, 0xe80940e5, 0x2d9c80cd, 0x69983e23,
	0x48b92571, 0xa2a6e56f, 0xdabc3ade, 0x332b7e42, 0x2953d16b, 0xf11cf23e,
	0x61cefcb1, 0xe118b3b3, 0x9322bc3b, 0xe57fbee1, 0x17d6956a, 0xbdbc7fc8,
	0x1f2baf8f, 0x43e03d54, 0xc50aef30, 0xf37b92c3, 0xc60bedcd, 0xd19fbe51,
	0x97e5963f, 0x209eab20, 0x4bde61ff, 0xe58d1f3c, 0x5fa79a76, 0xe58f3c1a,
	0x3c9e7bfc, 0x4d4c9e5d, 0x47f79fd6, 0x0fcf5099, 0xfebf418c, 0xf12a07f8,
	0xe6acf1d9, 0xcf4029b1, 0x639da613, 0x2ff5027f, 0xcc47bd4a, 0xe116df50,
	0x78c64bc9, 0x86756986, 0xe4f98592, 0x015cd687, 0xc67f3efd, 0x173122e2,
	0xcdbcf97e, 0x9b7c0773, 0x46fe043f, 0x6877ee3f, 0x73e00aa9, 0xe0c5b3be,
	0x38fc700f, 0xf0013931, 0x414478e2, 0x1a1d8b5f, 0xeb855f63, 0xe62699e0,
	0x0fdff609, 0x31bfb859, 0x15eb9939, 0x983c37e9, 0x3312e3cc, 0xd9bf9c4d,
	0x37e70acb, 0xed82a3f0, 0xf3dbd480, 0x0d579f31, 0xb7a901d8, 0xe533586b,
	0xcc9adc55, 0x8ab997fd, 0x3ae4fc8f, 0xf68090cc, 0xe9be0e55, 0xe6c9b353,
	0x98d265f3, 0x60ff608e, 0x27d7327d, 0x3ccfacf3, 0xcd5bec8a, 0x0d3cf83a,
	0xf8b73eed, 0x7b323aaa, 0xc72a9fdb, 0x3471e5fa, 0x7185c5be, 0xaf216ad2,
	0xcf8acdb5, 0xb70a7e4f, 0x399e32a3, 0xa351d85b, 0x9765ea7d, 0xb668f60c,
	0x66b2eec1, 0x78059dbd, 0x84acbce9, 0x3ba708d7, 0x98784ed2, 0xfda17007,
	0x5ef8f2ad, 0x15b8232b, 0x17b45017, 0x16bfe03c, 0xe03ce2c5, 0x1bd9dfbd,
	0x7abce33e, 0x69e62bc1, 0xf5cabb84, 0x4b9abf77, 0x2f8494f9, 0x3d243ce3,
	0xa49c7e8c, 0xe397954b, 0x214daab7, 0xe3d67e7a, 0x2b8a321f, 0x2d61be4b,
	0xbfa82ff0, 0x579823e4, 0xeab7ea19, 0x671f4047, 0x79a7e6f6, 0xf91a25ac,
	0x9bf98ea6, 0xee3f7fd0, 0x3971996f, 0xbdd605c6, 0xf29deb4b, 0x29b67f38,
	0x7de95016, 0x5749bef7, 0x88dcf806, 0xf7d1f3ef, 0x670fe2bb, 0x71f19667,
	0x0decd7c0, 0x523e16aa, 0xdde44ed7, 0xe61e4979, 0x8c56bd78, 0x7111ce87,
	0x59c1f3c5, 0x2ee7e66f, 0xc0af0bce, 0xf70d0fe7, 0x0e22c93b, 0xcaefcbd6,
	0x938eb90e, 0xe844fcf3, 0x7bdaf399, 0x467aebb3, 0xc1513ef6, 0xfa5f4178,
	0xf9d84abb, 0xa1f768d9, 0x1b76b23c, 0x7b3febc5, 0xcfed1b64, 0x1d999f59,
	0x91f87e8d, 0x60d733b5, 0x2d91e3fe, 0x57cec933, 0x79da5aff, 0xc107af58,
	0xe2b6b85b, 0xdf239fc9, 0x4ca70a6e, 0x1eddaad3, 0xbd020eb1, 0x6b9ced0a,
	0x8f651eb9, 0x8d5abd70, 0xc1e290f6, 0xeed8219e, 0x10cf2ace, 0xe7a0ffe4,
	0x9cef2764, 0x4bc3f9e9, 0x4f9dee30, 0x34bcba47, 0x44df8765, 0x8fc3bbfe,
	0xe176b0f6, 0x3cf1fbc7, 0x0fffd808, 0x1ff692ef, 0x9ecda7aa, 0x4b0ed06f,
	0xaeab5fbb, 0x9fa070cf, 0xffc4ec20, 0x112bbe36, 0x715fe4df, 0xc15c1f7c,
	0x35687cf1, 0x96d37bc7, 0x7eb8d181, 0x2062b83c, 0xb70755f9, 0x67be1364,
	0x937c02ad, 0xfbd4ed5f, 0xdf002b55, 0x7c407eb8, 0xbb955c03, 0x2edf029d,
	0x1c15ef8e, 0x2f356ccf, 0xabc2f567, 0xee7ff297, 0x85cdadfc, 0x70b1c27e,
	0xc74ff93f, 0x31acaab6, 0x7e92efc8, 0xf3583fcf, 0x933fd06f, 0xb83b9ef8,
	0x97ea2463, 0x1cff07f2, 0xbb9f788d, 0xf5ba6f95, 0x92d337c2, 0x7c0effd1,
	0x724fc7bf, 0xf2098ca5, 0x2e902e93, 0xc8cdcc75, 0x79fdb5fe, 0x1413ae1f,
	0xea1fc78d, 0x56a639e4, 0xcc2639fd, 0xc38f2a65, 0x2c2b8750, 0x3749e10c,
	0x30f2d39e, 0x67fa57dc, 0x5d6fdff6, 0xa5dc7248, 0x632d07cb, 0xbfc60b7e,
	0xe7428b58, 0xe5176b7f, 0xdc33e747, 0x38206ab7, 0xba28a5e6, 0xd55adf7c,
	0x8d62fe44, 0x328dfb95, 0x0a6a606f, 0xa6a607f7, 0xb4ff75f0, 0xa7950714,
	0xfbe919c2, 0x0fab7653, 0xfac0e9cf, 0xefbf0529, 0x7446c97d, 0x01308fdb,
	0x88ab55fe, 0x43a982fb, 0x7199bbfe, 0x6a39bc7e, 0xc19bed0f, 0xb409e4ca,
	0xb62cb77f, 0x4d8fc8b9, 0x9bfda188, 0xbb3e849b, 0x8dc9aa39, 0x2896e076,
	0x8c2586ab, 0x53a4c5eb, 0x1e7c014b, 0x67e96fbe, 0xf2aa3ca5, 0x7067ceb0,
	0xca5b7bc9, 0x00c23ba1, 0xddc0cbd4, 0xfc2cb8c6, 0x7c5cfdba, 0xe804ba6f,
	0xd7138fa3, 0x7b8e8447, 0xa0f02edc, 0x83c51a68, 0x0476306d, 0x8a6771c0,
	0x3a773f93, 0x1d787c78, 0xa01ec9d0, 0xf339f1af, 0x1ac1fdf2, 0xcf1dfbcc,
	0x11e48338, 0x1af575fe, 0xff7f7f2b, 0x3c951fda, 0xf7b18132, 0xa452f398,
	0x0cea0d5b, 0xc457d75c, 0x6cff70f8, 0xe3a7c60a, 0xbf1334b0, 0xaf33334c,
	0xa22b9789, 0xc454a730, 0x3e04cbab, 0xfcc79c7f, 0xff778031, 0xf978faeb,
	0x7f937ef5, 0x8a77e008, 0xfc8edfd9, 0x5a730a69, 0xf71df01c, 0xd7072524,
	0x2ecb3521, 0xdadf5e0c, 0x1ade086b, 0xeca7cf13, 0x1fc78bba, 0x4561066e,
	0x666addbc, 0xce1cd5bb, 0xfa978807, 0xda97a738, 0x3f68502d, 0x25e9c645,
	0xf0c147fd, 0x59bc74c1, 0xace307c0, 0xd6fec688, 0x92daf4d0, 0x2dcbd722,
	0x2f9e8eb4, 0x94be6ee4, 0x797a2db7, 0x84748bdb, 0xbdfa0af6, 0x459bb780,
	0xbc5c97d9, 0x3d7fc62e, 0x9fcfaf85, 0xb1efc8bf, 0x2c3f9e28, 0xc6d6a5e5,
	0x9fdf97c7, 0xe33fca22, 0x00c4afc1, 0x07afc03c, 0x68131c71, 0xc3d7e400,
	0xffe48dcd, 0xfb4161cc, 0x76819962, 0xd77baf92, 0xe988f47b, 0xaed6961c,
	0xe57a8859, 0xd42ee147, 0x5b5b37a3, 0x7aa21bb2, 0xb8fb93b7, 0x42c3ace5,
	0x38c8cef7, 0x1333b098, 0xdbca28d5, 0xf9f85729, 0x76f953da, 0xc0fc09af,
	0x213dc44f, 0xc42fc1a7, 0x2ac794ef, 0x4b74df94, 0x28659dcc, 0x56d1e5d7,
	0x889f9633, 0x656e447b, 0xa7fe345d, 0xeb98ac8e, 0xaa4de619, 0x000707b8,
	0xf704b4fc, 0xff511a41, 0x6d6afaf0, 0x449b4502, 0x0d5ec97d, 0x2cfd31f0,
	0xbdd501f0, 0xf77c1a25, 0x3de2abd4, 0x4ffd4a5b, 0xd9f823dd, 0xffaf0f7b,
	0x555fbe52, 0xad4ffd82, 0xf0d7ef94, 0x7c72fdfa, 0xf0d07f51, 0xfde1a97e,
	0xf5febc63, 0x5e2535da, 0x380b4ff4, 0x578f976b, 0x42695f48, 0xf32f946f,
	0x4dcb9e13, 0xc059793b, 0xf3dca6fc, 0xea9c1bb7, 0xf11252d6, 0x3b61f33c,
	0x69d1e1da, 0xc976869a, 0xa4b1ec99, 0xaa69bae2, 0xdea2b5e2, 0x7647c0fd,
	0xfc8faca1, 0xf5e84d3e, 0xd4dcfd21, 0x1831da5f, 0xf1353a27, 0x21d9c7e2,
	0x271a0ae0, 0xd3c0bbf9, 0x38d7afd8, 0xcf02efce, 0xd238c371, 0xd74a69cf,
	0x58f1c0ae, 0x78ba15d1, 0xb85ffce0, 0xc4ee3062, 0x500b9f30, 0x4b597f3f,
	0x7f1868c6, 0x642fb3fe, 0x255fa154, 0xb75d7dec, 0x47d034ca, 0x950addf5,
	0xc5ffb45f, 0xeb31e78a, 0x8b5bb7b6, 0x943d5da1, 0xd5704185, 0xdec13808,
	0xd905a799, 0x24d52d69, 0x3c83c6f4, 0xe3d9ed9f, 0x7ce7a466, 0x5f91cb53,
	0xaf1efda3, 0x1defdc84, 0xb7e7ca9a, 0x7c3c8fbf, 0xf180e4da, 0x26d0caee,
	0x6087fe22, 0x0bd4046e, 0xdfef431b, 0x28e0203f, 0xe66ff617, 0x13987b58,
	0x03e63cf0, 0xb55ddfbe, 0xe307332e, 0x05c945c1, 0xbebc7053, 0x3c5da8e3,
	0xe3c6da8e, 0x1d71e5a8, 0xb389408b, 0xaecfa955, 0xd975830e, 0x39495fe4,
	0xbe859103, 0xfeb26c93, 0x3a51496a, 0xbd61738f, 0x5797b1f6, 0x41ecdca3,
	0x3e6e3078, 0xd408d2ee, 0x91999d0f, 0xe9c60726, 0x21562a93, 0xbb8cb71c,
	0xe79f18b2, 0x2b83ecdb, 0xf89e5c78, 0x3dc920a2, 0x7b63df1b, 0xac787f8c,
	0x61ebc4fe, 0x54379e1e, 0x8cf28bca, 0xda84f48c, 0xf0299ebf, 0x41d52aba,
	0x0263d8f8, 0x70027338, 0x1f83efc8, 0xc603a8bf, 0x752cbc3b, 0xee272ad4,
	0x24afe4b7, 0xffdf127e, 0x4ee7925d, 0x1fefcbac, 0xb8c1b136, 0x3850b894,
	0x58f4176e, 0x78037489, 0xdf8013dc, 0xd373d682, 0xf575228a, 0x4cf125e9,
	0x4ecf8e0b, 0x6fd5d34f, 0x6ba81f28, 0xe1acd37f, 0xb6a5f7ba, 0x2086dc8e,
	0x7f6fb67f, 0xd5704bc9, 0xe811eddb, 0xf6da7dd7, 0x466e8f8f, 0xea83703f,
	0xee759f42, 0xba3f1b4b, 0x9a1e5182, 0x47714f16, 0x3ec9c527, 0xf232a3df,
	0x399accef, 0x24e87f78, 0xf71478eb, 0xf5bae50b, 0xe685f742, 0xbe53763b,
	0x1fb50fd8, 0x58aa74f4, 0x1cb0e6df, 0x1ba78fb4, 0x5d78a43e, 0xe79f145d,
	0x580e17c9, 0xf302af31, 0xdf01ce14, 0xd11d8d5f, 0xc506ec5f, 0xd85ff20f,
	0xd1f6807a, 0x72754dae, 0x817d3f7f, 0xd5e5cf19, 0xa0f68943, 0x0c56f418,
	0x3b474df0, 0xe63b74bb, 0xb9da6471, 0x1d7dde5f, 0x44f7c3c5, 0x9eceb8f0,
	0x9fba58a4, 0x6b8afe60, 0x775d79e8, 0x8eff8d24, 0x794c51da, 0xb42bcfbf,
	0x769a50ff, 0xcf9c32cb, 0x88ef089e, 0xa5bbe1db, 0x127ab87f, 0x3b6eade2,
	0x552f63cf, 0x005dcbdf, 0x35f34d65, 0x6554bfd4, 0x1ff0147b, 0xa66fba62,
	0x07d14b71, 0xd63aba80, 0xb2ed0abe, 0x7e0ff56a, 0xd58df51c, 0xbea6fa4e,
	0x4dfa9c3b, 0xfbf6e42e, 0xffee5483, 0x5c393a5a, 0xd2a7bb13, 0x7f17c97b,
	0xe5d2cd4d, 0x37125b97, 0x1b1ef198, 0xed42a74b, 0x4e1eedaf, 0x1bef9ca5,
	0xe74b7f43, 0x5f892dd6, 0xe05e6315, 0x838a091b, 0x3e8312dc, 0x2e30d33e,
	0x57d08586, 0xe6e9df3d, 0x6eb6b4f9, 0x207b5f9e, 0xb942eb4d, 0xd3bbbb2f,
	0x2c41fb8c, 0xf881cc2a, 0xe51bcb2a, 0x33920aac, 0x568de775, 0x91e58fa4,
	0xff68ad77, 0x0616506d, 0xcdfb97bd, 0x4ffd7d46, 0xfde41fa1, 0x7a3d6560,
	0xf3f882bd, 0x50608756, 0x84874721, 0x1dfecb1c, 0x3a01c6b4, 0xfc71e0ee,
	0xe13cd3af, 0x477de0fd, 0x39e1bb3e, 0x191d9fd2, 0x43f30fb8, 0x0e740fc1,
	0xec6fc853, 0xb2f1bca4, 0xe309a73c, 0xa4fdd1ff, 0x7cf2e1dd, 0x5bfc79be,
	0x951de3cc, 0xdf71c62d, 0x0eaaeab9, 0xff6bc60d, 0x68d1e8d9, 0x0777e417,
	0x7bf7e3f4, 0x59d74731, 0xbfd61f5c, 0xb944e91c, 0x19c5c52f, 0x64be7bee,
	0x3c0b75a3, 0xfa8cfda7, 0xe14f6d97, 0x68faab79, 0xf7c2bf58, 0xf7095f0b,
	0xbfb71f23, 0xfb466e12, 0x67864cf1, 0xf0a7e200, 0xb8452195, 0x6cdad45e,
	0x8ffe4666, 0xd897ece6, 0xd3e7bc37, 0x933e465f, 0xc159e9f2, 0xf042a5e5,
	0x3f90a569, 0x33a3908f, 0x8724c90d, 0xa006ee67, 0x6ef4bf71, 0xe8edd2e5,
	0x74ed382f, 0xcb9499df, 0xc11f5c52, 0xb1e1d2f3, 0xd35fa794, 0xc393ab1d,
	0x214ceeda, 0x5cf4f1df, 0x90a55bca, 0x2ff09b13, 0x96be0966, 0xc7948b7e,
	0x771ee9f1, 0x6973c03f, 0x347dc823, 0xa2e7ebed, 0xc6f8053c, 0x02fe40ea,
	0x0aa949be, 0xf6c69f92, 0x29fa191b, 0xf13704b6, 0x83282ccd, 0x3dd994fd,
	0x4e28e07c, 0x96cbf802, 0x7cf09a67, 0xe3ff7ca0, 0xffc7177e, 0x657da205,
	0xfd1b3f94, 0xb8434b5a, 0x9c7bcf0b, 0x3dfbe04e, 0x3c72570b, 0x0bb8b42e,
	0xf858cfd1, 0x32f14298, 0x2f503ff4, 0x60d7dd8d, 0xdcab8e0d, 0xf6923dd8,
	0x1eebafcb, 0xb2516544, 0x41f22667, 0x410cf745, 0x69df91af, 0xc68c717f,
	0x9f164ae3, 0x133eb5cd, 0x151e4ae3, 0x3fac7ce9, 0xbc1c3c73, 0xa556b79f,
	0x77dc9878, 0x1b267194, 0xb209a79e, 0x3730ffa7, 0x273dd067, 0x3e53b8c6,
	0x3627ffb7, 0xd7fec858, 0xd637bfb4, 0x573fef01, 0x9ed193f2, 0x3f3c5994,
	0x9bccf9c7, 0x02d67be6, 0x6ff7f9f5, 0x19dcbe8b, 0xd98b67c0, 0xb4f68d9f,
	0xf188f005, 0xead596af, 0x7bf71f24, 0x193ef922, 0xcfc96fe7, 0xd79f3e46,
	0x73f0903d, 0x7646c1a6, 0x2df00ce8, 0xd243b20b, 0x2f3d48ee, 0xebe48fed,
	0x5fd7335a, 0x943151b5, 0x3bb015d7, 0xc8f9dd53, 0x7e794377, 0x3ceec05e,
	0xca3c66b5, 0xca04a9c1, 0x4376966b, 0x4bf3c1ca, 0x479f2852, 0x072925da,
	0xfd4b9f52, 0xda5ef92e, 0xffa782ad, 0xf0afedbd, 0x9e697deb, 0x6baf88ad,
	0x5d7edccd, 0xff13b66b, 0x6a984c4c, 0x70b9be46, 0xe8407a3d, 0x3d3a03d1,
	0x1d87d75a, 0xfe8f63f8, 0xd83930bc, 0xb24fda20, 0xf5123f71, 0x5f78f07c,
	0x8ebc15a7, 0x1fbb78f3, 0x287fdbf7, 0xffd2fbb8, 0xfea45f6f, 0xf1c8517f,
	0x81fff4f9, 0x9cbcfc7e, 0x0733df51, 0xd4ea7fbf, 0x687cc34b, 0xb033f60f,
	0xdb07680f, 0x851b9d22, 0x117b203d, 0x36fbe311, 0xc657707b, 0xf7a803cc,
	0x8383d842, 0x777cc6fd, 0x4bf9207b, 0x13948dca, 0x39461729, 0xf9317292,
	0x222f583e, 0xe7e1de9d, 0xdecd6a7f, 0xe8cfb42d, 0xf2851c8c, 0x6dc7e3d9,
	0x7ade4857, 0x3f2109d9, 0xdbd17901, 0x521f290d, 0xd4fca45e, 0x2d98f90a,
	0xc5ca43e4, 0xe1e5b52e, 0x2eafd0f1, 0x369f13cd, 0x35272026, 0x43ed19cf,
	0x91857c9f, 0xa13b3646, 0xd55f2181, 0x57cc1942, 0x21e43eb6, 0xe4e2ed25,
	0x61769ac1, 0x34f0c4fe, 0x17fc4fee, 0x5a7869f9, 0x4462ff68, 0xa7e0f7da,
	0xc7ec7ede, 0xe7804eb9, 0xdbe82e4c, 0x4dbf00cc, 0xff71937e, 0x0f5f2061,
	0xe0933ac0, 0x4fed63de, 0xe7c99ff1, 0x51e20358, 0x45b303fa, 0x69f241bc,
	0x0801f82d, 0xae3fa4a7, 0x985c1607, 0xdb3a23de, 0xb8ac3a12, 0x650d993e,
	0x97d01fb0, 0x8be3fbff, 0xda6173a4, 0xaa8de985, 0x6fdc1fb4, 0xae83eaac,
	0xae87dfd5, 0xc44c85a5, 0x5aa5fc2b, 0x01e7d03a, 0x2aeef751, 0x91997945,
	0xdfb7df27, 0xfd420daf, 0x9c9c64c0, 0xa8ef1de2, 0xadf3beb2, 0xf93f6822,
	0xa3881661, 0x1389fbc3, 0x23e27a62, 0x6fb40b0a, 0xade57b4a, 0x66e784d5,
	0x69d29791, 0xa241fbe6, 0x7b750b9e, 0x50cf3d50, 0x47dbc75f, 0x70593b9b,
	0x8df208be, 0xece9c392, 0xe01ff20e, 0xa0cfbbf3, 0x0c2870bd, 0x09f51be3,
	0x833d5feb, 0xa155ad7a, 0x3c1ea9bd, 0xc528df78, 0x3bdd2bf8, 0xdfb7f54d,
	0xb4df79c2, 0x799fd79d, 0xbdfbbdfc, 0xd06e3166, 0x8b4b1cb9, 0x41be51a2,
	0xcacbe29e, 0x67ef8dec, 0x299fa4d2, 0x6e7461e1, 0xc33fa820, 0xe98bbc7c,
	0x9cc793df, 0xb6fdfd45, 0xf5fef88b, 0xa79f4213, 0xa1e425d8, 0xe4263728,
	0x54d337fb, 0x37117dfe, 0xa3c3efa0, 0x9f425aeb, 0x7c5f7f37, 0x4ff703b7,
	0xde5f9f08, 0xb0edf88f, 0xa49f7c4a, 0x74c644fa, 0x3ef83471, 0x7e3ff7d5,
	0x998574b2, 0xe033574f, 0xbbe6dbeb, 0x0fef4d35, 0x7a066fd0, 0xdf05bed9,
	0xdbe0423b, 0xffefefa9, 0xd8bd7a36, 0x6f82fbeb, 0xd63e48e7, 0x631efc74,
	0xc67f1376, 0xf40e2824, 0xe1dceba3, 0x10bd71ab, 0x917fcf90, 0x7dc8767c,
	0xf7f25e82, 0x5fca2975, 0xcf1e0f5d, 0xd07a8fde, 0xcf69ea6d, 0x35f251e5,
	0xbc02351e, 0xfa0fe852, 0xfbfda777, 0x024f8c7e, 0xaa7bd05f, 0x36e0839b,
	0xa18b63ca, 0xbf20c13e, 0x7f48fe42, 0x3c003da0, 0x4b7ea365, 0x06756038,
	0x3a7249f1, 0x9149f3c7, 0xc051de2f, 0x2c8ec9fd, 0xe74b8e5e, 0x7480e3fe,
	0xa221cf8e, 0x1044477d, 0xfc75d21e, 0x4b75c7e3, 0x4f09bcd0, 0x79482637,
	0x012b2b4e, 0xe388ee79, 0x4bad47ef, 0x109de35e, 0x1bc71ba8, 0x0cad2ebd,
	0xbe33d2f1, 0xd46df537, 0xbc0a378b, 0xefd75b8d, 0xa0946f6d, 0x3ee05273,
	0x2f0fe04f, 0xe45a83ea, 0x1e84250f, 0x5e9fcdee, 0xdfba7f43, 0x96feafbe,
	0xa9fc5ef4, 0xbc33fa19, 0xfbc2e0af, 0x1895ba0b, 0x40c93ae8, 0xbd4322d7,
	0x3a7dd65c, 0x72f52bfd, 0xf783eb65, 0x5c602524, 0x41e3a153, 0xa4be7e01,
	0xbe7ee50c, 0x70eff243, 0x9f806bc2, 0xfc8dbc47, 0xf245ad3b, 0x346ba5eb,
	0xa8a9c7e0, 0xea07c787, 0xa21ea1d7, 0xed32c8fa, 0x757b60b2, 0xdbd41ad9,
	0xed90afd7, 0xa6fed45d, 0x51bc72e5, 0x91d25ef4, 0xa2329cb1, 0x57b4ae6b,
	0xf7c6dfa3, 0xff78daf3, 0x6fb9e979, 0x8b7d077b, 0xf01b343c, 0xf750ceb2,
	0x723fda1a, 0xdcb6fb1e, 0xc36effd0, 0xfa86d5fb, 0x857d435a, 0x2cc57fbe,
	0x22b0e485, 0x1a53ef8f, 0x1fc8d2e5, 0xf1ef4d3f, 0xb9ec7b67, 0x9dfe4512,
	0x3726ae4e, 0xf4f2faf2, 0x2315b2fc, 0x0aebea82, 0x6e186e48, 0x2f9d06b5,
	0xf74b9d06, 0xd0fa591d, 0xe2fb0b9b, 0x7b46a1cb, 0x79e5d5ef, 0x23a1efee,
	0xaa976b87, 0x02abb7af, 0xedfbaf6e, 0xfbc15145, 0x70ca53ab, 0x3ee7d11d,
	0xacb4b78e, 0x622fd828, 0xd05a65a5, 0xe2fb653c, 0xf8a9ce6f, 0x2baf5fbd,
	0x8510db29, 0x7f629efb, 0x60978e33, 0xd7b4552f, 0x537e22f5, 0xb8ba798c,
	0xcfe1149f, 0x6822385e, 0x3065ac9e, 0x67fdb3ce, 0xad47bf2a, 0x8993e811,
	0xf2939dde, 0x8d32674c, 0x63db4ef2, 0x0eff1662, 0x99faedfa, 0xf4ed18ba,
	0x94f1c5fe, 0x74aff4c7, 0x15dd5ebe, 0x36692033, 0x6f23dbd4, 0x7edb7d23,
	0x772a44ef, 0x97535aaa, 0xd617b183, 0x0d459795, 0x8431f7c3, 0x37e91da7,
	0x5385e194, 0x824ee9ad, 0x48e713c3, 0x7b7f456a, 0x0df68595, 0x437e7e41,
	0x6dbf73fc, 0x2bb7ae14, 0x7da70e96, 0x4e5fcab1, 0x9d73c62d, 0x6858f795,
	0xe4d3a4bf, 0x679138a0, 0x93ca44d5, 0x945cb59a, 0x7ca9abde, 0x6dbf3fe5,
	0x5d9f73c4, 0x8f74284f, 0xb55f95ca, 0xea1239bc, 0xd2062bd5, 0xbb978bf9,
	0x7df7944d, 0x1f10ed70, 0x0a1f21e6, 0x51fca06f, 0x4fe74f68, 0xdf3acfab,
	0xf6c5cb2e, 0x385303aa, 0xf473c08e, 0x54ac8f9f, 0x9573c29f, 0x08f6d115,
	0xf23edfcc, 0xceb8a30d, 0x746c7b91, 0x28c1cb1f, 0x136badcf, 0x7a129ce8,
	0xe288ecfa, 0x0f00568c, 0x2fcfa51f, 0xe7c5494b, 0xf9cf4136, 0x878015d1,
	0xff0f530a, 0x8aa93d90, 0xd68ff5e5, 0x08db2bcd, 0xd8f23c78, 0x9b17ca10,
	0x38fb5fd2, 0x969df01d, 0x1f4beda1, 0xbb72f083, 0xf87fcaf5, 0x278be4be,
	0x6e30932a, 0xf5f05073, 0x4995ddcb, 0x57e1f7c1, 0x1f13349d, 0x2e7562bc,
	0x2334fba2, 0xceb82bfa, 0xc7883e06, 0xb12cf9b8, 0x5e7e016e, 0x7f842dbc,
	0xd2ae96d5, 0x25f7edb8, 0x06fa404e, 0xd22efaf8, 0x80deb4a7, 0x3bf499fa,
	0x8f8178d7, 0x6316db0f, 0xbe4f74ae, 0x4e15db23, 0x096cb278, 0x626785f7,
	0xc62b54fc, 0x65a52c7e, 0x907b34f0, 0x9ff68a1c, 0xef7e797a, 0xd71ed0a7,
	0xff7a9f7d, 0x3f783d8f, 0x8eafb643, 0xb9d17bb6, 0x9bb76a38, 0xcdfb1e91,
	0x7e608e4b, 0x1613d55a, 0x4f5503b2, 0x85ddde24, 0x06f807fa, 0x79c66be3,
	0xd0b7f7e5, 0x5fdefabc, 0x68acb7bd, 0xa57af042, 0xd2e55be9, 0x6ca9bfde,
	0xe5be88c3, 0xf5c1dab2, 0xfc13f153, 0x31ead6de, 0xb79d3376, 0x8dd5e27e,
	0x41772e74, 0x9b9e0e78, 0x46c27ea8, 0xdbb4eaf4, 0xf0cb8ebd, 0x1cdd813c,
	0x7f5a650b, 0xd47f2fae, 0xa14fcb9f, 0x3961ccca, 0x0939d254, 0x7c787fb9,
	0x628fc3f1, 0xcce7e5fa, 0xe01c6337, 0xf9c6b4ef, 0x9576f4f4, 0xfdc68fe2,
	0xb7d7dac4, 0x77d9f359, 0x63ec4fd8, 0x7586b11f, 0x43aafb8a, 0xf71a27ef,
	0x8bfb7311, 0xfb3d49f3, 0x6fba1688, 0x23ec5aa2, 0x0853ae16, 0xfcc5eafe,
	0x78c28f3e, 0xbc3e3f1e, 0x0860f804, 0xc8ebdfcd, 0x6e683cc1, 0xe299aa7f,
	0xaf5f830b, 0xe280b75e, 0xbe859b99, 0x8bf710a9, 0x65770a1e, 0xeabf7ae0,
	0x73c27089, 0x7ee66ff5, 0x9e2e58f4, 0x084d2bf7, 0x8b5f5f5e, 0xe34891fc,
	0x2c973c33, 0xf4ba39c7, 0x699f74e7, 0x4eb093e1, 0x58ec3cc6, 0x998decf6,
	0x0cd4b748, 0xed94efdc, 0x6cfd97aa, 0xeb076f30, 0xb9273c6c, 0x35f7e552,
	0x3d91b0ed, 0x614f9904, 0x67b7e741, 0x6add7f2d, 0xa58cf6e5, 0xb67e158c,
	0xed5e7033, 0x2bc7bc20, 0xb9c5ea01, 0x793f8934, 0xc4c2aa9e, 0x372c79ef,
	0x0ace7429, 0x4f9d1a34, 0xee7f49fa, 0xb288d6df, 0xe745c322, 0xd8d76a74,
	0xf932cb5c, 0xc8e73d38, 0x6b579d61, 0x7da2a8ea, 0x28da3fcd, 0x3cbf52be,
	0xe68f0b5c, 0x8dcf18f9, 0xb36abca0, 0x75c70e35, 0x5c9d71f2, 0x7df3c07f,
	0xb1a7dc66, 0x1b58fd73, 0xe28ef80b, 0x8b1a638c, 0xca3241f7, 0x52f1c4a3,
	0x577d0647, 0x539dcf11, 0x074676af, 0x6263ddc6, 0x833e302b, 0x448d87ed,
	0xb8cfc5fc, 0x467ae101, 0xe4067925, 0xbf43c9ac, 0x347519ef, 0x562bb7ae,
	0xfd462aee, 0x28eb7f3b, 0x2ac1293c, 0xec9f7d9e, 0xf7417cc7, 0x5687914e,
	0xafbc7509, 0x93c859ae, 0xa2f1e547, 0x491f8166, 0x76bef97f, 0xefc785a5,
	0x62a3cf41, 0x31fa5da9, 0xef6b5b8d, 0x5bfd4248, 0xe742c3bb, 0x70161fb4,
	0x3fed2e57, 0x53f01f61, 0xee8625a5, 0x96f1aced, 0xd35eb15a, 0xd03d50ac,
	0xf903312f, 0xcfe58bf3, 0x1cdf2347, 0xa367f70a, 0x105aea5d, 0x87f3a2ee,
	0xfbaf1e0e, 0x9d367962, 0xe8e59a57, 0x277de3b0, 0x8c0d16b3, 0xdfbdfd43,
	0xfbe2b7e1, 0x26992dfd, 0xc70e6bac, 0xe66bac04, 0x85fea8cb, 0x1fa173c8,
	0xd38527e4, 0x2ecb66b7, 0x9f3dfe2b, 0x4f7cc5e7, 0x60fef33e, 0x66d4ff8c,
	0xbb460c74, 0x9c1ff402, 0xacde7886, 0xdbae5d90, 0x25dbf3c2, 0xfe90ebfd,
	0x04f36f20, 0x3fb6ebdd, 0x839413ff, 0x4e7fa43a, 0x3e01fe6f, 0x9fcf4dde,
	0x78cc5f5b, 0x27c8ddff, 0x7d418ed2, 0x70e305b9, 0x156f5e56, 0x45e78478,
	0x0477b9fc, 0xc9ebabcf, 0x7ff1d043, 0xb0fdf45f, 0x5b47d8bf, 0xfb7d236a,
	0xea17ce21, 0x44772b9d, 0x3e4efd23, 0xdc35ebb3, 0x0e7da967, 0x8433b4ac,
	0xd47c081c, 0x09a3fce3, 0xea2ff27e, 0x81d1be71, 0xbdf0f7f9, 0xc67abf90,
	0x5be727e7, 0x97f3166f, 0x8fff45ef, 0x61af1e84, 0x87db5f02, 0xf2137970,
	0xf74bf285, 0x79f989b1, 0xb8f7f4e2, 0xf9fc159e, 0x73279899, 0x7e2344b4,
	0x77a8be90, 0xab347f80, 0xe4d023d4, 0x94f5d6e4, 0x25e92fc7, 0x3867b7e1,
	0x62d13da5, 0xec7402e3, 0xd55ee3ec, 0x39be087f, 0x46724f70, 0x8befe02b,
	0x1d9d744d, 0xe839abf1, 0xe46f927b, 0x9e9f0af7, 0x1bce2d7a, 0xf8e3f7c6,
	0xbdfbbbf2, 0x671c6691, 0x21f2e33f, 0x597297e1, 0xb5cb78d8, 0xddb1a2a3,
	0x11c0fb49, 0x7dfe6f38, 0xfa83867b, 0x402fe86b, 0xa155ad7f, 0xb101f5b8,
	0xcf703fce, 0x2395d1f3, 0x991efc02, 0x97ff08a1, 0x708cc5c7, 0xf093fe4a,
	0x71e389ee, 0xe16f0961, 0x8b5fd7bd, 0xb8dc25cf, 0x9fcc145f, 0x4f927f12,
	0x233d39e5, 0x49af12bf, 0xcdf6aa3b, 0x07e9f5d7, 0xd7a75f28, 0xc278e373,
	0xf2243a1f, 0xaf7ebbcb, 0xcbcbf3f2, 0xceeb7653, 0x15163111, 0x2e966f6c,
	0x8f91dab8, 0x145bb7fb, 0xed21c73a, 0x36acfc08, 0xe91fd907, 0xe0c82c0f,
	0x09f52af9, 0x63a471da, 0x628eb1cd, 0xfa524fbc, 0xe57e57a1, 0x5e306357,
	0xbde79db5, 0x39a97e49, 0xa0e49bb1, 0xaa7b9c56, 0xe97ef958, 0xdff7e438,
	0xa75f685b, 0x56899ee2, 0x6ee7eff4, 0xd116399c, 0x5022e781, 0x30df1faf,
	0x87a13466, 0xe0669239, 0x0f0d88f9, 0x9e09b8cf, 0xe9556acf, 0x071c181e,
	0x8ee2b7e5, 0x3d5f14d1, 0x3a59de14, 0xbbf8fd1e, 0xf1fa0754, 0x731c6c57,
	0xc2bfb637, 0x2e96203e, 0x4f10d9ef, 0x431ccd75, 0xbdfa41f6, 0xd1b01f32,
	0x737fe9c2, 0x69a79706, 0x9be7253d, 0xc1c6c6c2, 0xb5df1fb8, 0x61ee9c3e,
	0x5b3ab72a, 0x97bdf8fc, 0x519d6992, 0x737fe56f, 0xfdc298e2, 0x165639b2,
	0xcf439a96, 0xf9e152c3, 0x3b8e96eb, 0x7ebc8ed0, 0xde147d87, 0xb3d4cac3,
	0x3fb92b63, 0xe31df7cd, 0x43beee99, 0x194dc709, 0xe38ddf9c, 0x707bfec9,
	0xe747111d, 0xf1ffa913, 0x819fbfe5, 0xa6f8f076, 0xf79c38ec, 0xe9c297d1,
	0x8b51c13c, 0x8ba59efe, 0x3c65e73d, 0xadcf251f, 0xf3e864d6, 0x9fdf24c0,
	0x1b077cef, 0x4b797174, 0x3a309627, 0x60caedf7, 0xc8a2ddf4, 0x3e61b66f,
	0xcdb35561, 0x0e62e781, 0x7ee3ff23, 0xee950ed6, 0xdcb3a1e1, 0x3bc3af40,
	0xdef9d346, 0xbd784faa, 0xe1f145aa, 0x0fdde479, 0x0af94bde, 0xc4bfc1b3,
	0xfe3d9c23, 0xce0f23f3, 0xed383140, 0xb9e134f2, 0x789bd3fe, 0x7baf457e,
	0xf6df5e1a, 0x7ff3aa5a, 0xf1965fdf, 0xf433c788, 0xbe25fae7, 0x15ea3ae5,
	0x9cbc8be0, 0x5cbefe00, 0xe5fc8732, 0x543c4b13, 0xac0e529e, 0xd9f902b9,
	0x08e7431e, 0x587d6c5e, 0x6a667bc5, 0x8b3a8fb7, 0x51f1e1eb, 0xd2ff7431,
	0xd3164b97, 0x2589e626, 0x6b8fe20d, 0xd47a132d, 0xdb95e547, 0x97dfa9db,
	0xf0dba3ad, 0x51cbee9c, 0x69ad5c31, 0x1f7bba79, 0x3afb7d25, 0xf5e72c7f,
	0xce9c5df9, 0x37cfee12, 0x79c68ccd, 0xdf1e3fb5, 0x37d23976, 0xfe81c632,
	0x27c8b55f, 0xfb96b239, 0x62c2c7d5, 0x7402577e, 0xbaeeb63e, 0x6807bc24,
	0x19f4fb76, 0x25eabcf8, 0x01eb81c5, 0xa3534bd7, 0x99f6fd71, 0xcf1a33b9,
	0x56b67d4d, 0xd1f2b79e, 0x3f1b6fdf, 0xed875d89, 0xcccdfbc7, 0xc65b4999,
	0x9f972fc4, 0xd7f9d330, 0xc539e02f, 0x5046ce4b, 0xe27e04bc, 0xf6647f31,
	0xd2ce3c0b, 0xeb15deb3, 0xbcc42bbd, 0x71c466cf, 0x85e7897c, 0xd1f9fc79,
	0x70cadb75, 0x2c1be3bc, 0xcbfb840e, 0x7f1a160d, 0x4cd3ac1e, 0x4db1ef00,
	0x7583dd7c, 0xdf1f375c, 0xf337d7c4, 0xa6faf85a, 0xe3458176, 0x7cf545e7,
	0x8ed41859, 0xe3eb0dee, 0x1a79911e, 0xb03cdf9f, 0xf3df389b, 0x6b2c6ff1,
	0x1766f3a1, 0xe46a3f9b, 0xfa19d3df, 0xdf0f5ef5, 0x022fc5f6, 0xc8ff28af,
	0xe62f92b7, 0xf8fbe5ad, 0xf2a32d71, 0x9f24ff91, 0x6bd5ef18, 0x2f7e32b4,
	0x85c229aa, 0x946a617a, 0xe2f682d3, 0x22ce84ba, 0x032dcf44, 0x0b557eb8,
	0x8b9e1a4d, 0x90b68d63, 0x0e4578f7, 0x43d6fee0, 0xffcf1803, 0xf9e0e01f,
	0x987ce29d, 0xf55ec12c, 0x353e7b47, 0x4e1fee32, 0xe4f29268, 0xe06629aa,
	0xc457a9eb, 0x05d031dd, 0x99b278e4, 0xedc747d7, 0xd67a82c8, 0x98a60780,
	0x2f537e61, 0x81631b8b, 0x0fa5d2fa, 0xfa82294e, 0xa4b40355, 0x39df4101,
	0x3fb931be, 0xa79e0fce, 0x13a7f3e2, 0xd658e93d, 0xa762f38b, 0x8b91ae94,
	0xdfed0333, 0xffbec97d, 0xdea06745, 0x8f746169, 0x3f8410ce, 0x6ab2efb1,
	0xbfcd9680, 0xc95e7fab, 0xbf943dd8, 0x74e7e5e7, 0x961dc7e0, 0x38a8e784,
	0x73ca55df, 0xe70c2b3b, 0x7cfc5c76, 0x254f3c9a, 0x0b0d4bcf, 0x775b379c,
	0x4ecde731, 0x71dff859, 0x79fd3453, 0xcfeda531, 0xa3588f74, 0x13867597,
	0x70e7f41d, 0x4b5ef16a, 0xbcf693c0, 0x74051fdd, 0x244cf85e, 0xe95cc7c9,
	0x88f278f7, 0x05bde5df, 0xf89e33cc, 0x8fc10ef1, 0x86b09747, 0xbfcc1641,
	0x19a5f9de, 0xe11918e0, 0xeb801d29, 0x8cded35f, 0xe7944e85, 0x3ff468c6,
	0xbaab3e4e, 0x8d7da04a, 0x86d95ff0, 0x5417a144, 0x7ef055ff, 0xa7b0e64f,
	0x2f5d1ed0, 0xa644e9f8, 0x23ef033f, 0xf5f266f2, 0xbca3b412, 0xaecb49ba,
	0x2776c44e, 0x683bdeb6, 0x06cdd036, 0x6fcf07ea, 0xe663035d, 0x77bdd1c5,
	0x687da54c, 0xde17d11f, 0xf0e3a37b, 0x3387bd3e, 0x3a2339c4, 0x23e9283f,
	0x1e8bdef1, 0x6ff469f0, 0x82cc614d, 0x6c61d8eb, 0x3cddfd1d, 0x61a39749,
	0xbc921cfc, 0x0ee17557, 0x33a1871e, 0x714ea294, 0xf1f65ea5, 0x995ff255,
	0x47b507b8, 0x799bacff, 0x6f32f661, 0x713f15bd, 0x5d7376d1, 0xb3bd4861,
	0x3bd08074, 0xe0a8d8a3, 0x45ab637b, 0xb96a899b, 0x5bcfef13, 0xf7461898,
	0x627c2c97, 0xf625d920, 0x7eb4ddc8, 0xbad8ed96, 0xa697e278, 0x30e8954c,
	0xbca155b7, 0x34d6d2ca, 0x255784e6, 0x4654f1ad, 0xf3d2a777, 0x337bbfe3,
	0x4e25eb97, 0x49ffd2a7, 0xa63ca02e, 0xc05219ff, 0xf78debf3, 0x9f3c7122,
	0x9b3c7376, 0xfee8c3bd, 0xbfb88b5a, 0x78e334f6, 0xdf9d3d3f, 0xcf7a7713,
	0x89da3321, 0xf42a57e9, 0x08d443a7, 0xfbc6e7ce, 0x6d7e256b, 0xfbc63e82,
	0xfdc51b6c, 0xdb5ef28f, 0xbebb45eb, 0x219db5ee, 0xd47d71d0, 0xc79c129c,
	0x7bc5d1bd, 0xb8647d68, 0x46a6d6d7, 0x660f9059, 0x31e9eb94, 0x6ebeba7d,
	0xd277f099, 0x860996c7, 0x7d3525fb, 0x84034ffd, 0x0d8c39bf, 0x5ffee3eb,
	0xd3f4fd0d, 0x0fe38d9a, 0xfa8679ef, 0x61fc208c, 0x74e9cd3e, 0xdeefe133,
	0x352f8e70, 0xfc8bdf82, 0xcefdfbff, 0x8d9c7bc6, 0xdf0f34f7, 0xbf5750b4,
	0xbaa7e5b4, 0x2eb597f6, 0xe51fbdd3, 0x3f7ba55f, 0xba43cf7a, 0x5f8e98fa,
	0xdb8fdaeb, 0xfdee94f7, 0x759b9de5, 0xf638afef, 0x657eae9c, 0xed749fd7,
	0xa9deeaaf, 0x37b3e7ab, 0xc30bed75, 0x27d5d7de, 0xae8ffe3a, 0x8729d5fd,
	0x71afef74, 0xff7ba17e, 0x57f600ff, 0x80004ec1, 0x00008000, 0x00088b1f,
	0x00000000, 0x7de5ff00, 0xd554780d, 0x333ee8b5, 0x4c927e67, 0x66109392,
	0x9c24c926, 0x06091fc9, 0x80d22219, 0x603f2641, 0x820c29f8, 0x03b06d1a,
	0x9942a2a2, 0xd9f05a00, 0x13f0c4ce, 0x7a836d28, 0x80ea0221, 0x9f5f5ca8,
	0xcbd6b45f, 0x2009bfc5, 0x446977f2, 0xdf5f4feb, 0x16bd01bd, 0xa40758bd,
	0xeb4bda3e, 0x7ded6b5d, 0x13267392, 0xded7ef40, 0x7df2fbbe, 0xf7b59b7c,
	0xbdaf7b3e, 0xaf6b5af6, 0x673af6b5, 0xc17f95a6, 0xbfa33b54, 0xb7dfe0af,
	0xd4ceff7d, 0x63d87ef2, 0xabd5da0b, 0xd3e63fe1, 0xac61cb32, 0x86c4ae6d,
	0x7b3b1978, 0x583db670, 0x9aaa58c9, 0x1a71f39e, 0x8ab057b4, 0xa58cccaf,
	0xc318530c, 0x30ac25fe, 0x49b19230, 0x1b189ae6, 0x4b77fd03, 0xd8ca9b3e,
	0xbb4716e7, 0xe498c994, 0x36456c67, 0x05bff263, 0xb3b412fc, 0x4f7c907f,
	0x35667b41, 0xcfe6e9d4, 0xac99dbf2, 0xa3486fc3, 0x06878062, 0xaefe86dc,
	0x9ed0d526, 0xb4372c1b, 0x19f42fe7, 0xb55082e0, 0x15b0ffa1, 0x8dec037e,
	0x17fa1a34, 0x700c07b7, 0xa1934769, 0xa0cef0ff, 0xba22bda1, 0xc57ed0d0,
	0x1e0190ae, 0xd0c2b5d9, 0x88eed47f, 0xac747da1, 0xd57ed0dd, 0x7c030ec1,
	0xa1a74f75, 0x8fdeb7ff, 0xf5c7da1a, 0x5fb432ee, 0x00cbaa73, 0x36ef884f,
	0x3e789ff4, 0xd96b8066, 0x7aff4321, 0x78065bfb, 0xa181f292, 0x13ee75ff,
	0xea29f686, 0x49768627, 0x15735855, 0xcfcad363, 0x795feb18, 0x95d20ff3,
	0x307f7fc8, 0xf3a91f3c, 0xc88fe433, 0x4daf920b, 0x5aa16c65, 0x6365fc44,
	0xf80537ac, 0x00122dad, 0x580c64de, 0x5f0195a9, 0xe2244666, 0xd631602b,
	0x00a38d9c, 0x2c658ed3, 0xcf0bff03, 0x6eb1ca67, 0x936c8009, 0x30721bd7,
	0x2956c696, 0x267cc31f, 0xaeaff560, 0x6ff13982, 0xb812c0e2, 0xe1ac7d92,
	0xa7ddf30b, 0x31e3c232, 0xca0f7835, 0xcf5dddc7, 0xaa87ce4f, 0x0d6458bb,
	0x5cc931e2, 0xf20bd999, 0x7d852c71, 0x70395037, 0xa07629bc, 0x43be6e8b,
	0x2a9e1d29, 0x4ff3e0c7, 0xfea69fb1, 0xf85ae37d, 0x6fac12b8, 0x9ffc6ea9,
	0x0b530184, 0x90611d63, 0x1ec6529b, 0x3f042b0a, 0xbc137612, 0xd952ac29,
	0x72a72e19, 0xed47d84b, 0x04d5c2db, 0x13f61e3f, 0x52370d1c, 0xa01c23b9,
	0x26e19dfa, 0x070e9f82, 0x5e15dca9, 0xe1b3e548, 0x2cffb510, 0xe7e082bc,
	0xbb2a11c2, 0xff54edc2, 0xe083b842, 0x049dc317, 0x528e14bf, 0x8bbc3bb9,
	0x2ee13dca, 0xbc257f6a, 0xc2d7e09b, 0xe1638231, 0x0def0483, 0x3fbc10f7,
	0x07c13efc, 0x1e54bdc2, 0xf2a29f0c, 0xed4e3870, 0x09e7c347, 0x66afdfee,
	0x902be3e5, 0x57d3413e, 0x05b6d057, 0x14ee0f90, 0x3272c07c, 0xec64e665,
	0xeca5be0e, 0xd85b1353, 0x53bff405, 0x8ea5a1f0, 0x77c031b1, 0x1db2bc96,
	0x6adc5e6d, 0xe27293e0, 0x0d5fa393, 0x013e7cb9, 0x852505ce, 0x91cacc7c,
	0x4d72b4df, 0x5f22342d, 0xa7d148b7, 0x84ddd4bc, 0x73b52cf8, 0x1d9926fc,
	0xaf7cded4, 0x8c49b514, 0xc45995cd, 0x9bf3720a, 0x912b8c94, 0x2c86cfb9,
	0x4bb632e5, 0x24583ea9, 0x416affc0, 0x862fe0e4, 0x57ddff2c, 0x7bd7db6c,
	0x866af1fb, 0xfcf04de7, 0x0c5a6ed5, 0x2d07666b, 0xfbd40788, 0xaa2720cd,
	0x055fb82b, 0x302eef3c, 0x3c28ac45, 0x2059688e, 0x5706b19d, 0xefe44df0,
	0x0fdba1b3, 0x2a77e0e0, 0xe79c32be, 0xd0d8b6db, 0xf8fe609b, 0x876fb321,
	0x963d383a, 0xa5014c74, 0xd7f6917d, 0x0104f13e, 0x9b3fc68f, 0x63ff4883,
	0x28a6f496, 0x55aff3f0, 0x6bf6e889, 0xdf2864d5, 0x403f0571, 0x0f4cbe7c,
	0x12026add, 0xcb6d797e, 0x4960cbd3, 0x99a52dcd, 0x84cd1e78, 0x8cc5632d,
	0x05aa62cd, 0xe66cc2f5, 0x430bc37f, 0x0482c0dd, 0x5422c4df, 0x278339d6,
	0x599b9c71, 0x78e0e094, 0x75b2615b, 0x19f5e225, 0x963575e2, 0x72694326,
	0xfd234f07, 0x13f74cbe, 0x5dc6c75e, 0xd2eb8657, 0xab73aaf0, 0x160cff84,
	0xfbf11c7f, 0x1f33d5f2, 0xf903c54b, 0x17c02fe3, 0xfb1e180e, 0x73ec2b31,
	0x3e0ac81b, 0x8a52b6df, 0x7c6b5f22, 0x7cecccd1, 0x5ea007dc, 0xf009f3d2,
	0x4bca1547, 0x3a5670bc, 0x178a49f1, 0x399c64f9, 0xeb051d62, 0x24cb4534,
	0x5587f133, 0xcceefc02, 0x1a28fe01, 0xd7be0f9c, 0xef4ea50e, 0xc10d7f01,
	0x8ff77ef1, 0x7a472adf, 0x9c6d792d, 0x336af48a, 0x1f003ec1, 0xc99b0e47,
	0x9542602e, 0x1919af9b, 0xb266be45, 0x246b37cf, 0x83d717ee, 0xe2b666dd,
	0x767a24f9, 0xd7ef978c, 0x31a5b731, 0x3972e34a, 0xbd2bdad7, 0x452aff7c,
	0xbf2da5bf, 0xfc06645d, 0xc4fded8f, 0xb24c8eaa, 0xba3f158e, 0xcfc744af,
	0x989f764b, 0xb7a24fec, 0x34f18a67, 0xd35b31fe, 0x7a1ddb83, 0xc0bcf8bc,
	0x917957cf, 0x9f80b39f, 0x3f9f898b, 0xcd8c2386, 0x3799a9b0, 0xa40bd941,
	0x7c194189, 0xdf22b142, 0x2a3e67cc, 0x9500b017, 0x23f6c277, 0x1b2206ff,
	0xbbf748ad, 0x7fd51759, 0x2736faaf, 0xa61df3f2, 0x8bc22160, 0x2fd50f58,
	0xdc06f161, 0x5bda1bda, 0x190370df, 0x9c6c7767, 0xbdf40b94, 0x0def3a3e,
	0x94ed672c, 0x24a88e3e, 0xaf11931f, 0x3ab4295e, 0xe5bfe60f, 0xf3abb567,
	0x99867ea1, 0xc23b0bef, 0x1fd345f7, 0x7906eb89, 0xfafb8198, 0xd69f9665,
	0x3468ce65, 0x83f343c8, 0x38c12fcc, 0xd16d57f1, 0x7c9d5e1d, 0x2ff3df54,
	0xe4c7a8f9, 0xdfb8adf8, 0x65b35e4b, 0xcddf7ee3, 0xf92f39f8, 0xbc88ddb9,
	0x4677cfc6, 0x4b0f7efc, 0x4fbf61f5, 0x5a7f7f05, 0x3fbf88c0, 0x559f9895,
	0xac9ddbf5, 0x2aaee830, 0x97a73fee, 0x25767e98, 0xf1ce09d2, 0x77bd71db,
	0x66b5d87f, 0x7ff517b4, 0x0eed10b4, 0x5f36b3cb, 0x9e70d79b, 0x50d2afb0,
	0xd21884c9, 0xee3827f3, 0x497881a8, 0x80fe07d5, 0xcacd8676, 0x922af622,
	0xe516366f, 0xf24acf3a, 0x2da486d5, 0x2a0279c6, 0xf8e27dca, 0x07be04c7,
	0xbe2664ff, 0x9e7ac08f, 0xc3cd9292, 0x6a5b2bcf, 0x3fa43cff, 0x59e68c9c,
	0xac72e5e5, 0xbd1cc7cd, 0xebcbb41e, 0xb86d82d3, 0xb8f8a03f, 0x7eb8517e,
	0x6dfde839, 0x8ccfee09, 0xbd34ebf1, 0x6bb1e34c, 0x663a3eb9, 0x1f082351,
	0x40faf5ab, 0xd9e9f573, 0xbe6fd599, 0xb4cc788f, 0x2866623b, 0x74e58d59,
	0x160e76af, 0x33bf9ff5, 0x86b7f3b5, 0x8433bf9f, 0xbb44cf68, 0x3e639f0c,
	0xc157e20b, 0x63d1a37e, 0x9ab79e1b, 0xde701c7e, 0x907ac2c2, 0x62eab27e,
	0xf8952e50, 0xcafe97fa, 0xbed08d1c, 0xaf384df9, 0xc64fe855, 0xae78e542,
	0x9abbcf69, 0xf83155c0, 0x6256760b, 0x031417f0, 0x1b72105c, 0xa15b0ffa,
	0x91bdda1a, 0x717b4372, 0x9700cfbb, 0xfa1b5476, 0x1bf4ef0f, 0xa3688ae0,
	0xbb15ffa1, 0x64780602, 0xffa19357, 0x4341dda8, 0x42d8e8fb, 0x0755fb43,
	0xeaf80643, 0xfe86159e, 0x623f7adf, 0xdbd71f68, 0xe6bf686e, 0x9e018754,
	0xf434ef10, 0x6a3e789f, 0x7f65af68, 0xb7af686f, 0x9f806f3f, 0x146a73c0,
	0x68ff0dfa, 0x773aee78, 0x3c7e01b7, 0xf6076335, 0x321ea29b, 0x37f62f3e,
	0xc92a7372, 0xb7f2b4c3, 0xf7dded0c, 0x0cdcd88f, 0xdfbd12f2, 0xa6e6fe44,
	0xb14e7e46, 0x07ce3aa6, 0xb7efbc29, 0xe6181f7d, 0xbdc7342b, 0x59aac7c8,
	0x2eb943c9, 0x17b59ea9, 0xf9958ed8, 0xdd50ea5b, 0xdc6e3795, 0xc088e58b,
	0x362875f3, 0xed6f4d95, 0xe0caf2c5, 0x63603a99, 0xb5985be6, 0xd0aacb0f,
	0xa2177ae8, 0x3ed662b8, 0x5a46c72c, 0x82cf51ea, 0x9de9f859, 0x23eff780,
	0xc07ad823, 0xf80f232b, 0xfdeb12b6, 0x73cbb7c4, 0xcbe7244d, 0x5144766f,
	0x71af392f, 0x6cb4e8c8, 0xef86870e, 0x7ce69d07, 0x818ab9d8, 0x5d83b47c,
	0x760e1d1f, 0x58f9d802, 0x7c760a3e, 0xf5a19c14, 0xb963e760, 0xac7cec01,
	0x3e760adf, 0xab87cec2, 0xe5b9f1da, 0x58dedd6f, 0xbb0fe304, 0x2cd05657,
	0x5a9aab5d, 0xee3e02f6, 0xea0aad7b, 0x91f7ab12, 0x28f01514, 0x8c780c58,
	0x91f8b227, 0x022e8fd4, 0xc38f21c3, 0xddcfd029, 0x9dc03262, 0x4d823ff8,
	0x7e7c0691, 0x9df2c6e4, 0x8aaff03e, 0x805b675a, 0x3dc519d6, 0x42cf6f37,
	0xc0e7f998, 0x2f71393e, 0xee3ffc60, 0xa9159ac8, 0x543f081c, 0xc229c81a,
	0x55dc81f8, 0x0caa7281, 0xe22e4dff, 0x53eeaeb5, 0xfa81499f, 0xfdacc648,
	0x86c78eb0, 0x013c72a6, 0x672f95ae, 0xd1617f5c, 0x750faa50, 0xc523d125,
	0xfadcfc45, 0x33b71163, 0xfd414fe1, 0xc22ce2e4, 0x6527605c, 0x3cddbe82,
	0xf409c56e, 0x22256421, 0x17647ea1, 0x82b1f9e0, 0x4f04c504, 0x1738054c,
	0xa04fa061, 0xd71a382c, 0x76320ae3, 0xb9a7c752, 0x66f08d0b, 0x9693cfd8,
	0xdf2c7c7e, 0x58644535, 0x80c9e583, 0x6cf307cf, 0x05eb0b9b, 0xe8d5b378,
	0x31370e4f, 0xd61e2fb2, 0xdb30bef0, 0xc3da7687, 0xde7edc45, 0xfaaf2e12,
	0x9efe82c8, 0xf023eaaf, 0x8616f28f, 0x57e820a4, 0x17c07357, 0xaf967e81,
	0x456dde7e, 0xeb2efec6, 0xeb1cf3c2, 0xcf76755b, 0xcb5c6275, 0x9ba26657,
	0xcbe02da5, 0x316fcdd6, 0x24aea14b, 0x458dd776, 0x8dae7f32, 0xdf65bb51,
	0xf985494a, 0xd2a39af2, 0x484e34ed, 0x2bbd41f2, 0x9bf3ebc6, 0x0005a4bb,
	0xe9522aaf, 0xfc9c6d39, 0x8ebf8085, 0x22396e4e, 0xfbbcf029, 0x74848881,
	0x1f012b70, 0x075a474b, 0x0997be48, 0x18af7699, 0x10d1f55b, 0x0be03bc4,
	0x34d37ce0, 0x0c290b79, 0xf7d0f9f1, 0xd73c5acb, 0x4f66697e, 0xea85f141,
	0xb249cccb, 0xf5b4ad0e, 0x22ff999a, 0xe1464c7e, 0x273a21fd, 0xa5a8716f,
	0xdc4fbf20, 0x9eda68ec, 0x8956cf84, 0xa79b597d, 0x1f1c5b9d, 0x49d399a7,
	0x50beaf3b, 0x7a68ff38, 0x8716596b, 0x159671b5, 0x31bd218c, 0xceae3e18,
	0xe1d41614, 0x51e619bb, 0x9fdb7c60, 0x1ba4145a, 0x9a010ef8, 0x74fae64f,
	0xe4e563fb, 0xcff2262f, 0x89003900, 0xbe42accb, 0x01b68dec, 0x5ae6d8df,
	0xba2f687d, 0x4246b87e, 0x3ac7923d, 0xaea3d424, 0x32838682, 0xb072e79e,
	0x8ec49022, 0x683c94be, 0x25d9a9fb, 0x7d4ff703, 0x50ec96af, 0x5dbe430b,
	0xb85d55ea, 0x2e9f1a7f, 0x3b34343d, 0xe7cfdba8, 0xb3571f05, 0xe9ca330e,
	0x6545d678, 0xf2a1eb0d, 0xd2a7165a, 0xcb1914cf, 0xb2a3e63a, 0x9ca80581,
	0x365442cc, 0xa72a0eb2, 0xa72a2eb2, 0xc12a1eb3, 0xc032a3af, 0xaf3ff214,
	0xcb063b07, 0xe5402c39, 0xe5442c8d, 0x4ddfc13e, 0x5be083ac, 0xbb951758,
	0xe1d5fe41, 0x53b10f18, 0x73e80af9, 0x7d035f2c, 0xf40c658e, 0x78c36ab9,
	0xfb953948, 0x0f2a3ec3, 0x3ca9ab84, 0xbf53f618, 0x2a46e1c3, 0x5403868f,
	0x51370b1e, 0x520e13d9, 0x85e1e3bf, 0x0e13be54, 0x786ef951, 0x87ef9505,
	0x3afe5423, 0x70e54edc, 0xa415e82b, 0xe8ef7977, 0x0a1f81eb, 0x55fab43f,
	0x8b328f38, 0xcfb2dfb9, 0x8abbfa6f, 0x268fb831, 0x5731c58c, 0xf90932c3,
	0xf26e55d1, 0x5f5ca147, 0x0dba54be, 0xb8c7b5ca, 0xa5736b1d, 0xeaec9d93,
	0x30a92e5c, 0xd7a96eee, 0xfb7b069c, 0xcf163baf, 0xdd8057b2, 0x955b0af0,
	0xe97843e6, 0xe1f03b46, 0xbe284b76, 0x8b7bda1d, 0x70ecb342, 0x3f4f8c8e,
	0x72cf6ffe, 0xedc7da98, 0xc00a6d67, 0xdee3b6ff, 0xc712398d, 0xeff09503,
	0x6acc568b, 0x954f1195, 0x0bc67cf0, 0x19fa360e, 0x67e41d2b, 0x393cee8c,
	0xb8f004da, 0xf42a8e15, 0x28fd758f, 0xbf583d4e, 0xb9ed76c4, 0x36ce2d6d,
	0x8fdac3a4, 0xaa813dc1, 0xd1dee2c2, 0x8fd38f18, 0xf9bcba6b, 0xf322f999,
	0x1749fbeb, 0xe6502f19, 0xbfa2f7ff, 0xe44f3e01, 0x1f57cb6f, 0x78a26f3e,
	0xe78d9298, 0xae2ccefa, 0xa905e277, 0xf7801dd1, 0xaf016cce, 0xad75a12b,
	0xb5d61845, 0xd9117d76, 0x02533bf1, 0xfb610f4b, 0x1dbe4d8f, 0x3533b4d0,
	0xe082beb8, 0xacd38a12, 0xe3950ecd, 0xc69854b9, 0x9e4dc7cf, 0xfd5453fb,
	0xcfcc5939, 0xe735cdf7, 0x3fa3b67a, 0xa5626ed5, 0xf68edcf0, 0x61caebf9,
	0x8037279c, 0xe670045d, 0x4aeb0584, 0x9d68bda1, 0xe859ac69, 0xc9e3c43c,
	0x5e9e0b0d, 0x23b8e12f, 0xdc60cbb2, 0x0b3fa162, 0x5e8ef487, 0xc9be7c06,
	0x682b8c6a, 0x5e4295e5, 0x2730c016, 0x142dfce1, 0x16ed8af1, 0x373fa4d6,
	0x16fc0867, 0x32d2f195, 0x6cf1c791, 0x0fa352c3, 0x876bfac2, 0x738fb8f1,
	0x3ee29d95, 0xdf1fcf4e, 0x9dda0eba, 0x343e4cdb, 0xa2d76569, 0x3dfa0b56,
	0x942eb337, 0x7f12edc7, 0xedc0523e, 0x8a583064, 0x1efce966, 0x4aaa37b0,
	0x7752f174, 0x38c24453, 0x45b0ed46, 0x9d97c612, 0x8c25bb9e, 0x829b387f,
	0xfd1d3052, 0xb7b510a4, 0x16a70597, 0x9bb97f03, 0xfd9d79e1, 0x2e648e0c,
	0xdbcc2bee, 0x1ae745d4, 0xf7cfd2ab, 0x874e32fd, 0x1eb032d5, 0xacabefda,
	0xbd225784, 0x9baf0f66, 0xfb6be38d, 0x2ceed898, 0xf9d9f4e1, 0x72814c20,
	0x0fc78e30, 0x47953d8e, 0x4d8cf2f6, 0x23f47ea9, 0xd11c6d8f, 0xe343f040,
	0x1eff68fd, 0x64fc6a7b, 0x343c672c, 0x931dfa95, 0x0b8c41d8, 0x16e878cc,
	0x8b0beb19, 0xef1c2f01, 0x71f89584, 0x8b7743c6, 0xc06fefe7, 0xe4536af6,
	0x5d3fa27f, 0x1a6cf6dd, 0xa7c60bc6, 0xe58f90bf, 0xf2ef5331, 0xa67f986e,
	0x8f09fec2, 0x9cbac0eb, 0x7fc2371f, 0xb22c6d66, 0x65663c60, 0x98afbf31,
	0x0724fccd, 0xdbfc83d0, 0xfb3d5d9a, 0xd763a2c0, 0xf1ebc576, 0x5bbfccfa,
	0x5d658fd9, 0x346687cc, 0xd818386b, 0x9ee4e58f, 0x379a0350, 0xec77ef8d,
	0x4554f2c7, 0xe7d22570, 0xf8de1f99, 0x0f0033c2, 0x0572c1fb, 0x0792d0ed,
	0xa0eca77b, 0xa185a5b8, 0x1d5a3c3c, 0x032330ea, 0x50523bdb, 0x6edee43f,
	0x6ef9e132, 0x216476f3, 0xc4bdbb6c, 0x9da67184, 0x690b1d59, 0x0ca9a5dd,
	0xce1878e9, 0x478be421, 0x94148e95, 0xda4b9027, 0x3f82b587, 0x2521596d,
	0xbdc5eb0b, 0x54bf5f46, 0xafb8ff0e, 0x4496475f, 0x3848e4f3, 0x64119a0f,
	0x7cf38847, 0xda0bf033, 0xe0f4ce09, 0x3d6f8c76, 0x1ff2e7ea, 0xc0be7071,
	0xfce06bee, 0x4809df27, 0x4d08eee8, 0x3670fdc3, 0xbd5e91cb, 0x20c7009d,
	0x17be8b8e, 0x0ce1bfc5, 0x9361bb41, 0x33d061c4, 0x61fe1784, 0x70edc73c,
	0xd639476e, 0x8d0677f0, 0xae3ae1e3, 0xa73ff477, 0x620bddf1, 0x7315cf5d,
	0x20d1e8bb, 0xf7c34f1f, 0x5cfcc5e7, 0x9355bc07, 0x8e39ec93, 0xa4c3ac0f,
	0x8fd747c3, 0x3787d7d6, 0x2f91b9f3, 0x94248e40, 0xac92a423, 0xd902ff5f,
	0xf881929f, 0xe47df4bf, 0x23d40cef, 0xbb4fe780, 0x4e49d9c7, 0x66f1d613,
	0xc8fb88b1, 0xbf436760, 0xc941cda9, 0x904ff18f, 0x9ca7f467, 0x647a7602,
	0x8e9daf3a, 0xb74592f9, 0x0167a75e, 0x9b53d39d, 0xd816ad82, 0x69d5a9c7,
	0x69efe43e, 0xc2956bac, 0x097f7be5, 0xf59c37e0, 0xb69839fd, 0x73b8e81e,
	0x5af1dd41, 0x8b016ff8, 0xf9e056d5, 0xa63b83f9, 0xba6d1ca3, 0xc441ea7f,
	0x7b7cbf3f, 0xc0f8aa37, 0x6cefbe19, 0x956f8f2e, 0xd23f936c, 0x1cb3c3af,
	0xc99e9d60, 0x8184645b, 0xc6b00c1f, 0x61692e57, 0x4d1dc616, 0xcb539569,
	0x98666f50, 0x23cfae14, 0x24f49cd2, 0xaf91257a, 0xfdb5fd04, 0x09715df9,
	0x61d39bed, 0x71607da2, 0x7486fd9f, 0x9f6d72b1, 0xc4123ef0, 0xc9ef133c,
	0xc951cc1b, 0xfd05fb8b, 0xb38e0ed1, 0x89afb8a1, 0xa2ddb4fb, 0x3d432d4e,
	0xa0a4d1bd, 0x5748921f, 0x915fb760, 0x8731b29f, 0xb65ea1da, 0xc613dc53,
	0x4e6dd6d1, 0xe3f71b06, 0x631ffd52, 0xbccab33d, 0x3df3eb03, 0x0056a673,
	0x4621f97e, 0x3ed89ffb, 0xbee301fc, 0x063c1f92, 0x8d163cfd, 0x9cfd837d,
	0x40d9d9ea, 0xbec250fe, 0x38577c6a, 0xf0b9f924, 0xcb970964, 0xf1df34c2,
	0x642bb246, 0x050213b2, 0x9fbd50f2, 0xcfc25654, 0xe0ff89a1, 0x7d8873a0,
	0xc2968f68, 0xcf58bea3, 0x759d708f, 0x8db84ce7, 0x7ba38dec, 0xe50a9e1f,
	0x677a7fa4, 0x37e811e9, 0xab8e4fe9, 0xeb0f7eb0, 0xa081829d, 0xf90b41c8,
	0x3d9fad8d, 0xa20181dd, 0xc3e666b6, 0x679b5773, 0x65e79892, 0xfa40344b,
	0x3b6642b5, 0x0bb20f48, 0xc2fb695f, 0xda6605e3, 0x02c6de27, 0x47e41dcd,
	0x412a4aba, 0xb3786357, 0x17a43beb, 0xc6195b4f, 0x526faf5f, 0xfeb0b52d,
	0xcb559beb, 0x9967943c, 0x311da235, 0xf547c9bb, 0xbc7d9bb3, 0xe7ebcede,
	0x7ea9f934, 0xd79fb34e, 0xe81ea03b, 0xb4534371, 0xdee30c27, 0x4d56c8e0,
	0x1cd01f78, 0x6de7ede0, 0xfc147ed4, 0x630b1281, 0xd25129a9, 0x4ca71df7,
	0x5168defc, 0x2db5f12a, 0x8aa0eabd, 0xf2679bf4, 0x2b651da1, 0x70029990,
	0x6a205367, 0xac2df686, 0xb7d71723, 0x4154b827, 0x91e3dbf9, 0x1edf5c15,
	0x48fd6f70, 0xb47285bf, 0x1c982bd4, 0x3c0b3de0, 0x5db3af74, 0xb723efc4,
	0x0cde29db, 0x9bc50eb6, 0xc279edd9, 0xf4e7e18e, 0x5139f9d6, 0x3619e3d4,
	0xa472e1df, 0xbf7c53ef, 0x429dda7f, 0x167739e3, 0xe8bc5345, 0x95f8ea57,
	0xafcdfca1, 0xccd676c5, 0x7a7f9c14, 0xda2a6073, 0x98db6d91, 0xc830d50f,
	0xfb0f3d37, 0x0ceceb49, 0x82186f1e, 0x67cf8770, 0xd06002e6, 0x07c16d0b,
	0x9eb8a90f, 0x8e052645, 0x9e2fe84d, 0xd3b7545f, 0xe797edec, 0x350e4211,
	0xdf5031fd, 0x38e20ef8, 0x7ceb9bee, 0x011c1f18, 0xf3c60c3e, 0x447d5ab7,
	0xb22dc8e7, 0x446df90f, 0x19298e50, 0x11edf2fd, 0x39408ee3, 0x197771c4,
	0x4ef86de5, 0x136d1ca3, 0xc595ba72, 0x6e3821e4, 0x4b71a327, 0xc0fd8d3a,
	0x3cf09463, 0x48d7944a, 0xc05c5f59, 0x74018740, 0x9d7c945e, 0x3aeaebfd,
	0x32eb4654, 0x5ea175f1, 0xc732fa83, 0x1f50870b, 0xa4c93596, 0xc7584a6f,
	0xc97f5c71, 0x5a0c194e, 0x5560afd8, 0x7d373e2a, 0xdad48983, 0xe90f59b7,
	0x5bad4b85, 0xae24778b, 0x657d7133, 0x47ae6625, 0xb5707b34, 0x4dc1ec9d,
	0x3231812b, 0xc54adec9, 0x597b42b8, 0x4097dfdd, 0x3d84e7bf, 0xcccaf96a,
	0x839b49f5, 0x7ae2d4f8, 0x7f1f5ca0, 0xba88c9f8, 0xdfa84ae7, 0x791beb90,
	0xcfee82dc, 0x7bd8f512, 0xeb8d8f42, 0xb2f21935, 0x6a9539ae, 0x109acbc8,
	0x13c036cf, 0xfa19e7cf, 0xe9f082d7, 0x57edebdb, 0x2927da18, 0xebe01957,
	0xfa18d7dc, 0x0deb514f, 0x69f2b4f0, 0xb3627909, 0xeaccf00d, 0xcffa18ef,
	0x6866dff2, 0x8f78dd9f, 0xc086fda1, 0x537c0332, 0xf430ffd3, 0x66d839bf,
	0xc2ceff68, 0x13da191f, 0x3cad27fd, 0x3ce3c251, 0xb7a1dd9b, 0xec2d8028,
	0x7de724a9, 0x19efbf5c, 0x4a9edc69, 0xca5457ec, 0x8909f7f7, 0x6e22c7cf,
	0xf98e3c43, 0x5d7886dd, 0x7b78fc6c, 0x5aa38c2f, 0x3ca1ef7d, 0xbf0ea263,
	0xee1b76bf, 0x841fbad9, 0xd2de307e, 0x9e1722f4, 0x0dff1877, 0x16dee1c2,
	0x857dd135, 0x84b97dab, 0xcb0daef5, 0xbce55c79, 0x7d79e295, 0x1a46b078,
	0xaf710bef, 0x4db9e1a5, 0x60b691c4, 0x240f091c, 0xb7ea14ff, 0xfbf7852c,
	0x3b8b5389, 0xdcdc6906, 0xf2846b6a, 0x248416f1, 0x05b7038c, 0x26f78299,
	0xfce20f68, 0x32f9345f, 0xa2e245d9, 0xe66ec29b, 0xcbdcf987, 0x5856ad23,
	0xed53fa5b, 0xab8a3d0f, 0x0632310d, 0xff5a9f72, 0x0a63c610, 0xfc0090f0,
	0xe74e6572, 0xf3dbdfad, 0xdf30d3c9, 0x2aceb9a6, 0xed89abd4, 0x395e4bf9,
	0xed22e073, 0xf4bf175b, 0x7b171dc1, 0x4fbb7bfe, 0x0fb5d1ac, 0xca6d271a,
	0x1f1d7e63, 0xde92cd00, 0xe52c8c0f, 0xf192f9e7, 0x9d638a56, 0x94470737,
	0x3e7d9f02, 0x77638ffe, 0x53bf73c1, 0x7a8addcf, 0x9647ea10, 0xd7447ef2,
	0xa59c95df, 0x2bc292bc, 0x7187bec0, 0xf39252db, 0x5f18b36d, 0x31c73576,
	0xdd34b40e, 0x9f9fa2aa, 0x7d56f76f, 0xbb631574, 0x4eafdc2d, 0xf6b7dff4,
	0xe45ddbf9, 0x38c4077f, 0x2b34a20d, 0x8f6679fc, 0xec29d930, 0x30f424b3,
	0xa84a7467, 0xc816f2af, 0xa2e5eb1f, 0x714add3b, 0xc443a704, 0x0d0b1c1d,
	0x6e2d0171, 0x877e9dd0, 0x8cef7c84, 0x7cf145dd, 0x3dd0178c, 0xc497d8bf,
	0xbdbe4178, 0x7c1af084, 0x9f57d67c, 0x27992526, 0x3e2d0f01, 0x144f3891,
	0x9f3c09ed, 0x3d92a717, 0x87eeb891, 0xe1e76b4a, 0xf8d6a97e, 0xfea1d75b,
	0xf3a16e3e, 0x497e3068, 0x54595351, 0xd292fe37, 0x6937d222, 0xfa86d9e5,
	0x8b1e5f74, 0x8f77ce1a, 0x8cb27942, 0xacc3cddb, 0xe386ebbd, 0x7cf9877c,
	0x373e2cc7, 0xec7083d9, 0x6f7bb9e1, 0x66073f29, 0x1430e1a0, 0xe5fb8ce5,
	0x58d7209d, 0x642b096e, 0xf9036d9f, 0xb0f1f843, 0x5c34654a, 0xb08ee54e,
	0x8677da8f, 0x3a7e09ab, 0x577827ec, 0x67ca91b8, 0xffaa01c3, 0xe089b859,
	0x2a41c2e7, 0xa90bc2bb, 0x887085fe, 0x2bc317e0, 0xed097e08, 0x538c52c1,
	0x27b953b7, 0xafed41dc, 0x7e093b84, 0x32a51c2d, 0xf545de16, 0x045dc37b,
	0x26ef0fef, 0x463840f8, 0x41f0c1f0, 0x7b870f2a, 0xf868fea8, 0xe2e7827d,
	0x8fdef13a, 0x7384f7b5, 0x5596bfd0, 0x0d1eefb4, 0xbed0502e, 0x2933cf76,
	0xbec1cea8, 0x1ce30bba, 0x3df99adb, 0x6247de26, 0x6edd881c, 0x3dd27b22,
	0x934391ef, 0xb50e7da8, 0x7321c66f, 0xb85a3f81, 0x5b16cafd, 0x130b9fa9,
	0x6db9e0a2, 0x5ec99a8b, 0xa54b28ed, 0x4c8b5776, 0x5356df76, 0xb2fc8b28,
	0xdfd2655b, 0x1fb70b2e, 0x56783e34, 0x4b67dbe8, 0x32ef9e65, 0x4653ef9c,
	0x6473f271, 0x3766a96f, 0xf5c41fb5, 0xfac2e7b9, 0xcbb9df10, 0xeb2f78ed,
	0xf744ddba, 0xe02e8fb0, 0x799eb2f7, 0x7c055fdc, 0xe6cc2e28, 0xb8a7e4c9,
	0xbc22aee6, 0xa7aef33c, 0x03f86576, 0x77a7e859, 0x22cf9686, 0x8a659b7c,
	0xf706766b, 0xdb3de166, 0xe4ef9156, 0x881a9a1a, 0x67c40e56, 0xa7bf296f,
	0xc6dff0d3, 0x01e0dfb8, 0x24f9e97b, 0x5b34c0eb, 0x8898673a, 0x4f603de3,
	0x40fbc71a, 0xb891ef8c, 0x657bb1fc, 0x59c7bf92, 0x7ef9052c, 0xf94cb34b,
	0xcf75f923, 0x2abc60b6, 0x2bf82cb7, 0xd4c7c394, 0x80657b31, 0xf8f91bb3,
	0xa7e5cb45, 0xf7ed12cd, 0x7ea06b27, 0x021bdddd, 0x0d90ea88, 0x5b8a2b6a,
	0x7297bce7, 0x91e5fe31, 0x95a3fb8c, 0xf4fb15bf, 0xb78f9fb8, 0xf14cb965,
	0x8bcb5764, 0xde7cfdde, 0xbcde710f, 0xc149bfe1, 0x39e29534, 0x865509aa,
	0x067cae67, 0x67b94be7, 0x66912343, 0x6f9b5f83, 0xb977ce34, 0x83f61a74,
	0x09305706, 0x93e9835e, 0xf391e94b, 0x9839e9a5, 0x59f2c317, 0xad91ea3e,
	0x22b7ae16, 0x927b716f, 0x0dc68292, 0x17cb479c, 0x1207f2d0, 0xc26c05f3,
	0xb1b7cfae, 0x4ab9f7a4, 0xa11fdd9f, 0xfaff71f2, 0x78d9e500, 0x61d24c65,
	0x2eec2d4b, 0xb5a5e7dc, 0x126b4aa9, 0xb7d3e87e, 0xc080c7a8, 0xf62632a6,
	0x1f234365, 0x99c7c4c7, 0xae085ac0, 0x24912875, 0x1f2b5afa, 0xcb58e311,
	0xdfe6df38, 0x0775b3fd, 0x5b0f7f70, 0x8b6a3728, 0xfc8eba29, 0xd266638b,
	0xaee679af, 0xf0eb4fed, 0xece22e1a, 0x0ad1ac5b, 0x84ee87bc, 0xaf512af1,
	0x6254bca2, 0x18f8101e, 0xcf6bba3a, 0xbedc65a9, 0xdac2ec7c, 0x9e7fba2c,
	0xed052abb, 0x27664ea3, 0x4259707e, 0xfc75a359, 0x4cbe42e0, 0xca531fc2,
	0x31df42ac, 0xbc58ed47, 0x72e7e197, 0xc025ea3d, 0x1905d5fb, 0xcfd61e74,
	0x28da677b, 0xc9ce6b80, 0x65b2cf94, 0x1cd3cf11, 0xca26aff7, 0x07ed7913,
	0xf6bbefdc, 0xebf206be, 0xa8f94572, 0xda6af3f0, 0xfb062f99, 0x41c0b352,
	0xf384d4fe, 0x9fbd49f2, 0x31e92144, 0x78f05fe8, 0x687135cd, 0xb8dff1d7,
	0x40fec653, 0x19da3351, 0x7ac6bdb9, 0x4f17dcf7, 0x3a79824c, 0x3b87f117,
	0x0877bc2f, 0x1372c8e1, 0xfb8049c5, 0xb9237ac4, 0x2394e714, 0xb9bf98b9,
	0x9f48cece, 0x15d9e6bb, 0xcedd07d4, 0x9d7fd254, 0x0ec83b37, 0x34b25b5d,
	0xdb64ed05, 0x5859e5dc, 0xb646b30e, 0x5834ec63, 0x7bb66a36, 0x2d5be91c,
	0xaac2255f, 0xcdb81ec1, 0xdf1c8c2a, 0xd46493c3, 0x659f3c97, 0x87a8d97e,
	0xdf582523, 0x26a87841, 0xdf17c796, 0xe3c2df07, 0x50bcfc86, 0xf00ed0ad,
	0x778223ed, 0xe77ec196, 0xb1ba44e6, 0x64e3b369, 0x316bc533, 0xb7e608c9,
	0x2b31082c, 0xd95737d6, 0xc9ae72f5, 0xff95d7c9, 0xdf3dc4ab, 0xa5c0f4a5,
	0xbc94bdc6, 0x72e628cf, 0x6d3f9833, 0x6a9f441b, 0x2593f1fe, 0x6c517e5c,
	0x693d5ce9, 0xf55f6a4d, 0x6d51bd0a, 0x332a79e5, 0xd237269a, 0x57a44c3d,
	0x83be7cc6, 0x9d3a9e42, 0xdc4f74e9, 0x7862c459, 0x6f99106f, 0x1c9ef1e2,
	0xb9b3affe, 0x9b43e288, 0xa45650a4, 0x41ebe318, 0x275fee2f, 0xe61d28d0,
	0xf5c854df, 0x14868b3a, 0x7186afbc, 0x4ff1ea16, 0x7b25df12, 0xcc1af298,
	0x55aa7b24, 0x7970cf17, 0x8bf1a4e4, 0x3c237109, 0xae11bcf1, 0x5c031665,
	0x93c2376f, 0x0bfc2314, 0xdcebfeb1, 0xaa29fac6, 0xec14f611, 0xfcf1314f,
	0x2eb884fe, 0x4be3077b, 0x6b4d6205, 0x81d8ccaf, 0xde828a71, 0x5b2e3c45,
	0x63207a08, 0x9f239c60, 0x5fa42545, 0xb735fc62, 0xf2e295bc, 0xf18905ee,
	0x83c510a0, 0xb8b2e312, 0xcf0728bd, 0xcff3c95c, 0xff04554f, 0x74a5e509,
	0x99e3c714, 0x7ee94b6d, 0x90e6758a, 0xbe45795c, 0xf2f3c0d2, 0x3683a221,
	0x4445ca1e, 0x07947eb7, 0x11c3fc3d, 0x765dffc1, 0x888b9735, 0xecacfcfe,
	0x685ca0b5, 0x1f260df3, 0x8b567c9a, 0xef2d147b, 0x4b189ce6, 0x2e59bbcb,
	0x277705f2, 0xf39cebe4, 0xffa26434, 0x5967ae7c, 0x4439326a, 0xb8d88bb9,
	0x4eb9621c, 0x1ca0dfe4, 0x39738646, 0x9fdb7ac4, 0xecc9025a, 0xfb8b1fc5,
	0xdd767bd2, 0xdd23eeb5, 0xb57716fa, 0xbb25e018, 0xe7d3ae57, 0xff83dd47,
	0x76b3e4c1, 0x8bb5f946, 0x3b3e72c4, 0xdba7ebf1, 0xbf022ca0, 0xbb8c387f,
	0xe524f4b8, 0xb716338b, 0x58febee2, 0xf519a39c, 0x9cd7edc9, 0x2ffce2e1,
	0x31c436cf, 0xd2c478b4, 0x1b2baa8d, 0xd54ccb9e, 0x767c74f2, 0xf115c7ca,
	0xc1f6c18d, 0xa98d3e76, 0x6c01f7ba, 0xfe918872, 0xf5419f39, 0x9c5f7197,
	0xe0e87c3b, 0xe1aaa0f1, 0xdd6b8e9c, 0x078c1ea1, 0x33df0459, 0x2c67d03b,
	0x33ff01ca, 0x54bcf2a7, 0x1718c78b, 0x133e60b2, 0xbe9adff4, 0x2da9e490,
	0xbaa5e785, 0xa12f991f, 0x319d589e, 0x512be499, 0xc7e5128e, 0x13c5f225,
	0x33e607e5, 0xf2574bc0, 0xf24da5f3, 0x252f5105, 0x17ffe7ae, 0x3e94d03f,
	0xc9ec87a6, 0x76d55482, 0x53703b11, 0x9f1a3238, 0x5a1a9b5b, 0xf7bf7788,
	0x90dcf33c, 0xac0760d5, 0xc83918c5, 0xf667caec, 0xcffcc6cd, 0x574f824d,
	0x9f8898e7, 0xb738b79c, 0xe4fc759b, 0x68bd06b4, 0x224d3a07, 0x30ff09ef,
	0xb9dab47e, 0xf9927d63, 0xcfa67b35, 0x3c026bce, 0x49b8fb74, 0xf37d91d8,
	0xbb6f277d, 0xd38e3759, 0xf34d1c16, 0x89fde5f5, 0xb37cd6f9, 0x388b36f9,
	0xeb9f3690, 0x5cfae356, 0xcfad10d6, 0x36aff425, 0x5f5c66df, 0xe4bab912,
	0xecafc27c, 0xc6bbef9b, 0x216cb9f5, 0xcccb9f5a, 0xf37d69e3, 0xf366f9ad,
	0xae7c8459, 0x5939ef16, 0x28a30b52, 0x17bd838f, 0x5f97d6d0, 0x0f50501d,
	0x64e2d6ad, 0x4d9fcf42, 0x854bf3d0, 0x3f9ed79e, 0x7142539b, 0x6707b3cf,
	0x3bf4c92b, 0xec2675ea, 0x2bec262b, 0x842bec26, 0x589fd467, 0xf1f8143e,
	0x307ccfe7, 0x6cf3865b, 0xc6273dc6, 0xe47c0214, 0x10e6ab99, 0x1789ccfc,
	0xd191e1f3, 0x5b377ebb, 0xe33d7d06, 0x3ce713e1, 0xb888eed0, 0x5da034e7,
	0x61eb843b, 0xde6d6f0d, 0x4bc3d098, 0xb8f31456, 0xd44be81e, 0x21856ddf,
	0xcfb77186, 0x798cf13d, 0x41497fd0, 0x093f39dc, 0xc972b45d, 0x3cfe328a,
	0x31633f5a, 0xf3eb8b8f, 0x37f7b5eb, 0x6fef8d1a, 0x27ac6464, 0x458528bb,
	0x6963d415, 0x6fbd3f76, 0xd2ae5f58, 0x7cc0ddbe, 0x569edc4d, 0x031e794b,
	0x7663df7f, 0xa95718b5, 0xdfb605f9, 0x46aff260, 0xe357ef3f, 0xb3450ee6,
	0xbb17cb51, 0xcafdffa2, 0x3de75f9d, 0x4a1f19dc, 0xe4cc46dc, 0x23198871,
	0x78fa3e38, 0x8383da1a, 0x0377f3d1, 0xf4e7e9e8, 0x7a73f6cc, 0x568cf12a,
	0x5925ffd8, 0x2483e771, 0xf4a4b1a7, 0x04d7401a, 0x9c397dfa, 0x198ffe69,
	0xd14bcfcf, 0x96aba35b, 0xa926d757, 0xb2a764a5, 0x2c5e435c, 0xb26a39f8,
	0x61b58dfb, 0x77d00f7e, 0x0c827aae, 0xdbab30ed, 0xdf798e57, 0x27367f6d,
	0x28ab57cd, 0x6b717ee7, 0x3be52a46, 0xc95865b6, 0x98ceed0f, 0x2aee30ca,
	0x5d13263b, 0x291a321a, 0x843cd10f, 0x969fa175, 0xce6d7f98, 0x63f29bbc,
	0x5968f9cc, 0xbf97d943, 0x5ca3b7eb, 0x65f43f99, 0x2e01917a, 0xbe5aff33,
	0xf675fe54, 0x9d7f9e54, 0xe4315561, 0x9add3ab3, 0xcffaff34, 0xc6e81ec2,
	0x7ae0e5f5, 0xfede7d60, 0xbf0ac975, 0x34fac66f, 0x42567fbc, 0x62cee28c,
	0xce1e7ffd, 0x8feb45f7, 0x07ea2b5e, 0xa2a7d5b3, 0xe6ce62dd, 0x63dd87e7,
	0xfd3ae562, 0x87ffcda5, 0x7e7a16e1, 0xc78508d9, 0x5edcecdd, 0xe4cbf19d,
	0xcbe3f479, 0x724bb8b5, 0x6f8c1bbe, 0x7cf137ae, 0xe72e4d33, 0x0794ac38,
	0xaee1c737, 0x1cc178c3, 0xd953c460, 0xded7feba, 0x961fdfc4, 0xa7e46e7d,
	0xf899afb7, 0x8619b78b, 0x3edeb9c3, 0xef42c53e, 0x98971dd3, 0x303d97df,
	0xc81033cf, 0xce68849a, 0x15627e9c, 0x28e9638a, 0x33d27646, 0x6a3afbce,
	0x020bf254, 0x4e61d0e5, 0xf424d670, 0x1a6fae5d, 0x5ff606fd, 0xb9f5c692,
	0x24b2af76, 0x067af40d, 0x88dca3dd, 0xff1f3ffd, 0xf21d4669, 0x442f1c97,
	0xe9fd74bc, 0xbfd7457e, 0xc19ff459, 0xd38b375f, 0xe6ce27f7, 0x209bf47c,
	0x2771fda3, 0xcfd0a7b3, 0xd27dba60, 0x1bfa07f4, 0x33f47afa, 0x96cece98,
	0xdeaed59c, 0x2b44fa24, 0xcbb7ee9d, 0x701e8016, 0xa545bee6, 0x6fc9bf56,
	0xd9268c6e, 0x7d8a1fe7, 0x7ef6c6fe, 0xb63b6027, 0x3b07dedf, 0x8f4887ff,
	0x3b8e9acf, 0xbe92c0c7, 0xec8670d7, 0x93558b7d, 0x97fc9543, 0xcf78d87e,
	0x51dc39b7, 0x33d5ef86, 0x6b8c03a4, 0x5b46fa11, 0x406365af, 0xfc1f7b41,
	0x9dc23f67, 0x435978e1, 0xfff3ff69, 0x1611e84b, 0x6de7a329, 0x9edd6f82,
	0x31d2bae0, 0xf2251794, 0x3e831489, 0x3590d59b, 0xa0ed0729, 0xa1cf995b,
	0x5a3ad2e2, 0xa136ae51, 0x6e3b42be, 0x3b924aef, 0x45242797, 0xc479ba1c,
	0xc5cbd27b, 0x9cb9e87d, 0xa6cf5a06, 0xc4247f3e, 0x04f35fc8, 0x9d6f507a,
	0x0f42c47b, 0xb633aa6d, 0x60813dbb, 0xc777e02b, 0xcddf3c8b, 0x3ff60cd5,
	0x971e17c6, 0x780d9628, 0xa4405e50, 0xe623fb90, 0xc08b074e, 0xc1cab6fe,
	0xfb7a23bf, 0x5a4cfbd5, 0x5bf430e2, 0xf64acc3c, 0x38296adc, 0x66b7bf85,
	0x24e2c962, 0x38f3962f, 0x15ca2fc0, 0xfdd38f5a, 0xf71fe72e, 0x860b653b,
	0x1ffcbe5c, 0x1ffc7111, 0xdef4aa65, 0x6d1f668f, 0x2a3fc418, 0xfa0930a9,
	0xd0457389, 0x7682cecf, 0x14b31794, 0x5dc241e0, 0xacfb3ecf, 0xf9444893,
	0xfd84eb88, 0x5a938da3, 0x54c6a512, 0xa5f49f9f, 0x79f9f8a4, 0x11dc84a1,
	0x7fb5c390, 0xff9d2732, 0x14de76ac, 0xfec6e7dc, 0x1cb06a0d, 0x3ff7c4cb,
	0x51de14d6, 0x66b9fb8e, 0x5cbfd1aa, 0x8f7d5273, 0xf30e63f2, 0x82eef67b,
	0x60099732, 0x6c8b41c7, 0xda1c48bb, 0x7a89e70a, 0x2ac33b11, 0xecd7b4f2,
	0x6b95f9e5, 0x783d551c, 0x91c6bf9f, 0xebdb4553, 0x5a9af9e0, 0x00e3877f,
	0xc7c3a5f1, 0x781d2def, 0x2688487e, 0xf112a3d0, 0xd0f4403a, 0xbd451dfa,
	0xc7fb143b, 0x958fbe18, 0x7ea0ebe2, 0xc7e03976, 0x0e7b5cfc, 0xbb11fba3,
	0xb52be5c2, 0x49ecc4c4, 0x946fd1e2, 0x4d64f3f3, 0x1d4f5565, 0x17e327e1,
	0x771ad809, 0x79ce9b95, 0xdf3c3ba4, 0x73946b96, 0xb064854b, 0x1e44dbb7,
	0xb22bade9, 0x61570d22, 0xeff0257c, 0x63ae38e5, 0xcce51dbe, 0xa2e63e9c,
	0x3a0e65e3, 0x312af75e, 0x6ae2a59e, 0xc14aa71c, 0x6f422cf1, 0x40bdd224,
	0xbd9ff38c, 0xd2ca06b7, 0xd304c3fb, 0xc9dcc586, 0xdbea43de, 0x9d1f713f,
	0xd637dcf8, 0xf18cabc7, 0x3ec7d017, 0xcae2ff5c, 0xa8ea0793, 0x1e5dc786,
	0xe68cfe17, 0xd8c53897, 0xbde86ea0, 0xea9488f6, 0x0840efa3, 0x6299c53f,
	0x7bff43a4, 0xbe1f7ca4, 0x67f9e268, 0xba30e45f, 0xeb94481f, 0x987e8e2f,
	0xd067f7a5, 0xb8dbf18f, 0xef17e31f, 0x7c45fa91, 0x378c610a, 0xf216f290,
	0x6d1f17df, 0x035a7f52, 0x8f40d9f8, 0xc95c609b, 0xb6fe2213, 0x28bd7a79,
	0xbbe285ef, 0x7e748907, 0x74afec58, 0xc62f29ff, 0xe2721bf3, 0xfde4c9b9,
	0x73e79589, 0x4c4f3d71, 0xa157cbe9, 0x4e27967b, 0xfcf19ba8, 0xbe321c88,
	0xbf8da5f7, 0xb3efd0f4, 0x2f79ba82, 0xc6555ef5, 0xc8cbf5c9, 0xedcf9c6e,
	0x7bf6bfc6, 0xe3cf8f56, 0xc96eea76, 0x2c7f9fa8, 0xa0bb72f4, 0x4cbceb97,
	0x2f68cddf, 0x18acae0b, 0x650cf18a, 0xc2e5ea3e, 0x6d1f3c95, 0x9f960fe9,
	0x7c8933ba, 0x304464fc, 0xb835fd8c, 0x7a4addba, 0x9451cdaf, 0x83fbb179,
	0x443df7c1, 0xefdb4a7a, 0x3cedfbda, 0xedc8234f, 0x0ef06768, 0xcc48ffca,
	0xdfac18cb, 0x07ae0ad4, 0x26b6feb5, 0x39b76f6e, 0xc2b8a7ae, 0x2431f459,
	0xc9fc3fb2, 0x5c068fce, 0x1d8fa09c, 0xbd8cc9ce, 0xb8e0a577, 0x3dcfe116,
	0x9a45c5ae, 0xdd7eecaa, 0xab9b96f3, 0x3e3a75ec, 0x2f3c6369, 0xf7fc7136,
	0x22fb342a, 0x2120edc6, 0x7f3c16cf, 0x2394c631, 0x3bd3ee9f, 0xbcf27864,
	0x72fd65ac, 0x830ee3cc, 0x70a561e7, 0x7b22adb9, 0x63e6136c, 0xdadc1d81,
	0xd2187f34, 0x7c1c9377, 0x887405c2, 0xfca3607f, 0x72167fe1, 0x74e42bda,
	0xb08bfdb0, 0xfe9494bd, 0x2f8fdb20, 0x8c9f0183, 0x68b944c9, 0x4635312b,
	0x1df3ac93, 0xd88bceb1, 0xbe2b07e3, 0xac7e3d9e, 0x8e3d8922, 0x213fb6f6,
	0xd187afae, 0xb127f6ce, 0x22498fc7, 0x63f220be, 0xddd4598e, 0x639740bd,
	0xbbe93213, 0xfc69a560, 0xfa18e1be, 0x87e05527, 0x04a2733c, 0x521997ed,
	0x848077df, 0x0608c43f, 0xea24e47f, 0xf42c59e3, 0xc9129dec, 0xc0a7bf11,
	0xa5e7685b, 0x0ad9f9f7, 0x0ebb7c46, 0xfae30ff6, 0x9bcc2e9b, 0x9e6e2c92,
	0x5f2fa237, 0xef75d996, 0x1ddc32d1, 0x80ce3ddd, 0xfb84a9fb, 0xc0aebc28,
	0xbeed5b7c, 0xccffb12a, 0xd17de36a, 0x2e3c0bba, 0x458bbb62, 0x1f30941f,
	0xbb3ed8d3, 0x1f7892d1, 0xba47b866, 0xc4496021, 0x37cfa227, 0x3776d82e,
	0x2a4f3bdd, 0xb63479e0, 0x04e28cc5, 0xb64cf789, 0x337e3dd1, 0x3134c55e,
	0x8c0eaa9f, 0x267e6393, 0x189b0fc5, 0x5ff982db, 0xbc798c0b, 0x7fa647ae,
	0xd20bbfc2, 0xb8f388d1, 0x7b420ec1, 0xf63415da, 0x3073eed3, 0xbeff452d,
	0x24bdf6b2, 0xc226cde7, 0x5226458f, 0x87f716bb, 0x675a8efe, 0x2d9dbaff,
	0xbd3fafac, 0xbe4914b7, 0xa69bcdee, 0xc61df7f3, 0xa0c74684, 0x88c7df29,
	0x580bf90e, 0x1d12f554, 0xb6e8f70c, 0xceb49d82, 0x1b190bb3, 0x0c1d1122,
	0xd270b9ed, 0x02c0fdd3, 0xac3abde3, 0xfa2700d3, 0x53f297ab, 0x1725056d,
	0x8a97f3d5, 0x7dc4da63, 0xc42375dc, 0xb2471e77, 0x39176891, 0xf6847e6f,
	0x07ec2ce3, 0x927bb9e5, 0x806db7df, 0x6cbbf1f1, 0x6979099f, 0xdaba7713,
	0x5f986cf7, 0xa4b7f7a6, 0x34b38e6a, 0x63efc024, 0xb9c9192b, 0x31d9952d,
	0x6f1a5c2f, 0x6ddd23f3, 0xc9618036, 0x73d99592, 0xe22cdea1, 0x9312add9,
	0xcf8a6611, 0xda8fe3ce, 0xf4a274f7, 0xe6c19d3d, 0xc823bed1, 0x6d39fc22,
	0x8fdf019e, 0xf8f3c8bb, 0x6f36919e, 0x140df3ff, 0x1fe6d4cf, 0x7d83fe8c,
	0xd4ffee2f, 0x8f3573bf, 0x5f887aa7, 0x95f9fb9b, 0x1f8279e0, 0x0bd479f1,
	0xeecd69b7, 0x3fe8919e, 0xcd37bc9c, 0xadd25eb7, 0xcccd3223, 0xf5f783bf,
	0xc3c3ebc6, 0xf7f216ad, 0xc4bac4d2, 0x5d775f78, 0x6bd3a7f4, 0x0da5f16b,
	0x6668f7cc, 0x0cef7f74, 0xd3227dd6, 0xc1ac3bbd, 0xdf7427a0, 0xd6f18007,
	0x1fefc83e, 0x2df7e336, 0x6f67fef0, 0x6ae9de7f, 0xe907b607, 0x3e5a12fb,
	0xae8fe62a, 0x0f7fecaa, 0xc1bef137, 0x24e30cdd, 0xc04dd789, 0x137cc085,
	0x06922cec, 0x39d64be7, 0xc3dfaf8e, 0x1ea1d7a2, 0x0f04f012, 0xf1367fd7,
	0xf994357e, 0xfb3fa231, 0x98dbb60d, 0xbafdf28d, 0x8ff51b25, 0xb8fef015,
	0xa8724b41, 0x630bbe9d, 0x96fb3d63, 0x3849bf40, 0xdc7e8e6e, 0xe7b71898,
	0x13a4fc61, 0x0e1ef4c2, 0x7c4ddfbe, 0xe1cf55d8, 0x3317e8a8, 0x5d73d267,
	0xfea432fb, 0x8c42c67a, 0xae7fe3ef, 0x3c1efdb4, 0x5f07380a, 0x79494375,
	0xef4c2d09, 0x9d5ea067, 0xba6bcba2, 0x9d39dd96, 0x37e705cb, 0x384fd459,
	0xabe8356f, 0x8356e26b, 0xac2f933e, 0xafe78339, 0x3d4254ed, 0x7cb7eebb,
	0xebc520bc, 0x7db1b765, 0xf9e3c8a2, 0x7d6f4d67, 0xf88b7d8b, 0xd24e42f0,
	0xbe7eb8fc, 0x3fbe188d, 0xaaf58562, 0x44632c66, 0x9f78ab67, 0x34f48ade,
	0xdfffcff7, 0xf9bab4a5, 0x0ae6013d, 0x8e76fd20, 0xb8af5808, 0xa0feffba,
	0xec00e506, 0x2f78acc2, 0x58de6373, 0x1c91f335, 0xdee663c4, 0xcbcce724,
	0x68f95de9, 0xf67f7517, 0xbfb63e52, 0x7ca5e67c, 0xfe5f73b4, 0x8e3369ec,
	0x3f8a7b57, 0x0f250357, 0xfe242d2e, 0xfa5d29e0, 0xd3df1e7a, 0x713e13d7,
	0xdbe7a2f5, 0xb37cf14f, 0xcc0739e2, 0xbf049651, 0x23160e09, 0x0d2bb9ff,
	0xe41670ed, 0x3e08d7f3, 0xca6e397e, 0xbe75806a, 0x13e4ca7c, 0xfe7f36f9,
	0xc62f6b4a, 0x70d217f6, 0xef4f97fe, 0x78750735, 0xfbf8235e, 0x50f03c6c,
	0x3e673e06, 0x9093ed4a, 0x69f7884e, 0xe792bfc0, 0xda7e2243, 0xe783983a,
	0xd4fb666f, 0x0e7b8c5a, 0x7f8a3e61, 0xb15cf7e2, 0x7cf14fdf, 0xb8f5c32e,
	0x0d3f2609, 0x0f3c57e0, 0x6cde62d6, 0x1ba3bf9e, 0x77c877df, 0x79847f47,
	0x613adac0, 0xfb13f27c, 0x65b688f1, 0x35615e60, 0x51ac2bcf, 0x87456662,
	0x893e1f57, 0x5fbcab78, 0xc3579887, 0x4fc09b67, 0x91c60bc3, 0x337e386c,
	0x9c98a1f3, 0xb1bbc78d, 0x6b7bf8f4, 0x702cadd1, 0xfedf0907, 0x758bb27d,
	0x5c65fb69, 0xa3c4e667, 0x5ac788f9, 0xfd348ecf, 0x5f735b7e, 0x8cfac34c,
	0x8dfba338, 0x84d5b89a, 0xf1830ef7, 0x49dc4643, 0x0d4d73e7, 0x5451e168,
	0x01bf458e, 0x8f016aca, 0x960d7017, 0xd30f0b6b, 0xaa35197c, 0xa8cfc70f,
	0xf9f0f9f1, 0x80bf1a8c, 0x5e349543, 0xfde1495c, 0xe2bf0422, 0x7d70c0b9,
	0xc6d9a71d, 0x5faf550c, 0x077386a2, 0x63c4339e, 0x1c3be2ac, 0xa5141656,
	0x077ae65f, 0x52b04ea8, 0xfd224f39, 0xd5ef56d3, 0x511ea3eb, 0x2e328af6,
	0xc6d315f4, 0xd783227b, 0x3979da17, 0xefc7b792, 0xfbd95135, 0x57fc5c98,
	0x1e9a33d4, 0x18230771, 0x07149f8f, 0x7274023d, 0x7d41fe81, 0x0681e9a0,
	0xb0b28721, 0x0f48df43, 0x0c9f4878, 0xfd83c9bd, 0xd1bdc8de, 0x9ac1fa83,
	0x68ef7ff3, 0xeeb57e81, 0x89714ca0, 0xcd8d895e, 0x07ffb81e, 0x281df3dc,
	0xdb9407e7, 0x90af42ec, 0x7908373c, 0xb8f5035e, 0xf3dc6b1f, 0xd48e3e99,
	0x8bee3fb7, 0xcf4d1beb, 0xa622e8b0, 0x36a0eeff, 0xdfc15eef, 0x2fb31407,
	0xadeb0636, 0xf5dc3e5c, 0xe30c7cab, 0x873e5faa, 0xb8e258b6, 0x7dbc84a7,
	0x2d3fc62a, 0xd0cf63e4, 0xe02b9ec0, 0xa517fabc, 0x51a3a7f8, 0xa0bfb8df,
	0x875a8df7, 0x02dcd4de, 0x6af03d74, 0xbc97bd3a, 0x5cfe2324, 0xf1f0778b,
	0xa36f454e, 0x6ae36af5, 0x7f8fc0fd, 0xbf1d0af3, 0xcc9f71ae, 0x5ca73d20,
	0x559d7e5e, 0xa9613de4, 0xf053f3f0, 0x65f05473, 0xa2432887, 0x8d7be35e,
	0xdff2237f, 0xe49b39c2, 0xe904fc5c, 0xd38b9dae, 0xba464398, 0xc894aa4f,
	0xe9869bbe, 0xf3fedeb6, 0x0f38aa60, 0x5a5eb266, 0x8c59b7df, 0xb79523ca,
	0xb4c97e51, 0x2a65e7f2, 0x5fc4bd2b, 0x0c7c84d3, 0x6fb15fe0, 0xab2d9559,
	0x175fcf90, 0x585af7fb, 0x5572be25, 0x1a30dbce, 0x5b9a66b6, 0x729f7da2,
	0x1c617581, 0xe0f4cde7, 0x7fa82caa, 0xf7d98273, 0x88fbc320, 0xbcfc93ef,
	0xea4ef239, 0x448566ff, 0xe575dbe7, 0x02979b1b, 0xf92b53fe, 0x5834d3f3,
	0x0235f549, 0x6dabf13c, 0x708f921e, 0x9173e735, 0xf05fb27f, 0xe89a94cd,
	0xed3fec36, 0xd9e69dbc, 0x2bf7f42b, 0xf72a72e1, 0x4e547d84, 0x7ee9f8f3,
	0x9b0acde0, 0x9f417f38, 0x5c8e7ac2, 0xe51fb1d8, 0xfa3e56d8, 0xf3072fa8,
	0x7df4cd60, 0x19cac99b, 0x1ac0cc33, 0xda3f6c58, 0xa52ac7b5, 0xafd05955,
	0xa1b8dd51, 0x2ccdfa0a, 0xd098e615, 0xee428d1b, 0xd76fa90e, 0x473e0267,
	0xf3864976, 0xbbc851bb, 0x07dbe475, 0x511cb550, 0xbbf199f7, 0x4a76470d,
	0xb4f79ef4, 0x01a3b6ca, 0x54e7bfa8, 0x75f70324, 0xd910e9d1, 0x5b2b67b9,
	0xbe723ca8, 0xc33e8721, 0xae72e410, 0xdf9da7cd, 0x5da31533, 0x4ceaedfb,
	0xf7ea7d83, 0xfef00cb9, 0x7b46494a, 0xe1fab0fa, 0x2f8825d6, 0x0d61afc3,
	0xfa88f7c4, 0x13c23ec5, 0xf3c725f4, 0x73e23349, 0x59bb7b8d, 0x8d65ddff,
	0x1164588f, 0xc09a63d1, 0x93e570ef, 0xab0e87a4, 0xfdb03a4f, 0x65cff970,
	0x62bf5fe4, 0xf7d3e033, 0x5363d0bc, 0xf2a1db45, 0x30bddadb, 0xb34aa1ff,
	0xdeb7d38f, 0xeb063dd7, 0xeac7a4cd, 0xf4e38c72, 0xc4ead3e3, 0xf0950e79,
	0x17c6faf9, 0x9f8696f6, 0x73c35fd6, 0x1d15f9da, 0x57d7d6e8, 0x8550df6e,
	0x8996e57c, 0x1a8aef2f, 0x5767b9e7, 0x8bde81a6, 0xf8065cbb, 0xc1fd6550,
	0x7e8c822a, 0x6f25abca, 0xccf5e6cf, 0xf3a9c531, 0x52773c57, 0x6911e7be,
	0x97a9f93a, 0xd72a53f4, 0x3c53f726, 0xfc50a7e0, 0x929fb92a, 0xa1b46fe8,
	0x91f1852f, 0xf4f9463c, 0xc4cef9da, 0xf8ad8e77, 0x7fa9639d, 0xe56effbc,
	0xf6af4a9e, 0x11f162bd, 0x8dff5e4d, 0x4b96e1ef, 0x622f3eb2, 0x442deb31,
	0xc6845145, 0x3df3cc19, 0xe113af53, 0x537c59cf, 0x1af9d02a, 0x7e36ed99,
	0x5eff99cf, 0xd05b7005, 0xaa3efd06, 0x257dfe0c, 0x169d5fde, 0xf8f677df,
	0x3d4ffe79, 0xdfc4e3cf, 0xd9d16863, 0xecaf3f07, 0xf831dfcb, 0x57b4a62f,
	0xf1b9f1f2, 0xbe3cada7, 0x1ef12a7c, 0xc53f8b41, 0x38db8a24, 0x95d7bf92,
	0x339ade78, 0xcf2fb8f9, 0x2f49f7e2, 0x1fefc0df, 0xe5e5ae5e, 0x9c792b2f,
	0x5e045fff, 0xaff809ef, 0xff3c5f41, 0x43cca077, 0x822347fd, 0x5ee92bc7,
	0xc413c445, 0xfd836a39, 0x2c3ec0b6, 0x6ef822bd, 0xf4fdd5e5, 0xa979bab5,
	0x8af47f3d, 0x7b07afe0, 0xf3d3365e, 0x74395cff, 0x9fa1e7f0, 0x7dfbc2df,
	0x6479b178, 0x7c476be6, 0x51971864, 0x49f1e219, 0x3c783770, 0xf2edffe4,
	0x9c77fe00, 0x443ddeae, 0x2d871dc8, 0x6d95f178, 0xfd2aa584, 0xfdfe5138,
	0xa2dfa80b, 0xa5f1a7eb, 0x584ee22c, 0x843e61d6, 0x2b656388, 0x0724ec8c,
	0xaa5149d8, 0x8fde0e67, 0xe625723d, 0x13ef89e3, 0xb8a3e632, 0x2dbeea39,
	0x9b371f54, 0x3d6f7fa9, 0x7fcc7b2f, 0xcfc1fbdb, 0x1b4dfa6f, 0x7bfb338a,
	0xc7ae004a, 0x29611516, 0xefc58d22, 0x3dbff230, 0x1e34deca, 0xcf73a8d7,
	0xe57af687, 0xacdc430e, 0xefd1fe2f, 0x3c5f939f, 0x0ce6be3e, 0x578d03e6,
	0x3379d326, 0x7cf1ba67, 0xd18e71bc, 0x366a68fe, 0x2cb71fda, 0xdf386618,
	0x370d179a, 0x1f2eb7c0, 0x0f838065, 0xcf00cb7c, 0x30d1355f, 0xd70d82de,
	0x78efda19, 0x5e01a664, 0x0326edb8, 0xefcef77c, 0xc68b9c26, 0x0f3b5a73,
	0x9d5ef512, 0xbf4eb8c3, 0xbdaf846c, 0xc76f3c60, 0xf3c2339f, 0xa0f88a47,
	0x0f8a54ca, 0xed9ea65e, 0xf9abff87, 0x465d2feb, 0xeeb884a4, 0x106ffb45,
	0x4f332dfe, 0xc72a3d27, 0x5abcf0a6, 0xef1eac5f, 0x5762d7df, 0x185f7d1d,
	0x1edef3c9, 0x6bde291e, 0x4d5d9abe, 0x309350fb, 0xda78c26f, 0x7d7cdaf3,
	0xc3cc46fa, 0xd897553c, 0xd6bfd6c7, 0x81bce7b9, 0x97d95f02, 0x7b332fe5,
	0xdeffd244, 0x4eeb60cb, 0x91d825f7, 0x6c1af409, 0x95e8c19e, 0xf62a2fd8,
	0xd6f172e5, 0x29ea2b60, 0xea6ab71e, 0x7ffdfa91, 0x855b8ecd, 0xb7da313e,
	0xbefc4cb9, 0xdd86dfcd, 0xf3cb4df9, 0xbec2bd23, 0xc11af0e3, 0xbe497f1f,
	0xe7dff8c2, 0xc5ddfc6a, 0x2d373f50, 0x64902cb6, 0x34ae52ff, 0x89f2e7fd,
	0xb75d86bf, 0x9d77f604, 0xc60f7635, 0xea39f6e5, 0xf12bf3ed, 0x6ecc8e73,
	0xa7c7eaab, 0x0322caec, 0xef4ac89f, 0xcfb7ec50, 0xfbf88cb1, 0xd89395d6,
	0x6b6ae2c5, 0x2b79e495, 0xc5fe5765, 0xf177d7ed, 0xe573edbe, 0x614bbbec,
	0x2607b609, 0x2f1087d1, 0x57732785, 0xfe6e425d, 0xc347fae2, 0xe87dd37b,
	0xef2fb84f, 0x5becd35c, 0x7abceb2c, 0x8ee837bb, 0x4f15bd91, 0xb7f1ede3,
	0xfb7edebd, 0xfaebb34b, 0x36cc7bdb, 0xf3d5ef6e, 0xf6f32fd2, 0x614cfa9e,
	0xea1a6607, 0x762aff7b, 0xb277bb5c, 0x81a6ec9b, 0x5f6495f7, 0x78ea7969,
	0xed0a597f, 0x736c0493, 0x49c87bf3, 0xa1b31ec2, 0x6d41959d, 0xdda38e2a,
	0xff18ca67, 0x4d57edd0, 0x5131bd82, 0x12dbb631, 0x89560ae2, 0x57bdefef,
	0x3b44bb0a, 0x9dee130f, 0xd38e67ec, 0xe7abc4bd, 0x0d7dd38e, 0x35ef1b73,
	0x78bb9c27, 0xa7427a9c, 0x5c3bf0d9, 0x35107cfd, 0x38c04fdc, 0x659bf786,
	0xfdf125d6, 0x2f9daaea, 0x2a23f9e9, 0xfa0f7df1, 0xd117c4ad, 0xe46bc956,
	0x4f1f5e27, 0x193e7133, 0x349ecbc2, 0x057b2866, 0xf81af53f, 0xef65afea,
	0x099698c8, 0xe2be6ea6, 0xb474b08f, 0xfb1e79bf, 0x9ef12830, 0xbf116f22,
	0x44f7c8a7, 0x60c7f3dc, 0x27bd2b3f, 0x6ceef760, 0x6c9df7c5, 0x26a3df98,
	0x0fba2fe5, 0xdaf2106f, 0xa6eff0a0, 0xa178284e, 0xbca5cd1b, 0x495f2085,
	0x2f9123f8, 0x5b4517f3, 0x2322ffa9, 0x99fc695f, 0xf8d2a718, 0xaf1096d4,
	0x9f38c3da, 0xcf841ded, 0x62bf84f2, 0xba05ebbf, 0xe8badad7, 0x277bfe05,
	0x247a8ca7, 0xf9c5d17f, 0x1bda0b6c, 0xfa162718, 0x0fb0a265, 0xf91652b4,
	0xaf4e5015, 0x7503e830, 0xa5f88595, 0xd7265f77, 0xf654a233, 0xd8feb85b,
	0x9747f5c7, 0x380a8fa8, 0x3070e314, 0x189f61c6, 0xa29f6bbf, 0xcbafd7e3,
	0x8a4c0d17, 0x39be3359, 0xa1b93d5f, 0x7f37ce8e, 0x7bc54b35, 0xabe45ac5,
	0x8cdf7a4a, 0xec75fee2, 0x538c3ecc, 0x3bfc29d7, 0xf817b5bb, 0x996a5b77,
	0x629407cd, 0x6e9f7baf, 0xd5f39253, 0xb7174c3b, 0x71e7609c, 0xd17c06ab,
	0x1ffd0ab0, 0xff9a67ce, 0x400fed84, 0x7c75437d, 0x5b5fd60e, 0x07b2ff02,
	0x77c68df2, 0xfcd35e9a, 0xc5a51aa2, 0x880c788f, 0xe4b5b27f, 0x7f880e7f,
	0xe8fee05e, 0x81cf7160, 0x7c141ef2, 0x89e71711, 0x76a56b06, 0xf19884ce,
	0x3ed189dc, 0xaa8fc3af, 0xc95f1d03, 0xf85df466, 0x4ba9f3fe, 0xfa9455f0,
	0xf04bbac1, 0x62e017be, 0xa1549fa1, 0xf77fa887, 0xce34ac1f, 0x3dda59eb,
	0xc52b7c4e, 0xca0edc21, 0x7efc043f, 0x32913f84, 0x5d611ea8, 0x17bd3347,
	0xb5a40be1, 0xfa986e76, 0xabedade9, 0x56f4ed29, 0x3b313f7a, 0xa79ff295,
	0xa9bbfccb, 0xde1e3e5a, 0x0d57e527, 0xa8f76ba4, 0xd3dfd22c, 0xd94a7b45,
	0x5e273a79, 0xe782fcaf, 0x28e7e037, 0xca26f374, 0x5d0bc4eb, 0xcf002f74,
	0x7cbfbdd1, 0xabf7d181, 0x4eb5d053, 0x95aa9f72, 0xfdb9b2eb, 0xe8ff5897,
	0xad9f6e28, 0xa9f7e72f, 0x92296513, 0x4d7e7eec, 0x8fbe8841, 0xbd0a56b8,
	0x9150f98f, 0x77f95bdf, 0xfbd0e533, 0xe3ee80f3, 0xd7a3dd0b, 0x73fefeb3,
	0x9fe05c71, 0xa7ddcfd7, 0xebc7bde2, 0xe2bf230a, 0xca7653f5, 0xe55d7cdb,
	0xe782e7df, 0xde811bd5, 0xb77bdd13, 0x899384fe, 0xa2ee4e49, 0x5c5673e2,
	0x35b5c81f, 0x1f45a6be, 0xe1f6d167, 0x6dea1288, 0xf3cf71c5, 0x4ee9b9df,
	0xed077d8f, 0xe62fa46d, 0x8fcf5a21, 0x7f1933bd, 0xe702054f, 0x51befb43,
	0x2e9deedc, 0x89be8d60, 0x058530f3, 0x7dfecead, 0x3bfc3d91, 0x1bdd83ef,
	0x0459574c, 0x23c04c4d, 0xdc78c5e6, 0x6f1a12fe, 0x4cfbc2ba, 0xae87f714,
	0x132e9c0b, 0x57fcf3cf, 0xc0269be4, 0x2085fa63, 0xbdd785e9, 0xc2d7d6ef,
	0xdc1d53fc, 0x8c8c03d5, 0x75e445fa, 0xa7e0bd4e, 0xcbd7dc3c, 0x41898c77,
	0xcc4c75bd, 0x6c87bfcc, 0xfac1f78c, 0xa97d7072, 0x7f88e715, 0x1de85e26,
	0x9f47bfa2, 0x67c633e6, 0x4b385c8e, 0x7fa8997c, 0x3c2371ac, 0x4fd44955,
	0xde3bfc1d, 0xa70aa217, 0xba2d5327, 0x7e589d7d, 0x41a77e92, 0xa7cbdfdb,
	0xbf802057, 0x1cf1342b, 0x40f79eff, 0x75a01d7a, 0x612bd3f7, 0xd7a1071f,
	0xa467fd40, 0x9f8c75b3, 0x445ffde3, 0x94a3c9bf, 0xdc69fcbe, 0xd390ab4f,
	0xff380b57, 0xfe07fabc, 0x4f2018bb, 0xe47ef8bd, 0xf49c676b, 0x33fc6a9d,
	0xebc9f4eb, 0x5c9fa7ee, 0x8df5eaa2, 0xe9833e91, 0x5fb9359b, 0x7c8df41a,
	0x90a3c85e, 0xe55f6d0b, 0xeb379738, 0x8c8f9039, 0xa449397e, 0x7701f7ef,
	0xfa81fe43, 0xd68fdd12, 0x6c7af9ba, 0xb75eb8a7, 0x9b768c21, 0xc52fbda2,
	0x7cad23ef, 0xfced24a8, 0x3b593f3e, 0xf59f41e6, 0x79f4fbf8, 0x97dfbd32,
	0x8dee221f, 0x2751c6fb, 0x9a9773d3, 0x7cdf8b4f, 0x68f779dd, 0xfa84b971,
	0xb9af00ff, 0x80005f58, 0x00008000, 0x00088b1f, 0x00000000, 0x7dedff00,
	0x5554740b, 0x55b9e896, 0x92556eb7, 0x4849524a, 0x370f90a8, 0x00946084,
	0x07e47e45, 0x301084a9, 0x68205d82, 0x882a6210, 0x01521288, 0xae59c6d1,
	0x08626149, 0xa5d0bda8, 0x339e663c, 0xc0e03053, 0x1a44f68c, 0x29c120e9,
	0xdab433e4, 0x79a681dd, 0xc1addd3a, 0x9af0ec66, 0x0fb4214f, 0xede3e0df,
	0xa4bdcfbd, 0x4456e56e, 0x9c7baa5b, 0xe1ed5ea9, 0x67dff3dc, 0x2739f7ff,
	0x2b99398c, 0xe7fdb196, 0x303318eb, 0xcb573e66, 0x63147f53, 0x36498c85,
	0x18128be6, 0x2d03fcfc, 0x4ac71790, 0xe6328db6, 0x7d353b79, 0xed4d5ec7,
	0xc7485ca4, 0xa33b7b40, 0x3f6866f6, 0x7d686b2b, 0xca59f627, 0xdae8d458,
	0xbfa09a0f, 0x318f2c77, 0x17d41e77, 0x5303995b, 0x13ba7fbb, 0x26d30ed2,
	0xb195a247, 0x57fb4f0d, 0xba8d20b8, 0x12fb29ed, 0xafe3af48, 0x40fa6872,
	0x2b36a3ba, 0x5d6db18e, 0x2349d7db, 0x983af318, 0x4a860723, 0xfea3ee6b,
	0x1c6b7ad5, 0x18648130, 0x45deec67, 0xef5c30ef, 0x79864c93, 0x364c5d49,
	0x77ed0fc7, 0xc769c9bd, 0xd6a47579, 0xeb5e71da, 0x934d5e13, 0x7ceb7d21,
	0xd609bdad, 0xe3e04de9, 0xc770bfec, 0x4ae3066c, 0x8c23d5e9, 0xa2ffe602,
	0x31c20c6b, 0x2358de7d, 0x6c894794, 0x70889893, 0x824ffdf5, 0x08a939e7,
	0x1c637d20, 0xb2cfba73, 0xd6f7d614, 0x43d827d9, 0x67ced879, 0x8d7981c9,
	0x409939b6, 0x4cc732fd, 0x926d9780, 0xc451c2bb, 0xc39d3598, 0x96700ad9,
	0x76b1ce01, 0x58f907a8, 0xa138731b, 0x33d7199e, 0x9977f709, 0x6afd7825,
	0xdabe99da, 0xbb3be0c2, 0x29605d76, 0xfe05bfd0, 0xdbd6ed0d, 0x309c5b57,
	0x4bb3b28f, 0xde075b99, 0x9359d263, 0x1bdb0e39, 0x78f2f966, 0xecc371fd,
	0x387fd60b, 0xcd33e68e, 0x1bdf03ad, 0xc278ce70, 0xb8762cbe, 0xee6d027e,
	0xb39eb089, 0x674fbd52, 0xbeca65bc, 0xc27c5d46, 0x5eb3fb8e, 0xf680fd68,
	0xd8eac727, 0x4fd686c1, 0x3ea81873, 0xfc3527fd, 0x5503d0b8, 0xe0a890d9,
	0xa62cc8a1, 0x45f2c1c4, 0x47ec0fd8, 0x4af744e7, 0xcf1517dc, 0x8437d845,
	0x4f9dd7fb, 0xa94f8393, 0xfbfba27a, 0xeb6dfd7a, 0xf6f4cd5a, 0xbb1c06f3,
	0xd097da44, 0xcf32b2ef, 0xd91f3b15, 0x1af70670, 0x5fff00e7, 0x934abdd9,
	0xb93cf4f7, 0x60ee4ce1, 0x03fe057e, 0x08d6c3e0, 0xac662b22, 0x95b11799,
	0x01933fac, 0x65118f62, 0xd0c5b7ea, 0xf00b2a7f, 0x67fa62f0, 0xfe1a2f29,
	0x4ed7d353, 0xd37ff247, 0x8ab96857, 0x3f10cbe7, 0x9f333521, 0x666ffb88,
	0xfa9e467d, 0xa60225c4, 0xc6cb237e, 0x6530cdd4, 0xffe155ac, 0x2f52c9ff,
	0xdbec3a60, 0xadf7c654, 0x80a40aee, 0x92e97527, 0x035c918f, 0x9729a7a9,
	0x6e54fdbb, 0x9f311871, 0x788f159b, 0x26dd6ed1, 0x502cca62, 0x22e498bf,
	0x7ddceafd, 0x7f7c1b46, 0x12320dae, 0x6fec73a7, 0xf82782b5, 0x42be40b3,
	0xffc7b7a1, 0xd23a6af0, 0x7e4574c5, 0xf612039a, 0xdf4e8379, 0x722ff0cd,
	0x25ef7941, 0xdb7889c9, 0xadc8fb79, 0xfeea2748, 0xb40b2719, 0x1c09bd6f,
	0x92a9bdaf, 0x075f076f, 0x55377fd5, 0xcf23757a, 0xb8298d7b, 0x03eb8c7f,
	0x0a339857, 0xfd772bf1, 0x9d69062a, 0xe2637985, 0xf0f396b1, 0xa957a858,
	0xae646fcc, 0x9c02fd40, 0x67f8667c, 0x6cd36e65, 0xded4f806, 0x804667ea,
	0x8f20bbcb, 0x365d7cbd, 0x0534e75c, 0xf17b666e, 0xbe0f58c3, 0x0562c5ba,
	0x7e106314, 0x3e9063a7, 0xefdec0a4, 0x962e500b, 0x38555cba, 0x4fda80cf,
	0x9cacbc08, 0x7216c78f, 0x7b97593e, 0x9bdb093c, 0xca7021ed, 0x05d6827a,
	0xc7ee192d, 0x2a81bc20, 0xd9f19453, 0xdca4dc20, 0x3e38b3aa, 0xb03b3633,
	0xb4d769bf, 0xd15c55fd, 0x368745e6, 0xf36ba52f, 0x83293caa, 0x981f48aa,
	0x4e5e01fa, 0x0e72ef45, 0x8cabbd70, 0xcaae8805, 0xd791b758, 0x6df52873,
	0xf98c7744, 0xb709ae8c, 0x5a0af532, 0xff5f0cf8, 0xb8f1e200, 0xa153bcc1,
	0xcf580a97, 0xf5a1ac98, 0x244e4d2f, 0x3f0b7c7c, 0x9fcdbec1, 0xd3e23b1c,
	0x7c9634f1, 0x3077d61d, 0x9ab1af6b, 0xb34ab5e0, 0x5f84874f, 0x73fdf0c7,
	0x7be0735a, 0x535fb2b5, 0x41889fcf, 0xa2f151bc, 0x72afc15c, 0x464bfaeb,
	0xf16abfd8, 0xbf88d9e1, 0xdfcce2e5, 0xe139be11, 0x4abed07f, 0x86b95f69,
	0x55f38889, 0x906ff816, 0x02c69bfc, 0x7f71e287, 0x8e2369d8, 0x1194895b,
	0xaf539fb4, 0xa0fa9a4a, 0xcafad32f, 0x35b3e843, 0xd58c7d64, 0x76853ed8,
	0xd70bf302, 0x7fa70fc7, 0xb553ec88, 0xfec76a7f, 0x3ba475df, 0xc1f01bec,
	0x8ac1a5f2, 0x26540ef8, 0x2721c9ea, 0x5c287ce3, 0xff0aedff, 0xd0b36f69,
	0x17e0ddfe, 0xf01bb4d0, 0x7fe40d9d, 0x8eb47e85, 0x7c0ad1f6, 0x2e93e713,
	0xdab77df3, 0xfb07cf99, 0x09f4756e, 0xdc04af98, 0xb3bc824e, 0x2f1fd5b0,
	0xe90990e3, 0xf2ee104b, 0xaac7a266, 0x3b0e5c6b, 0x198731cf, 0x18d79dca,
	0xa63c87a7, 0xb4e5dbf0, 0x71bf2aaf, 0x143eeb5e, 0x9963e587, 0x0697e143,
	0xded2b96d, 0x0c27080a, 0xc32023c5, 0xaadf5893, 0x6f818fd4, 0xad25016b,
	0xfe609e0a, 0x75ba5829, 0xa400e02c, 0x020c30d1, 0xbe842625, 0xd1af090f,
	0x45cc8dfc, 0x5ab951e5, 0xfe22307c, 0x03e50dc5, 0xf843c446, 0x473a026e,
	0xa11c69b9, 0xdb19f76d, 0xae7c426a, 0x2fb5e6ba, 0x5a48b821, 0x0e04b8b8,
	0xad335f17, 0xd75952ab, 0xe9fb2133, 0x566f36bf, 0x5bf7d416, 0x1a4e1505,
	0x335ff1fc, 0x7afe7f50, 0xc2cc67c1, 0xf9a72f71, 0x5faf3d79, 0x7df03f95,
	0xd07df201, 0x300fee77, 0x7bcc3c67, 0xfff7a140, 0xae738cad, 0x7de946cd,
	0x38426bcc, 0x678e642c, 0xcfbb43a6, 0xb4ca5ce7, 0x4363fe40, 0xa40371e0,
	0xf819dd1f, 0xfbd605b4, 0x17fbb256, 0xda6f0193, 0x82fcfcbf, 0xd8faba07,
	0x20ef1d9a, 0x933cf87c, 0x34a003e3, 0x8a37bbae, 0x5bac09e4, 0x590acda4,
	0xc23e286f, 0x77a4ac7a, 0xd1275d0d, 0xf10fae09, 0xeebfad4e, 0xe57fcfcb,
	0x3feff581, 0xfa40eb10, 0xf3fe7fdf, 0x43e7c889, 0xe3e037d7, 0x53aea5f4,
	0xe8d57f6d, 0x3939373e, 0xdbf67c68, 0x4dd13738, 0xf0e9c922, 0xf6e5e374,
	0x042bc587, 0xef9531cb, 0x4dae121d, 0x683ed337, 0x2bb4dcf9, 0xe4193c5a,
	0xe542ab7b, 0xc1f14dd9, 0xcc60c003, 0x3f086c59, 0x9583e50c, 0xff89fad7,
	0x307cb1fd, 0x60f81f21, 0xf2cefb0c, 0x19938dc1, 0x63eb22a5, 0xf7bb4e5c,
	0x2c7801bc, 0x8db64a16, 0x927e8ab4, 0x1fa2a2eb, 0xe9cb1f3f, 0xdf1cec19,
	0x6fbf010e, 0x1660f25a, 0x71ea57b5, 0x687f1a7d, 0x2ddb887f, 0xc751bf7f,
	0x9067f2af, 0x17bf705a, 0xfad367e4, 0x52a7e3f7, 0x40f7498e, 0x5f42f3f9,
	0xceb883fd, 0xff640c2f, 0xdcf973b2, 0xc3b2240f, 0xf0f3fc22, 0xbf4b6ad5,
	0x253c2875, 0x12da70f9, 0x1b0edfc0, 0xf9e03660, 0x2776d93f, 0x8b553572,
	0xd5d4e6ef, 0xa82f5516, 0x53c8bc02, 0xb02f3ef0, 0xd8d0f48c, 0x098da711,
	0x1ddf1f90, 0x3a718faa, 0x07fa9511, 0x9f89f784, 0x9efa16c7, 0x76373546,
	0xc5af16a7, 0x47449d2b, 0xb43fdc56, 0x81e4427b, 0xba25a818, 0xcef44312,
	0xfe457cd6, 0x60a2b117, 0x3ac58dfc, 0x7d14b790, 0xdbeefa42, 0x92313f57,
	0x512e70bd, 0xaed36f83, 0xefe2c3ca, 0xeafc2a3f, 0x185fc435, 0x9f0a87fa,
	0x53b36eea, 0x4c9b777e, 0x5cb69ee9, 0xcdb7befa, 0xb69ef941, 0xf5e94512,
	0xa1ba3f12, 0xc4d882f7, 0x5c8a4979, 0xe45f9897, 0xf0544fa9, 0xfb445731,
	0x363b459b, 0xfb7a980a, 0x859f7d79, 0xd719bb97, 0xd33cfef7, 0xa99e4532,
	0xb70184f9, 0x246ff117, 0xf47efa30, 0x0bf82847, 0x0b1ce9f8, 0xeb19d15b,
	0xe7ffa3b6, 0x3b32ea60, 0xed9e7796, 0x199213b4, 0xfc76359b, 0x86d7bb0c,
	0x6ea588fd, 0xfd986d8b, 0x9b3eec92, 0xae07fb9b, 0xc7bb475f, 0x98c0f1ce,
	0xdda2b526, 0xe5b037ef, 0xbbed41dd, 0x76fdb80b, 0xd5b85f24, 0xcc149c7e,
	0x5381645f, 0x078fb039, 0xfe3a1e71, 0x51f95380, 0xbdc79a91, 0x103da3b7,
	0xd0dbedcb, 0x815efc79, 0xdc31c1c7, 0xfcb4373f, 0x6ebdfb96, 0xc03c73cc,
	0x55eb2bab, 0xd543e223, 0x9e219b80, 0x25729048, 0x65afeb93, 0xdf833f4a,
	0xf64adeb9, 0xa27a8cb6, 0xe90ba4e3, 0x9039806a, 0xe1f6484d, 0x9157bee9,
	0x7229cf5b, 0x062badeb, 0xd6dfff5d, 0x1be69102, 0x80c77dfa, 0x051cfd7e,
	0x7d337adf, 0x7767a8ed, 0x00706cbe, 0xf6756647, 0x1fc851ce, 0x42581adf,
	0x7cdccf78, 0x5815b35d, 0x5eddd9d6, 0xf9c67446, 0x9f22995b, 0x44bbfceb,
	0x89d603f4, 0x7dfd113e, 0xeccb6915, 0xd4cefeb8, 0xc733fe30, 0x1f2a1683,
	0x92e54258, 0x1de91b7d, 0xc388e943, 0x7c4bc767, 0x9f76753e, 0x99c47e88,
	0x84455bb9, 0x7c0a8bff, 0xa89b72ea, 0x7fcb3cdc, 0xbb382458, 0x997fd89d,
	0xa63b6b63, 0x09d60392, 0x36713a72, 0xb264f873, 0xc8d9d7b7, 0x3a5afb6f,
	0x4e551fca, 0xa842f6a8, 0x219a39fc, 0x19d3dd91, 0x0abe9030, 0x80cf67f5,
	0xb52977fa, 0x649de9ad, 0x776e7407, 0x9eb1141c, 0xc63f2043, 0x930fb95d,
	0x72e6b27c, 0x7522ac7d, 0x22c93b5b, 0xa013e09f, 0x2f053aff, 0xfab4f2ea,
	0x74e39956, 0x57a61c7b, 0xaa6672b5, 0xfa8477a2, 0xda85ac25, 0x2281757c,
	0x3cb9728f, 0x1ffb306a, 0xd692fa43, 0x040c2508, 0x211ad45f, 0x2ee3e715,
	0x08e97ee0, 0x49e6cfd0, 0x95667690, 0x68c7ff90, 0x0081fa3f, 0xbcc4340b,
	0x66fb8696, 0x28fc901c, 0x3b40c177, 0x4b8eafd7, 0x8dba6f7a, 0xe8a649f4,
	0x9bc4b685, 0xc89fe7f2, 0xd3bcfce0, 0x75bbeac4, 0x80b6aff0, 0x328f8df3,
	0xf8f5eb5a, 0xb65e5a8a, 0x22392046, 0xcca4f229, 0xf47a9cce, 0x20dfd6a4,
	0x76553e71, 0x9308f58d, 0xf1cb2fd0, 0xd6536766, 0x8153b436, 0xf37a9c5e,
	0xf4e428c9, 0x59816ef8, 0xf5391ff5, 0x95cff2f8, 0xfebcaafd, 0xbe387d94,
	0xb900ae61, 0x823dfb87, 0xf3a523f7, 0xa7912571, 0x3c790a53, 0x4f117ae5,
	0x27228a1b, 0x4764a677, 0x81220f0e, 0x5e9031d7, 0xf7d1b7cf, 0x483bb1e9,
	0x8e02443e, 0x638411d9, 0xa6f1cc99, 0x4bc5a1cc, 0x67b782a3, 0x3f86220b,
	0x904796f7, 0x7f02448f, 0xf45bbeca, 0xbbf4aa70, 0x91293fb5, 0x8731cf5c,
	0xe510acbb, 0xe44f80ce, 0xd7ae0e71, 0x3dc13bbc, 0x8abdfb55, 0x6fed20e2,
	0x77efebe9, 0x123d7c29, 0xf80558f4, 0xffd32f3b, 0xdefe9ea0, 0xbe311858,
	0xe61d3290, 0xf5c490d1, 0xb479d09c, 0x1e0c4616, 0x1e606b9b, 0x8780258b,
	0x8bacbece, 0xd7363c1c, 0x0a2ebda2, 0x7b979e3c, 0xc8318cec, 0x58df810e,
	0x4af5ea03, 0xf465f41e, 0x2c9e83a5, 0xc3e2f538, 0xbf08225b, 0x1ea0e33a,
	0x8e8f3a15, 0x337e1c29, 0xf51ebe98, 0x79e6e47a, 0x7a36546f, 0x4a7d3937,
	0x7f35f461, 0xd3ecc461, 0xd06336cd, 0x9134467c, 0x2d9a4c93, 0x27abeae8,
	0x90885ed0, 0x3806483c, 0x2cd83bb5, 0x36fcf83d, 0x6295fb72, 0x04f97487,
	0xc985a7f7, 0x4cf97768, 0xa2f43009, 0xe05e5511, 0x0907eccc, 0x41dbbaae,
	0x6b3def4f, 0x9ea36c70, 0xbe280b02, 0xd0183769, 0xee7e65ff, 0xf5fd17b0,
	0x8381e955, 0x8dfe7e66, 0x031535e2, 0xfe4669cc, 0x8c5edccf, 0x653d956f,
	0xe8e7e7ca, 0x98d9bdb8, 0xfcc0e090, 0x7b4081f4, 0x4f9da41c, 0x5da074e5,
	0x47d03557, 0x3f40e779, 0xf6a179d9, 0x8fbdbf66, 0x02548de4, 0x1fda2926,
	0xcc467de9, 0x4e7ded5b, 0x455bb78c, 0x3d4321c1, 0x5f6bc071, 0x48fe4852,
	0xe0839387, 0xa353f624, 0x85ba63c0, 0xec6abdc7, 0x502e28cb, 0x87981251,
	0xc77e1f76, 0x128d57f8, 0xf9b4aaff, 0xdd342e28, 0xab43b5a6, 0xf3c44c03,
	0x82f1a10e, 0xdedc03a9, 0xb027121d, 0x9d68ff73, 0x8d0f07e2, 0xb827581b,
	0xded08a53, 0x2e283b00, 0x658e5071, 0xc9f9189b, 0xe7cc033b, 0x25f482cd,
	0x6dcdfb91, 0x0b272f82, 0x5a061ce3, 0xd9133947, 0x53b34862, 0x4b9d225d,
	0xe2d8f804, 0x5c02c595, 0xf04f6fb2, 0xdcfb246d, 0xfd54f04e, 0x3b9feb31,
	0xce85fe49, 0xff8ec554, 0xc18be6c2, 0x4c6dd3b8, 0x5dc2d4f8, 0x358f88f9,
	0xf25af322, 0x7e48ce29, 0x7bbb38d0, 0xec8e2db6, 0x1e211ea6, 0xc53227e3,
	0xb733a7e7, 0xbaf7a712, 0x65339e71, 0xf6fd0d8b, 0x5fa3f6e5, 0xb50279e0,
	0xf0e4e0be, 0x5b1b6417, 0x27b2fd0c, 0x6f18edfc, 0x9ee7933b, 0x29f80452,
	0xdcc5f528, 0x840befb9, 0x5e2cdf37, 0xc4fd2912, 0xeab42318, 0x91ddf1d1,
	0x6fa46b93, 0xc7300ddc, 0x7d33b4f9, 0x229af2be, 0x9c06ea27, 0xdaa828e2,
	0x087eea5c, 0x7b633de1, 0x55e60753, 0xc610dbbc, 0x6ffdf8af, 0x79da7f59,
	0xf88494f6, 0x1fe84177, 0x63757887, 0x8e20425d, 0x2f63e9fc, 0x1a9fa0a5,
	0x28bfbcf4, 0x3e8b73a2, 0xea2ee311, 0xba65e73c, 0x84d7a8ed, 0x173c67f3,
	0x737dfb39, 0x9ebc318a, 0x9b9137f5, 0x1bf3f107, 0xec7c8dfa, 0x9f5831b0,
	0x3e913471, 0x0436ff83, 0x764901f1, 0xf92b56b3, 0xe2e5755f, 0x83f4119b,
	0x8c5ca3a4, 0x748ed47b, 0xf60fb9da, 0x790fd315, 0x7ba7ceaa, 0x27c3c70a,
	0x2727224b, 0x229c63c7, 0x2bcf99be, 0x32f3e04a, 0xcd799a09, 0x3a70e129,
	0xf072253d, 0xd7f4862a, 0x8a8fee25, 0x96acdce8, 0x9fae403e, 0x769ba3d6,
	0x247284fc, 0x70f3a057, 0xb0067f20, 0x6e6d8d7d, 0x81c8024d, 0xf2b3dbe5,
	0xdad5be51, 0x422476b7, 0x4c9b51fe, 0xa569f97e, 0xf5ebdfee, 0x9fcee7f7,
	0x715faddb, 0xfc0dd87e, 0x35dca752, 0x9fdaa8c5, 0xbac9c5d1, 0xb16c67f6,
	0xd8c37c1e, 0x2253c99f, 0xb3856f6b, 0xb98a0b3f, 0xbf1c34bf, 0xdc8e282a,
	0x6b1ed13c, 0xd617630c, 0xb31e7044, 0xe17635b2, 0x7f106376, 0x8e0dc424,
	0xf1b80d57, 0x86fe168c, 0xb7148bd8, 0x8bdbe871, 0x4e47140f, 0x38c1cd1e,
	0x1cbeb566, 0x2c4714f7, 0xf7ef71be, 0x7d2fbd20, 0x5011a1eb, 0x7e30bcc4,
	0xb7dc60ca, 0x434abdde, 0x3a8df797, 0x0753a0fa, 0x1c899f1f, 0x1b454edc,
	0xd12c5f91, 0xa6aea73d, 0xf5f58b9d, 0x2453a5ab, 0xe6666fea, 0x6e7843ae,
	0xb32cf3a5, 0xcced1f21, 0xdbd22ff2, 0x7e14f787, 0xe39b3f50, 0xdfca2d4b,
	0x8a5b7aa0, 0x47b2fc79, 0xc3332b91, 0x22b949d0, 0xfe296707, 0xe63659e8,
	0xef53addc, 0xb311c587, 0x848d4fbb, 0xfeb46674, 0xe6576f7c, 0x7f18677b,
	0xe1c8a1c5, 0xa034e6e7, 0xfad59993, 0x39193cf3, 0x266f73fe, 0xfb5ee3cc,
	0xeed0330b, 0x33af259e, 0xc3fbf229, 0x5eb91d62, 0x50a3bcc7, 0x250c5e3f,
	0x1a9fb006, 0x49f29520, 0xf28c7f8e, 0x1b4001e8, 0x3e907e5b, 0xdc0f861f,
	0xc3e38536, 0x3fba26cf, 0xb9871bd5, 0xa2f6359b, 0xf22abf24, 0xf1217773,
	0xf1f7b47b, 0xf8b3093e, 0x4cf74098, 0x7df9123a, 0xa017ba3a, 0x5effabc6,
	0xf21f3fd4, 0x67231b56, 0x44776491, 0xf1857e93, 0xb1d92b79, 0x758edcd1,
	0xb9d5cf44, 0xba99d1c7, 0xcc34decc, 0xbb388efd, 0x4ed82eab, 0xbb5a9c15,
	0xd34dec13, 0x01f3a094, 0x98e9ddaa, 0xd14cb6ec, 0x14adf5c8, 0xdb53fabf,
	0x94119993, 0x643fa887, 0x9ee55d42, 0x785a1dd7, 0xbc00fc70, 0xbfe53099,
	0x46ccde26, 0xcde0e878, 0xc6f0f4f7, 0xf1c38532, 0x90ffd37d, 0xc68663ad,
	0xde7ed42b, 0xa82dbab7, 0x2fb7ad8f, 0x97bde0b1, 0xe2dbb74e, 0x58f3f2b0,
	0x7eeff7c1, 0x38bdc93d, 0xeec97c78, 0xa022f3a3, 0xedea368f, 0x347d3853,
	0xc9b3e141, 0x6666fcca, 0xe17f7e32, 0x0db7c17e, 0xb67a82ec, 0x467c84c9,
	0x125d1fad, 0x8ef63b39, 0x4f7fe26c, 0x1867adea, 0xf886d7fe, 0xeffcb378,
	0x715e8ab7, 0xc61fae1b, 0xf5ccd459, 0xa67619fa, 0x75fdbfab, 0x14baece4,
	0x4633a42b, 0x87af0d34, 0x161f3984, 0xa9ff7f41, 0x8f1c6cd8, 0x49d80fe3,
	0x27453cff, 0x22fdf74e, 0xcf4e1e5e, 0xbb39183f, 0x9868d4e8, 0x62bb236f,
	0xd3877f42, 0x1e8665f8, 0xc04d1b7c, 0x1fbe746f, 0xe735922b, 0xd9531ac9,
	0xdaadd00f, 0xdfafa099, 0x45e850ed, 0xcb42efd5, 0x1ed044b7, 0xf1c6c848,
	0x3b879e38, 0x08abf837, 0xb90b47c6, 0x7a0fe2df, 0x7f740df4, 0xe18f9755,
	0xe2dfad27, 0x09bbd63a, 0xe4a185bf, 0x7c5bf45b, 0xd8e1c456, 0x737e2619,
	0x4afb722a, 0x5e012fe7, 0x4f5f2599, 0xf25b1c4f, 0x50c4f435, 0x6f5e193e,
	0x2e3f9c8f, 0x31e388c3, 0x4c2b3efa, 0x1187f19c, 0x235487dc, 0xafa5a78e,
	0xeaee0546, 0x89281e7c, 0x6a735d98, 0x77e311a2, 0xef79e48c, 0x039e5ced,
	0x78e52dbd, 0xae37bfc2, 0x718ada4b, 0x7bba20a1, 0x744e8f58, 0xe4a5aee8,
	0xab85fce6, 0x8ff2f0f4, 0x7270bba5, 0x6fc29d64, 0x7562163f, 0x20ff73ef,
	0xbdcbfa72, 0x4ad7e839, 0xdfe79fd4, 0x9b1e6e45, 0xfafecb6f, 0x673d4cf2,
	0xd682aff9, 0x32aefeef, 0xf3912def, 0x308ca423, 0x70adca0e, 0x72923672,
	0x8e483e34, 0x83e186d6, 0x724f9c91, 0x3baa7c10, 0x6653a204, 0x561f1463,
	0x78895bef, 0x9838c59f, 0x37b833ff, 0x51a547f5, 0x070459a5, 0x5bdeaf35,
	0x4e3e0489, 0x3c44de30, 0xd0edc9c1, 0xa599efd0, 0x6ffcc452, 0x4d3bffc8,
	0xc967f7df, 0x5929e7e1, 0xc9e90cdd, 0x68656f6c, 0x563b9a6f, 0xf318f9d1,
	0xf47e55ec, 0x810eb25f, 0xb66121de, 0x92fe3413, 0xe411ef74, 0x74f9430f,
	0x7ee4c467, 0x4defe221, 0xbd4051fa, 0x7f8d9b71, 0x53fd7c7a, 0xcfc8a2a5,
	0xad4e0bdb, 0x7f7d42ff, 0xfd1db040, 0x6758fd02, 0x4acbdcf2, 0xd9da8393,
	0x37127bf8, 0x06f79f7b, 0x7e7b413e, 0xdf59ce5f, 0x13b2880a, 0xa5df0591,
	0x37a4654a, 0x0ebbca48, 0x183afdea, 0x6fbd18ef, 0x6f20ce73, 0x72af72a4,
	0x6c71c47e, 0xa77d2162, 0x5f50a3fb, 0x36ecf7e4, 0xf3b512c9, 0xdb147a8e,
	0xe326976d, 0xf7e82239, 0x6f9d1c58, 0x99373f71, 0x237937f7, 0x9967ae0b,
	0xb4c3f4ac, 0x0fbaf4f7, 0xa8b951c5, 0xf7b5bfd4, 0x7c2876ef, 0xf0e04cab,
	0xdaefbf57, 0x3fee97b1, 0xa6eb9f56, 0x3be5787b, 0xaf288dbb, 0x47b9cfcb,
	0xe067c70f, 0xc1286897, 0xa4a09fc4, 0xeb4ec182, 0x843f3016, 0x13df6d2f,
	0x5fd30f23, 0x1b6eb9f9, 0x76bbc3da, 0xa7f57458, 0xefd72940, 0xfd87eda5,
	0xcac65aa8, 0x8d0fe455, 0xc346b099, 0xbbed3b0f, 0x73d63d69, 0xf46fba7e,
	0x7a09de6c, 0xdf1ca0e7, 0x1c719043, 0xa7fdee9f, 0xbf76e7f5, 0xc5f11137,
	0x50391cc6, 0xbf1cf3af, 0xaf3fbfa7, 0x0f9e3b7a, 0xc23bdf52, 0xca1e8d77,
	0xa6f79e0b, 0x37e8a5c4, 0x198eedb3, 0x04bf8c3b, 0x3af587d7, 0x97840dd2,
	0xefe6f3fb, 0x78a18410, 0x3ee49b6f, 0x69ac9a56, 0x8ac87967, 0x9619aceb,
	0xfd3077ef, 0xa5a7f238, 0x65da5f5c, 0x46b25a72, 0x07457c20, 0xdb2dce50,
	0x8c271af7, 0xdbe78853, 0x7c1f0e8c, 0x44b92a3d, 0x14d1e384, 0x38026d81,
	0x1ddf4fae, 0x495f9c33, 0xc36783c5, 0x294767ac, 0xb63a63b7, 0xf74fdc77,
	0xe846078f, 0x7a1109f2, 0x0a72fba1, 0x77cbc89f, 0x1a2d2e5f, 0x630def0a,
	0xc58fc9ba, 0x057fe606, 0xbf9a7f5f, 0xe9bdd4c3, 0x37205adf, 0xe1eb676b,
	0xf1e6f968, 0xaca9577c, 0x3aea57e1, 0x8b9625db, 0x86bcd3f7, 0xa9f20768,
	0x117ed639, 0x46999dcf, 0x558fc804, 0xbef1c659, 0xc967e55d, 0xd3199f9c,
	0xd1b27e38, 0x68577f32, 0xe913206c, 0x6c7fed59, 0x6f794199, 0xbf1d2fad,
	0xb13989cf, 0x36307646, 0x41b62caa, 0x89cd7804, 0x0b26b13f, 0x716519f2,
	0x7bac220d, 0x2b89da4e, 0xaee83659, 0xc7e79e2c, 0x0632b89f, 0x366559f2,
	0x0d87c79e, 0x2b0b0146, 0xe6f0684b, 0x4d36ff61, 0x12f063ff, 0x4f37f25d,
	0x6e83668d, 0xb28261dc, 0x7099f87e, 0xbfef571c, 0x65c3fc52, 0xbcf1fab1,
	0x429a7323, 0x14501ee2, 0x8d900f74, 0xaef92388, 0x4bbbebde, 0xf8a41ff4,
	0xf04fc589, 0x90758dbd, 0x7ad0083d, 0xcdc17ae9, 0x538283db, 0xd7dad72b,
	0xf1147732, 0xbc36c5f7, 0xa73027e7, 0xbf8f3ae1, 0x757c70b8, 0x43f8ea3e,
	0x8b5b05e6, 0x5e7065fc, 0xea3f50af, 0x364e2ebc, 0x7a9e517b, 0x6b6e59ab,
	0x0a2e9c10, 0x9d05bf81, 0xf6f97d9b, 0xbee2365f, 0x640d8c5e, 0xe2ff900a,
	0x9f68a7ad, 0xfe07262f, 0xe5047056, 0xef1f7c4d, 0xf683bb29, 0xbce89671,
	0x5af10ca7, 0xbc6176b2, 0x6e3a2ba1, 0x7d6f9e22, 0x45edd936, 0xe77807be,
	0xbcb677c0, 0x07639219, 0x50a6b3cc, 0xa1b97e7b, 0xd397f38c, 0x30cdbe0a,
	0x0e3d6a6f, 0x23d9e978, 0xdf5075b0, 0x84b2ed73, 0xde9cde7a, 0xff9e12d3,
	0x5a73d96a, 0x3cc53192, 0x8af2d3f4, 0x3c9feba4, 0xf454665f, 0x59b71e6c,
	0x3a70e36d, 0x99ee3192, 0x969f3011, 0x1fbd02a5, 0xc25f7ab2, 0x6eafcc0c,
	0x763255c2, 0x331bc57f, 0x5c1a5d10, 0xb4c19f07, 0x191ff591, 0xd0b42801,
	0x9072646d, 0x7968b83e, 0xf483930c, 0x24d686c1, 0x1371be4d, 0x4844ceec,
	0xda69a6d7, 0x9b5d3c31, 0x0cadef82, 0x8c14c4fe, 0x2df9f057, 0x87d73fb4,
	0x6e85b8f1, 0xa83fb793, 0xebbd39bf, 0xb44ff444, 0x7a0e0ab4, 0x64cbc136,
	0xaf88b76c, 0xb0715210, 0x467dc03e, 0xdef4408f, 0xe1f46cd2, 0x7b8b217b,
	0x78b57db8, 0x0593e0b9, 0x373f0384, 0xa811e9eb, 0x42f3d3dc, 0x3cafc60d,
	0x33bbf86b, 0xb6e2a329, 0xf552bde1, 0x32a36d1e, 0x71ef4f57, 0xe8b3f613,
	0x07de8171, 0xdf675e62, 0x37f9a0d8, 0x4b3acfd6, 0xff85e9f8, 0xb3ae0f15,
	0xce947e5e, 0xfe8e372b, 0x81c9de94, 0xd7e99df5, 0x6f9b53c0, 0x1be6d568,
	0xdbf36ad7, 0x497794cb, 0x48f1b3c6, 0x04cabb4f, 0xaafdcf11, 0xa71973f9,
	0x9fe7867e, 0xd7ae8817, 0x9b2360ca, 0xd444ff25, 0x6e8816c3, 0xf0e5abca,
	0x55eb85bd, 0x44fd27e2, 0x67d102c7, 0xc369c9bb, 0x2bbccbf7, 0x45dbc205,
	0x9f8eae58, 0xf29f5835, 0x8ff9a1c6, 0xdd1db8cb, 0x435ae51e, 0x8203a7fe,
	0xa90bdf0d, 0x62629d11, 0xbd45d11e, 0x57eabf1e, 0x7867e1e8, 0x35e61d1b,
	0xf614910e, 0xf13ddc69, 0xdc7a8e74, 0xd17934bf, 0x005719be, 0xdd232078,
	0x7cdad81b, 0x23e2454c, 0x8c3f0377, 0xb19c7482, 0xfbf89ebb, 0xdfc6c924,
	0x60b3b38d, 0xa5dce17e, 0x577d273d, 0xa7d231fa, 0x1cf2deef, 0x9b1f039d,
	0x017fcced, 0x1f1468e5, 0x827dd9ff, 0xd3f41d6f, 0xc7e3c792, 0x702d0123,
	0xc2bb16dc, 0x8f807b47, 0xfd87ebaa, 0x0d7c891d, 0xcecc040f, 0x2d5371a3,
	0x893bb62a, 0x6afe0a0f, 0x46cffa03, 0x5b3ee32a, 0xa7fd1325, 0xe02dda3c,
	0x779833ba, 0xfde3009d, 0x45b1031c, 0xb637e983, 0x76b46ad3, 0xddd118da,
	0xa56b7c80, 0xf1e25fbd, 0xf28480dd, 0xffec5be1, 0x61febd61, 0xa0aef4f9,
	0x18668fca, 0xfea1c5af, 0xf640fab4, 0xde8c3648, 0x3418b464, 0x8b64c47c,
	0xbb9bf0d6, 0x67fcb572, 0x77cb438e, 0xad9257be, 0x1ceb9f29, 0x67bf29af,
	0xbf268156, 0xa9ae55c0, 0x74fd5f7f, 0xaf6cde4d, 0x928fd4d3, 0x31f269e7,
	0xea6bf7b9, 0x68963ac7, 0x793fcdca, 0xfbc05eb3, 0xbf6f1610, 0x05d0e01b,
	0x389251b4, 0xc7c64728, 0xa3486541, 0x98aca20b, 0xfb364d76, 0x46ba4f11,
	0xc7897c81, 0xfddb8ff6, 0xfe258fd0, 0xf2680b35, 0x5f049fec, 0x01f41275,
	0xdea37260, 0xda53c777, 0xa6bbc0f3, 0x92ac7a29, 0x4f77284e, 0x6f3480ab,
	0xdfc69ca7, 0x03bbe9a1, 0xcd12c7f7, 0xd7b45eb8, 0x24d17a42, 0xf4829bd4,
	0xaaabe7c3, 0xddb1cbf2, 0x913bce53, 0xb30f582e, 0x1b6abfa1, 0xe728901a,
	0x1a77f2f6, 0x0dfa7af3, 0x7efa20ce, 0x21eb9ca7, 0xefaabb2f, 0x7a5bfec4,
	0x3d22ca41, 0x4244f96d, 0xf7a5af7d, 0xb3ca1c60, 0x244fae89, 0xbf063bb4,
	0x0c4e722b, 0x8239e344, 0xea36ee7f, 0xaab0ffbe, 0x51ffdf9c, 0x786835df,
	0x5de378dc, 0x41e2aa83, 0x46f0dcfe, 0xf1846fc0, 0x79af801b, 0x8f5937f9,
	0xfe7f034f, 0xbedf9824, 0x60f20a9c, 0x91a7f512, 0xf897f707, 0x967f244d,
	0xce37eb6b, 0x1877a5af, 0xbf6b8f81, 0x002aef2b, 0x1ea133a7, 0x5b5d7c0d,
	0xaf837e5e, 0x3e075de7, 0xff4b81f0, 0xa7378bbd, 0x0fdeb489, 0x1f69d3dc,
	0xe278065e, 0x8797fc7d, 0xf5c38fc0, 0x3af6e0ab, 0xfed040e2, 0x383bd685,
	0xebdfef8d, 0x31f6f861, 0x09b77f65, 0x54c8f97d, 0xc268ae3d, 0xa69645df,
	0x700a6715, 0x44ef3e5f, 0x4de1b23b, 0xfdbca181, 0xa49fc1d5, 0x6fbb3bd0,
	0xf7c1491c, 0x47dd3c67, 0x8e1df052, 0x0ebc9366, 0x0fc079f5, 0x2d3fea07,
	0xff9a7e3d, 0x7a02eeca, 0x8f656287, 0xec9640e0, 0x96a973d9, 0x3bfac9d6,
	0x16daeed1, 0x97cf5e66, 0x52df7c73, 0x3cfcd32e, 0x00437a6e, 0x3e7d9bda,
	0xf801f101, 0x1f6bce13, 0xdf9057d8, 0x7edf41b6, 0xef02a9fe, 0x86241bc3,
	0x433508ef, 0xd1c75c7b, 0x0592a38c, 0x580de9f1, 0x38eb8097, 0xfb0620be,
	0xa862635f, 0x3bf3a867, 0x11f7d19f, 0xa5c3ffae, 0x92a97c26, 0x12352fb5,
	0xc35c3fbc, 0x43e313f5, 0x0699deff, 0x978085f9, 0xd0eb0f78, 0xd347cbd2,
	0x970fdfa0, 0xfa6d3d73, 0xcba22643, 0xbeb8ab85, 0x2ad78a12, 0x82b5fede,
	0x1bf8a1a7, 0xf043b78a, 0xc337f975, 0x95cb37d7, 0xb3c63977, 0x61f72889,
	0x448c67ff, 0xd1927a3c, 0xd7f559bb, 0xc246990e, 0xda74c7bc, 0xb201601c,
	0x33df4609, 0x0e37c829, 0xcdc9f2f1, 0x7fce055b, 0x7d71fbe4, 0xc3125d69,
	0x72b1d6b8, 0x531f0fae, 0x01664df6, 0x3137ef01, 0xf20c6fb1, 0xce252ca9,
	0xeac4dbb1, 0x53fb40df, 0xc267fce4, 0x375bed8f, 0x13efe106, 0x7caa5e0a,
	0xdcc4bc71, 0x2b5da06f, 0x0b9a8f76, 0xdcaebcfd, 0xfa54c93f, 0xd40ec9cb,
	0xacf485ce, 0x0509fe32, 0xbffcd47f, 0xdcc0742b, 0x739e0917, 0x75fe1c2c,
	0x718bfd6b, 0xeecdb31d, 0x7ca1ca0f, 0x66a9e676, 0x635d7b94, 0x71e3cdde,
	0xe1e90733, 0x87fe051e, 0xcaf77f4a, 0xa8deb063, 0x7f69a3db, 0x60bc0ea3,
	0xca8e7c43, 0x9c391c29, 0x9ab9ef7d, 0x8049dcc5, 0x29b35757, 0xdf73f355,
	0x93f52b39, 0x96a9705d, 0x2a6ae5e8, 0x7ddb577d, 0x827bcca8, 0x7ac0e1c4,
	0x06dc9047, 0x04962dbe, 0x385539c5, 0x547af6a8, 0xafda76ce, 0xc9b156c7,
	0x17b1e6a4, 0xc736f394, 0xe7e82685, 0x64d3933e, 0x8a9f7805, 0x26715faf,
	0xdb77b187, 0xd8cb71d0, 0xe6166dfb, 0xb8f40dbe, 0xfbe51b36, 0x3f94ecda,
	0xda5326d1, 0x86bae518, 0xb8705a70, 0x76e10735, 0xabb36328, 0xf8b9c61a,
	0x41e089be, 0xfdf8063b, 0x976b8298, 0x02cc8d7b, 0x08f797e5, 0x9d4cde74,
	0xd35703ff, 0xcbf81b98, 0xd078e1bf, 0x5fdae570, 0x2c73df10, 0x768b54bf,
	0xd3e6e4d2, 0xacf7989d, 0xea2d43fd, 0x3c811f17, 0xbd033c41, 0xe405d99f,
	0x1925c727, 0xd5f160f0, 0x75e7ea24, 0xe916a043, 0xc0b6fbce, 0xea3f3f10,
	0xe48d24b9, 0x05ae8af2, 0x7746d2be, 0x8ad4d8ec, 0x7a4fce04, 0xfef81b27,
	0xef821a16, 0xe3bc1e3b, 0x7ee1c6ff, 0x3fcad658, 0xcb59df47, 0xba432331,
	0x881d58de, 0xf70f3bd3, 0x878bf401, 0x981d70eb, 0x4bd79686, 0xb4071cde,
	0x38f057ab, 0xe2b4bcb4, 0xc4c2bf86, 0x63a0c8fd, 0x03f3f0a6, 0x25806bf8,
	0x1d9227c5, 0x7a068fe4, 0x7e9de86e, 0x55b4c456, 0xed689f60, 0x9049f633,
	0x0f0e1f1e, 0x5f45366f, 0x833927cf, 0x8323b479, 0x1da24fef, 0xb0def7a9,
	0xc8ec6339, 0x9e68fce1, 0x60efd07e, 0x71405abf, 0xdf109392, 0x617a53c7,
	0xce997adf, 0x360745ed, 0xe360bca3, 0xac77640c, 0xa1f56af4, 0x7db8d309,
	0x87d14132, 0xfd8056e6, 0xd86ecb94, 0xcd27604f, 0xec08fd47, 0x9877b8a4,
	0xfd0a7ec6, 0x0593f64e, 0x1dc60ae9, 0x5bb3fb0f, 0x55a67f6f, 0x4648ac2f,
	0x7844dafa, 0x11cf00ce, 0xb9d742bf, 0x4bcf82b4, 0x4885eba5, 0x3dbf88d7,
	0xfb43ae9c, 0xb55699ad, 0x21b3e714, 0x32c1bdcc, 0xb72b9d65, 0xcf2f0408,
	0xd3822496, 0x55c5b679, 0x1e79780d, 0xf00db1e6, 0x15cba2f2, 0x2fed0093,
	0xf8315dba, 0x3e542c77, 0x8625b2d0, 0x3b186dda, 0xf209a92f, 0x7f782a4f,
	0x05ba67a1, 0x16c0fce1, 0x78ea7f4e, 0x2617f91f, 0x99153d21, 0x7f9e1202,
	0x1d3def4c, 0xd1607a87, 0x90927bbe, 0x73cdc30e, 0x9fce54e5, 0x6c7dae56,
	0x8e2499c5, 0x638f780f, 0x3cdf2285, 0x8425fb4f, 0x8cb58aff, 0xdee0f7f0,
	0x1d20b55f, 0xb18de85f, 0x7f3c3ca1, 0xfc8bc620, 0x66dbe2ff, 0x3b20419f,
	0x7c0f1bc4, 0xffa9bced, 0xf737d26e, 0x3f686d19, 0xfdfede7a, 0xcf47a466,
	0x7e6a335e, 0xfaef456c, 0x9af7284b, 0x2b3cef7b, 0x645afa62, 0xdae561e9,
	0x6abd6827, 0x166df7fe, 0x05e8f919, 0x1589f391, 0xfd223f3d, 0xcbb5c577,
	0x7acfd113, 0x147fc0fe, 0xfcf35f23, 0xe462e5cb, 0x97fd9e67, 0xf3dcb18b,
	0x3d5698e3, 0x34d2e5bd, 0xe55207ee, 0x5149d665, 0xa45a2fe3, 0x8eac85c8,
	0x00c6b34d, 0xcf8e8afc, 0x6abbf3a7, 0xc18e5179, 0x7e8bf585, 0x50f49359,
	0x3e8ebb50, 0x85a4e291, 0x96626bc7, 0x6ba5e106, 0x37f5499a, 0x0f3f237e,
	0xeabbe296, 0x7d3afc37, 0xd4146706, 0xdca7d0db, 0xefce5e9f, 0x12fe834f,
	0xa9f48eda, 0xf1248f8b, 0xeba2d2fb, 0x988509ae, 0xeafba1cf, 0x32396bcc,
	0x5a5f4836, 0xe3f067d8, 0xefa82ddf, 0xdf49fb35, 0x534f13ef, 0x1ea3d15e,
	0xd8bbf4b8, 0x4fc7412c, 0x06627b93, 0x7f50f1f2, 0x7162fc0d, 0x757eaade,
	0x8ffb952a, 0x866d5bd2, 0xc5af3039, 0xc93efc1d, 0xfd4ebf10, 0x8517f24c,
	0xbee477fa, 0x4ed82c97, 0xe1b06b1e, 0x14bd557c, 0x0e8f71f7, 0x2a68781f,
	0xbe9573a7, 0x1c78fa3a, 0xdaafa3bb, 0x07957182, 0x63dafa14, 0xc02f3033,
	0x9ef7a3a5, 0xe85fe81d, 0xcc5f76b8, 0xe3a71804, 0x34f63ce4, 0xb55b01f2,
	0x5ddb0725, 0x9059699b, 0xa1378837, 0xca984de3, 0xbea0e6f9, 0x32ff2fa0,
	0x4a457995, 0xfa9a8e0e, 0x608390dd, 0xe54d679f, 0xee22f9f6, 0x79f6e13f,
	0xf950fca8, 0x3cefdab2, 0xf2879f65, 0xe7a4b3e5, 0x7c4d1d80, 0x9954de79,
	0xcef7a5ea, 0xfafb224d, 0xd924fce4, 0x6cffb43a, 0xcc4861d1, 0xaabfda1b,
	0xcebc79cf, 0x7bb41623, 0x4fa2469c, 0x87c17ccf, 0xff553971, 0xd204b8f3,
	0x4d8b3dcb, 0xcea7ac3e, 0xf73e6fab, 0x9a702ec7, 0xa807efe8, 0x47aaa27a,
	0x087728de, 0x95eaae54, 0xe7d8feaa, 0xf9ddfee2, 0x31bcbc85, 0xc2277dca,
	0xbbfc23eb, 0x4ac7c804, 0x41efe505, 0x5da08eb9, 0x02bddf75, 0x5858efe3,
	0xaa1a7834, 0x9bd67e77, 0x1f9c3f1d, 0x3f0515ea, 0x0ccb3a55, 0x8e550fa1,
	0xf1c8a93d, 0x05e39416, 0xd0bfc728, 0xfda1e7e8, 0x986f1c82, 0xb518ed4a,
	0xe8a5fc2f, 0x2fd7b3d2, 0x54aefd2a, 0x70efaff7, 0x8337ce15, 0x3b43adf5,
	0x757c9c33, 0xb84e7a2b, 0x6e2b27f2, 0x28b79e8e, 0x3d148beb, 0xa11df4bf,
	0xa1fa1be7, 0x9f7f4614, 0xb837f556, 0xd6c6d1ff, 0xbfa42abe, 0x77e44cf7,
	0xacd7ad0f, 0x644c73e8, 0x9239fd9a, 0x3ed01921, 0xfee72cf2, 0xf904ae83,
	0xfcc764e7, 0x9fb0c8c4, 0xa20f6015, 0xd5e8f71e, 0x519b4a04, 0xd174865f,
	0x8f14e3ce, 0x3b5cb458, 0xe9f42eff, 0x5955fb62, 0x0377cef4, 0x533f21ab,
	0xad826f43, 0x5742841d, 0xa451f772, 0xa30eef2b, 0xfeb823bc, 0x0b7d6a23,
	0x4dadc3f7, 0x35ec51f5, 0x68681f44, 0xb5fbd50d, 0xe2b941fa, 0x27a70a37,
	0xc5183fec, 0x2331caf9, 0xfa0b79d1, 0x2631269b, 0xe0be72f5, 0x24fdcb59,
	0xe2ebbd2d, 0x4acde018, 0xec407ca5, 0xc5143f23, 0xd9eaa0d7, 0xe85217de,
	0x1b53b03e, 0xfdb95a4f, 0x432fc497, 0x7b894ae3, 0x34f25f38, 0x5238951b,
	0x95f980b1, 0x448e4f60, 0xbf9652fd, 0x79877087, 0x1bf11f31, 0xb2efc6a7,
	0x7d2b894d, 0x64b7ec76, 0x17da2e87, 0x55d48e26, 0x4e48e3c7, 0x238fd4e6,
	0x26923d1d, 0xa91c757f, 0xdd38e7a5, 0x78aafc47, 0x5aa985d2, 0x9168e3bf,
	0xf74777fb, 0x57f4360a, 0xebe5ee8d, 0x9a21b29e, 0xdfdaebf4, 0x7e424d2c,
	0x85d3eea0, 0x17be1cb9, 0x8552bc3e, 0x237f8aed, 0x5d60a2da, 0xf35c3ffb,
	0x979e348b, 0x5bb6322d, 0xccf68313, 0x8eacdf85, 0x87eef841, 0xc7e7f714,
	0x1dffe81f, 0xfe8355b0, 0xf234e36a, 0x6afe2b3b, 0xec61e411, 0xb4275fa0,
	0x5da526dd, 0xe42b9817, 0xe3c7dcd7, 0xeea95dfe, 0xd5ffca3a, 0xf483b618,
	0xa3f92744, 0x8d78047f, 0xb0f1a37e, 0xff4b8c58, 0x60759a30, 0xd92ba91c,
	0xd1d12efd, 0xa464195f, 0xf14f6823, 0x321bef27, 0x7d7447c9, 0xa2679c61,
	0xf7c17304, 0x8cf16870, 0x63eca1dd, 0x18b3d82a, 0xccd98267, 0x78f438c7,
	0x3133de25, 0xffd8899a, 0x46f726b3, 0xd9e9a77c, 0x57bd2283, 0x124744cc,
	0x8d0b7bde, 0x1e4e093b, 0x4fe3572f, 0x5c3cdc6a, 0x71c049fc, 0xe3fc7226,
	0x029db5e7, 0x38d5d3c6, 0x45d7bb13, 0x92f6afc1, 0xb5573a56, 0xdf08831e,
	0x76697c6e, 0x67fc4e85, 0xe2530561, 0xe378dad2, 0x84dddcc6, 0xce375fa7,
	0xb7ea65b8, 0xcb996f3d, 0x177990d7, 0x42967c26, 0xff97d776, 0x6ce48e27,
	0x879265ef, 0xd6660317, 0x7ec7fe47, 0x35ef77ee, 0x22e19f91, 0x41c96fd8,
	0x056f7672, 0xde9df7ef, 0x7bff84e9, 0xb0626afa, 0x7df2bf7e, 0xf7f9c9c3,
	0xedefbea0, 0x4db9f913, 0x3db1edc6, 0xea11627d, 0xbee2df2d, 0x6755323c,
	0x2e68967d, 0x28e9429f, 0x4ca3a153, 0x805803fc, 0xe43fd337, 0x0d679876,
	0x14d8af8f, 0xe569e0be, 0x19a3f571, 0x4fea8229, 0x7f17a91f, 0xb92017d9,
	0x7f08f0d1, 0xe366fa4f, 0xeaa62f2f, 0xf517e3c7, 0xbf8fd69c, 0xfe25aacc,
	0x1d9fce19, 0xc1fec7ea, 0x4dff8534, 0x366c7ee0, 0x4eeb46cd, 0x355c9d6c,
	0xffae0d92, 0xa987dc5b, 0xfe36b795, 0xb5bce8da, 0xfe81dffd, 0xffd85bdb,
	0x76b7e583, 0x716eabfe, 0x62dc2fff, 0xc5bd9cf8, 0xc5b89ffd, 0x27a9d9f0,
	0x9eabfe1f, 0xff8d080f, 0x08179e87, 0xfe60073d, 0x2c5e43c9, 0x173c2f5b,
	0x896a43f0, 0x002f5bdb, 0xb613141f, 0xd9dcf9d3, 0xb61e3ca5, 0xdbe2c6a1,
	0x1b9e0c2a, 0xb735e150, 0xb611db8a, 0x3c5e4bbc, 0xece99bd7, 0x7f4249ab,
	0x3b232959, 0x8f1462f8, 0x96d1318b, 0x41ce973a, 0x81e752db, 0xa515d25e,
	0x0ffd671f, 0x861762a7, 0x57cf2391, 0xbf229555, 0x77b985b3, 0x87e282f3,
	0xfbf0f5b4, 0x53944cdb, 0x72b8d1e7, 0xf143ea2a, 0x38f7f987, 0xa56e733f,
	0xf359c979, 0xb3941ec8, 0x2a2f7e70, 0xbac4dff1, 0x97e85971, 0x10bd044e,
	0x602f82e3, 0x59ec907c, 0xc753d51b, 0xaf92af7b, 0x131345ff, 0xbdeb9e30,
	0x62739f9d, 0x71352fae, 0xfe4df7bd, 0xc5024d33, 0xc257e6f5, 0xf06a7efc,
	0x52cb6de7, 0x9be01890, 0xf146c7b7, 0xfe959fc6, 0x2f3f2e43, 0x8f7ce3cb,
	0x439578d9, 0x3cc33768, 0x40503b1e, 0x9de8bbf8, 0x18b5ffd2, 0x22b18fed,
	0x5d8879c1, 0x3e0bf8a9, 0xaa1dfc50, 0x6f8d40bf, 0x93f15afd, 0x17fe847c,
	0x1fd1fb48, 0xcaaae902, 0xa27ef23f, 0xd4ac7f0e, 0x0a2f2fe1, 0xfde43fdc,
	0x150ff729, 0xe0ec8e48, 0x597f94f3, 0xc9b1f7c9, 0xaa17e3cf, 0x951fe7bf,
	0x693c14f5, 0xa2fbe3f4, 0x24139d05, 0x9d05f394, 0x4e98d119, 0x290cfa74,
	0x4b85ef00, 0xfba830df, 0x5d4787a7, 0x1c373aca, 0xef7c500b, 0xff712147,
	0x79f92af7, 0x3e2a9a86, 0x1be0f78f, 0x88e58fa6, 0xe3d628ed, 0xbd466c2b,
	0xd80352b8, 0xa6cf38c5, 0x156f3e2e, 0x797e0dde, 0xfa738e3a, 0xd313a048,
	0xd359e5fc, 0x7cdeefc9, 0x37f513a9, 0x47cbb5cf, 0x265fc92b, 0x3c4f68c9,
	0xbbf5afd0, 0xfdc5583d, 0x05423fef, 0xa776e11c, 0xc171f648, 0x4fe1229d,
	0xd9144362, 0x662689af, 0x2e7e62b4, 0x67f28bd7, 0x798e988d, 0xf4813f36,
	0x7263fcc1, 0x579b9e02, 0x778960fd, 0x384649ae, 0x559c557d, 0x4635a7f5,
	0x7ee17739, 0xeb38dd7e, 0xd24ff7ca, 0x5d755379, 0x78d45c2a, 0xab38b869,
	0x33c1ee7a, 0x9ce68aeb, 0xd40c4786, 0xe0b1ffa2, 0x394969c0, 0x67b3697f,
	0x0b61c60d, 0xf8a25df6, 0xf56f1aab, 0xbd225eb4, 0xd849da1a, 0x8f1b4f7e,
	0x7985eebf, 0xeb03da60, 0x3df19a76, 0xbda53b11, 0xfefc6eb0, 0xa52e5b76,
	0xa50736fe, 0x5095b4ef, 0x226e7f8a, 0xb6e31135, 0xdb6e2897, 0xfb8da957,
	0x05bd71a9, 0xc817eba2, 0x7ee282af, 0xfb8d0f94, 0xbfb9a319, 0x44cc73c6,
	0xde7aecef, 0xaeff10b7, 0x8d1a6dea, 0xc7e7c1f6, 0xde71a3dd, 0x0b77182d,
	0x4e0b8bc2, 0xda025447, 0x14472ec1, 0x0e0adbc6, 0x3cf0959e, 0x27d88b4c,
	0x660c3fa1, 0x1647869e, 0xf12e7b3d, 0x55bdbf73, 0xafdf0851, 0x7cf58f8c,
	0xff63e337, 0xc340d61f, 0x00800092, 0x00000000, 0x00088b1f, 0x00000000,
	0x17adff00, 0x67534c5d, 0xdb977cf4, 0x179fcb72, 0x71914414, 0x505112c1,
	0x1a744c2b, 0xac745ee5, 0x9514b653, 0x351804a5, 0xd09b1973, 0x96166732,
	0xe34eb43d, 0x0c60f740, 0x493f660f, 0x64b8d45d, 0x5992750f, 0x8b2aeab7,
	0xf11a2586, 0xb0f88e61, 0x06646180, 0x37187137, 0xce761737, 0x2f6d6f77,
	0x920f64d6, 0x9f9ee734, 0xfcef9cef, 0xe34f4c7f, 0x84c00d5f, 0x4ac6525f,
	0x27177e01, 0x800ae4b3, 0x56d3e19d, 0xa9c3e095, 0xbf842e65, 0x5aa7fb9d,
	0x7df000c9, 0x880d5537, 0xaa9dbefb, 0x4cefbe26, 0xe910577a, 0x189e86d3,
	0x002969f4, 0x334e012b, 0x5f908770, 0xa3d412e9, 0xdb550704, 0xb97115eb,
	0xa4e0975e, 0x92f6bdf3, 0xb9f7a26c, 0x2477b24a, 0x14e7dbe8, 0xe7a4419d,
	0x25b768bc, 0x0b3407d2, 0x19d22e40, 0xec4942b8, 0xb702a997, 0x9be4f3bf,
	0xf01263bd, 0x75fc69bf, 0xe136de86, 0xbd7bf0be, 0x7c716563, 0xc3cc7d27,
	0x422646df, 0xce874035, 0x53d11282, 0xcebea2a6, 0x942b11fc, 0xead26510,
	0xbaf18a5a, 0xe5b0f522, 0xbece1700, 0xc1523451, 0x03c82545, 0xf5ce3268,
	0x6514773a, 0x0c0801ce, 0xd32942a7, 0xddf22269, 0x5470a1f4, 0x334ed111,
	0x9b95e17d, 0x4a1a3ff2, 0x63d08659, 0xdc248c09, 0xa829d9ab, 0xf76e2cb6,
	0x924c8699, 0x62fce317, 0xccf93a52, 0xa984a596, 0xc13e4205, 0x26ac0140,
	0x57b45d20, 0x80ddedc7, 0x94768fe0, 0xd10a726f, 0x8ee3b454, 0xf50146a4,
	0xf0453a56, 0xdbb08b3f, 0xc4662c12, 0x5f394717, 0xf89eab79, 0x02cae4fb,
	0xbe7e3f40, 0x1767956c, 0x8d8dfbf3, 0xe1d1c424, 0x8253d63c, 0xcc1d1de7,
	0xb7356e41, 0x97f8f99b, 0x19b67e49, 0x9f9bc971, 0x02cc39f5, 0x785f0d68,
	0xac0f00be, 0x1b3d4380, 0xbb0afcf1, 0x6f114720, 0x6f9f32ed, 0x316f3b73,
	0x183a27ba, 0x75b738c2, 0x6754f99b, 0x0bde90a7, 0x87ac4ce0, 0xda0ea336,
	0x67e1c654, 0x98c381eb, 0x99b9d89e, 0xc86fd3f5, 0x8317d4cf, 0x4b9f88c7,
	0x6bd959f5, 0x0bd6fca7, 0x7883ed80, 0xd04f64ad, 0xb9154bb7, 0x00b2c39e,
	0x17db9401, 0x619c7ad9, 0x7c3df6fc, 0xb9446a41, 0x54ad723b, 0x7dc7119a,
	0x309eb197, 0x1e17552e, 0xfbbc51d4, 0x686c0c22, 0xf78f97ca, 0xf3aab945,
	0x965b20da, 0xbfdd4f78, 0x50f9cc3e, 0x2381d506, 0x40bf741b, 0xce0678c2,
	0xb471e0b1, 0x6f7f5957, 0x70711d20, 0x154a3b65, 0x9bdf63b2, 0x5eafb881,
	0x7708c95c, 0xb7c201e1, 0x9f84a0b1, 0x6fb6af5b, 0xd553b402, 0xe51ae2b8,
	0xe2c5b1a5, 0xebf1e1b0, 0x693bdcb3, 0xeabd6c4e, 0x47f9d3ae, 0x7e23483f,
	0x14d87319, 0x896b3ba2, 0xa8cbf9be, 0x12fcf548, 0xde216945, 0x4898f2ed,
	0xf366d37d, 0xaa3ea61c, 0xe823406a, 0x5b16b6df, 0x8c6bfc90, 0x83205834,
	0x7d408fb7, 0xdb918ef7, 0x67ef0bef, 0x2a7d208d, 0xfc8b3552, 0xb4996d9a,
	0xa156103a, 0x083979ee, 0x02b5ddcf, 0x9c4f83f6, 0xd728cab4, 0x2ec4c7ef,
	0x2fdaf802, 0xcbf61871, 0x7c02a6a0, 0x30e7cfe3, 0xfd3857e2, 0xc38cbfbc,
	0xe1c1dfa8, 0x87357f80, 0xe3ccaafd, 0x57723cb9, 0x34e4fba0, 0xf364ae08,
	0x1f51976d, 0x91697cb1, 0xcf7445ed, 0x453cd7fb, 0x18f91272, 0xc2058b44,
	0x193fbd6a, 0xbce7cce6, 0xbc764757, 0xce9fb230, 0x586f9829, 0x11872005,
	0xfd727dce, 0xbc08d68d, 0xf005b2fe, 0x62ffe324, 0x952627d4, 0xa49773c7,
	0x2585fff7, 0x4a78f37f, 0x5aeae561, 0x30779bcc, 0x7e915205, 0xfb9f56a0,
	0x630cf533, 0x76e3013c, 0x7049e303, 0x0d6ddf26, 0xdc3e5294, 0xe7248f74,
	0xc4fa8d47, 0x32b8b00a, 0x9c329cf5, 0x1cc62d7f, 0xcc40c568, 0x84b63cc2,
	0xfb0d3459, 0xe1b235bb, 0x8bb04896, 0xfcf34dc1, 0x79b19b80, 0xf8e4f297,
	0x25e85ffe, 0xbc71a57d, 0x134a83c9, 0x3a7b6de7, 0xb847f24d, 0x59c7a694,
	0xc7b0eab2, 0xf5b5efa6, 0x31075e9a, 0x71e9a358, 0x82cd483f, 0x2cf07df5,
	0xfec1ee0b, 0x1a5c56f3, 0x5735f9a6, 0xe1c6e805, 0x88cfcde3, 0x0f3cd0a6,
	0x9a3f6e5b, 0x731fd8e3, 0x725a1915, 0x30638c68, 0x8cf36f31, 0xc601203b,
	0x73458e51, 0x9472e984, 0x80f8305b, 0x14d41df4, 0xd5ef2f6e, 0xa1740310,
	0x687b0210, 0x82b45cbe, 0x77ed0a76, 0x43d833f4, 0x006c1dfd, 0x1fe90aa5,
	0x05ffd8df, 0x4cfdbdd2, 0x19d475a6, 0x7cf7c6ba, 0xfbc438a7, 0xb0991bc7,
	0x8d0c7af2, 0x5330f4ea, 0xfaf24983, 0x37dfb1be, 0x46e7c0aa, 0x6094eee7,
	0xebadda2a, 0xd7dafbd7, 0x7e0a82c5, 0x577c2a5e, 0x2cf5bc24, 0xc734b983,
	0x74dca194, 0x40b6efe2, 0x55fb98b0, 0x27ec25af, 0x77e429fc, 0xf6c67f6c,
	0x2f26178f, 0xb6bd5015, 0x07ed0733, 0xcd373fdc, 0x922f05fb, 0x872fdf17,
	0xc17ee1e6, 0x1e1cdcbd, 0xc21cd0b5, 0x6f92647d, 0xd16eeb53, 0x633dc51c,
	0x7fd82fa6, 0xfb82f297, 0xa45f44c5, 0xc719ce65, 0x543943b8, 0x5b3ce34c,
	0xb8f32359, 0x798c3dbb, 0xb96a682a, 0x384fc83a, 0xb79a64cf, 0x4eb5e333,
	0x7360fbd3, 0xe6374180, 0xaf5584f7, 0x586b138f, 0x9bf28030, 0x9fbca511,
	0xc03dbf38, 0x9513cfd0, 0x3c5021cc, 0xb1e30848, 0x62cf88c9, 0xc4b8c008,
	0xd37d0a9f, 0x7197cf98, 0x9eb0d8bd, 0x00f51b36, 0x1a76e410, 0xe945a48e,
	0x12d0711d, 0x77f077ca, 0x77df8049, 0x3085f282, 0x92ba152d, 0x4d62ebf5,
	0x3cf9a09b, 0x4fdff4f1, 0xf1f72d2e, 0x3487d3f7, 0x2bced113, 0x2fc9131a,
	0xf5396f8c, 0xebc2edf7, 0x36880359, 0x3a26ae8a, 0x2e8d61d7, 0x146efaa3,
	0xf18f1c3d, 0xfda5ee91, 0x26ef8b82, 0x8c0091f5, 0x650387cf, 0x2f28595f,
	0xdd8f44cd, 0xc72e38b7, 0xf1c794f1, 0xb69e1571, 0x926a47df, 0xa29f1bbc,
	0xef648cfe, 0x5fa8a7d2, 0xdfe892d2, 0x492ff34b, 0xe6315cfd, 0x7902c020,
	0xce313d3c, 0xcfec1a98, 0x3af0325d, 0xf5ec68be, 0x44fca61e, 0x83f0287b,
	0xf12b8e05, 0xa993dab9, 0x98d4ffeb, 0xc67831a7, 0x5d163d80, 0x01fda66e,
	0x5453bec3, 0x293aa13f, 0x9280293f, 0x50d2f7e0, 0x7e09281a, 0x98e70f2f,
	0xf9d115f0, 0xc1aaf926, 0xe57f1312, 0x7f1312d0, 0x09a570d5, 0x8d646e7f,
	0xafed7e49, 0xdd7c26b5, 0x7c9326e4, 0x4c5b5fcd, 0x357fac78, 0x73c4dcac,
	0x4cd7a41b, 0x66ed0572, 0xccbb0abf, 0x9b75157e, 0x2de98afd, 0x5bfd980e,
	0x2ff663d8, 0x3c8ffb27, 0xffa1de85, 0xfb4599fe, 0xc53237a0, 0x326774f3,
	0x8e688615, 0x7efa2388, 0x5ef85888, 0x2fff83b8, 0x21e426e6, 0x9db8555f,
	0x1b42c881, 0xb4ec3b9d, 0x56dde8db, 0xf28a7382, 0xdbb01ff6, 0x0e70044a,
	0x00000e70
};

static const u32 csem_int_table_data_e1h[] = {
	0x00088b1f, 0x00000000, 0xe4b3ff00, 0x51f86066, 0xb97bc10f, 0x726e1818,
	0x0143f821, 0xd08667cf, 0x0c0c2c6a, 0xc6cc401a, 0xcec0c0c4, 0x717ebc44,
	0x1d7b044e, 0x4cc30307, 0x31c8de20, 0x481afef0, 0x7e87957c, 0x42f2a976,
	0x81c16968, 0x970837f7, 0xd430310b, 0x04303309, 0x4ff84088, 0x2be55045,
	0x366c1084, 0x12ecca49, 0x0007ea02, 0x0fb3beda, 0x00000380
};

static const u32 csem_pram_data_e1h[] = {
	0x00088b1f, 0x00000000, 0x7de5ff00, 0xd554780b, 0x733ef0b5, 0x7993331e,
	0x0f20f264, 0x0084f102, 0x010e02a2, 0x93c443c2, 0x80d06210, 0x2a5e4041,
	0x24863bc3, 0xa7f68113, 0x84cef7ad, 0x36b5a220, 0x97836c5a, 0x8d04077a,
	0x68d03a8a, 0x00e84e03, 0x6bdab11a, 0xeada5454, 0x8088a0ed, 0xc5978490,
	0xd7bfca96, 0x7324e7da, 0x6a24264e, 0xffffdffb, 0x6df9f8fe, 0xece7d9f6,
	0xed7af6bd, 0x7b5ed6b5, 0x21f5208f, 0x72113789, 0x1968fe19, 0x7d2109e1,
	0xfcb6cb3a, 0x992463f6, 0xa22bff10, 0x84239dbc, 0x7c239dfb, 0xde4228d3,
	0xcc05c2de, 0x6bde1eb4, 0x4fd68423, 0x301e9e6f, 0x6fb21167, 0xf7815984,
	0xc3cb6f4f, 0x3f97a4fa, 0xbdb40a70, 0x805e65e2, 0x09ef69ba, 0x884ec467,
	0xc8f2dcd7, 0xfb79f40d, 0x4ad93ccb, 0x49fe2287, 0xc8429226, 0x7f610b31,
	0x997d5917, 0xb62b5595, 0xfa1bbbec, 0x13346d2d, 0x62a7ed2b, 0x3769f2f7,
	0x83f2fad0, 0x2a578122, 0x7d4b57b6, 0x009efd69, 0xdafa8417, 0x71c67fbd,
	0x6949f2da, 0x27212870, 0x5f22167d, 0x96ceeb4d, 0x79f45994, 0x21676059,
	0x83b65fbc, 0xfbe89b73, 0x7df79b65, 0x3597fd0c, 0xda790388, 0x1b7a8aff,
	0xb1b08791, 0xc798132f, 0x6f0069d2, 0x31229bc5, 0xa5e97ad3, 0x1c011255,
	0x8952b509, 0x547fc603, 0xce301d92, 0xc3471c41, 0x74b3c567, 0xe55dfa1c,
	0xa61b9c8b, 0x1e226956, 0xb775a780, 0x7653ce75, 0x34b55798, 0xfddfbe18,
	0x2def0480, 0xc57c2c0f, 0x5b7c032a, 0x738042a4, 0xd96916f3, 0x56feced0,
	0x83a5bfd4, 0x765d58eb, 0xddaa27aa, 0x11f49e58, 0xeb3b9b22, 0x41288465,
	0x901dc03b, 0x7ceb0fa6, 0x204b9e7e, 0xcff43464, 0xd9d2d913, 0xf20c253f,
	0xfa03ff81, 0x2683e04f, 0x567b6047, 0xba56bd27, 0x4ee5bfe8, 0xa9759d7a,
	0x73da13f4, 0xcad7fba3, 0x140e8047, 0x0b9f5a9e, 0x697cc7cb, 0xc9f46e58,
	0xfa5fb788, 0xe7596086, 0x27f3e373, 0xdcb1637c, 0x7cb053ec, 0x658457d2,
	0xef8257c0, 0xc1cdf56d, 0x83cf9b72, 0x95f69fcf, 0xabef5962, 0xf9cfe7c2,
	0xc3b960d6, 0x2fe7c7e7, 0x196036fa, 0xb962d5f4, 0x658757cb, 0xef802f83,
	0xc7abe2bd, 0xc417d1b2, 0x8d7c7be7, 0x617c8658, 0x7d02f72c, 0xb5f61969,
	0x77dfb960, 0x7cd7cb18, 0xd9aefc11, 0x87cb1c77, 0x273bbc55, 0xe2813c90,
	0x1710a9cd, 0x58921715, 0xb489e4ac, 0xeac2589e, 0xf3fa7729, 0xf14f5a24,
	0x63c53ad0, 0x9e70f2df, 0x56fbd699, 0xfbccf6b1, 0xd685be48, 0x7dacfd33,
	0xbe4ac3c0, 0xd407d695, 0x9bc1f6b2, 0xb471f9fd, 0xdac0383e, 0xce11ddaf,
	0xb5fad1b7, 0x3c3ed641, 0x69d92644, 0xd598787d, 0x2656de73, 0xa73d6839,
	0x3f73d585, 0xd2724ff6, 0x7d846e7a, 0x7854fe3f, 0x8fad3c52, 0x13ed676f,
	0x1702912f, 0x1c244fad, 0x79edf3d6, 0x9eb40905, 0xc2f562ef, 0x39050b7e,
	0x15edff06, 0xe5098b23, 0x6dff7a85, 0xeb4e908a, 0x71156452, 0xe7fa7c53,
	0x922c3d60, 0xb6fed025, 0x8c22a17f, 0xac8975a3, 0xf6fff686, 0x7efb6197,
	0x76f6c651, 0xdf6c2aff, 0x6ed8c92f, 0xeb0fbeaa, 0xb60a89af, 0x8fdf5727,
	0x2926bfef, 0xfab83ed8, 0x8b37ac11, 0x5b1f6c1e, 0xbf7c2bfd, 0xfb60f259,
	0x4a02eb63, 0x07ffad01, 0x7c0ad9e7, 0x4a79c35d, 0x6bf03649, 0xf284ad30,
	0xcc8e7aeb, 0x0878f901, 0xc3ca9a98, 0x014974fa, 0x1ff7b6fd, 0x9cf14fb9,
	0x50c9dbca, 0x43f4f65f, 0xf3cfd859, 0xfb488fd8, 0x67ee7be1, 0x756337e2,
	0xa6fc4cfd, 0x01a7eb54, 0xf6b1abde, 0xdfbd9fae, 0xf3c3d78c, 0x4fd6994d,
	0xe8e3f613, 0x5e26bcdd, 0xe787a09e, 0x4fd6b972, 0xd093f633, 0xe2c2783b,
	0x613f5d18, 0xcfd6b971, 0x9f4fd83b, 0x48a3c1de, 0x28fd74e3, 0x3f5a3dd2,
	0xf49fb187, 0x9613f5de, 0x23c3d06e, 0x39fad0ad, 0xeff4fd82, 0xf314bcdd,
	0xcc787a8d, 0x273f5a15, 0xbd59ee91, 0x43bf67eb, 0x8efd9f8f, 0x439cfc0e,
	0x6ef50678, 0x3d4ef95e, 0x1d9df27e, 0xfd84b9f8, 0x7ebbd35c, 0xf8f53bf6,
	0xc0ecefd9, 0xbcc1c88f, 0x5e6ef586, 0xfc7af1f9, 0xe077c7e4, 0x3c01c9c7,
	0xcf077a23, 0xf8f47d6b, 0x074fad79, 0x9e11527e, 0xa783bdd1, 0x9f8f4520,
	0xfc0e9482, 0xb8cf08c8, 0x5af3f5de, 0xaf3f1e8a, 0xe7e074a5, 0xc6e7ec1a,
	0x20abcdde, 0x829f8f55, 0xe4fc0ed4, 0x9e793f60, 0xd087847a, 0xf7dd1c7e,
	0x8f5fdcd3, 0x1dfee69f, 0xfb01b9f8, 0xc9fb4c99, 0xc29fb9ee, 0x0a7e3d4c,
	0x53f03b33, 0xd29e7880, 0x339a7ebb, 0xce69f8f5, 0x54cfc0ec, 0xef6a67ec,
	0x957855e6, 0x57853f1e, 0x24dcfc31, 0x8675c08c, 0x9e6e9dae, 0xbf73727e,
	0xefa3853c, 0xe7562ef3, 0x76026e5d, 0x33d9af0f, 0xe9e145a4, 0x091df6fb,
	0x68910f39, 0x2eff26bb, 0x5a838fc0, 0x4d76d179, 0x9d38d8fc, 0x24a0951d,
	0x4549eaea, 0xf7ef757d, 0x6ba01929, 0xad739d4f, 0x93dd3dae, 0x9467aba3,
	0xdfbdd78e, 0x575f2abf, 0x2dcd6abf, 0xfcb3f7ba, 0xd9eaebb7, 0xdee9e61b,
	0x48bb541f, 0x5d757ed7, 0x9afdae99, 0xfd5d4ac0, 0xeb1ffaba, 0x5c161fde,
	0xbebf6bab, 0xfb5d21f1, 0xba63f088, 0x4f83c8fa, 0xdd1fdee8, 0x3ed755b2,
	0xba73f0e6, 0x5d9171f6, 0xc70dfaba, 0xbfdee8f7, 0xaebf7db1, 0xdfc5d37e,
	0x23cfdeeb, 0x6dedebef, 0xef759fcb, 0xa67d764f, 0xed39bf6b, 0x6a9d834b,
	0x4ebb1d77, 0x5720f3ad, 0x7f12fd04, 0x6af684ba, 0x5d6121d8, 0x7e676bea,
	0x7c99638a, 0xb48ff294, 0x8c9cb17f, 0xa8ff497c, 0xb7d790dd, 0x7d08eaf4,
	0x9ef1c3fe, 0xf9f45dab, 0xf5cf250f, 0x0df618ae, 0xa48e37e5, 0xa09b2941,
	0x203fb634, 0xcfcf7e32, 0x08f834b8, 0x6a6bdefd, 0xeb409c1f, 0x4179f3d7,
	0x38578f90, 0x71d5da13, 0xf782a93c, 0xfd04cce2, 0x72b207a6, 0xc947f29f,
	0xd4fe86c3, 0xfb3ae0ce, 0xd27a20dd, 0xfeaa8ed0, 0xce760fc4, 0x5e74fefa,
	0x9579097d, 0x1fec24fb, 0xbfefbf48, 0xfb43cd2c, 0xcfd44b33, 0xa25f1e88,
	0xf1c50fe3, 0xcd0f20c3, 0xaee8fe30, 0x8c079be3, 0xc96f8dd5, 0x6f8dd52c,
	0x2ef8e891, 0xfd5f7e42, 0x253e3ab9, 0xde4278c2, 0xf1c73ee2, 0x38a599cd,
	0xf51203fe, 0x8fc7a2bb, 0x05bf18eb, 0x7761ffe6, 0x5e301ff3, 0x32ccff3f,
	0x3625fcfd, 0x9f553fff, 0xc38fc756, 0x3b99fff9, 0x599fe6cd, 0x666fe6c6,
	0xef8c76fd, 0x047fc0ec, 0xcdd63fc6, 0x09ece6f8, 0x555ff9fa, 0x99bf9fae,
	0xfab27f8d, 0x1dbe3a82, 0xbb92ffc7, 0x557fe6c0, 0x992f8e39, 0x1fe06e3d,
	0x2aae2329, 0xfd27c740, 0x054be2a8, 0x40e3a176, 0x0a912439, 0xb9db210d,
	0x0fc70801, 0x7dbf18e3, 0x0df94715, 0x9f1f99f5, 0x9cd50093, 0x546fd4b9,
	0x8ec57d79, 0x1ef4093c, 0x6b7f53b6, 0x92ea0aa9, 0x9bf91e46, 0x0607346c,
	0x1b5b7851, 0x97d43f79, 0x0031bc6c, 0x266bd5fa, 0x3be04a0b, 0xf9e18481,
	0xdb0f8fe7, 0x632f3d1a, 0x3c56b4b9, 0xb7928916, 0x9f303f0e, 0xf0a2a90c,
	0x1826064d, 0x94ff59dd, 0x18e071fa, 0x1efd4c7f, 0xcf9ffd42, 0x7fde3644,
	0xea0f7f53, 0xa1efea11, 0xf1aa4ce3, 0xa1ddda3b, 0x897f0a34, 0x02a7ff0a,
	0xef4fd793, 0x2a7e02e4, 0x68fd5f9f, 0x0bd7fa04, 0xd228d8d6, 0xe858e13b,
	0xe9d5d24f, 0xa740fcbc, 0xc0e6ddf6, 0x2bf10e56, 0xa3a6be03, 0x78b21268,
	0x75c50643, 0xed1ffbe7, 0x39ccda9d, 0x2883b909, 0xff7d2a62, 0x7f5cd5ae,
	0x96771d17, 0xeb61ce62, 0x42619290, 0xa61926b9, 0xdedc84b1, 0x3da44230,
	0xf88ae990, 0xdc6a2469, 0xfafa4519, 0xbd7d12ac, 0x13445455, 0x3a75ab85,
	0x7ed0b647, 0xb7d1cf67, 0x340ce36b, 0xab3a3225, 0x9c5095e3, 0xb347d3a4,
	0xc781cca1, 0x1cf3a42e, 0x8356fb17, 0x2458bbc7, 0xfde3f461, 0xd5d0087d,
	0xcdef8c9f, 0x1b79b173, 0x5a239de1, 0xcf3a1294, 0x00f90b39, 0xfe11b7f0,
	0x29b5ed3f, 0xdcb4e1a6, 0x98910bf0, 0x08c7ceba, 0x718f5cff, 0xd611413e,
	0xc6a5f9f9, 0x8e6f8ce7, 0x14fff4a9, 0x5f9683f8, 0xf8507f00, 0xd1fcaa8f,
	0x7f1957a9, 0x699ecd78, 0x9bed0fc0, 0x55748278, 0x950ee5f9, 0xead6965f,
	0x8f1082f9, 0x3e5c7408, 0x2879cb87, 0xab660f8a, 0x4ebcb07c, 0x117737cf,
	0x831e98bf, 0x6e37732e, 0xee4d3fb9, 0x544fbf3a, 0xf0ff99be, 0xd74fc43e,
	0xdd3a3279, 0xaee9d2ad, 0x1dfb7d2a, 0x52ef5d2a, 0xeea73ae9, 0xfaa9d7d1,
	0x80e4f320, 0xfdeef208, 0x88cf4689, 0x951e9e8e, 0xef38469e, 0xf779e956,
	0x8d3d188f, 0x7a5446f0, 0x89ceea46, 0x78574064, 0x582df08d, 0x183e65d3,
	0x8fe85ad7, 0x636f4f4d, 0x51a3aade, 0x53822bcf, 0x928d1d56, 0xd3f515b3,
	0x027bf575, 0x2fef7573, 0x6ba85baf, 0x8f7b5a5f, 0x86f17dae, 0x85f5757b,
	0xdee91ffe, 0x5aa6b05f, 0xd5577ed7, 0xf9f6ba83, 0xeaea8fa5, 0x749b3d73,
	0xb39ecfef, 0xab3ed745, 0xfb5d59e4, 0xba9da28c, 0xb76574fa, 0xded37dee,
	0xfe036e6b, 0x9e03fb7c, 0xc1713d80, 0x33c605fd, 0x3745b82f, 0x27d473bc,
	0xf31f5f23, 0xb8f2c10d, 0x7f7c8dcf, 0xcb1637d2, 0x7603c6d6, 0xbae82758,
	0x10248cb8, 0x579a68d2, 0xac1fa1bd, 0xd3d704d3, 0xed53c990, 0x2603f5a7,
	0xb8a1e519, 0x91e1224e, 0xd8b07084, 0xf3b470a8, 0x1e91ed51, 0xe2a8ebda,
	0x5edaea4f, 0xdcfd891c, 0xabc2d8fb, 0x5bbb2f80, 0x065fe81f, 0xaa6d3dd8,
	0x2f6c6f5d, 0xf44948e7, 0x22d64273, 0xb313561c, 0x2625ca3b, 0xd2bbe5ff,
	0xea1389f3, 0x5755c1e1, 0x99482f1a, 0x24f8153c, 0xcbc7275b, 0xe9d3aeeb,
	0xe4d10277, 0x236fc03e, 0xd457cf75, 0xeefba0df, 0xe11e3ed4, 0x315d04ae,
	0x92c5960e, 0x87a04ccf, 0x673207c3, 0x9538030c, 0xec6f58a3, 0x29e17683,
	0xa3aad15f, 0x257e8083, 0xcdf71e58, 0xcf98f2c1, 0x5f51e583, 0xfa9f9629,
	0xf88cb0aa, 0xdff960d6, 0x1f963f3e, 0xf96036fb, 0x962d5f27, 0x58757d87,
	0x600be87e, 0x8f57c879, 0x20be7be5, 0x46be2d96, 0x0a7d5b2c, 0xf5dc9a96,
	0xd5c777c4, 0xf024f875, 0x933e0c5f, 0x1bd5fc6a, 0x59f27426, 0xf200ff1c,
	0xe2e78699, 0x0fcab33a, 0x487e3a29, 0xf90e5f00, 0x3af687ac, 0xeec3e551,
	0xeedd8fbe, 0xe1affadd, 0x93dfa9b7, 0x29f93adf, 0xd94fc0c3, 0x30d3f13d,
	0xa69f8a3e, 0xeecc5c9a, 0xa7e9f951, 0x7e188f30, 0x42303cc5, 0x6bd944fa,
	0xd6099e4a, 0x3eea95b1, 0xf5807d08, 0x35d8eab3, 0xb416ddf4, 0x604302eb,
	0xe43b38dd, 0x1f61836f, 0x4a61ece1, 0xe7eeacfc, 0xee93e467, 0x7fa0aef1,
	0x89402cb3, 0xddb5d49e, 0x6af0c71a, 0x42229135, 0x0707b5d7, 0x345eed3d,
	0x4902eb14, 0xee03ef84, 0xfd188ee9, 0xf0195b52, 0x6b5e13db, 0x870d5f1c,
	0xf13d8efe, 0xa7285cf7, 0x1cbd989a, 0xbb478077, 0x729f849d, 0xd63b7e03,
	0x0d3bb325, 0x83edede2, 0x0dda1724, 0x7f1e9264, 0xfe1d7cfe, 0x6a38a41e,
	0x36b775c1, 0xf037f10d, 0xbde9c1ab, 0xfa4f5fc0, 0x2e7c27bd, 0x0bff7982,
	0x7e93d9f0, 0x122f49ec, 0x91b17e45, 0xef6dbfce, 0x64879cb0, 0xf8caf718,
	0x8cd7f6d6, 0x2dfe3cf0, 0x452db8f9, 0x4c96e3e3, 0x2a907e02, 0xae1b672f,
	0x74ba078e, 0x3d03d3f4, 0x927ddfb9, 0xe9fbfe09, 0x0f7f7d2c, 0x978bfb18,
	0x1d3d7708, 0x244921d7, 0xbc95fa9e, 0xfe8f3b67, 0x87e23b8c, 0x9b5ec1b8,
	0xbf0646bb, 0x857fe4f1, 0x1f59e865, 0xf07b385f, 0x61f82729, 0xaaf8d32b,
	0xa8e831a3, 0xacc11595, 0xbfb47b2a, 0x9fafa8d2, 0x828ae5ad, 0x7e392f38,
	0x675830e6, 0x4547555c, 0x5869fbd0, 0x4cacfd6a, 0x939c7093, 0xccf1d9f5,
	0x7d300bff, 0xf50123b2, 0x059f49cd, 0xc367ffdf, 0x1a3f5dd3, 0x9034843c,
	0xcfa02ccf, 0xf7765b69, 0x0f2b77ef, 0xe20979c2, 0x7e2424a7, 0x95a6fe05,
	0x00797ffe, 0x5d602bf4, 0xe41bd7eb, 0xe1ebe6fd, 0x78dd0ef9, 0xdb593bf4,
	0xbaef8633, 0x1c813b97, 0xd29ef8d3, 0xfeea2fef, 0x6b7a8af6, 0x4d8ede95,
	0x8dbdd5d0, 0xbb3a55e9, 0x8601fe16, 0xc027157b, 0xb2ae5612, 0xdf609b61,
	0x07b4fc00, 0xbfe09382, 0x0abdec70, 0xc8f2444b, 0xc02d2e28, 0x6ac68ba7,
	0xfecf2ffc, 0x2753d533, 0xc80912de, 0xa144b919, 0x8fecedca, 0x44c4f4ae,
	0xdad58beb, 0xc51586a2, 0x789d6eb0, 0x43f456e5, 0x27129096, 0xa4a5c7f8,
	0xb5e21736, 0x08a989a7, 0x7934f3e4, 0x4a3239cf, 0x8482ad1e, 0x41bc5cf3,
	0xff53c76f, 0x5e5f575e, 0x232fafa7, 0xbec0a7b7, 0x228db2fd, 0x37a07009,
	0xf35fedf4, 0x3977ec2e, 0xeb0f5aa9, 0xad9146f6, 0x445c8b67, 0xab7aa0c8,
	0xcebfb7e2, 0x2eeb485d, 0xb459c581, 0x127be87d, 0x1653ff99, 0xb42922dc,
	0x9186b3fd, 0x440d5077, 0x87ac0fbf, 0x32ffcb75, 0x772edee7, 0x85b7dfa5,
	0x66af08df, 0x0fd9740f, 0xa8a8e157, 0x0c4094e7, 0xe053207b, 0xfaa99c98,
	0xe9705f2e, 0x0cd31ee2, 0x4fcceff5, 0x4fc744c9, 0xae4f787b, 0x0ff19a30,
	0xd09c7ff8, 0x4fbe792e, 0xfa5d69ff, 0xf6a7ffcf, 0x9ff68fdf, 0xda7febab,
	0x81ffb53f, 0x179fe05d, 0xdf8affab, 0x9f8af0be, 0x97b293ea, 0xba12771e,
	0x6a109e4e, 0xbe94dc53, 0x77efdbe5, 0x0b8f9d02, 0xebf0277e, 0x145f0089,
	0x3d6eb188, 0x3c6a702a, 0x1073b146, 0xd27f8377, 0xf73e4ffe, 0x7c478c53,
	0x61745db5, 0x1cdead3c, 0xac395336, 0x98a7b86c, 0x11fac70c, 0x0ce07f56,
	0x3d46f50f, 0xf33d95ff, 0x87e40a78, 0xe3514e50, 0x67b4614b, 0x5e7db72b,
	0x9793eb08, 0x191ca3b4, 0x2ff183bf, 0x5bfea226, 0x6d77c528, 0x9c6270a7,
	0xc5e2abc0, 0x33d3f0db, 0x29ca13bc, 0xa0be805f, 0xf1fa089e, 0x554aefc6,
	0xe0ad753b, 0xa3663e48, 0xc6431eff, 0xf0d45e80, 0x4ecc0242, 0x57f679ad,
	0xb8508fc3, 0xcb7b6d4e, 0x4be145c9, 0xc1b3a793, 0x47b9ffc5, 0xb6ef5eee,
	0xb68b7952, 0x4b75b487, 0xebed546e, 0xc5cb2b10, 0x79f213b0, 0x6e88b7ca,
	0xfe5c7d3f, 0x3f4f53c2, 0x3fccf101, 0x6883dd9a, 0x785e2bff, 0xb4f1c3fd,
	0x98a762be, 0x61a6cc5c, 0xe93a52e7, 0xafffa5e3, 0x47a4e9c9, 0x975e6fd9,
	0xf9ec61e4, 0x749d897d, 0x9f73b159, 0xc5758644, 0x3ee0a4c7, 0x418f6229,
	0x4291e09f, 0x9e6a17b0, 0x7104abfd, 0x397b13c6, 0x03159a92, 0x475e5b9f,
	0x84f0007b, 0xd5e954f4, 0xfbc33f41, 0xd0174a5e, 0x197a46db, 0xeaac5bdf,
	0xf217e817, 0xbf7f282c, 0xa0f207b8, 0x037664fe, 0x5c5f4a1e, 0x7cf984e5,
	0x3e315421, 0x29fdf5ff, 0x54bf1d0a, 0xb0b8a7f4, 0x9f4bcf64, 0xdff201fc,
	0x907f77f2, 0xa225f182, 0x2d709ba4, 0x3cc3a7f2, 0x859e6e97, 0x3c465cf3,
	0xbfa587c8, 0x1f404be6, 0xd148105e, 0x627218ce, 0x7c9c9915, 0x971295b1,
	0xf00bf3ce, 0xe83f2127, 0x1db03e3d, 0x097beeed, 0xa81f83e8, 0x0316a173,
	0x18582fd6, 0xaea2febd, 0xcfac040b, 0xf6ddfe68, 0xe9d00b40, 0x15257f64,
	0x44bc5df6, 0xe0f8abf0, 0xf97ed32e, 0x32a72777, 0xc859113a, 0xeba3bf55,
	0x0e7824fe, 0x8a88b7ef, 0x3beeb875, 0x73ab3972, 0xf8ead5fc, 0x5838ee14,
	0x8948bfaf, 0x8ae6bf6d, 0xeba01e9a, 0x459f1476, 0xff933bc9, 0x79320f6d,
	0x303fe4d7, 0xcfda08bd, 0x0472621f, 0x487ac1df, 0x62a70ae1, 0x1c99befb,
	0x47ea07ea, 0x6df392c7, 0xfae72aa2, 0x50bf2376, 0x3e2e05f8, 0x9c606f8a,
	0xee03a444, 0x48db2cbb, 0xa3d28fbf, 0xd9d7185e, 0x8e4d5fb5, 0xab7e6b97,
	0x6407d7a8, 0xdd03d333, 0xc47e55db, 0x7818b953, 0x5f9009fa, 0x197eaf2a,
	0x812c57e4, 0xe3b97ff9, 0xa8f387c0, 0xd4197edc, 0x57af56e4, 0xba5b728d,
	0x2589346b, 0xddda5fb7, 0xd2dca624, 0xd6e531e7, 0xfe7e411e, 0x3557ad3f,
	0x3c030e3c, 0x4789d75e, 0x87764f4d, 0x3c9ea34f, 0x5788c828, 0x7fa49ea3,
	0x576e4887, 0x50f8d47e, 0xe7b2bfe3, 0x7d02ae2b, 0x1aa7c1d4, 0xa9f0761f,
	0xe25d87c6, 0x1a3c3abb, 0x3ec02fdb, 0xbe6b850d, 0xa3b4d365, 0xb4b495d4,
	0xc9b7dc13, 0xbee3c99b, 0x613ce5aa, 0xc4442079, 0x4c8fd0fc, 0x4ec1a355,
	0x3bf7f89d, 0xc290ff4e, 0x45f89f3b, 0x2b501796, 0xe97fdda2, 0x7409e5f2,
	0x3c54f33e, 0x9f68a7cf, 0x4732e94a, 0x1471c2e0, 0xf102b9ce, 0xfc4227c7,
	0x469f2396, 0x54bf31c1, 0x89bf875f, 0xf4fd9d29, 0xf5b7fef4, 0xf96bbe53,
	0xa7eba52e, 0x1f790883, 0x1787114a, 0x3a6af9a2, 0xcfe295d0, 0x0c0b8a3b,
	0x11153d40, 0xaefca24a, 0x7f664517, 0x63305bbe, 0x7937d834, 0x33c587b3,
	0x7e8c1f7e, 0x67d557af, 0x3c72fd67, 0xa1b3f9e8, 0xcf6ff46c, 0x88ec5c1e,
	0x407a1795, 0xd5d7b3e5, 0x3b36977d, 0xfe53cb57, 0x68ed236f, 0x56edf8df,
	0xbec63db2, 0xd35126e0, 0xe8dd2ad7, 0x9fc74f1f, 0x5ce1f2a3, 0x4e7c69fa,
	0x4e66dd14, 0xbb38213d, 0x3efe01d2, 0xbec3f28d, 0xaf817e2f, 0xac07bf01,
	0x1892c291, 0x2af3fbf6, 0xffee26fe, 0x0b73f31a, 0xe0027942, 0xebcec0b1,
	0x694f20e2, 0x0c943af2, 0xee26b805, 0xa367e7bf, 0x0f7b1f29, 0xc7c86ef2,
	0x48ce86f5, 0xb0fe189e, 0x3fd09f11, 0x444799d8, 0x03ebe217, 0xe02964b1,
	0x565983f5, 0xef9afb02, 0x588aee4b, 0xb3342e70, 0x292e66f5, 0xfb8a30b9,
	0x79bf0fbf, 0x7ce11db3, 0x76b38f8a, 0x95ddf796, 0x9fdc98ff, 0x6a817175,
	0x6790f80e, 0x002e64f5, 0xe242b471, 0x0e04d9f9, 0x68a6fde5, 0x38d795fd,
	0xebc805fd, 0x2e710ca9, 0x14af6d13, 0xb1f01222, 0x00a771b7, 0x32adfbf6,
	0x211e3051, 0x199b0d54, 0x223af715, 0x03af880a, 0x17779b7f, 0x4cdcf7e0,
	0x94b80133, 0x609c67a1, 0x8d0b9c07, 0x6ee83944, 0x91f07f5e, 0xf4220569,
	0x8c3f9043, 0x6c9850fc, 0x4d67d5d3, 0x94dcfd22, 0x91cd136e, 0xf418ee55,
	0x9f1891ab, 0x59bf5af5, 0x6fd33ffe, 0x637ea813, 0xeb462d7c, 0xc6255bb7,
	0x2dfa51f7, 0x5b7e9635, 0x02a72d59, 0xca6cac5f, 0xaeba054e, 0x9f69737c,
	0x0dedfa58, 0xdfeff31f, 0xdbccf354, 0x76fd51fa, 0xeb7e947d, 0x8c5bf547,
	0xa968eeb8, 0xf2cdfa97, 0x6f7f233f, 0x318b7e80, 0x7f1522df, 0x0a2b7e9a,
	0x2b7ea355, 0xf2ebc7ea, 0x7a926ea5, 0x1f0b6fd2, 0xd175859f, 0x3fc18b6d,
	0x6fd05780, 0x0e7aaa6f, 0xf73d01c6, 0x5beb92ef, 0xde8ab9e9, 0x21ffb9ea,
	0x6e7a6b3c, 0xed0e7f65, 0xc87cae99, 0x2ccadcf4, 0x3656e7a6, 0x72b73d31,
	0x4673d310, 0x45df96fd, 0x2befb1bf, 0xd1efd087, 0xd5facc8f, 0x78bdb49d,
	0xd0b6e88e, 0xed658bf7, 0xe8d5467c, 0xeff77d68, 0xcefa3752, 0xb9cf067d,
	0xdeefa4f4, 0x08377d01, 0x9040d8f5, 0xdc7f2323, 0xcba6d032, 0xebe0fba7,
	0x04bfcf63, 0x1e07f2f2, 0x4c8feffd, 0xfbda4fcc, 0x2091b1f5, 0x3c001f77,
	0xab3ddf54, 0xcfab5ff2, 0xd274fa8f, 0x15ef2650, 0x55fc31f7, 0xbe6c7036,
	0x0c80f9ab, 0x2edfc0eb, 0x577d1fa2, 0x67a3f313, 0xd8fa5b9b, 0x5fffcfc0,
	0xfd25ca22, 0xc5185e2b, 0x962e730f, 0x5773dc61, 0xf82b739c, 0x62047399,
	0xc1763b01, 0x804e5bc1, 0xe2e0bafd, 0x177bb406, 0xd244f3c0, 0xb731f791,
	0xedea4f43, 0x3b8d79d7, 0x5d20cf5f, 0x9a2621f3, 0xae265d19, 0xb25b02e2,
	0x5047e6ba, 0x5bf30cbb, 0xbf12798c, 0x9b3fe757, 0xc8be208f, 0x7b7bbc3b,
	0xbdf9f90c, 0x866e4f11, 0xbcd58a97, 0x5c554f1e, 0x4a513c4c, 0xe94c2f17,
	0x2f5dcbc4, 0x4067d647, 0xfa1c3dfb, 0x6b79c65b, 0x5fce3378, 0xdfe6a3c3,
	0x9fdf502c, 0x33123a1f, 0x73c3444f, 0x0d117c97, 0xbc7c06ef, 0xeb99e9ad,
	0xcb9030c8, 0x9f9e4c8f, 0xfa3e068d, 0xdd718f3d, 0xd20ee63b, 0x4f7a579d,
	0xcf54cbc5, 0x19148291, 0x80aa48f0, 0xee95e6cf, 0xce853d7c, 0x2b2536ef,
	0xb3ea4207, 0x207926fe, 0xdac0711e, 0xe3507a8e, 0x266651c3, 0xaf556617,
	0x55d7d07c, 0x234deb80, 0x0af942e7, 0x9a9cf41b, 0x8fbde667, 0xee01dfc9,
	0x4633ebaf, 0xb9619e21, 0x7ada8520, 0xffa17405, 0x74621a9c, 0xe85d02f1,
	0xf691a73f, 0x657bc066, 0xc30ee732, 0xef3b8dfb, 0xc37a7e07, 0x9c839f4a,
	0xadee7297, 0xf4f61d0c, 0xb1f22b94, 0x318f8b10, 0xb9db9198, 0xf7802e7e,
	0x27dabb12, 0x1f2dcd13, 0xa9131c00, 0x87816cdc, 0x145ffa01, 0x8bf68dfd,
	0xca7a0f91, 0xdf8eea07, 0xbf3c5473, 0x03b07401, 0xb025dbbe, 0xb661bc87,
	0x5eed68fe, 0xbc402e41, 0xa4687469, 0x4628cbeb, 0x3c0c5307, 0x55d5a6df,
	0x9c437b3c, 0xa14fdf08, 0x07126ffe, 0x375f7ebb, 0x966efc6b, 0xe209e2bb,
	0x7a51e90a, 0xf45bf403, 0xe36566be, 0x5baf88bb, 0x4cf35356, 0x8d2f8aee,
	0xaf07a03e, 0xe56eb784, 0xcc48f1a7, 0x2b6fb0bc, 0x7acca33f, 0x6d6bd9f9,
	0x887aeb7f, 0xa87135ab, 0x41284857, 0x69983f17, 0x01cb7666, 0xbcf907ab,
	0xbdd14dfd, 0x7faaee55, 0x0174ab26, 0x7cfa257f, 0x089824e2, 0x95974de8,
	0x7bcda67c, 0xe8b7e300, 0xab0de0f5, 0x5dd7e907, 0xcccc33ff, 0x1eceedfe,
	0xc337ead3, 0x28d79078, 0xae33c7eb, 0xa95c5a47, 0xd47979a7, 0xbcebbf71,
	0xedbe71b4, 0xb49784be, 0xdb4e3c60, 0x7bc3d89f, 0x3f608976, 0x7e827116,
	0xf71daf1f, 0xfd09ff37, 0xee8d26df, 0x1f887fbe, 0xdf9e2985, 0xc614f1d8,
	0x773f4fb1, 0xcfc81a64, 0x6279578a, 0xbad7f2a1, 0x2cc241c3, 0x3b02444f,
	0x5781aca1, 0x842fce30, 0xd9446773, 0x6193d419, 0x81c978f8, 0x976caf7a,
	0xbf4c5039, 0xb3e57b2f, 0x6b7f10e1, 0x9ff4cb5d, 0x1f9539ff, 0x90e191fd,
	0xb026500f, 0x7d2379fd, 0xf3f9531e, 0x1cdb6ed4, 0x3d5cdfd0, 0x165bc73b,
	0xa39a2d9c, 0x9a0f0ce2, 0xdee71645, 0x6c3cc36d, 0xe61cb3ff, 0xd17c0331,
	0xfcb548e7, 0x32cf53d0, 0x28d65cbd, 0x703ce006, 0x56cefd59, 0x1d978b88,
	0xeafda336, 0xfb833fad, 0x7a5e937a, 0x6e379d81, 0xd0f175e4, 0x7ac8712e,
	0xf8866c3e, 0xea054359, 0x823f5a01, 0xf71aa0f5, 0xb27196fb, 0xbd352f15,
	0x5c28a7e2, 0x9c679bf1, 0x65b82e78, 0x91e313bb, 0x17de57f5, 0x0c7712e8,
	0x1dc6a83e, 0x70417ea7, 0x771d887d, 0x49f2a93c, 0x3b8facc8, 0x8c24fa92,
	0x73385247, 0x2fc4624b, 0x85fff83a, 0xbec24f0b, 0x5f5da9d9, 0x9770093e,
	0xc9ee737f, 0x527c509f, 0x7582e405, 0x07dcfbdb, 0x7da0cfb8, 0x4faaa1f7,
	0x067d9f5a, 0xff5a69f7, 0x6f437668, 0x645f4dad, 0xeb453ec2, 0x2053afce,
	0x69babb8e, 0xab6bfa32, 0x4a949e5f, 0x5a03f862, 0xe81bfc09, 0x91913ec5,
	0x0e1a076e, 0xa79c0264, 0xfd61dd29, 0x072788ee, 0x5e9c582b, 0x3bc8e356,
	0x75cbef62, 0xcc371b89, 0x5846edb8, 0xb7441bc7, 0x3f117a4c, 0x79e9443e,
	0xb8e82f7d, 0x0827dd43, 0xfc62bd4e, 0x83fc34f8, 0x5982ebd2, 0xd0bf871f,
	0x9f3ff4b0, 0xa486b680, 0xe1c7e36e, 0xdb4fe05e, 0x5667dbf7, 0x68e40588,
	0xb718f3d7, 0xdf51fa07, 0x70beb483, 0x2ee21321, 0xbbf6c5c7, 0xc9baff31,
	0x6554798c, 0x3ca11f4d, 0x2efcbeb5, 0x7511abee, 0x7495adff, 0x127db1fc,
	0x6ef3a7d5, 0xb3b8b073, 0x4b88074a, 0xae7c4ecb, 0x5f199fc6, 0xeee9716b,
	0x2d63d1e2, 0xbbfed803, 0xb1591fba, 0x3112cfed, 0xb1b9fbc4, 0x5723af40,
	0xf0d547dc, 0x8c3c02e0, 0x896fde89, 0xd8efff1d, 0x0dd0316f, 0x58f609e8,
	0xad0a7ec7, 0x7ab883f7, 0xd628fb80, 0x16eb5dfe, 0x2ad34fb6, 0xd45bcec6,
	0x5a465ff6, 0x812efb0c, 0xf4bbedde, 0x8b6f8f34, 0x42706ca7, 0xd7c574fb,
	0xf5b14ba9, 0x4e161dfb, 0x3be037bd, 0x7397ebee, 0x5981bcc6, 0x0d1597c0,
	0xa7b02447, 0x9b4df5b4, 0x7fd529ef, 0x8f1cf53e, 0x07d644e7, 0x377ea00f,
	0xc24a8fea, 0x784686e2, 0x6f4c2d4b, 0xf5b23655, 0x472ed4e3, 0x39fb4ec0,
	0xf2377fb5, 0x238ee575, 0xd7f69f92, 0x291bff5c, 0x05679512, 0x0a2047eb,
	0xee2f53fe, 0x97f6ce1b, 0x1c6ebf98, 0x38ea87e7, 0x71ec50de, 0xe8ce3bbc,
	0x0fe159c6, 0xcfdcec4a, 0x293bc795, 0xbfa1b328, 0x81222d93, 0x4193ffbc,
	0xde5628be, 0xa88b5cca, 0xfc98b3c5, 0xcf1475d0, 0xb9d83a61, 0x42513e4b,
	0x63b57bbb, 0xef3861ec, 0xc921dabf, 0xa9a8bf10, 0x353c7966, 0x034ee6ff,
	0xdc24d77a, 0xb571fb81, 0x92bafc06, 0xd710795d, 0x8c941570, 0xea357602,
	0xa4c5049d, 0xa3b57f83, 0x70a65528, 0x34ed53ae, 0x5cf1b822, 0x2c2cef28,
	0x2ef0f982, 0x631acb93, 0x97b441df, 0x5e144f10, 0x1cfe9744, 0x5234b927,
	0xfcb47e86, 0x4b4b729b, 0x14ba3633, 0xc616314c, 0x66f377b2, 0x6dde70ba,
	0x41ff543b, 0x852bb221, 0x3ac191e5, 0x7e2bb6d2, 0x3f1eb938, 0x47e50a24,
	0xdb9cfa9b, 0xe81f6fb1, 0xa24e75a5, 0xa3395024, 0x6cf99558, 0xc23acf38,
	0x9f0365c2, 0x57aff99e, 0x10d6bf69, 0x9b457e8f, 0x5527cb5d, 0x6cce4012,
	0x1bcc61e4, 0x9cbe5604, 0x31a709d4, 0x2bc0909f, 0x4c69f751, 0x0fe8ede6,
	0xe2ccdd9d, 0xf6b93c03, 0x7c581357, 0x7e00048e, 0xa1597d75, 0x109679c2,
	0xdfde1877, 0xc078c0e1, 0xa31737f2, 0xa21d00fc, 0xa45495f1, 0x675af73f,
	0x7f070e75, 0xf5559366, 0x0b4afc6b, 0xa259b39c, 0x44a7dbf6, 0x8a962e7f,
	0x75e41fa1, 0x5faf2aa9, 0x883c2b2e, 0x659e68f9, 0xe753e7a8, 0x1acdcfe8,
	0xa204b4f3, 0xe601c9fa, 0xdbc9773f, 0x7082dc6a, 0x56b7f31b, 0x1aebebd4,
	0xbd013f1e, 0x93a00d79, 0x0714afd8, 0x91bf11ec, 0x309abfc1, 0xd7e3dbea,
	0xafc7a69c, 0xd7e3d655, 0x3f88c436, 0x6e1d7e3d, 0xbf34be3d, 0xc6fc3bb4,
	0x439fd58f, 0x57e157fe, 0xa476aab4, 0x57fa578a, 0x2a614962, 0x174ee01b,
	0x461728c2, 0x87b0ca39, 0xff77f839, 0x7e3540e4, 0x7ea076e5, 0xc3e7534f,
	0xd9df612d, 0x80788e40, 0x04728dd7, 0xcf410127, 0xaec7c8db, 0xd6205663,
	0x75f2e467, 0xd573d3dd, 0x2c8ed7f4, 0x066d5fa2, 0xf91ebdfe, 0x4df79d81,
	0x2c9a8124, 0x0bb75390, 0xcfa0efd6, 0xc2225ee2, 0xbdc42fbd, 0xf7dc1064,
	0x11f2c2e2, 0x6da55f35, 0x8373c128, 0x14f9f0c1, 0xe48f4fd0, 0xbd034fb4,
	0x4a4a5de7, 0x20fe0f40, 0x781f9d8e, 0xc5fb2d48, 0x2d5eaa49, 0xf826f378,
	0x70ca243e, 0xb42dbd5e, 0xea0832dd, 0xa3de3c8d, 0xbda84de2, 0x0d6fc606,
	0x25ae0c89, 0x8820c096, 0x38893483, 0x0992eb6e, 0xc3b32e78, 0x7cb10b7e,
	0x67d0b691, 0xfa51c5ce, 0x17f1b5bc, 0x6b9c40d7, 0x9e762993, 0xe9ab64ca,
	0xc1bfadfb, 0x937b792e, 0xeeaf2cad, 0x1e740191, 0xaacfd395, 0x879330eb,
	0xbf3a541b, 0x9c16ecb6, 0x4e21cbff, 0x90a47586, 0x61d6f3bf, 0x3ee39e74,
	0x0cf8d410, 0x528e578b, 0xfd01afdf, 0xf6b5fa82, 0xdc3e9e7d, 0x7020547d,
	0xd5546f4e, 0x5eb7f432, 0xa73e5275, 0x04ab917c, 0x16df0247, 0xdef01284,
	0x04c7ef1c, 0x2dd1faed, 0x733f8e82, 0x373575d5, 0x4c05e542, 0xf6fac394,
	0x60c11171, 0xe0780507, 0xeb8e1baf, 0xaab22f9f, 0xa4939776, 0xbc6f9f00,
	0xf79073c4, 0xdc4ed6da, 0x6ddc296b, 0x1c22fa4b, 0xd4e1e76d, 0xf12f2d2f,
	0xfbd6b145, 0x17c65655, 0xeb82249b, 0x7665a6cc, 0x5fee2f8c, 0xac157656,
	0xc8fd5fef, 0x73ac5573, 0x29fa51e4, 0x2963e59e, 0xf02c64f1, 0xe18e3af7,
	0x24bd36bd, 0xc6bfbe46, 0x6b7f1acf, 0x2cbe9d7c, 0xaf2b13ce, 0xb32b1bf1,
	0x0d97f2d3, 0xd7f024e1, 0x1c7872f6, 0xe7ad75b7, 0xfc6ee78a, 0xc0066d64,
	0x873c6de3, 0x1425b776, 0xa3764f3b, 0xb7fd89d5, 0x4357f5ae, 0xa90fdf1e,
	0xec9e8270, 0xe88ddfbe, 0x8218fd6f, 0xa59df0b2, 0xe39e2176, 0x5b216a5d,
	0xd42dde21, 0x00eedfa6, 0x65349ffe, 0x89f7853d, 0xafae1312, 0xc237449b,
	0x0420afef, 0x3c6a0fe3, 0xb234dfb7, 0xf33cfa25, 0xe7bcd693, 0xcf1e94ac,
	0x97485d59, 0x039b8f24, 0xf8ffddf8, 0xbbe413ab, 0xe919a2ed, 0x87f557d8,
	0xb75eefb4, 0x666dbb32, 0xbe0db29c, 0x28c9a527, 0xd38f6e27, 0xdc2464bd,
	0x1ef1409b, 0xf49d4725, 0x8977e3f3, 0x28e3aa1e, 0x1376893c, 0x145125f2,
	0x538ba5d9, 0x348e51fa, 0x8e6120b9, 0xa69b1e40, 0x1710b957, 0x18395076,
	0xc187b165, 0xa52c48ef, 0x5820a6f3, 0xd7f58589, 0x38ea9c22, 0xf2798d97,
	0xe1732f94, 0x90c11470, 0x42e22428, 0xd5be9aff, 0x04baf4f4, 0xeeb2f282,
	0x43502151, 0x442cd9fb, 0xc95f10ac, 0x487ce452, 0x64144a35, 0xbfde2f3c,
	0xa5fe6094, 0x09d7fb2d, 0x150b761d, 0xf0df11fa, 0xe7ed620b, 0xbe1a71f1,
	0xbd007f3c, 0xfb60fc31, 0xdc6f307e, 0xfb9e3656, 0xe9da0b75, 0xb543fa1d,
	0xf5d50ac7, 0x26e7dc77, 0xbe104f96, 0xb3ef4489, 0x6687f519, 0x31bb8c9f,
	0x8bf616b2, 0xc191fdc6, 0xe055bb49, 0x7cead1bb, 0xba89f43b, 0x51098e6e,
	0xcfbf427d, 0x003c8d09, 0x7ce560f7, 0x8bb8e4cc, 0xe7e8393e, 0x55df7f01,
	0x62f9188f, 0xa5ca9844, 0x86543eda, 0x1d5c34fb, 0x633f6875, 0xd3c93bd0,
	0x9da2a547, 0x119bf2ab, 0x1b7c9acf, 0x8d673ee5, 0xc19980fb, 0xc348fcc5,
	0x84eb8438, 0xbd06ce43, 0xf60f36f4, 0xc51e5b7e, 0x97eb8503, 0x7e947f20,
	0x5303e709, 0x431bfe60, 0x4e415b37, 0x127af3be, 0xe5475fa2, 0x7bc33f69,
	0xe0fae3e2, 0x3c04e27a, 0xaf3bee54, 0xa46127ae, 0x501c8777, 0x978e8939,
	0xe46ffc68, 0x6a3e4d77, 0x6c8de2e0, 0x6047673c, 0x20b9e59d, 0x2663065e,
	0x57805d9b, 0x51aedecd, 0x4fe25bed, 0xb56ffb47, 0x51eba88b, 0xa4f80066,
	0x75ecd446, 0x3e3a25b7, 0x9f91dab5, 0x54fda57a, 0x9fea45ef, 0xf1b39d45,
	0xbfe8ed0a, 0xf84a2f79, 0xafe33bfc, 0xab914291, 0xb898dfc3, 0x17f15dd1,
	0xbb08471f, 0xf9ffec2f, 0xf230cdf9, 0xe77203c7, 0x9e206efc, 0x7f542357,
	0x50daaee4, 0x93f19363, 0x5db96943, 0xffb682f5, 0x301e9dd9, 0xf298fbca,
	0x6e1803da, 0xbdde41e9, 0x84bf1536, 0x367d00cc, 0x96ed4c3e, 0x7ff2aeac,
	0xd79f9d5e, 0x76def0c6, 0x9060fb47, 0xa7bc0da7, 0xc5ed0e2a, 0x7604c988,
	0x76826ec5, 0x51df7b8f, 0x4b7bca27, 0xe9fd6e92, 0x51f8176a, 0x54fb353e,
	0xef8d4bb3, 0xeaa5d875, 0x47c5a37a, 0x2f2a46b9, 0xe2a79e14, 0xa3807e3c,
	0x57fcc5c6, 0x7a0ae038, 0xa7ab49ec, 0x46cbf806, 0xfb0712e7, 0x59c24325,
	0xd612de2c, 0xf27767c9, 0x5bc83368, 0xd607e290, 0xff5d3f3f, 0xc3dd7106,
	0x812e3633, 0x10b54bc1, 0x72fd37d8, 0x92ac1b09, 0xbf78fe60, 0x9afeece1,
	0xbeec397e, 0xcc712dcc, 0x286ad97e, 0x3c96b49f, 0x0512f301, 0x7ce737e2,
	0x5401b877, 0x153e4388, 0x3e01d4a7, 0xce0a452c, 0xdc45c323, 0x8677a51c,
	0x6f20e410, 0xe65cb122, 0x7491fc58, 0xfed23fee, 0x3ce58a32, 0x818c8fe0,
	0x668dcf04, 0x83149d80, 0x89c6af4e, 0x6f5ecfdf, 0xe60e72e8, 0x9a7e5555,
	0xa4df3a25, 0xa60e7662, 0xc143ee23, 0x3ab6fc07, 0xb6c9c0ee, 0xacfb605e,
	0x678604fe, 0x0406ffa3, 0x6a097983, 0x08897efd, 0xaff444d6, 0x7ebfc0fc,
	0x2bfd0593, 0x4107711b, 0xc7147edf, 0x39ebb3e2, 0xffa806f7, 0xc0b7685c,
	0xdc9a3f3d, 0xc8f0f268, 0x02dddb84, 0xe379d57d, 0xfbe0e1d9, 0x0f78b952,
	0xe13adcf0, 0x3875e0ec, 0xc64cf693, 0xcbaf0a77, 0xd7e8d7b7, 0x67e8ea28,
	0xb44ab885, 0x4348779e, 0xe56f6ec0, 0x57e0dce2, 0x31c3deb5, 0x7a8b3978,
	0xcdd0411e, 0xfcc6cd33, 0x7f553691, 0x0b2e3dfe, 0x4f5b51f9, 0x6036fce8,
	0x8f30d7fc, 0x86a8738e, 0x73c6a773, 0x1dd969a9, 0xcc74a071, 0xe0912dc7,
	0x3672332e, 0xce3b4364, 0x24cf6ceb, 0xa64bce31, 0xcf31ac46, 0xc5256b05,
	0xb780d7db, 0x012ab154, 0x5dea71f4, 0xf1188f4c, 0x47f9c6d1, 0xda3ec334,
	0xf998c41f, 0x96995a28, 0x12c26b76, 0xfa5a7efa, 0xe7b52c14, 0x66217675,
	0xc6c9315c, 0x9373bf7d, 0xf062c475, 0xb46c9337, 0xf79ed3bf, 0xfc50543e,
	0x5eee31db, 0x5ef0c717, 0x5ef0c717, 0x94f86927, 0x3afe41e3, 0xde5d6eeb,
	0x259f46d3, 0x443c8041, 0xe7ca3a7f, 0x77a31752, 0xda0afbe7, 0x32887d37,
	0x89282e65, 0x8ed9228d, 0x43e2cf7c, 0x5f90f9da, 0x804d9efa, 0x2db7297c,
	0x2df7f54b, 0x0c09be8c, 0x271bf3ee, 0x6429b8e3, 0xc53075ad, 0x9312b2f3,
	0xa746e21b, 0x09c9fd17, 0x6517a647, 0x3c82e4b4, 0x48f9c2a4, 0xde69defa,
	0x267986e3, 0x954551d7, 0xe402f8c4, 0x0a69d292, 0x342e77ee, 0x1ebbccc5,
	0xa7fb6363, 0x585ce347, 0x434da5a6, 0x8bd6753a, 0x312fc013, 0xd79529f2,
	0x3aa325f4, 0xbe5331cf, 0xe4316c51, 0x8d244dad, 0x616fae1c, 0xc6b257c4,
	0xd6deaace, 0xe41925e4, 0x4aadf610, 0xe8d51ea8, 0x357d403c, 0xf8a2e305,
	0xf8de85c7, 0xe70dfc1a, 0x17a8f98d, 0x43223935, 0x82b79e98, 0x878a8dde,
	0xd47d35b6, 0x3f1df61f, 0x0e73b7f9, 0x8bfa77d8, 0x3d00eed0, 0xf7befc7b,
	0xe98e701d, 0x5c58fb93, 0x9f836ee4, 0xf4c6d8b6, 0x64ada37f, 0x816bcc1e,
	0x9eb91fef, 0x6b257e28, 0x3dc9fed8, 0xde70de01, 0x506f7f5d, 0x70c93045,
	0xf11f908f, 0x8ec4215a, 0xb1b26feb, 0x3b3dcb78, 0x321948b6, 0x8729ef8c,
	0x7eab8ff1, 0x7606f1e8, 0xcf06957f, 0x24231da2, 0x12fecdf0, 0xeffbab32,
	0x3f5b222d, 0x3fd86294, 0x3378a8f3, 0xdeacd9c2, 0x71f4bdab, 0x90b31f96,
	0xea86b58e, 0x9d884f61, 0x63ce30f7, 0x617227e9, 0xd2de252a, 0xbbf43907,
	0xe8fbfde1, 0xf359e67a, 0x19b3ee00, 0x5ef5d9e7, 0xb3fd051f, 0x8dbd2ae5,
	0x87976de7, 0x12f83ed8, 0xecf941e2, 0xc436fe72, 0xe318c5ce, 0x660f678d,
	0x3f0f00db, 0xc4f1a9b7, 0xce06325c, 0x383aef6d, 0xf74afe20, 0xef529f56,
	0xbb7b828b, 0x23ee3ca1, 0x2303ce58, 0x3cbbe290, 0xf0216ef4, 0x4ee36557,
	0xdbed0fbc, 0xd08aa3ea, 0x52e42709, 0xda897a6b, 0x8e81dba1, 0xb3a70964,
	0x9cb72b4f, 0xcd5f9893, 0xfaa773f0, 0xc7c04efc, 0x96f7c870, 0xd2813a7f,
	0xf172cefb, 0x697df47c, 0xfbf4d82f, 0xaf9dbdf0, 0x750acf36, 0xbf9b4aff,
	0xa9e7ef91, 0xdb64b87c, 0x297df5f4, 0xbe9a6a4a, 0xc5cf54c8, 0x8d20f9e1,
	0x929396af, 0xfc18f4c2, 0x83b3d1a3, 0xc33f424f, 0x5c7468f9, 0x9d50bb52,
	0xdd4d3fb7, 0xf8834c3f, 0x7a6f9194, 0x2add973a, 0x9e413246, 0xdad17c8d,
	0x7b27fdcd, 0x589ecc6c, 0xa0852b22, 0xbbb9a937, 0xcf6515de, 0x9b6a171c,
	0xb672027f, 0x8779f18d, 0x182703de, 0x225bf9f4, 0x1d2bf7ae, 0xf7dc2a72,
	0x071af487, 0x3f6608f9, 0x738da7bc, 0x0328a7cc, 0x1177c045, 0x257d2796,
	0x9d41c0ca, 0x9d36cbed, 0xddbd8273, 0x9c608436, 0x87a1d5a8, 0x8f1b4bf7,
	0x954be27a, 0xcb42e51e, 0x1d067f37, 0xf305adb5, 0x525d8e2c, 0xcc974ce3,
	0x29e6b145, 0x4a3ad9d9, 0xeecd7bd4, 0xf34ee556, 0xf4a81663, 0xf6c43bbb,
	0x9e6d17cf, 0x92e8f48e, 0x3ffaa96f, 0xd4381b0b, 0x2cfa4633, 0xf98cdf75,
	0x79038b67, 0x7a177df8, 0xee918791, 0xed79ba46, 0x9b6f762e, 0x3dc12550,
	0x7336c776, 0xa2b8dfb8, 0xcb38bd1b, 0xf356fa6e, 0x3ba3ce31, 0xab6f97f8,
	0xc097df5e, 0xc04847fc, 0xb5f846e7, 0x0a252ff9, 0x7cea4bd3, 0x89179bbb,
	0x32f2c4dc, 0x1efe75d4, 0xfb02a738, 0x2cf30f25, 0x3b8d5b7f, 0xf06bf069,
	0xc851e71a, 0x8279e397, 0xf31e3ab6, 0x07f6efb0, 0x09efc3d6, 0xc38ebddc,
	0x3a3bb6f5, 0xdb447a69, 0x5c6ca9df, 0x1e5a7988, 0xadd80fda, 0xb6131f6d,
	0xc381b12f, 0xa5badd7b, 0x27e58867, 0x424f4775, 0x5096dd18, 0xd9bf81ba,
	0x3c84bef5, 0xbef46065, 0x328a6050, 0x8a9f7a30, 0x653f3104, 0xdd74fd45,
	0x5ebb22f3, 0x7f24f78f, 0x66212aa4, 0x37934b3c, 0x7934fe4d, 0x6665daf4,
	0xe6810a5f, 0xcfc02c8c, 0x50cfe8a3, 0xaec73cfd, 0xa5cc4bee, 0x3a6e54af,
	0x5897dba7, 0x6bd1963a, 0xcf8c5f29, 0x14b3d3bb, 0xbd3d3a0f, 0xbbcfaec8,
	0xd1f3bef8, 0x89c9a1e6, 0x9ca33f36, 0xd237bf18, 0x19e78b43, 0x07a462e9,
	0xc57e09c0, 0xc0b64ddb, 0xdbe70a5a, 0xdfdb831c, 0x5bb84564, 0x702926d3,
	0x7d32b34e, 0x807f963e, 0x1ec1d30f, 0xa3b6a92c, 0x5dfaa87f, 0x87177aa3,
	0xb0ed51c8, 0x48caad97, 0x24a9ce76, 0x6264f809, 0xc5866475, 0x0fa3c845,
	0xf7085cdf, 0x347c4fed, 0xef420332, 0x853c3f8f, 0xde47b7d5, 0xfee1b8b7,
	0xf10b5bfe, 0x2fd07dfe, 0x52bf7e30, 0x6ddf7c1b, 0x5cae789d, 0xa3fbd997,
	0xd9f325cc, 0xbdacd5bd, 0x1663da9c, 0x1f95deba, 0xc81afc1a, 0x714b796f,
	0xca81c411, 0xd74ee221, 0x19c50abb, 0xeb670db6, 0xdefa78fc, 0x1b679b61,
	0x75c5d7f2, 0x1f962eb8, 0xc8be5012, 0x158f1641, 0xf4ad5ce8, 0xd47175bb,
	0x5df8a62e, 0x83716897, 0xfb9f4c1f, 0x975e3fc1, 0xd472c8a8, 0xf07e8d73,
	0xceb1c01d, 0xf607f2c4, 0x3e3839bd, 0x603b0572, 0x83148f9f, 0x67c072ff,
	0x9ed8d2c1, 0xfcf0b927, 0xc5899e46, 0xefed8c47, 0xc8987a68, 0x9517c019,
	0x7f942507, 0xb37b03f8, 0xa9393082, 0x59dcec24, 0xe78221c5, 0x160f2a6c,
	0x381b39e2, 0x4ea9f087, 0xce6bfc0f, 0x15f274d9, 0xc0be53c3, 0xe3510b15,
	0xbaadd816, 0x1a6a9f3a, 0x7c21f302, 0x89ce1b9c, 0xaaa619f0, 0xfcfe745d,
	0xf8a4b455, 0x1e6e5c10, 0x9da99bee, 0xfb879134, 0xfbd46ab2, 0xec4c6a68,
	0xde36bc3c, 0x5a3f1551, 0xf251d7d9, 0xf4fdd029, 0x36b92d3b, 0x7e827fb6,
	0x1adf36b4, 0xf81c214e, 0x3c13af67, 0x4c9390bf, 0x6cfe000e, 0xfc0b1944,
	0x55123926, 0x6bfdb37c, 0xa50197fa, 0x8dfa6cdb, 0xaffdf94c, 0x10b8ff0f,
	0xc77609ee, 0xd165569b, 0x8fbb65fa, 0xe74c33d5, 0x730b28b2, 0x5fab3f0e,
	0x80373a67, 0x354779d6, 0x2b46c3ab, 0xc744f85d, 0x50ff42da, 0xf7e54718,
	0xc075ca1d, 0xc58982df, 0x12fd8471, 0xf968e7ee, 0xcf28eb29, 0x0e4a3f00,
	0xaa65c599, 0x41b79ff3, 0x915f3c9c, 0x8f625f21, 0x77d1ef7a, 0xf2bc352d,
	0x07de1336, 0xdfe02506, 0xd4f860e1, 0x941a42e8, 0x976f20eb, 0x60eb9504,
	0xc3afaf1f, 0xfec072e3, 0x132ddbc4, 0xbc379f41, 0xbc5ca7f7, 0xd62afdbf,
	0xa9b7c8cf, 0x73e748cf, 0xb7fdb7fa, 0xf78bef44, 0x81f5e475, 0xd01928ef,
	0x1764e57e, 0x61ca93b9, 0x2964428d, 0xbd6bfc1b, 0x9840d93f, 0x2b6c3a7e,
	0x7d40efe9, 0x6c75c612, 0x4323dd8d, 0x9327e8dd, 0xe55ec496, 0xd7c349d9,
	0x6250fee0, 0x45e1e346, 0x8efc2eb0, 0x29c24bdd, 0xbe9be60a, 0x1b3f71d4,
	0x8d9438c1, 0x4e21b9c4, 0xcd24dc4c, 0xd3c6a29f, 0x92af8c4c, 0x65fca373,
	0xfbf43e75, 0x1f8bc802, 0x0cf96363, 0xe83c7e74, 0xc64411d7, 0xc5c42472,
	0x1ea481b2, 0xc121efac, 0xfda13fc3, 0xf165663f, 0xd13d4b28, 0x38171bc5,
	0xc1ba5d98, 0xdbfbb229, 0x60ede0c4, 0x219dc457, 0xda2bb02e, 0xb8092d7e,
	0x6eb82f1f, 0x66ba7dc5, 0x9fb5c613, 0xd82e0311, 0x46bf6a1f, 0xce92b790,
	0xba54dafe, 0x263efd6b, 0x9c40d7c9, 0x564e67ef, 0x608f267f, 0x09fb76de,
	0xb7fb0029, 0xaa961989, 0x1cd1f8e8, 0x9b77b307, 0x3bb7f95c, 0x14dd9e20,
	0x31fc6047, 0x404ce37b, 0xe477e78f, 0x5e2f8158, 0x3c511c02, 0xf75d9a24,
	0xe7897f42, 0xf859bc28, 0x0bf3e59c, 0x8a7888f2, 0xd8b7f1df, 0xeb37b865,
	0x16f06b19, 0xc17d53cc, 0xbf04f784, 0x43a7b924, 0xb2b3a5fd, 0x33f0f40b,
	0x9c38c159, 0x9c260bcf, 0xed714bcf, 0x70a4aed7, 0xc584343f, 0x111b04b7,
	0xa60b3f40, 0xf05ef97c, 0xd63e5453, 0xaa13f5f4, 0x11c63d1c, 0x9820b73c,
	0xb48e50f2, 0x76b6a1fc, 0x7d43f982, 0xc0f0b666, 0xb5d371cf, 0x87985338,
	0x1284d0f8, 0x04dcf682, 0x5ae788bb, 0xce197f20, 0xf5544db7, 0xcb8fc4f0,
	0xb03e598b, 0xe3dc10fb, 0xdeaec079, 0x6beea607, 0xc9f2a4de, 0x5bc2248d,
	0x178dfb68, 0x059c3b89, 0xf7ebe7f7, 0xd8369e1f, 0xfed59397, 0x01577695,
	0x7a23ce3c, 0x5d726ffb, 0x0f5809e1, 0x002289f3, 0x18b24d3f, 0x748ec1da,
	0xfafbbdc2, 0xaa1c1be7, 0x324994bd, 0xb4d6f3a3, 0xfcc9a77d, 0xbf684dd0,
	0xc06e4916, 0xf2bb4ecb, 0xf803e411, 0xa572445b, 0x3ed3e438, 0xe4385f96,
	0x15c08da2, 0xed3f9485, 0xeb6b9f30, 0x3a56fd6a, 0xb2076bef, 0x410f81fe,
	0xebfd5cbf, 0xf7d024e4, 0x697a5563, 0xc077c6a5, 0xc678ae5f, 0x3bebae5f,
	0x83bb73e5, 0x7934f3c5, 0x7e83be03, 0xf98188f6, 0x29b7f6b1, 0xbd076ebf,
	0xd04ed3b1, 0xba69fb8f, 0x99c80e65, 0x9529ce36, 0xfae58daf, 0xe0fb95ea,
	0x17fc9e77, 0xd051bad8, 0xbd14a2f7, 0x302527ee, 0xd72bddff, 0x790698ce,
	0xf3117667, 0x73d452ca, 0x92fcd150, 0x1a2fc51e, 0x59dab5df, 0x9fe3485c,
	0xe7dfbb49, 0x0ba4f9e1, 0x48b2b884, 0xf1a2bf87, 0x187f44cf, 0x12277df7,
	0xf9189fe6, 0xfc375767, 0x165e7793, 0xe1756f40, 0x7f8c839f, 0xda1be3ba,
	0x6163de0f, 0x87169fe4, 0xcb743fea, 0xfcf0973f, 0x49a6eafe, 0x6c9fdc57,
	0x51f3e9f4, 0x5b38e58d, 0xa7657cec, 0x52ddf78a, 0x41c3aded, 0xb1354c6f,
	0xc9027af3, 0xbbc29db8, 0x27bb4e3b, 0xea1b2abf, 0x87a6053b, 0xa8cc8676,
	0x3dda7687, 0xa6d78c1e, 0x5579d859, 0xf38113c1, 0x16beee07, 0x4777fa39,
	0x71b0769e, 0xdc786282, 0xbf8f6017, 0xec60f8c9, 0x521e1cd4, 0x3097d2cf,
	0xb8ea30bd, 0x6f7e05b4, 0xde6751ee, 0x298bd039, 0x8be03b80, 0xabde12a3,
	0x42547954, 0xbddbf8fd, 0x3c4216ef, 0x1e6bcb54, 0xc2dde7b3, 0x3b3f887c,
	0x5dfdbf19, 0x8ead3be5, 0x5f403e47, 0x1fd9ee1a, 0x4afe71d7, 0x097e4f7f,
	0xcef0d1f0, 0xf1fde376, 0x5fb638c1, 0x22c89b32, 0x68e3310c, 0x9d70fdc9,
	0xf91ef199, 0xde7661d9, 0x4f21e66d, 0x55e47bec, 0x67de30fe, 0x64efed4e,
	0xcfdfd827, 0xd085ecb7, 0xbad99108, 0xaeaa941d, 0x55467e63, 0x2693f036,
	0xf147f887, 0x8864fc17, 0xe60c77ee, 0xc3d1eba9, 0x47dd816e, 0x1f709115,
	0x7d8467f2, 0xb1d75417, 0xbe16671c, 0xc5fab397, 0xc8e700f9, 0xd000e552,
	0xe3c5dea5, 0xb0939ff3, 0xe6e81b25, 0x24ff7016, 0xbe93ca28, 0x23df3ae0,
	0x3b10c942, 0x27d3df6d, 0xff8c246e, 0xda33d3a8, 0xd0a07609, 0x1bbe107e,
	0x24673e33, 0x88fb71e8, 0xaeb04975, 0xb8537069, 0x3bdbb68a, 0x1ae0d0e1,
	0xf2fc64e0, 0x68e173a8, 0x077c03c0, 0xc8f1a97a, 0xaf7c0b31, 0xe9b043f1,
	0x2883e30c, 0xe83e00be, 0x016e0be4, 0x4c3c35d4, 0xab41f954, 0x42f9b3ff,
	0xc8f46b8b, 0x70b71017, 0x98be277e, 0xf235780d, 0xeee7b505, 0xe7b0c676,
	0x93cb1282, 0x635f3e34, 0xddf7c3cf, 0x273cc112, 0x7ecad7b2, 0x8093d0c7,
	0x71bf1efb, 0x3edb31b1, 0x4d499639, 0x93af7251, 0xefdaf5d9, 0x73088ca6,
	0xa08e7f68, 0xb44ee28a, 0x9ea1faf3, 0x23f8ab74, 0xee0e38c7, 0xf85cc517,
	0xc343b00c, 0x8daf6049, 0x41871730, 0x26d9761e, 0x98fd8066, 0x0d909b63,
	0xc8657ff3, 0x4960b7ea, 0xe96fa57b, 0x9dc9b66f, 0x0fa695f6, 0x6adda80f,
	0x6c9dfbe3, 0x6149bb7d, 0xaf409be7, 0xada1c347, 0x8026400f, 0x36cf0b83,
	0x1ea1b65d, 0xde28450f, 0x2838026e, 0xa471f61e, 0x3c87ec01, 0x093c9293,
	0x613ec0ec, 0x6b6ce001, 0xe2133afa, 0x37a1c59d, 0xc5bc030e, 0x5babbeda,
	0xb46aefbf, 0x487b35b7, 0x7b343ff3, 0xc17bf349, 0x05f682ae, 0xfc1773ea,
	0x6fac0ace, 0x9fde0b61, 0xf959d8f0, 0x6795451a, 0x58a3ce81, 0xa46dc79d,
	0xeed2e105, 0xe2a6994f, 0xf520f8a3, 0x3b438757, 0x1e295321, 0xa7f7aaa6,
	0xefeb754c, 0x6c6db887, 0xb453fbec, 0xdf7a7a7e, 0x60dc6eb8, 0xbefa7fd8,
	0xbb1f41e5, 0x3ef7e52f, 0x1f8f0fe6, 0x5805fbc0, 0xb166c77f, 0x0c5c26fb,
	0xd8a5070f, 0xaa57d8eb, 0x45378f3c, 0xebf9c386, 0x8efe7b7d, 0x3dfee6eb,
	0xec10ff7f, 0x042771c8, 0xe3b87902, 0xc78a8c4f, 0x32b1807c, 0xafd695f2,
	0x1b06f3f7, 0xf449cf61, 0x5334cbef, 0x01ab9478, 0xaf960b3e, 0x17ec7a9e,
	0xa3f9dfd0, 0xe73e8902, 0x06792851, 0x50be5c42, 0x66a19dfd, 0x5a53d98e,
	0xfbfab37b, 0x6a717f1e, 0x411688f1, 0x1cc557bb, 0xeaa9e745, 0x5d1a1f7d,
	0x3a2f1ea7, 0x4aef0c21, 0x67fbf81f, 0xf8b421c4, 0x2f5519c3, 0xc47f0392,
	0x373738f3, 0xfd802bdc, 0x4f1a737e, 0xa771a894, 0x8fd3d4c8, 0x771c438a,
	0x03dfec1a, 0x1a62fecf, 0xcdbf29e4, 0x37a3ca63, 0xe1adf3b4, 0x63e16f50,
	0xc462a3de, 0x7ba1cdef, 0xd9951ef1, 0x7a3e4cf1, 0xb5fc7f1a, 0x07ae4f94,
	0x076613ba, 0x487bb2e6, 0xbfddf48c, 0x22923fe7, 0x77c7bb43, 0xd237f477,
	0xf953d5e1, 0x13d56fb8, 0xbb7c8c3d, 0x7fd3ce97, 0xaa4efc35, 0x77f1f885,
	0x7f585d52, 0x758697cd, 0x4dbd5f8d, 0x9d81254f, 0xe4e9f1a7, 0xe337c624,
	0x8922ff76, 0x65e93bd8, 0xf175dbc4, 0x5b2f7e8c, 0x3dc4bb35, 0xf47d1a6b,
	0x90875d3e, 0x05a4fd51, 0x544ac4f2, 0x2a1f6758, 0xa884bb44, 0xeb8c57e7,
	0xcefe6cdb, 0x7b4ea0c9, 0x999f9dfa, 0xfd5ec2f2, 0xdbd14e3e, 0x83ac02b5,
	0xa66ac285, 0x5e3b54c7, 0xe748c783, 0xc209480f, 0x467c1ddf, 0xf9c2303e,
	0xbd7e4772, 0xf681eb82, 0x063337bb, 0x31898966, 0x63e1a1e6, 0x71eba126,
	0xe3d7ef76, 0xfdbd78a2, 0xc178ee7e, 0xeed6803b, 0x3748cde4, 0x3fa6bb63,
	0x1c80610a, 0x9f60fd2c, 0x414f8ecc, 0x28bc2879, 0x25f20511, 0xf1cfe9fa,
	0x91abe293, 0xd8b956df, 0xadf8eeb3, 0x3c4f22f2, 0x4ef93b23, 0x06d47c6c,
	0xa85bb77c, 0xf51c41b5, 0x1af4fb46, 0xcf82bd10, 0x7de267f3, 0x81131115,
	0xd0e4dad0, 0x67100399, 0x78261ef0, 0xb43f219e, 0xe9f0126f, 0xfa0b426b,
	0xa9e76d59, 0x776516ad, 0x6c6a8636, 0x26359760, 0xcd78f3b3, 0x2f974409,
	0xafca95fd, 0x4ecf478d, 0x0fb46253, 0x3e7d3173, 0xc3c92883, 0x370b3fe9,
	0x3f00fe50, 0xe3038fb8, 0xfb9c0524, 0x5bb064f5, 0xb1fbb2e6, 0xbcc69adb,
	0x6de14c9e, 0xf5012bbd, 0x07c6e4cc, 0x425175ee, 0x1231ff04, 0xe42fb79f,
	0x4284bef0, 0xc2f58dd9, 0xf7e85925, 0x6926f98d, 0x4fb43146, 0x99efd111,
	0x100b97cc, 0xc69d3aaf, 0x7b1dd5e1, 0xfc3548b8, 0x3a7fb0fe, 0xfcb8871b,
	0xbe9fe049, 0x02349c57, 0xd64f237f, 0x77f083ea, 0x7fc18916, 0xb9f2fd5b,
	0xbeda667d, 0xf987167a, 0x195d93c5, 0x3fc51fc4, 0x9c241b85, 0xd4a1edd7,
	0x19ebe07c, 0x8e73fa45, 0x9c9ed561, 0x81236255, 0xce48fde8, 0x6cdd7285,
	0x7f03bf6d, 0x2449bc37, 0xce4d3f30, 0x7df9516f, 0xdd249cf6, 0xb309d377,
	0xbab9353b, 0x5bbf9555, 0xae79bf54, 0x7e374327, 0xd0f66109, 0x017b481f,
	0x2ec7ec90, 0xad3d1fb6, 0x7cd0e5bd, 0x37ef8978, 0xade1f41a, 0x2f7e0c43,
	0xf90ebe5f, 0xe3738d22, 0x7d6e31bd, 0xf5636dfb, 0x1afca375, 0xc82cc3f5,
	0xeabbe3da, 0xcc1f4d09, 0x8845e26a, 0xa3cacd07, 0x58bb4678, 0xa4f7b76f,
	0x75c4c62f, 0xc92e2fa3, 0xd21983f7, 0x5c7c5f45, 0xc5f49df4, 0x32dba96f,
	0x3bf5ca96, 0x4fe8de9a, 0x98de83fa, 0x05f8efcc, 0x5d1b51f0, 0xf831cd37,
	0xb4775b48, 0x95214038, 0xa703d463, 0xe4cc7ed8, 0x3fc4e98b, 0xd00e33b2,
	0x5da847a1, 0x2f618ee2, 0xd6cf8a9d, 0xa1d24fdd, 0x12eca257, 0xdbfbf731,
	0x3da99325, 0x7c00e52a, 0x42be10fd, 0x42921ef5, 0xf882b048, 0x8c19da61,
	0xea057903, 0xfcfae2cf, 0xf473d314, 0xa7625c5f, 0x15ed187c, 0xea5d0e2d,
	0x3d29ecd2, 0x23c474bf, 0x577bb267, 0x04293e35, 0xcffc827c, 0xc09f71e4,
	0x1bff37c8, 0xfa32ca23, 0x00008000, 0x00088b1f, 0x00000000, 0x7cbdff00,
	0x55547809, 0x753eeeb6, 0x2a490d4e, 0x62c65549, 0x4a61270a, 0x0843c048,
	0x91602018, 0x520c6201, 0xad0e2280, 0x210c0e05, 0xfaf5cd09, 0xe76f6dba,
	0xd11a0484, 0xfdb1c5af, 0x15fbbe9e, 0x2b8fbd5e, 0x30188a41, 0x015b9260,
	0x06d88081, 0x9f3e01c1, 0xa88d2a5d, 0x6e874921, 0x3efdd82f, 0xef6b5ade,
	0x8a555493, 0x77befa6e, 0x66f6d25f, 0xf5af3d9f, 0x610f69af, 0x4cd9532a,
	0xf83096c6, 0xb05b1951, 0xd3dcc2d5, 0x7f36ef21, 0xfa31b415, 0x05ff06b9,
	0x635e1262, 0x33739889, 0x5dd8c696, 0xbfb2fea2, 0xf3f19ba8, 0xfaf0f2b2,
	0xdf85b177, 0xdd8c094a, 0x3666bcc1, 0x3d3bb18e, 0xff4fe591, 0xbbf28641,
	0x4f7f8456, 0x5ca7c471, 0x8c7f8388, 0xc9afe367, 0x4dc9958c, 0xc05edfcf,
	0x5949df58, 0x266af2b3, 0x0751ff1c, 0xf6d1ff1f, 0xc7967492, 0xc53dbbd8,
	0x8f485e89, 0x270cc1d6, 0x6755d631, 0xe404f4a3, 0x1af0d07d, 0xeb02dcfe,
	0xdfaf30b3, 0x94f6290e, 0x92cea94f, 0x80e09b18, 0x7f21534e, 0x0c9fd605,
	0xd863a365, 0x5e62d9d7, 0xc91d8c59, 0xa0fb9736, 0xa7f4075d, 0xe801bf43,
	0x0f7e875f, 0xff2839d5, 0xf28b9d5e, 0xf5129ca3, 0x13089353, 0x4558c19c,
	0x2f769dce, 0xc8e35bb4, 0x9cab3ca2, 0x1b7a4264, 0x797b2ff3, 0xde81d334,
	0x14ab8247, 0x5ab18529, 0x3359a497, 0xab00f887, 0xfa84afb1, 0x35de8295,
	0x83e6255b, 0xaf9f95ef, 0xbf4064af, 0x0f1876de, 0x2a5b53e8, 0xcff06cfb,
	0x9f67b692, 0xb33379e7, 0xf886d44a, 0x852f88bb, 0x153a57cd, 0x58b38c1b,
	0xc6193493, 0xf6f1b771, 0x9f25bbb7, 0xa45cff0a, 0x23a3f385, 0x44cbef82,
	0xfff18b3f, 0x72e2dda0, 0x7e8017c9, 0xb7861716, 0xc165765b, 0xe1d4d2b7,
	0x7c865a38, 0x2f1c3a9f, 0x8fbe0ccb, 0xef916365, 0x7e962f97, 0xf10d9538,
	0xe48d322d, 0xf5f96473, 0x6feabcf8, 0xff68d9f0, 0x11bcf8b7, 0x3cfc8269,
	0xc6a2d57c, 0xedb0b633, 0x79f20aa7, 0xfa8515e1, 0xe4f5c6ad, 0xcb067942,
	0xb1fcf5c0, 0xdb99ff27, 0xdafd50d9, 0xbc583fb6, 0x9ebfae53, 0x37be35bf,
	0xe075a551, 0xa1bceeb8, 0xc0142b71, 0xb6f3ac20, 0x46fa70ec, 0x5f9235f2,
	0x48bb444b, 0x58896d7e, 0xd617c187, 0x111a2003, 0x6457ee85, 0xf8f5c79a,
	0x8b17c836, 0x3796bc77, 0x7fb19cbc, 0xf50eba21, 0xbac4f827, 0x3e14cf15,
	0x3c88732f, 0x44f5ae00, 0x17656fe0, 0xc4c2c40b, 0xff2c5d16, 0x9354c156,
	0xeb2157d8, 0x0caf9fc0, 0xfd43cb3e, 0x41195d97, 0x5b8c67f2, 0x92dd30a6,
	0x5cb9df8f, 0x06afce46, 0xf58099fb, 0x96ffa275, 0x7e15a61d, 0x0b5cc758,
	0x6983c07b, 0x1c5b4f2c, 0xdfb7f512, 0x7d7aa261, 0xd899b27f, 0xe9ed8c4d,
	0x30662f48, 0x78eacd3f, 0xdfa2f51f, 0x7e7da8cc, 0xe6e7e702, 0xc0c7a678,
	0xb6e94cf8, 0x4a270079, 0x20d96331, 0x8b48ca67, 0x6cba01af, 0x941e0252,
	0x614d3ebb, 0x537720f5, 0xb38c1db0, 0x2f7e90f9, 0xfe6c9603, 0x21a9a26a,
	0xba07db13, 0x9bbd40e7, 0x1b7515f3, 0xd55a7154, 0x6f79629f, 0xed81d5bb,
	0xb7fc0efa, 0xf3f6334e, 0x0cc1a627, 0x00ed7bd9, 0xb22f282a, 0x37a87d9b,
	0xb293e4ca, 0xfd7df209, 0x2a3ea18c, 0x6128115a, 0xacb9b7c0, 0xe901c1bb,
	0x1463e46c, 0xf5c55dfe, 0x6b7ae0ce, 0x9e69f004, 0xa13cd3e0, 0x65da4aaf,
	0xf1251bd2, 0x0e658fb2, 0x045ba7e9, 0xdde9e68f, 0xee308925, 0x1ad2453c,
	0x15cb7f20, 0x6f8f0c25, 0x69ba3ea1, 0x89951f48, 0xaafdddfe, 0xcd819602,
	0x2df8e167, 0xa87ae56b, 0x5df116c4, 0x49681fd8, 0x84732ab8, 0xdd46cf97,
	0x60bef809, 0x25e85fe0, 0xca7f6116, 0x0424bfe4, 0x2c7b0e81, 0xc0e74fee,
	0x994ffbbc, 0x9df06bd9, 0xaccc845d, 0x8d69f4e1, 0xe99147b0, 0xb7588e81,
	0x83daf30a, 0x7e63b238, 0x7a9d5ba4, 0x8353fafd, 0x8cb8c5fd, 0x154b4d3d,
	0x3cb04596, 0xa21b4ae3, 0x0afa30fb, 0xb5d2443e, 0x7779e859, 0x543de3ab,
	0xd8e8c3c3, 0x79ec80b5, 0x05551fc9, 0x4bdfdf55, 0xf65e434f, 0x2375885c,
	0x185cf7fe, 0xf479c6e9, 0x1bdc73c4, 0xfce070f2, 0x51ea2c40, 0x00aaa7a0,
	0x369dfa4e, 0x33c235ed, 0x88ff0397, 0x906dbe89, 0x71cf1f3f, 0xffb627bf,
	0x7dd22e44, 0x0d7b4991, 0x8c365187, 0xf5053a5b, 0xe7a5d6e7, 0x6e498ccd,
	0xe40cfd26, 0xec1d5249, 0x9075483e, 0x9e9fc427, 0x27287cc4, 0x3867e666,
	0xbd9b836e, 0x22bce982, 0x3ee91135, 0xdb767d00, 0x11353fb1, 0x72fecf71,
	0xca67a679, 0xd737fa70, 0xe3028f31, 0x3cd9d4b4, 0xfd85e80a, 0xb7ca0e75,
	0x3d28b9d6, 0xba52a758, 0x9f84fde9, 0xeb50ffa1, 0x109478b6, 0xc49e52bd,
	0xd03cc3f5, 0x79af383b, 0x80e9f24c, 0x304f79bd, 0x03904792, 0xf90926df,
	0x1ec9eb05, 0x67f027a2, 0x67921820, 0x8ce34a8d, 0xe20a9234, 0x89ae7e7b,
	0xe01383da, 0x7873237b, 0x587fe07d, 0x5bf0b97e, 0x4bba77ee, 0x65be909c,
	0x813994f7, 0x5dd2cdbe, 0xca312f87, 0xcdefc42f, 0x25f2ddd2, 0x607a7fe8,
	0xd819fb3e, 0x18c0e98b, 0xdcfc2ba4, 0xd19ff38b, 0x1fc86169, 0x9f24ac30,
	0xfe7c86f9, 0x60174920, 0x6ba1143c, 0xb59da0a3, 0xda788032, 0x48c982cf,
	0x279b02f7, 0xb977e50e, 0x2dc1e393, 0xa092e9dd, 0x16a959bf, 0x3a55464d,
	0x037d33ce, 0x1533afd0, 0x9dfa8406, 0xd5a3699d, 0xb1db443c, 0xddbe50cf,
	0x26407b36, 0x09ee64c3, 0x74f3d886, 0xe503aaf6, 0x35dc7517, 0xbf5d23b0,
	0xcf49d04b, 0x50f8b15d, 0x4e9d75af, 0xce3002d0, 0xf2362bdc, 0x21b19b2f,
	0x6c476dc8, 0x33d254c2, 0xa0c3413b, 0x3af8d8fc, 0xebbd9a16, 0x02dfa49c,
	0x76803f87, 0x18c03eff, 0xddb9d7ea, 0x87e8cb9f, 0xd2729896, 0xc3cf3083,
	0x4c44a4d2, 0x425dfa5f, 0x13a7a51e, 0x1d3e907a, 0xc71538a6, 0x2d4eb8fd,
	0xf9780f1d, 0x8e958ea0, 0x587c7c07, 0x54f4a367, 0xd3d2839d, 0x0f4a2e75,
	0xe7e23943, 0xbe239408, 0xe639418e, 0xa639438f, 0x983f43ef, 0x9bb43fba,
	0x7de77e50, 0xcd305768, 0xd29e37bf, 0x2de27be6, 0x048e8eb8, 0x8f8c64d6,
	0x06c40a78, 0xfa06985a, 0x49fd2923, 0x9fb018db, 0x6914ef56, 0x293d2c1a,
	0xf20556fd, 0xf8cc2fef, 0xbca09ff9, 0x49e32928, 0x8ef7cc1b, 0x9396f6d3,
	0x6e7e2f90, 0xc47693ec, 0xa0b1fbe7, 0x990e9124, 0x9b20ddc7, 0x8c6951d3,
	0x59bbb224, 0x8d93e421, 0xa5ade67c, 0x25e58500, 0x64e65cc1, 0xb367d9ec,
	0x7d01b56e, 0xff79c797, 0xbd16f311, 0x0c74bcab, 0x40ee99e6, 0x3ecc9779,
	0x52d1f792, 0x7fb052ca, 0x82deec5b, 0xc07f10a4, 0x193efd2d, 0xb74cc3f5,
	0xc4299cc4, 0x6904df6f, 0x6f51bbe8, 0x20acbd8b, 0xc3b47009, 0x669e1329,
	0x9f6e4914, 0x1afcb87d, 0x579c66f5, 0x337f914b, 0xc4682e2f, 0x93b97174,
	0x37159ef2, 0x97fca237, 0xbed7afda, 0xe5bfda84, 0xc538d334, 0x628bd40a,
	0xd37a8d17, 0x7fe86401, 0xf58f1ff7, 0x3eb886bd, 0x87886de3, 0x332b997c,
	0x9a3a165f, 0x63b9de51, 0x1e57961b, 0xd2b92169, 0x133535e2, 0x9a5dd8a1,
	0xedf3e50c, 0x15401692, 0x6365f458, 0x243b9632, 0xdf36c90d, 0x0283ed3d,
	0x6b2f1f2c, 0x467f31f3, 0x7a40752d, 0xe73f995a, 0x985bd412, 0xa0d9a89d,
	0xcfc0e9dd, 0xe77e232f, 0x316bc767, 0xbe05c62a, 0xaf306a57, 0x157ab559,
	0x496cf1d7, 0x4aa3f602, 0xcdf2099a, 0x13fc97b7, 0x93d8a3ce, 0xcb0924c8,
	0xb1fa0a9d, 0x97eefd2f, 0xd7a80ea5, 0x9431219c, 0x9c81d39f, 0xf3fe71ef,
	0x18d562bb, 0xc5b35098, 0x9aed8a51, 0x1363922d, 0x58253de5, 0x56689f5f,
	0x4f7e80df, 0xf64713de, 0x3cc3f2a0, 0xde4e8bf2, 0x42ec8a33, 0xc54587e5,
	0x71349e98, 0xc3f2bdbf, 0x372a72ca, 0x952a00b1, 0x427f7bca, 0xfc97b6ed,
	0xfa0534b2, 0x93ac7f7f, 0xa9f00b74, 0x6bd10954, 0xd8499f50, 0xaa6adefe,
	0xffa529df, 0xbfd43cfc, 0x6f98979c, 0xa417f185, 0x2fd584c4, 0xcb0ced1f,
	0x511f8c57, 0xb1d884aa, 0xb0ccbcca, 0x5205edfc, 0xfa90f8e9, 0xb098a29e,
	0x6752d2fc, 0xfa90f8e9, 0x088e5477, 0x23bf2fcb, 0xdf3f2c33, 0x8feb8b34,
	0xca59563a, 0x94b2bee5, 0xd22ccdfc, 0x5e0ef943, 0x3f9418f7, 0xc7f9e504,
	0xef953fb9, 0xf80a7f04, 0x80bc7a52, 0xd0e380fc, 0xe20bcb0e, 0x59d31e84,
	0xda266bb7, 0x83e3f101, 0x8b17c85f, 0xf06efcec, 0x5f22a60b, 0xcc876ec1,
	0x6e1ed4bf, 0xb9639bc7, 0xbcce509f, 0x67e04e8d, 0xf9055779, 0xf5296557,
	0xf4860105, 0x391f6f0c, 0xcfa2506f, 0xec3887df, 0x966f4852, 0xef188e8f,
	0xfc9da978, 0x95dfe118, 0xb8c6568b, 0xa377774c, 0xc3ac637f, 0xeb7aff18,
	0xc88b9729, 0xeb5bfc2f, 0xa4bd905a, 0xfcea2934, 0x133f9037, 0x249ccf39,
	0x7f82af11, 0x57617e45, 0xf08bf912, 0x4fcd1293, 0x4a9ffc30, 0x50ce73d0,
	0x5297673d, 0xbeb94c96, 0xbdfa339e, 0x1837ff9e, 0xacf68887, 0x8df1a649,
	0x55df83f6, 0x9df7fa29, 0xca3e3f50, 0xfa2914f7, 0xebc3d7f7, 0x06d453cf,
	0x09f3c83b, 0xd23a6926, 0xa0aaa4fd, 0xc672566b, 0xd96988dd, 0xdd055ee7,
	0xf5e785c2, 0xf4e74c46, 0x615a4ef8, 0xcb66b7fd, 0x183fee2a, 0xbae4517e,
	0x7f7127d6, 0x3515c4e4, 0x66f2854e, 0xb8c38d5d, 0x3509f9a3, 0x66abe30e,
	0x38c72b37, 0xb4ce3dd2, 0x7710e301, 0xff90a42e, 0xf7d71249, 0x48ded15e,
	0x2f5eca0f, 0x5b6adfea, 0x93e8d7f0, 0xb7ed5cd4, 0xa04e2e20, 0xdc3797bf,
	0xf8a13bdf, 0x89de38ec, 0x4f767c27, 0x51bf3e88, 0x6083cf7f, 0x9538819a,
	0xa4faa13c, 0x09e316c4, 0x0e651fd5, 0x1a7e5867, 0x6ed03ffa, 0x58446ba1,
	0xccd55bbb, 0xc7e07ab0, 0xd43fa366, 0x0ad96160, 0xac5353ea, 0x245e7e86,
	0xeb10bf1d, 0x740eecd7, 0x453998a3, 0xec51bd95, 0xe9c25693, 0xc9fdf917,
	0x25cf1e24, 0x1cf5f327, 0x6bf3e24b, 0x99dc3d94, 0xf119ff03, 0x58879910,
	0x07f60575, 0x7710bb3d, 0x32e99c5a, 0xe76ce0b8, 0x2ab71573, 0xba6d6780,
	0x41c61fe9, 0xde73d0fe, 0x07f0155b, 0xb7a639b4, 0xdeff20b3, 0xf9792b73,
	0x66e9a64d, 0xd57fb18d, 0x0a5add57, 0xcf148af9, 0x7d7f106f, 0x0956fb66,
	0x926280f4, 0x50ca7e58, 0x0594fc5c, 0x16302aec, 0x0276e640, 0x3cace3ed,
	0x0189ae8e, 0x8bf587fd, 0xabd22add, 0x73e0c626, 0x3bed0d30, 0xd8466f7b,
	0x059c5c7e, 0x32fb41da, 0x715ff79b, 0x205b6abc, 0xf47d0541, 0x74b281e8,
	0x24b1c5c4, 0xf73fad07, 0xd42e39ed, 0x37af3053, 0x1fff5711, 0xe38075e7,
	0x8d5e7c38, 0x4f4e3e66, 0xda096e73, 0xc0b1dcdf, 0x5f88690e, 0xdf4a8af9,
	0x1580fc63, 0x2eddcff2, 0x706c6fdc, 0xd7f4345a, 0x535e218f, 0x106d3c6f,
	0x1c7216fb, 0x689c8dc7, 0xd217b0da, 0x7cbc0adf, 0xe2a6e388, 0x4b19fd38,
	0xd1cc0f00, 0x0a74b19f, 0x641e23cf, 0xfd1fbf39, 0xc49ffeee, 0x8f2f146b,
	0x17e2ffee, 0xbef4ff90, 0xc2ed0d5c, 0x9f4e58b9, 0x86acbe15, 0x59a7e420,
	0x9f70637d, 0x3dec9fd1, 0xc7bfeb8b, 0x78409bea, 0xc7886fb3, 0xa33725fe,
	0xf388c478, 0x2d539e20, 0xfffb86e3, 0x3665c7c3, 0xb35df3a4, 0x718d9d38,
	0xb436a681, 0xf2169f3f, 0x603cc6ef, 0x7c716ffc, 0xf3833e63, 0x641da360,
	0x5fdf180f, 0x43f115ea, 0xfbe76c99, 0xd137bfb3, 0x0a2d4abe, 0x3edfe421,
	0xcf38a26f, 0x602ddfd8, 0x1f599c7c, 0xb269926c, 0x14cefc3a, 0xa4d8295b,
	0xf6e28ab5, 0x444add19, 0x3b26ed5c, 0xbfb44739, 0x625bcbb9, 0xf0b3f4c7,
	0x7c44737a, 0x327cc85e, 0x82b34fc6, 0xb7ade511, 0xcffd837d, 0xddfe18b9,
	0xdcec2c92, 0x74323648, 0x88a363ff, 0x664e0687, 0x155e2225, 0xa0640188,
	0x599545bf, 0xfe90d261, 0x7a83a968, 0x3693d456, 0x719ca74a, 0xb4e3883c,
	0x27b001d6, 0x5174bea1, 0x94d5c86a, 0x3601ec33, 0x811c6435, 0x038e837f,
	0x4e3a719f, 0xa6ff660b, 0x2ee6f208, 0x43a9f333, 0xe82d9874, 0xc5196105,
	0xed170375, 0x1e669764, 0xbca3265f, 0xa6265d5a, 0x462fac86, 0x886a658d,
	0x4ecb8d9e, 0x82cbcb0a, 0xe1318d8f, 0x3174c7fe, 0x3236bc4e, 0x0fc33fac,
	0x3079f831, 0xfa174169, 0x6bedd327, 0x2c491fc8, 0xbfeb0acc, 0xbd3864e0,
	0x8dc799f3, 0x39f6af71, 0xe67eff23, 0xefcc2519, 0x276c0c28, 0x1e7e147c,
	0xf9f67dfe, 0x64dcfcf0, 0xc9156fb1, 0x93d1ebb7, 0x514dfd4d, 0x4f4fdfca,
	0x9e9c3ba7, 0xf4e1e5c9, 0xd384f54c, 0x38457d33, 0xc37846bd, 0xcd6a31e9,
	0x31f2b0e4, 0xf2c3f21b, 0x3b367f63, 0x18267eac, 0xb8fcd0c2, 0xf56115ad,
	0x1a5f6c27, 0xf2f49f96, 0x73f5613d, 0xcac2ab7c, 0xfbae7773, 0xc53ff8bb,
	0x3eac31bf, 0x57f4d992, 0xeb537ff8, 0xfde361e3, 0x9ffff157, 0x8b76e422,
	0x604edbd0, 0x1987ee2b, 0x0ddd0af6, 0xb6ce97d4, 0x3f715763, 0x69562f46,
	0x60af4a1f, 0xbd94035a, 0xd4247b20, 0xd480a36f, 0x8d1bd026, 0xf506b626,
	0x264daffe, 0xe4349fda, 0xf732477c, 0xf3247633, 0x29b3acfd, 0xd3ce225a,
	0x4ce7a7d0, 0x7ea03fdb, 0x1bea6c13, 0x814c7f64, 0x730e305b, 0x579fb4a9,
	0xe2a85092, 0x523caa3e, 0x70133c5b, 0x33293968, 0xe1ac8930, 0x201ff3e4,
	0x6ddb2e3d, 0x4e54e22a, 0xb768eaf2, 0x37fe5d60, 0xec057920, 0x6353da2b,
	0xe9d69f1e, 0x325e30ab, 0x1b5c2bf2, 0x15fd6336, 0x809fcdf7, 0xf7e0ec71,
	0x9557eafb, 0x742bd086, 0xf8a34b5d, 0xdcc94d47, 0xb9eb19ae, 0x0436aac7,
	0x64d3de61, 0x2ec1ffae, 0xbac32534, 0x984f49cf, 0x9ba59fb9, 0x3b02cfd1,
	0x4e01e749, 0x4237a870, 0x8f64389a, 0xa2006bd4, 0x1bdf1673, 0x4e5d212f,
	0xc3c61ac8, 0x6109c5bf, 0x646aa11c, 0xf436efff, 0x3a26aaac, 0x6035e643,
	0x0757f70f, 0x7a471a1e, 0xa0fdecf8, 0x67af0164, 0x463d7c2d, 0x0f428bfd,
	0x70f4277f, 0x90dfea0f, 0x3b35e87d, 0x3f478f9e, 0xf7366cfb, 0x67ef8dab,
	0xc639f992, 0x57ee6499, 0xd98ced57, 0xaf043e70, 0x58677ed5, 0xc475b6be,
	0xca7dd086, 0x5e3d632a, 0xacf5c149, 0xdd537217, 0x87b84c15, 0x1a7e5f91,
	0xe3b356e9, 0xb1fbfdf2, 0x8d3fa9bd, 0xc69d53db, 0x4653ebbb, 0x7f5dfdfe,
	0xe9fe6166, 0x9a66c9d7, 0x2f38d7d7, 0xe2439748, 0x072c1c00, 0xf4c4ef1b,
	0x9402d158, 0x901ef837, 0x8bb8bf20, 0x2d5f5199, 0x919a66f1, 0xf699a7f8,
	0x5a583ef1, 0xed4ab26f, 0x3a1e60ef, 0xfee4fea7, 0x37ac78ea, 0x0fd19fd8,
	0x6ffa0008, 0x73753a9f, 0xccdfee1a, 0x807fc895, 0xddf86cf1, 0xcda8df73,
	0xf18d7768, 0x4bde613e, 0x963e031f, 0x35fa8d32, 0xdc7867fa, 0xcf87a212,
	0xf7005859, 0x5673f473, 0x9f301bdf, 0x01c7e88d, 0xa7b6361e, 0xb7d07f93,
	0xbf763fee, 0x181ef504, 0xfe831c15, 0x7f75b9cc, 0xbab8889e, 0xa99965fb,
	0x9c4f1f80, 0x3f48cff7, 0x1f672e83, 0xe58f1cba, 0xae1097e0, 0x86ab2ed8,
	0xdd6e7272, 0x7ea189ae, 0x3e6539bf, 0xa2e7414b, 0x39ea3930, 0xb97c6445,
	0xe7fbe2ce, 0x4eee51c7, 0x033fa998, 0x3e056b9f, 0xe9aa6637, 0x18dcf8a1,
	0xf24f883f, 0x21be374f, 0xd8d95e93, 0x3ee7431e, 0xd45c0b1f, 0xd6fabaee,
	0xb8662ae3, 0xe035f85f, 0xfe5c0554, 0x82aa701e, 0xe00df05f, 0x655bf314,
	0xf7ce3a4f, 0x4ebfa7eb, 0x8ef8b8a0, 0x9f779b1b, 0xbdc9ffd4, 0x5ce3df48,
	0xc0d806be, 0x5af76427, 0x83f45472, 0xfd5ff64b, 0x4d43f504, 0x65f6958b,
	0x4783392f, 0x07fac15f, 0x6bf58624, 0xcca43102, 0x1f245a6b, 0x6bad67ee,
	0x1465bbdd, 0x2d35d7e4, 0xd6984029, 0x63d23026, 0x0f92cd35, 0xd42eb7f7,
	0xee7855e9, 0xeaf07250, 0xf7b7ec05, 0x62f7ef20, 0xc620fe9d, 0x2bcdbd8b,
	0xd6fec0bf, 0x0c5958b7, 0xb019cfe2, 0xf6f1c28c, 0x6f1c7e4a, 0x0b59ff8d,
	0xf5e6bff6, 0x0dd1e325, 0xbf59daac, 0xa87f742a, 0x8b29ff77, 0xd35a740a,
	0x5102ecf2, 0x779b80af, 0xe9b9d85f, 0x83fd5f5a, 0x7822f1a1, 0x399f4cb3,
	0x03e36f74, 0x6d15ff41, 0x9c901ae3, 0xbdf6c7a0, 0x2b1e9122, 0xd63d414b,
	0xbd7ffbb1, 0xf81de38b, 0x3710139f, 0xe8c6e0ac, 0xf93a3ccd, 0x1c62350d,
	0x05b4f176, 0x169ac1e3, 0xe76885f3, 0xcf14be41, 0x88cf1c52, 0xe8fd2367,
	0x8c4b40ad, 0x58ccf45b, 0xded90f92, 0xf309596f, 0x805615f9, 0x7e8e28f9,
	0x6fc82acb, 0xb2f5124d, 0x7168be6c, 0x0a292bf0, 0xc596c7d1, 0xcb239fcf,
	0x87e5165f, 0xe0b3beb3, 0x7a8d5bfe, 0xadb882d1, 0xcfcb7c09, 0x5cbf5beb,
	0xeed28ee0, 0xf76e14a5, 0x9acf26cc, 0xf243051d, 0x14da51b1, 0xf1b5bb44,
	0x275524c0, 0x9a41eb3e, 0x1518bedf, 0xffb251d7, 0x90c199db, 0x7c07befe,
	0x91bf7ee0, 0xe5f3d9af, 0xedd23354, 0x2aa72fed, 0x7bdf43f1, 0xa26becd3,
	0x94bc97ed, 0xe6eeedc2, 0x1c45cf04, 0x55bf7ab7, 0x8ef844dd, 0xef8802d1,
	0xdf3a38b6, 0x365b7c00, 0xfbe28415, 0x4d779a6e, 0xbda1ac9b, 0xe25d69ad,
	0xf1faa7ad, 0x6e41b21a, 0xce23af9d, 0xf0878764, 0xe302fec8, 0x3ae714cd,
	0xa6e68fa0, 0xb9469f78, 0xaafaec54, 0x1a8afdd0, 0xcf033053, 0xbd9ab619,
	0xc887e7db, 0xd5d76c9f, 0xa5cf784d, 0xd5935935, 0x4d99fe21, 0x6abd2f9c,
	0xed092130, 0x9271d826, 0x09b7c097, 0xad2dff48, 0xee50da0f, 0x70714fef,
	0x15745a3e, 0xc6ee67f7, 0xab7bac3c, 0xe506b3c5, 0x2c5a6b6a, 0xdf476f8f,
	0x2f59bed8, 0x3c04ebca, 0xfed2f407, 0x5bc0af45, 0xfa4618ef, 0xccd0ee97,
	0xad3722c2, 0x0ebcc6d7, 0x5adb57ac, 0xf76a155f, 0xa5dc0f7a, 0xb1ccfce1,
	0xe34b3dbc, 0xf71c8d78, 0xf90ce208, 0x7db55a64, 0x8fdd887e, 0xd45877ac,
	0x14c0e833, 0x6051f69d, 0xfc347768, 0xfc5291de, 0xe6d1ca2e, 0xea364f24,
	0x86270561, 0x512d5478, 0x3bf501e7, 0xfd466f91, 0x168e823d, 0x7481d7b3,
	0xcde4537d, 0x19d10f16, 0x39455b04, 0x965f5c1e, 0x7d9caa25, 0x35bde621,
	0x91ef9c33, 0xf2173ef5, 0xaee93666, 0x0ecf3855, 0x4fa6e499, 0x1bfe27ed,
	0x5702faf5, 0x2edbff39, 0x5cf78edf, 0x272e66b6, 0x6ff77e7c, 0x4872f939,
	0xe294e6bf, 0xf7feb873, 0x9ab63e05, 0xfbce1775, 0x2a3ac468, 0x94c13c52,
	0x36247d90, 0x7086e53a, 0xa4fc44c2, 0xf1077b09, 0xf5bbed13, 0xafba58b1,
	0x09c457b5, 0x4e10f30a, 0x92a698e2, 0xef66e31f, 0x868c3de3, 0x06db134e,
	0x14dc04d9, 0x4b27390a, 0x90464d90, 0x2841b6e5, 0x58b6c78c, 0x3617c7fe,
	0xf9e23457, 0xee65d33f, 0x13ef850f, 0x96e4b730, 0xde07f742, 0xfb63775b,
	0x1b7aaf03, 0xf723ce50, 0x4c056607, 0x37892d2b, 0x5ef04fb0, 0x827dd445,
	0x78f0d4b8, 0xd2aa99d3, 0x1cd9fce4, 0xac40fe87, 0xb13bef8f, 0xd3e388e9,
	0x7f285348, 0x8b53c5d7, 0x736d9bd4, 0xfc5fa902, 0x45adb6d5, 0x39e36720,
	0x80df301d, 0x7f720e60, 0xe1df7063, 0xefe4c9bd, 0x29923e82, 0xb98876de,
	0x00aff044, 0xac1e24fc, 0x16fb6169, 0x263fa381, 0x9dddfea0, 0xfc887ea4,
	0xd32e3fe9, 0x25188dbd, 0x91467168, 0x3fe8fdaf, 0x6f723f83, 0xb6b3d72a,
	0x67ce7e56, 0xed0cdd53, 0x31c38c7c, 0xb3910e4d, 0x37ee54c4, 0x973d1f57,
	0xf27f0161, 0x4264e992, 0x7ebff41e, 0x6e02735f, 0xfd9d5583, 0x955e2668,
	0x4ef147b9, 0xdf7a854f, 0xda263b49, 0xeadc3fd0, 0xf1f48a9b, 0x3ee8b207,
	0xe98514e3, 0xf9f0fe4a, 0x8b0cbed4, 0xf35c9302, 0x53a53272, 0x46afa6da,
	0xc036b53f, 0x98638bd7, 0xb4e60541, 0x6def944a, 0xfec2486d, 0x7dbdff6a,
	0x5da9ea24, 0xf67f7ca9, 0xbcb92bcd, 0xac14c2bd, 0x14ea9e5f, 0x7099f778,
	0xd8976ebf, 0x22bdebe7, 0xfc633d53, 0x65f3ad29, 0x2f20e007, 0xed10fdb0,
	0xc959b62b, 0x9d798a9f, 0xc5b47a71, 0x6d5479d0, 0xf68642c7, 0x34c9cfa8,
	0xc777ca09, 0xd3ff93f6, 0xf1556edf, 0xb1c633fc, 0xefbca19d, 0x72a7f716,
	0xf6cdb000, 0x78c6efa1, 0xc1bf6d31, 0x05c4393d, 0x28c6c39d, 0x7b5cd9db,
	0x89e3bd28, 0xee716bde, 0xc04e38a9, 0xfd12e784, 0xa35f3ba0, 0x93cd0d79,
	0x3cc6b8d1, 0xefcf4873, 0xf85ff4b6, 0xcbcd0a45, 0x61c83881, 0x6dac9e7c,
	0x31abc512, 0x23ad370e, 0xba6aa1c6, 0xb55e7c34, 0x0301c153, 0x26f5f9f9,
	0x28cf2836, 0x43b1b5df, 0xc2c81b79, 0xe4262cee, 0xd2b6e0ff, 0x283cd0a2,
	0xf6a1c29a, 0x6db17cbf, 0xed11635b, 0xf032e9ab, 0xf8d20e3f, 0x97275c24,
	0x7709102b, 0x03a73e6a, 0xb38ba3de, 0xfac1f2f1, 0xe63b7380, 0x669ebced,
	0x6455c475, 0x79d0bc92, 0x3d9fe19c, 0xdc2e052a, 0x79edac02, 0x079893d6,
	0x1d31eaeb, 0xea09ac7a, 0x3fd2bf7d, 0x4ef90031, 0xc449f7ab, 0xaf9f3be7,
	0xea0a6a7a, 0xad66dddd, 0x504ff512, 0xe0fc8e7f, 0xb6eacd37, 0xa363b910,
	0x9ee8d3fb, 0xb538c45e, 0x873d3767, 0x01df6e7e, 0xe7f3c549, 0x067f733e,
	0xeda6bbce, 0xf5ea0b1b, 0x925f03da, 0xe6939b5f, 0xf815317d, 0x4f5ad857,
	0xb166cdf7, 0x2cdf74ed, 0x7e07f857, 0x0327d717, 0x56be2667, 0x7787c21f,
	0x7eb1bc85, 0x53b458ef, 0x3b5e426d, 0x7485de30, 0xe3dde75f, 0x227dffb0,
	0xd5da371e, 0x90a343b3, 0x7bd89bee, 0x1dda0e94, 0x7df7429f, 0x3db13f73,
	0xbfa90ee0, 0xbeffc84f, 0x2df7ee54, 0xc2eef34a, 0x7e7556f9, 0x78abc165,
	0x19fde7b5, 0x21fa5f18, 0xd144772e, 0x1bf28323, 0x4ab54f21, 0xd7eb05bf,
	0x57a4645e, 0x898ddf80, 0x9f5dbfc0, 0x095e4eb4, 0x4f01f7df, 0x385fd112,
	0x7dc4e3cb, 0xac28cf66, 0x0ff1ff5f, 0xfd8f5153, 0xfc049c0f, 0xaaf687ef,
	0xc03748b1, 0xca2c717f, 0x7a465ed9, 0x3cd390cd, 0x9f685394, 0xc02ff887,
	0xe5e90e7c, 0x0aee96dd, 0x267dcb92, 0xf8097286, 0xfc007927, 0xe72ed03b,
	0xa81e4039, 0xf39224fd, 0x3726dddd, 0xd7a0b3f9, 0x78be5027, 0x7777e619,
	0xce483a97, 0x1f3edcf1, 0x887035e5, 0x8633f1fa, 0xc4814c6e, 0x12fba13c,
	0xc409a989, 0x8e5f4337, 0xcfebf211, 0x58351356, 0x872c9c47, 0xbd8847c9,
	0x4f6179e4, 0x6d2ed3b3, 0x7e34617b, 0x84edc69e, 0x7549d843, 0x7ffde91a,
	0xe36ab610, 0x9b8bd991, 0x40ff2fd0, 0xb10ef2a6, 0x3810122f, 0x45f62439,
	0xc9a86ed0, 0x7e2dbefc, 0xbc79019f, 0xbdd33d8f, 0x51cd04a1, 0xc3f6f961,
	0xf8f6ce98, 0x2c65d04b, 0xd87dd15a, 0x173cc5cc, 0xe872d7f1, 0xbfbc5cd6,
	0xc79677d6, 0xf63f2d79, 0xd026f17f, 0xa00eb1e1, 0x053b147f, 0x81fc21cb,
	0xb98a359f, 0x49f79786, 0xd7e88f42, 0xbd8f102a, 0x1e50f22d, 0xc0035226,
	0x5e5ffcc6, 0x74dbdffc, 0xe6953fc8, 0xf09086be, 0xa1af7ba7, 0xfa9df6fc,
	0x72c50d31, 0x28af99df, 0xb8b16e7e, 0x2d3f1173, 0x46721059, 0xa9f7e9c1,
	0x8143e266, 0x173d4595, 0xe5c6971c, 0x9ecea260, 0x963e2892, 0x9f8c3e1d,
	0x05b7645b, 0x4c8ba0fc, 0xf5073e5f, 0x7d2fd88d, 0x371f8998, 0x1e7f02fc,
	0xd187d911, 0xf5bb016f, 0xe7910bc8, 0x5bf26eee, 0xc622fd8c, 0x5f109836,
	0xf624dbab, 0x6b1681df, 0xbfaf0d5e, 0x5f2bdc5e, 0xe8e3badb, 0xbaebe028,
	0xd1ca23d7, 0x0573a16f, 0xeba3c53f, 0xffcfc29b, 0xff09a5c7, 0x871b1c65,
	0x8ae00bfe, 0x615984f4, 0xf1c0565d, 0x075ee947, 0x899771d2, 0x2bf40bd3,
	0xf843a7c9, 0xb98bbb31, 0xc4bfea5e, 0xce4f5ee8, 0xbc61ff4e, 0x29bb333f,
	0x6631c353, 0x767cbc2b, 0xf73f266b, 0x9e327c51, 0xbdba17fb, 0xd6bfc80b,
	0x7ef067dd, 0x2fa11ac6, 0x717e0399, 0x7eac457f, 0xd6eff08d, 0x55ef22fa,
	0x8ad53a72, 0xaf98b37a, 0xbd5dc701, 0xaa0fdf93, 0xbf5e19da, 0xfd69d056,
	0xe28ea7cb, 0x3fb55cb6, 0xa9d05ca2, 0xdee235b6, 0x959cef07, 0x657d89a7,
	0x46fc1f71, 0x6f7c27ef, 0x47c6fee6, 0x7ca31fa2, 0x57df1a6d, 0x206581ad,
	0x64fbd77f, 0x8d68e21f, 0xbf7027a4, 0xc257d997, 0x60341efa, 0x3eb3ee20,
	0xa0f4e824, 0x1fad0fc0, 0xcabf57da, 0xf43c23df, 0xd7fcf874, 0x14658f31,
	0xe5a47f7c, 0xdfdc16a7, 0x9adbc48b, 0xbff93326, 0x227d04eb, 0x106eb5f1,
	0x682ddb3f, 0x55f122df, 0x33ae95e3, 0xffb7ee7f, 0xe0dfcedf, 0x4dd13af3,
	0xfb403995, 0x4a2f5544, 0x7f5eae9a, 0x11eb835d, 0xd77bfbeb, 0x8b90c5b5,
	0xf1326cc9, 0x06f93cbb, 0x7f70a5e3, 0xcb85af7b, 0xf7c280cd, 0x453c0db1,
	0xfc205fb6, 0x732f85f5, 0xeb52f5bf, 0x97dc04e5, 0x481eebee, 0xca9a9460,
	0x7e623ed1, 0x7a5e887c, 0x93c78d29, 0xff5f5c5b, 0x85f9fd1a, 0xde1acd7b,
	0xc63f5aef, 0xbe3b41ec, 0xb491cc7e, 0xe77621f1, 0xe17f5155, 0xc53787de,
	0xbfc47ee0, 0x658a1a49, 0x1e3fdb5f, 0x24debcc2, 0xfda01369, 0xdf81eed1,
	0x6aeebde2, 0xec4cdc57, 0x2cbdb6af, 0x8fe43777, 0x0b5d36be, 0x268f3f8d,
	0x1c2df5f1, 0xdabb2663, 0x5fee3233, 0xd0bf712a, 0xbbe483bd, 0x16dbe0e7,
	0x5bbfb7ba, 0xe8182e62, 0x5bf0eba8, 0x67bbd03a, 0x3a0b29ff, 0xa72d25eb,
	0xe2bfc12c, 0x70825c2f, 0xa9fb402c, 0x2f742ddb, 0x2defdf71, 0xf3525e78,
	0x4fb497fa, 0x7cfd0eb5, 0x955ec7f4, 0xe1cf1de9, 0x882c77f6, 0x89269aa7,
	0x968667a5, 0xf51ca99b, 0x69bfe620, 0xc0d4fae2, 0x4b812ae9, 0x6e06a703,
	0xf3fd0957, 0xb8e8d6e0, 0x23d4f434, 0x2465bdcc, 0xd370f7f4, 0xf35fba4a,
	0xfaf0f6f0, 0xbcce31ab, 0x5c73eb09, 0xbc397eae, 0x1e20ed7c, 0x91d3d275,
	0x4333eefa, 0x1cb0e4ff, 0x6040e3c4, 0x700558d5, 0x75a9c3ff, 0x73945963,
	0xbec2939b, 0x7af5f61b, 0xbd6dedf4, 0x58bb416c, 0xf14cda3b, 0x3fe8ed45,
	0xf2f14259, 0x82cbc095, 0x9f103fb6, 0xe93adb2a, 0xe622e87e, 0x5e748f5d,
	0x40e716d4, 0xc832b97f, 0xcda2b8e5, 0x3849f3ea, 0xc3d9133f, 0x88dfcc45,
	0xe0ebe838, 0x83f42cef, 0x4c4df912, 0x82d5b7e8, 0x9d05abee, 0x363c4357,
	0x8889ef0a, 0xc446bc78, 0x77b36bdd, 0x15abc51c, 0xfd7ca235, 0x4809c3f1,
	0xf5c60ae7, 0xeb9f854f, 0x867f831f, 0x7b94893d, 0x23f754b0, 0xacdaabff,
	0x36fb5f74, 0x6b6e7fa1, 0x0d23fd02, 0x237d03d7, 0xf9bdf8e2, 0x91de7c7d,
	0x25a6b3f6, 0x5a6f7ebc, 0x406bd12a, 0xe989c1f8, 0xbe088f42, 0xb8b3f655,
	0x42afe83c, 0xb51f3595, 0xfc7056ea, 0x4780a9ae, 0x1d4bbfe8, 0x9eed1897,
	0x56fe9192, 0x7e46f7f8, 0x418bee31, 0xbb63bf7d, 0x7f7e343d, 0x97db9d3c,
	0x1d64b375, 0xef1210f9, 0x8ccfce2c, 0x4c4cef1a, 0xa32e7bc7, 0x5a7a7c1f,
	0xdee3bc68, 0xf8f11131, 0x95f3d72b, 0xb6a7bf78, 0xde97eb89, 0x1137e842,
	0xfe4677fd, 0xd5936d70, 0x2d497187, 0x65de89e0, 0x5e505e21, 0xc232a4db,
	0x3f379a4b, 0xb7bd067d, 0xd5bde334, 0xa760ad25, 0xa525fba1, 0x1dfc207f,
	0x0dd7cf1f, 0x168f4b74, 0x4371183f, 0x9fee15cd, 0x946bdf1a, 0x350fc520,
	0x729efc6d, 0x19aba1cb, 0xbedf3099, 0x58c8fff6, 0xe9c3e909, 0x296b5fdc,
	0xf7857ff6, 0x6dd87e6c, 0x0e87ea8b, 0x91a971ea, 0x1cc6a5e4, 0xe4ff234c,
	0x3783f800, 0xd1f1bc43, 0xb46f1477, 0x00798a1c, 0x577bc3f7, 0xfe3ac779,
	0xd9ea9f0a, 0x3767f226, 0xd14a46b1, 0xfff509cf, 0xbdf83b56, 0x1d84479d,
	0x8013fcc4, 0xeea047eb, 0xfae1fcbc, 0xd537d0c1, 0x996bd702, 0x348e65be,
	0x0b544f5c, 0xdbcaa9b9, 0x91df4741, 0x90b5507e, 0xc9fcf027, 0x41fa45ee,
	0xeb87a78f, 0x628ffa99, 0x3bedcfc9, 0x4f703b2e, 0xcffbe818, 0x03dfd123,
	0xca2b3eff, 0x0277e83e, 0xbce23d9f, 0x2650beb5, 0xf16699fa, 0x809bf0d4,
	0xbe9b848e, 0xc61f7653, 0xef1db909, 0xaa0e2164, 0x50bd4276, 0x7a3e03f9,
	0x8f94fee9, 0xe3f92bef, 0x28c74ce8, 0xcef1d5df, 0xfd5bc464, 0xe44e3f47,
	0xd13ab9fc, 0xf9fd7292, 0xf124a919, 0xf124d7f8, 0x129f77f8, 0xabb8c04c,
	0x09ec80f6, 0xf06ec7bd, 0x238129fb, 0xff38f0a6, 0xe6957499, 0xf1c6df53,
	0x29e76a61, 0xef9cbf8c, 0xfc6998f3, 0x80c5e561, 0xef62bf9b, 0x300bce18,
	0x27ee6b50, 0x329ed5fc, 0x4f6a7cd1, 0xda85a40d, 0x4dfb1d7d, 0xbf57fd47,
	0x893e919e, 0x6f77a863, 0x908177c3, 0x18b3edbf, 0x668ea7f2, 0xfa49553d,
	0xa8664b2b, 0x68fb1ebf, 0x7b50a4dd, 0xcfce9c91, 0xc1d219b7, 0x0bcc5e85,
	0x87417c7c, 0xd8a96c4d, 0x7e78e027, 0x103fc441, 0x8f4aed5f, 0xa8dd5f12,
	0x6edf5c5f, 0x5c8fb865, 0xf74ace7b, 0x5f687e70, 0xbb3bf14d, 0xfa849de2,
	0x37bd7986, 0xc758fa61, 0xfdf849ea, 0x37b58e87, 0xb4a7bed1, 0xe99ecc29,
	0xfa173f38, 0xe1a71f4b, 0xf6ea98bb, 0x611ee98f, 0xe699bb75, 0x7b50f98f,
	0xedce96d6, 0x0c675f59, 0x2c486fed, 0x8d80e38b, 0x7d77eb0f, 0x2ff211cb,
	0x61cab7d6, 0x768c1aef, 0x7ef9d327, 0x0381b77f, 0x3e26e4bf, 0xfae9e5ef,
	0x3e69b7d6, 0xf13f6655, 0xccc9beb1, 0x14f377cb, 0xa76a4efc, 0xe71d24b3,
	0xbff717bf, 0xed08b9f9, 0x924d4073, 0x1cec818f, 0x7887be1f, 0x5d013f1f,
	0xc6267c07, 0x3ce95bbf, 0x1c6ba1b9, 0xe819b7bd, 0x9a253b7a, 0xe78938dd,
	0x13950028, 0x890e3c99, 0xc5d67f2c, 0x9c4e1ff7, 0xc4ecfae5, 0x68a4ef7c,
	0xc5674d7a, 0x04974e3c, 0xbbf85bbd, 0xcf7ac8f0, 0x8e76fe88, 0x7ae04fd6,
	0xd0c6f67a, 0x938f5c79, 0x3496a7ef, 0xddf0571f, 0x348b5546, 0x5548ed03,
	0xaef4a7f6, 0xa805f203, 0x0702aad7, 0xbab1dce8, 0x7702ef69, 0xefdc7994,
	0xc2ad76e2, 0x333cfd12, 0x79f1c5c3, 0x22a9699a, 0x04ca7a8e, 0x34ae9de3,
	0x2cfbf83b, 0x76f33efe, 0x2d9787a1, 0x729f9332, 0x7e66a99a, 0x17cfc16e,
	0x7b3d0b16, 0x91cfd0bb, 0x7d0d86ef, 0x67e8a77c, 0x336cabc9, 0xbe442f9e,
	0xf853be23, 0x9b994b7b, 0xff7c8ffa, 0xfbf0a77d, 0x404eff22, 0xe1e84b9a,
	0xea226c89, 0x07d83f61, 0x9cc6fbe4, 0xb7b3b218, 0xd510994d, 0xd4f7c04f,
	0x8d4f78aa, 0xfaffc1a9, 0x7ec94f9c, 0xfb3ce89d, 0x3fc3dd16, 0xa2b2c31b,
	0xd90d8f9c, 0xefee432f, 0xe7177ce0, 0x3e0ed50d, 0x97ff8347, 0xdd0a3220,
	0x3ff832d7, 0x3fe1f04b, 0x9b266f7d, 0x20fba129, 0x2cef6507, 0xffde2a57,
	0x1aff21ed, 0x0bf64056, 0xd62195d6, 0xb10d6195, 0xac46974b, 0xa1e38a8c,
	0x5ce925f5, 0xda50a7ff, 0xf9256399, 0xf44bf6ab, 0xc03aae3e, 0x0efab1e5,
	0x2709f689, 0x7dd274b6, 0x92a5e585, 0xec6ae6e6, 0xc0cfce0c, 0xb71b62d1,
	0x065e06e7, 0x847025e9, 0x6fdf68e5, 0x123df617, 0xf758934f, 0x2effec02,
	0x3de1a4b7, 0x68e2ebc4, 0xa823b4c5, 0x2387afae, 0xf519a5c0, 0x5e9e2466,
	0x22577972, 0x5c7e20fd, 0x3ffa053e, 0x064df391, 0x3ae6a7e2, 0x9084f472,
	0xfd769db3, 0xf5ffda04, 0xbd5ce2cd, 0x8835a739, 0xe462e974, 0xbb38f607,
	0xfee46cb7, 0x57ab9d31, 0xbee86207, 0x1c5b7564, 0x6eaaafbd, 0x8c9d8fa9,
	0xac9b6471, 0xb2be41c5, 0xc62954e5, 0xfc0595ef, 0xa58d479e, 0xb9d0fc9f,
	0x5cc7de29, 0x7afdf033, 0xba79d87d, 0xe1ebcf31, 0x3dcf523d, 0xea56be83,
	0x79fe9d7f, 0xe365d046, 0x9369cbf1, 0x7aa31e19, 0xf779c69f, 0x82d3791d,
	0x276a054f, 0xaf00b3bf, 0x52e33d56, 0xa6a2dea9, 0xc6dc46ce, 0x45ffe635,
	0xefbf83ba, 0x9346fb30, 0x6377997f, 0x0fea4bf7, 0xfe8a9b1c, 0xf1e76f74,
	0x9c1096a9, 0x7d046cf7, 0xf57f851d, 0x57e424cc, 0x969254a1, 0xcb877f0a,
	0xe1fb6d73, 0xe85fdc34, 0xc3ce3941, 0xb404e3f4, 0x4f7bd593, 0xbf404c27,
	0x8d4f1f63, 0xc9b52efe, 0xc1298f54, 0x87c67789, 0xcd336fce, 0xf79f92ef,
	0xe27058c3, 0xe5a129b2, 0xf5afff0d, 0x77a441c0, 0xa6182db5, 0x413a0c07,
	0x5cef4f74, 0x9d2b0ef5, 0x4b79e3d3, 0x4facfde8, 0x866eff04, 0x75e507a0,
	0x8f339e16, 0x614cd743, 0x615e61f7, 0xcf092501, 0xbf320383, 0xf49a36b7,
	0xfe314cfc, 0x13a04acd, 0x12ceb5ef, 0x59b393e7, 0xc79bd537, 0x337529fa,
	0x2dd3bd07, 0x85a51a66, 0x186dc0b6, 0xfdf9e5fe, 0x9024fef4, 0xd82f38a6,
	0x28e07bc4, 0x9ba21efc, 0xf4182ec2, 0x8b1cf190, 0x5c8c07df, 0x1eb19f4f,
	0xe83fd737, 0xd6bde05a, 0xf3a7e642, 0x282cb9f3, 0xafa3d1ce, 0x6fc40e63,
	0x17366e78, 0xa25899dc, 0x17ea8f87, 0x68e47ae1, 0x46de09eb, 0x0ea5666c,
	0x48149f9c, 0xbb8b5d33, 0xe1f475f1, 0x67dc472d, 0xf7bfb07e, 0xe7430517,
	0xb1db5a8e, 0xae1ef0cf, 0x3dd376e4, 0x35df0d5d, 0x50129c63, 0x58f5067a,
	0xd755a816, 0x8f511faa, 0x981def19, 0x8cfdd197, 0xb80ef7c8, 0x7f218bdc,
	0xbfb8c7af, 0x54b7d3ba, 0xb0efbfc5, 0x7f46c522, 0x96df2607, 0x0ff71d31,
	0x1fdec9fd, 0xa4e75711, 0x89d409a6, 0x7e419be2, 0x1c55c0a8, 0xfae21773,
	0xdef1b725, 0x065e1182, 0x31a7d5df, 0x6712f77a, 0x9e51efe5, 0x92da1c02,
	0xde2afd08, 0x944f661f, 0x6eefe8a8, 0xf434da71, 0xdf38ace7, 0x36f9a1b8,
	0x8a3df8d8, 0x0f865b06, 0x2f71b8f5, 0x0d9e922c, 0x926e8b40, 0xfe46cd43,
	0x997bc472, 0x19bcda5f, 0x8f1d6023, 0xdfd317c6, 0x53ddca07, 0xbcbf42e4,
	0x69bbbc41, 0xc7d27490, 0xefc4d3ba, 0x17773233, 0x8b7693f9, 0x9dfb8dba,
	0x206faf74, 0xf3bf2545, 0xd896fc70, 0x586f90c9, 0xaa3dd129, 0x31355486,
	0xcbef00b3, 0x7bf50ccb, 0x17495743, 0x8f6c07da, 0x93837c7e, 0x53d6e3df,
	0x43ebdd19, 0x7c19143e, 0xc1f10d30, 0xe4f7ee2f, 0x831adedb, 0x52d3f5fb,
	0x9bb60958, 0x404f7016, 0x4bef189a, 0x46b32f80, 0xf0f7e2a4, 0x714c567b,
	0x830a7dd0, 0x0214002f, 0xdbf043b7, 0x78c393e0, 0xc256ef1f, 0xfc1bc7de,
	0xf3962a7b, 0x5c378cc9, 0x155b51c6, 0xcfe48dfb, 0xec3501ff, 0x4a307ca6,
	0x00004a30
};

static const u32 xsem_int_table_data_e1h[] = {
	0x00088b1f, 0x00000000, 0x92cbff00, 0x51f86061, 0xa507c08f, 0xf3761818,
	0x12d18aa0, 0x6064e29f, 0x6062e190, 0x19e20470, 0x00977b40, 0xfc40a5e9,
	0x03df880e, 0x03371871, 0x9e2054c3, 0x8047c406, 0x6e6849fc, 0x6062616b,
	0x0ee20368, 0x6202ee20, 0x0606461d, 0xede2465d, 0xc0c42a3f, 0xe08e2010,
	0xafb2004f, 0xffcfd24a, 0xb67f0d83, 0x357dafa2, 0x290c0cd6, 0x71fe082e,
	0x54860667, 0x69355417, 0x48cdf82e, 0x40cf9347, 0xd1e267e3, 0x951f5dff,
	0xca89a32f, 0x6066d337, 0xf04034a8, 0xbbf13565, 0x00af1d05, 0x40695dea,
	0x232efabc, 0x3195be54, 0xe8000684, 0xa8f9d363, 0x00a8f9d3
};

static const u32 xsem_pram_data_e1h[] = {
	0x00088b1f, 0x00000000, 0x7de5ff00, 0xd5547c09, 0x73b9f8b9, 0x2cc99997,
	0x2cac8499, 0x04455871, 0x0310849c, 0x11161da2, 0xb4a0e22d, 0x044c0b82,
	0xf5206fb2, 0x032fb541, 0x1ad2d361, 0xd1a0c06a, 0xb068304e, 0x301b0701,
	0xd4018048, 0xa1ad2be2, 0x18b6adc5, 0x9316c314, 0xdabe1b80, 0x77df3ff2,
	0xbdee4dce, 0xfdb60899, 0xfbdefafd, 0x387b3fa7, 0xb7cb3dcb, 0xe77cef9d,
	0x4a48df3b, 0x1efb893c, 0x8fe09721, 0x089937a6, 0xd3bb6321, 0x23739685,
	0xaee98e4e, 0xb32644ff, 0x1d692343, 0x1cee5529, 0xc84e5dd5, 0x8cff6c0a,
	0x449a39d5, 0x24129a43, 0x185c5a4e, 0x8419226f, 0xf822e83c, 0x378c4cf7,
	0xa4274845, 0xb5d9bd73, 0x972d2079, 0x8e214edd, 0x760e8fa6, 0xcef80405,
	0xcef9009d, 0x66d76547, 0x5cdf279a, 0xc97be112, 0xd027bec2, 0x3921024f,
	0x84c1eff0, 0xe24517c8, 0xafd343ef, 0x919f4c05, 0x9d1f3cc9, 0x93baec9f,
	0xcf77b44c, 0x23e715cf, 0x1df2d11f, 0xe5a7ad0a, 0xe2cf9c72, 0x7f5dd91f,
	0xfe70110d, 0xec329be4, 0x956f1d5f, 0x178b4eeb, 0xb5101bd7, 0x0bae1de5,
	0xd55f284e, 0x43f61774, 0x259d706b, 0xad373f30, 0x2148fb8f, 0xbbfeeea6,
	0x71c414e1, 0x89bbbcd4, 0x213d7b8e, 0xb5bffec2, 0xf2eeba12, 0x4cdbb29d,
	0xa77932e1, 0xcd1efe1c, 0x4108d517, 0x59f69bc8, 0x6b70a109, 0xb0f966af,
	0xfb42f143, 0x9e696b4f, 0x6e625176, 0x000df9fe, 0xd9229dd7, 0x4cf8c38c,
	0x1556df30, 0x9f2c8d6e, 0xa2d9656d, 0xe173039a, 0x3346dcfb, 0x8afed2b1,
	0xb8cce776, 0x0e73e681, 0x149a04cb, 0xf4ae596d, 0xa0bcf9a5, 0xc77c8210,
	0x07e38224, 0x2dc18976, 0xb3877db4, 0x1407e139, 0x2ccb678e, 0x9d357dc4,
	0x6139a3b7, 0x7e438516, 0xf854c770, 0xf05ebf2e, 0xde4d0900, 0x648de5b9,
	0x56d15dfa, 0x70a663c1, 0x11b3a829, 0x873670f7, 0xd6bff44b, 0x3dfc3106,
	0xae98bf5a, 0xbc040c93, 0x22254c56, 0x715ebf8c, 0x74e1ba3b, 0x71386cb6,
	0x45f3bb9b, 0xf438e95b, 0x82ede2bb, 0x6c589607, 0xcba07e22, 0xd9d6ddf6,
	0x7d61d9cf, 0x0e6195cb, 0x051ad758, 0xb304e5da, 0x30dd5976, 0x2a651abf,
	0xaeafcfad, 0xf835b251, 0x96bba82f, 0x799a2db8, 0xd44e0d55, 0x3d3187d2,
	0x3b44c94b, 0xbc427c9f, 0x41903b21, 0xe1a99950, 0x0c42be8b, 0x4ea0bbe2,
	0x214ff5d4, 0xfd3c4849, 0x3fe9b7ff, 0x7b02bc29, 0x1557081d, 0x1d398b6f,
	0xc0bb78a9, 0x9d4887f9, 0xd5feda19, 0x0780e7f4, 0x328a9f3a, 0x28bfa617,
	0xb2b4c24b, 0xd9f88dcc, 0xe9a3f008, 0xe76f3e3a, 0xa2513204, 0xc4bd3ae3,
	0x3b166c05, 0xa6513bdd, 0xcb1f58f9, 0x17e7dc27, 0x7eb2dfdc, 0xfb28dd35,
	0x372780b3, 0x295ea990, 0xff15e699, 0xe3a1e222, 0xa778774b, 0x35e4238c,
	0xd61c7fe2, 0xe7f052bf, 0x09095e02, 0x5e28f925, 0x8e540b56, 0x81ad7850,
	0xac385245, 0x4cf4a64e, 0xfef1b4f1, 0x8144e78c, 0xf20e35af, 0x363fcfd9,
	0xc2a9fb10, 0xcfda647e, 0x93f7cbe0, 0xd7533730, 0x5cdcc24f, 0xec1a9fb5,
	0xfd657ac7, 0x5e3b9c6c, 0xf9b99f3f, 0x422f3f6a, 0x2b8e95bb, 0xbcc2575b,
	0xccf9fa09, 0x127ec42b, 0x3f10f3ef, 0xf4aa2f6d, 0x22bd9a43, 0xc7d7b7ad,
	0xb4463da4, 0x17693474, 0x5ca0e7f4, 0xe8a3a5a5, 0x3f1d28cc, 0x756378c5,
	0xfad33ef9, 0xfbc7daea, 0x13eae906, 0xd0308f67, 0x7ad5dda5, 0x49d3cf2d,
	0x9c146385, 0x4157d2af, 0xafb133b9, 0xf50ff305, 0x79dca3b5, 0x6affbc68,
	0xcc379d17, 0x3ffc5095, 0x73aff8a4, 0xba1ba045, 0x4124812e, 0x6a4136ea,
	0x33235fac, 0xf7ea4db8, 0xf413b0cd, 0xe75312fb, 0xff9a18b0, 0x1df130a3,
	0x419ff758, 0x45bc5298, 0xda14a489, 0xca099945, 0x330335bf, 0xe0680b9e,
	0xa50076ba, 0xdfbba117, 0x093fb2b5, 0x5025b1e8, 0x5cfa001a, 0xa7ae803d,
	0x4827212f, 0x84303869, 0x3b203f7e, 0x566fe009, 0x8ed0fca8, 0x47f1d0af,
	0x30adf8e2, 0xe32f5b7e, 0xea65079b, 0xe4a4b7c6, 0x28b7c6ea, 0x1fca7c74,
	0x7ca5819d, 0xf1bf0a7c, 0x4b279c84, 0x4a737c71, 0x46bf8e2e, 0xf1bab921,
	0xffc6baa3, 0x06fdc612, 0xb08f8fc6, 0xf5e341fe, 0xd7c94feb, 0xeb615faf,
	0x7c03cb27, 0xbf5c28fc, 0xfad80420, 0xfad9f253, 0xaedfaccd, 0xf05d9df1,
	0xae3a0457, 0xfd65e85d, 0xd7e82783, 0x7ea1557f, 0xbe3666fd, 0x3e5af96b,
	0x8fc71dbe, 0xf5b2d611, 0xe388555f, 0x07bf662b, 0x17e948e8, 0xfd841a55,
	0xa0653fb4, 0x5e819444, 0x12c7874c, 0x6fc9e542, 0xc38420c9, 0xee8c5143,
	0xf4a28cbe, 0xa796ef66, 0x90394824, 0x9cc5c3ee, 0x27ea0ba6, 0x0e7f6c2a,
	0x90bebee0, 0xa341754f, 0xa919fb88, 0xd2870734, 0x8a37b6f9, 0xa82fc801,
	0xe22831bc, 0x08f4ca7e, 0x94309122, 0xd461b27f, 0x8cbaed66, 0xb90ac2e9,
	0x57c345b5, 0x127df25d, 0xe74a5e19, 0x30440a57, 0x4adf3bb6, 0x72a134e5,
	0x8f2a23f8, 0x33253d21, 0x9524e4bd, 0x2d6ae4e3, 0x7a672cdf, 0x1b1c8049,
	0x43ffe74e, 0x8956ff3e, 0x8975bbc1, 0x7ff80410, 0x02917eb9, 0x85616cf2,
	0x7bbd028d, 0x4f1c251e, 0x41cdbb9d, 0x76e8a7d4, 0x1bb9f000, 0xbf909159,
	0x0dfdbbec, 0x3969ea81, 0xdf747d55, 0xab8247dd, 0xf9fb6892, 0xb806b2eb,
	0x9deffae8, 0x61134e6d, 0x7ede227f, 0xd263e426, 0xc84994cf, 0x72f586ec,
	0x7bb99a3f, 0x8b51fcb6, 0x7e39fbe6, 0x5cdefe7d, 0x0e5dbe7d, 0x67d026ca,
	0x435204f2, 0x54bfbdfb, 0x338eaf5f, 0x7865884d, 0x90fde3e5, 0x169920c2,
	0x1a690fdd, 0xaf10bb14, 0x5bec5d73, 0x0f253e75, 0xfb8c24cb, 0x413c4b71,
	0x3b63c7fc, 0xdbad8bbf, 0xb2b9df38, 0xf3a3ebc5, 0x444cbb99, 0xdfe71a78,
	0x35e6cfb2, 0xd569a68d, 0xa0903267, 0xf9c63d71, 0x5c6a5bcf, 0xfd814b8f,
	0x2c602b21, 0xa4627467, 0x89c692a7, 0xd0d49c4f, 0xd6e85153, 0xbe6a4e27,
	0xa99ba82b, 0xe705e7cb, 0x54e7dae8, 0x17eae965, 0xeae9e456, 0xa45dafe7,
	0x960567cb, 0x5bcfdae9, 0x7f575cba, 0xbaa3e97f, 0xd7737bfa, 0xfc73f2eb,
	0xefed749b, 0xaba35d9e, 0xe6bbed37, 0xf2a3e00e, 0xfb0245b7, 0xd6f617c6,
	0xf9be839f, 0x00f25d85, 0x7d534e3e, 0x2ce0f805, 0x6d2057d5, 0x7a831c6f,
	0xd9839535, 0xd550aa84, 0xdac091c2, 0x09972009, 0xf0a0cfca, 0x3fa04087,
	0x6e082f21, 0xa5589f84, 0x61253090, 0xd176c481, 0xa9a8a771, 0x7d4cb96f,
	0x31f46515, 0x96c5eb3d, 0x9b25e5c8, 0xd972aeb3, 0xf407977b, 0x73ec1faf,
	0x301f5c1d, 0xc40a17d6, 0xcf572da7, 0x4c09d74f, 0x73f217ce, 0xc9cbe14a,
	0x551ce093, 0x958784a8, 0x2178db7e, 0x9390540a, 0x03c7fda0, 0xd02e503d,
	0x6ea0a3e0, 0xdbbf8eb0, 0xaf38880e, 0x54099062, 0xdf12a6ae, 0x4ce40121,
	0x5dca50f8, 0xde1e60a3, 0x93ee40d7, 0xd7dc78c6, 0x3da6cadb, 0xfc065271,
	0x5d3d30f8, 0xd6d31b36, 0x27a63f32, 0xfd3172cb, 0xd314aca8, 0x98a5b296,
	0x600b2f1e, 0xb5b2e7fa, 0xaca9fe98, 0xcaf7d302, 0xa77d30aa, 0x7b69882c,
	0x95531799, 0xafe4ba1f, 0xfcc3eb8f, 0x980b42dc, 0xb2d7cc3e, 0x466db692,
	0x0124f73e, 0x7fb05f9f, 0xfdf40c39, 0x2251ef0b, 0xbc3bd81a, 0x3bd6f48c,
	0xafa8bd1e, 0xf1290764, 0x6f59e9f4, 0xb278628d, 0x4234c89a, 0x43a3d1e5,
	0x303cf79f, 0x9012f312, 0xcf54a50c, 0x7e84474c, 0xf807dee9, 0x889e1cba,
	0x9c3473b7, 0xfa9f5bb3, 0x7bf4066b, 0xed88309d, 0xdc4487c3, 0x39f84987,
	0xbbebe00f, 0xffd84dc2, 0xda169497, 0xf82ed3ee, 0x9a10a735, 0xd85c122e,
	0x330685ff, 0x4d8e0091, 0x8d1c20b6, 0xce7e1c2f, 0x38b8fc09, 0xdad0ac49,
	0x51698c03, 0x5d856068, 0x46929eb3, 0x8542fe7d, 0x0fd98d30, 0x46b3d1dc,
	0x2ab95d01, 0xfc050e4e, 0xf6aa6127, 0xc14938b3, 0x0dd6ce71, 0x77fb668e,
	0xf583ed90, 0xf4af4831, 0xffed89dc, 0xade9f3d5, 0x843e751f, 0x2d8f9034,
	0xdd680f20, 0x8f9fcbe0, 0xfa5de07a, 0xbe01f15c, 0x412fe49a, 0xffa2885f,
	0xfd041a5d, 0xfb57984a, 0x0189092d, 0x5e5075f3, 0x7e8f1baf, 0xf4cf56e7,
	0x74ef5df0, 0x7556912b, 0xdd5e549d, 0x0539edc8, 0xfd0ad675, 0xcba312be,
	0x57263497, 0xf819f6e8, 0x527fe507, 0x3f40482a, 0x3a9a9c85, 0x815afb24,
	0xe4c92fce, 0x044b7ec6, 0xd2c8aed6, 0x48ddf8a2, 0x67a0cd8e, 0xd2a9903c,
	0x0feefb9f, 0xf33fbca8, 0x063c995b, 0xa3aedcf5, 0x087747f6, 0xf9f9a262,
	0x4340f73c, 0x7b9074c1, 0x1f7d7667, 0xc40593f5, 0x524384e7, 0x00c8a92e,
	0x6253e73d, 0xfff4069a, 0x7383f929, 0x91bce68c, 0x3e705263, 0xf7ead7f3,
	0xe99faa59, 0xfa5539f2, 0x33b9367c, 0xbb3de801, 0x0b7ba652, 0xfebea5f0,
	0xf90b936e, 0xae94872b, 0x92bfb906, 0x701e579f, 0xe51fa911, 0x9e57a2fb,
	0x091ac8c9, 0xbf260876, 0x5e40fb55, 0xf253d32c, 0xd80a3543, 0x186e3e8b,
	0x081bc3f3, 0x0d5c1f7c, 0x4ec09276, 0xddc5b3c1, 0x75df7f13, 0xaaf9c6fe,
	0x3b0f49fb, 0x51479f05, 0x460de09d, 0x311e4fd8, 0x0adf5c09, 0xaf8eba60,
	0xab5bd55b, 0x435af90c, 0xffc8643e, 0x4716f4c3, 0x6496f474, 0xe29957f2,
	0xbe817d19, 0x8a9d4820, 0x3fe99fff, 0xb5ff47a9, 0xfbfed2ff, 0x7433fed3,
	0xa5fe87fd, 0x31e90ffd, 0xfd48a6ff, 0x6db2bd17, 0x9bca8057, 0x383697fc,
	0xce87dd09, 0x1e091548, 0x2dc2ff8a, 0x797ed0ab, 0x81380a5a, 0xc504cf9e,
	0xe708c169, 0xdc4ccff6, 0x76bc4a2e, 0xf055ce01, 0xd9ffda4f, 0x033a7f17,
	0xb72fb9f4, 0x2f3c2ec8, 0x66c399d5, 0x0dc5a7ca, 0x68c9d379, 0xf9609fcc,
	0xc845e735, 0x33e9ea37, 0x090d85ff, 0x94a3df60, 0x6113cfc2, 0x6b8a97d4,
	0xfb0a993f, 0x44e90950, 0x077e333e, 0x458c5fe3, 0x44a598f9, 0xf3a7acf7,
	0x84bf3d44, 0xe1a4a5c3, 0x2745e7a7, 0x429eb7a4, 0x4169347b, 0x5df8dc3d,
	0x4e83d72e, 0xad711c9a, 0xae4508f4, 0xdc83d727, 0x8242e154, 0xdf2a0f4c,
	0x13e8e4fa, 0xb56d5e74, 0x1a0a75bf, 0x76fca978, 0x97ff3421, 0x977bbaaf,
	0xbcfcedcb, 0x105dfdd7, 0x723773bf, 0xa589adfd, 0x09d87285, 0x8d6171fa,
	0xe2d009ec, 0x3dcf6dc2, 0x579c14ff, 0x867b37df, 0xb60bfed2, 0x78cefebd,
	0x21d82f9a, 0xcb674dc7, 0xdd090bb0, 0xffa129f8, 0xc6eb4d2d, 0x5faffe47,
	0x58a3dc57, 0xddb123f9, 0x71d82978, 0x7aa32140, 0xe87263c2, 0x8f62d280,
	0x89d09f80, 0x9567a0a9, 0x814afd6f, 0x7d99e573, 0x181c4902, 0xaf359e01,
	0x7000bea3, 0x7c727c42, 0xd0cfe175, 0x05e284be, 0x5f11bae4, 0x83af76c6,
	0xfacb197c, 0xa524fb05, 0x82afedef, 0x664ffb1d, 0x7721c00f, 0x584e83fb,
	0x94a929cf, 0xab33f9d1, 0xfc74bc12, 0xe090395c, 0xe79594c2, 0xa423fb3e,
	0x3fa39cbf, 0x43e7604a, 0xf709b26f, 0xac3240aa, 0x0ff56173, 0xc4d99d70,
	0xfb98748f, 0x7903e88c, 0xa64485f9, 0x27c088ed, 0x93e32205, 0x72299b53,
	0xc14f3ae9, 0xfbe40539, 0x16e0c41f, 0x222c8fb4, 0xa47e0f20, 0x62c9e3da,
	0x61617fcc, 0x9a289af8, 0x45ae73d4, 0x6bb5bf47, 0x674f019a, 0xc1137807,
	0xa44256ae, 0x70878700, 0x1e2bf689, 0xe19139bd, 0x0ca5b889, 0x0bd51dfe,
	0xb4394326, 0xd6bd966f, 0xc8efbad1, 0xe3dd81a5, 0xd3e3e12f, 0x7ec14779,
	0xe4812a7e, 0xafac2286, 0x00e5544a, 0x7435d7dd, 0xc677e1a6, 0x328fb5ff,
	0x3ff9577e, 0xd41a7338, 0xf18c7e7f, 0xfb077c11, 0x38579d25, 0xcc0feb11,
	0x983e5012, 0x9f123849, 0xcf9ccad7, 0x7a46f5f5, 0x8497f3a1, 0xc0dd0d68,
	0x0788b138, 0x5765abb4, 0x72b5efd2, 0xf675c615, 0xe3e557ec, 0xb20f2e1c,
	0xae0f2a45, 0xa40796ed, 0xde81c99a, 0x3b00aef5, 0xe7c1c9bf, 0xa5fe029f,
	0x03701afc, 0x583ecaff, 0x43fab9ff, 0xf943dcef, 0xe5485cf6, 0x355cbd5b,
	0xcbee6df2, 0x53a0045b, 0xcb9edf23, 0x244a5aa5, 0x11e5a5be, 0xe5b736f9,
	0x555722df, 0xea2e3e38, 0x272aaae5, 0x51a7837b, 0xdd108e4e, 0xfd24e511,
	0x7a32463b, 0x874aa3d2, 0xffe5fd2a, 0xb42ae8aa, 0xaa74a827, 0x9d1761d2,
	0xc3d874aa, 0xa383a33e, 0xa06efeb1, 0xdf04ba09, 0x89ed196e, 0x3eec4d85,
	0x46f77e8e, 0x978474bf, 0x5239b717, 0x38bf46f1, 0xc8683e6d, 0xbded0c87,
	0xd0cfbc86, 0x97c86fde, 0x3617daea, 0xd208521e, 0xced75841, 0xf269f4bc,
	0xac738471, 0x34950fba, 0x4002579c, 0x153bfd1f, 0x0af27f90, 0xfd807012,
	0xf688af70, 0xe30a0ec3, 0x8e9c74d5, 0x00c181fa, 0xacab2395, 0x19d9bcec,
	0xb906acaf, 0x74eae1d7, 0xcade42c6, 0x5f0ee3f4, 0xa34633a7, 0x12689e67,
	0x04b76e51, 0x7648b4c9, 0x20b3ba11, 0x6f485b3c, 0xda1eccf5, 0x99eec511,
	0x29ed166f, 0x5a9ce14b, 0xb9287a21, 0xefcb0590, 0xbca98276, 0x1df069a3,
	0xc2f969b3, 0x3d764537, 0xc94af013, 0x69c5f39a, 0x4138d812, 0x75bb7b80,
	0x9bf32748, 0xc16379d8, 0x9f74c8ba, 0xb6cbbfcf, 0xbe40512f, 0x47c273d2,
	0xdaaf7b5a, 0xa1b56e4f, 0x9cfbe9bc, 0xdcf02a3f, 0xafab5f97, 0xd373f3f7,
	0x499caa67, 0x6728a925, 0xe70440e0, 0x6f9f2e77, 0x31de4716, 0xe3a1e29b,
	0x1ee048b0, 0x889342f5, 0xcf50b878, 0x20494dee, 0x98acf91e, 0x545ca274,
	0x7c06d5e1, 0xf2ef7574, 0x5fe76daa, 0x7a061e32, 0xe8c1f5d9, 0xb6da69a7,
	0x7b61fdeb, 0xbbcaff20, 0x9e901f29, 0xb3ef27ed, 0x63b93da2, 0xbce9039f,
	0x52efef63, 0x6efc861e, 0x3af1da33, 0x1a357df6, 0x8563aee8, 0x5de41739,
	0x2fe600c7, 0xabf7be50, 0xcfb82dd1, 0xa5fc44ae, 0xf9e20a48, 0x8f5fd342,
	0x85ff7dc3, 0xd02aba26, 0x90d9f623, 0xb55e4a8f, 0x63a1dda2, 0x7e1957ef,
	0x3d6ebffb, 0xa79efcc5, 0xbf6641c3, 0x618bf30c, 0x3d92f1f6, 0x0e5b9ee3,
	0x070de0f7, 0x7eb4f994, 0x8dbffef2, 0xf1da3906, 0xda8fd332, 0xe16796e5,
	0xc91ae31e, 0xf8a642b4, 0xea66076a, 0x6911f54b, 0xc8c0a4f2, 0x1bf97048,
	0x14ae53da, 0x9d895e1e, 0xc3e7ff5b, 0x3932f043, 0x045a08e7, 0xc7d7f758,
	0xb079003f, 0xa9748ccf, 0x685cf7ae, 0x972dea39, 0xffbcf75b, 0xa5707435,
	0x57c216eb, 0xfcffeeb2, 0x496ebe1f, 0x8cfce372, 0xce93d07c, 0xf9843ef7,
	0xce0f0e6d, 0xfde90af7, 0xf46bffd9, 0xbbc532fe, 0xdeebf2f3, 0xef16bffb,
	0x78e5ce6f, 0x401f8177, 0xe1bffec9, 0x9cabbefc, 0xd2ffcbfb, 0xfd7aabf5,
	0x63ee4c6f, 0x34fdb4a9, 0xc5076152, 0x83a2d6e2, 0xdad2a66f, 0x143ff4df,
	0x649df303, 0x5351d7b8, 0x4fcecca7, 0x877ee093, 0x04624b8e, 0xe7642e7e,
	0xbf5c7ea9, 0x1b24b7e8, 0xfd7e90f5, 0x04fa867f, 0x7095dc91, 0x949bf92f,
	0xb1f41ef9, 0xf9ef6920, 0x91baef21, 0xcae7f5e7, 0x85e205a7, 0x297ed32b,
	0xfa0c3fdf, 0x22feff6c, 0x4534bbea, 0xe735f73d, 0xa85e5634, 0xb73dcee8,
	0xa0e7f5ba, 0xf3fa71a9, 0xdfde14d2, 0xffcd84cd, 0x0c10bb66, 0x1a4c3852,
	0xd81c44f0, 0x950d274d, 0x53f34089, 0x9c257f89, 0xf5d8a62f, 0xfb859dfd,
	0x70ddb1ea, 0x245f6fec, 0x034c5d01, 0xb40c747d, 0xfef9654f, 0x2fef0901,
	0x8b7a3eb8, 0xfb84917b, 0x0954ff6b, 0xd9639be0, 0xae127f9d, 0xce023daa,
	0x1336eae3, 0xba4b21ca, 0xbc33f480, 0x51fcc24a, 0xe02c6b93, 0xaf0dc667,
	0xc0465b9c, 0x9855eb6e, 0xf663e822, 0x5d2e6ff7, 0xe701909a, 0xfe07f67b,
	0xf3d3b784, 0x126a82c0, 0x5a70a28e, 0x74409128, 0x055dd82c, 0xeece91f2,
	0xdfc3cfaa, 0xfddd094d, 0x6f7dae5c, 0x4eaffbf4, 0xf2fca15f, 0x764250d1,
	0x6af78a43, 0x9ea85ecc, 0x626faedf, 0x42392af0, 0xbdd88382, 0xdcd3e8be,
	0x6644fd53, 0xfe57e076, 0x3818f2fc, 0x18ec4d37, 0x38f8cd19, 0x7239f99d,
	0x7102f4bd, 0xc0ec7b47, 0xf1a383c7, 0xe8b0edfe, 0xb737e488, 0x7ee79f95,
	0x340dfe05, 0x1525a8ed, 0x48179c22, 0x0311da27, 0x25b216b5, 0xae457f82,
	0xc374e26c, 0xc4ff46f1, 0x600fb80c, 0x9fa42fe3, 0xd6f16b46, 0x348cfd36,
	0xe01e27ba, 0x7dcd23ef, 0x5f0b3fc8, 0x7c023f38, 0xa65b5ab7, 0xfbf022fa,
	0xcfbf398f, 0xda35f838, 0xd53446dd, 0x477e8098, 0xf7749ad4, 0xae658b7b,
	0x3491a7f7, 0x838cd798, 0xe03a4756, 0x01e8b0e5, 0xa692c57f, 0xc23f8af3,
	0x9e1194bd, 0x73d83fd0, 0xc70bb243, 0xe68723dd, 0x7cf75c03, 0x4e70216a,
	0x1454addb, 0x10e79a44, 0x42e79b33, 0xf4707a12, 0xf079ffc0, 0x0f61d89d,
	0x4e73824f, 0x6ae7e12d, 0xa411fd23, 0x24750be3, 0xce1c7208, 0x2e172045,
	0x47dc13d4, 0x067e4828, 0xefca3ce7, 0x09dad3df, 0xf1dc6eae, 0x8a7fd82b,
	0x9817049b, 0x16a58bb8, 0x2582ec05, 0xc822318d, 0xeab754fb, 0x351ae9cf,
	0x2117c34b, 0x1d784259, 0x5ee7bf1a, 0x36b3f718, 0xe87ec085, 0x09d3ad7d,
	0x4d67c5fb, 0x7a0f9063, 0xcbafd75b, 0x1914fe48, 0x5fc821fa, 0x59187a46,
	0xdfcba51f, 0x02fbfa20, 0xb730cd7f, 0xc044f12c, 0xc30a9ddf, 0xb7cb15df,
	0xf267ffe0, 0xdf2a98ed, 0xeb4fa2fc, 0xa6e1cb97, 0x91896f91, 0xc162dbe4,
	0x5f70089d, 0x227077bc, 0x9bf175e0, 0xf9247c72, 0xdd8cadb6, 0xfdc4bdb3,
	0xa81a3b70, 0x234ebb7c, 0x7ca81adf, 0x208fe08b, 0xdf285729, 0xfe1eff82,
	0x2df206db, 0x15137ac2, 0xf2a83fb6, 0x09d3746d, 0x1ba36f94, 0x52ff3a4c,
	0x7eedc2a7, 0x2137cabd, 0x61e8167e, 0x2d8f6587, 0xe36cfd02, 0xdc4bdf7a,
	0x01c60e2f, 0xe2bb7739, 0x54aff1c2, 0x54ae79ce, 0xe09bfdce, 0xc5b9caac,
	0xd9fa093b, 0x2643a4f6, 0xa6ef16e7, 0x7a004e72, 0xf16e7264, 0x3fecc25e,
	0xbc36f906, 0xd8237c87, 0xbecc38be, 0xf81c692f, 0xbfb47de4, 0xb1ecaf34,
	0xdd69f6d0, 0x56ac6ef2, 0x48aeddde, 0xf21ee708, 0xc995f0ee, 0xde5c9dbb,
	0x08363951, 0x3e91abe4, 0xff7a4d3c, 0x4ee33de5, 0xf81affd5, 0xde2277e5,
	0xb1351d73, 0x8fdf88fb, 0xf40e953b, 0xf930ab55, 0x5fd394bb, 0xfb00597b,
	0x5b1afc9f, 0xb33d515f, 0x303716bf, 0x56b8b0fd, 0x3fe9ba0c, 0x5aff8ea7,
	0xede7f981, 0xcd224815, 0x6c5734cf, 0xfe1e83b4, 0x1eb84c82, 0x43553d3e,
	0x0b320b0f, 0x6e5c8ed0, 0x94266e75, 0xc448178f, 0x02e2f602, 0xa033d4fb,
	0x32641707, 0x2f0172fb, 0x552afd57, 0x7de352ff, 0xa2e3767d, 0x9e91fa37,
	0xcc33f6f7, 0x9e33af0c, 0x07e08213, 0x3f1ef3d9, 0xa0a17288, 0x89be5f4e,
	0xd8a67faf, 0x6f22f082, 0x112d9e89, 0x119367f8, 0x9c39874e, 0x70745c28,
	0xe1110a0a, 0x3d3d3144, 0x2e1ba135, 0x596bbf79, 0xbce6760d, 0x4bde024d,
	0xc2add71a, 0x157eb8cd, 0xb53daa8e, 0xd397f780, 0x64ef8354, 0xe151708c,
	0x1747846c, 0x78f00ddc, 0xa933955a, 0xc9f80c64, 0x3941ba50, 0x112ff813,
	0x137c2bfd, 0x73deea87, 0x3ff970d4, 0x64e262a6, 0x099f4eb8, 0x3eb4cd7e,
	0x1bd16abb, 0x631e14c9, 0xc1a773df, 0x78c37a76, 0xfdee1fb3, 0x513b5ab6,
	0xf874aa0e, 0x66c3a715, 0xbe9ecfde, 0x3cf093a5, 0x40b828d9, 0x5b09290f,
	0x9425ae11, 0xc9b4ad1e, 0x4e5f4da1, 0xe17570e5, 0xbe469d7b, 0x983c513f,
	0xeea4dce0, 0xbef64157, 0xc3134c67, 0xc31d494b, 0x44e93a4b, 0x95717efb,
	0xf5d309e0, 0x422e3714, 0x3e5566bf, 0x16bb3fd3, 0x57e8114f, 0x04bf448a,
	0xdd199a8c, 0x6f0166fb, 0xf15cc337, 0xcc1bdc0e, 0x8351fca0, 0xf7ff4864,
	0x397df42d, 0xbe23147f, 0xb974e0be, 0x076ae00d, 0xfd3275f8, 0xbe35fc2b,
	0x4beb51fb, 0xae0e80a4, 0xc8ba9f93, 0xe0af6fe8, 0x174bfb06, 0x699e80dc,
	0x6e1558fd, 0x8780cf40, 0xf2112ca6, 0x7dde14d9, 0x2f5cf606, 0xf969bfdc,
	0x09ef6f3e, 0x8233ffd6, 0xf7584487, 0xefefa677, 0xf1bdd748, 0xfa0657fb,
	0xf3b5bdfe, 0xefa018c8, 0x3df202bd, 0xddd18a69, 0x999a25a3, 0x4ad5b15e,
	0x6fee00f9, 0x9b3d94de, 0x83e53ddd, 0x0ce0ccc5, 0xc6b709e7, 0x2c0d72be,
	0xeb17fc04, 0x867fe82c, 0xf4c418f3, 0xdebcad55, 0xb3f12566, 0x3fef7bd2,
	0x9bdff781, 0x47e6a4be, 0x472078c1, 0xc378e91b, 0xee33c7bb, 0xe0fdaa17,
	0xfc1aeb72, 0x1d4bae4f, 0xe7fabbe7, 0x00895094, 0x9faa2ff7, 0xbfc9924e,
	0xfd7b865c, 0xf7a48269, 0x78e4eb77, 0x4ffba7fe, 0x7fa5be51, 0xbdd16492,
	0xb459bcbf, 0xdb850093, 0xf9195e67, 0x6f196a85, 0x63fd804f, 0x6907dd12,
	0xb191d9f2, 0xf587deef, 0xdce7de22, 0x453ebbf1, 0x0775df70, 0x7722c9f3,
	0x3fa80aa4, 0xc6ce851c, 0x216e1e81, 0x921f335e, 0x1f5e67d6, 0x12778413,
	0x9315b5a9, 0xd3af94dd, 0x90e582ea, 0xc677267a, 0x35f01efd, 0xaf802451,
	0xc99f6f66, 0xf83effb0, 0xab854909, 0x6027aa5d, 0x4987693f, 0xef1bb43c,
	0xcce3c78d, 0x8fcf86b8, 0x37e745dd, 0x71e888ee, 0x0f3376d3, 0x67c0edd9,
	0xc44dabc3, 0x78cb81af, 0xbb072c12, 0xde93b8d3, 0xe41e40bb, 0xde07bd52,
	0xd536e42b, 0x5f213b94, 0x25f7e02d, 0x2754ff01, 0xaab6df9d, 0x05af53f3,
	0x41db40b9, 0xacd52537, 0xe0ad495d, 0xecd99701, 0xdfe8f5a6, 0xe02b5d92,
	0x416db883, 0xbf585881, 0x77ed0b41, 0x3efd355b, 0xfa2ff61d, 0x7b5bf43d,
	0x205dd8fe, 0xf13ce877, 0xff767afb, 0x73bf4d9b, 0x2ed49f03, 0xaaf2fec2,
	0x2aef0205, 0xfed9eb72, 0xf6447b94, 0x81c37d40, 0x4eefb84d, 0x0f25e3a7,
	0x3c28fd84, 0x8ca7df05, 0x2ef85c11, 0xe50536b0, 0x182c074a, 0xc01dc83e,
	0x9e05e3ee, 0x551fe7e7, 0xccc4fbff, 0x3db384fc, 0xb43e95cb, 0xc667df9f,
	0x3d21340f, 0xdd7bc79d, 0x7ede1493, 0xdca3ef0a, 0xe650e23f, 0x668b4ac7,
	0x0659347f, 0x682ffd23, 0x037e889c, 0xfd0f890b, 0x638c6606, 0x375be77a,
	0xef60835a, 0xecee4b7b, 0x6e87e50f, 0xfb796334, 0xdb872636, 0x7da0b407,
	0x4cb554f7, 0x79453de0, 0xe27288b5, 0xef8cbd54, 0xd867c540, 0x36ce797d,
	0xaa1c87a6, 0xaa9efd66, 0xe4dbfa63, 0x15307e67, 0x2d9ce1f6, 0x2aa8ddec,
	0x6873d5a7, 0xb74f2bb6, 0xace519bf, 0x388b872a, 0x6a2b723c, 0x28d6def0,
	0xfdd48b77, 0x8b6f20d0, 0xef173ee0, 0x47c8c36d, 0xbfa32145, 0x5cfbbd92,
	0xfe10f403, 0xf8bbe91a, 0x5ce04c88, 0x36dc7c23, 0x60a3fd15, 0xe3f5a7bf,
	0xdc2f049a, 0x67bee7a3, 0x1e3ea20e, 0x63f79acc, 0x37de67d8, 0xd0827813,
	0x72a0f80a, 0xf9dcd32a, 0xf96827e7, 0xf016a399, 0x93f4a144, 0xfd57f085,
	0x30b7d34e, 0xa3f4923f, 0x7ef00995, 0x83e94c95, 0x4aa72072, 0xdc8d7e24,
	0xef782338, 0x0fed87ba, 0x697fad2e, 0x0d9152ba, 0x85ba6cfb, 0x16f747c9,
	0x7f1fdf19, 0xf447cfc0, 0xa17e80bc, 0x27d7bb79, 0xc87a1a28, 0x813ebbdb,
	0x9ab20e8a, 0xf3945ffb, 0x0a79cb77, 0x9f6f271b, 0x8cd1aae0, 0xf6a3f6a3,
	0xdf66ecab, 0xd2cbde0d, 0x83cffade, 0xbf3ae1f9, 0x186e4050, 0x7e31e9fb,
	0xfe64fd2f, 0xbc2562f1, 0x4b7ccf33, 0xcce9e744, 0xd60fa78f, 0xa9a827de,
	0x38ce676a, 0x0d5e2266, 0x1cff32fc, 0x7c1abc45, 0xfca58c37, 0x7b77f14f,
	0x1ae7d323, 0x8a509ec6, 0x02ef31d2, 0xf6e62f7e, 0xec29e2e8, 0xf521a89e,
	0xffe04ae8, 0xd202e9e9, 0x95f80903, 0xbfa8713e, 0x39ffc1b9, 0x9f7d9d27,
	0xbe07bf43, 0xf8c4d86c, 0x370bca94, 0xeae293c8, 0x7db153f5, 0xfe86e0ad,
	0x50b26a1b, 0x14cdc92f, 0x9ed7d609, 0xb7293d40, 0xf01c44f1, 0x4adfe533,
	0x278a07d0, 0x8e205d98, 0xf954be55, 0xafee2dfc, 0x51ae2c4c, 0x35605ef0,
	0xfe045530, 0xae108f16, 0x2cbe32b7, 0xfb7c64c9, 0x561936d6, 0x8e7c2578,
	0xb1f2ad7c, 0xde9c7c08, 0xaa87c7cd, 0xd7c02b27, 0xfa0282a7, 0x39064c6b,
	0x55be7c00, 0x7a619bf5, 0xf9f295ec, 0x22ccf4e5, 0x5fb0bfca, 0xf2ae7caa,
	0x9b9f91b5, 0x305996a5, 0xb46f078f, 0xdf263ae2, 0x079dfbb4, 0x7bc2bc99,
	0x2d37c9be, 0x98f9004b, 0x21bf312d, 0x1245ae15, 0x31eb33f3, 0x4ae5caaf,
	0xcfcc95f2, 0x66ad8f30, 0x03e4bdbd, 0xa7f30c73, 0xee9195ae, 0x3d9fc72f,
	0xf90aecf8, 0xeaf94af3, 0x8ea9fc72, 0xf7d5ee2f, 0x710001f3, 0xdafecf6c,
	0x14c31c29, 0x7fa9bf8e, 0x3f4dfd0e, 0x0cc4f17d, 0x1ec143c0, 0x5f40e74a,
	0x06120ef5, 0x71052739, 0x106fcadf, 0x2b8fe8bd, 0x72ee3385, 0xf998f968,
	0xe4bc150d, 0x7fca7a40, 0x4e9c1cd9, 0xf5dfcfbf, 0xdff468f1, 0x7e89d158,
	0xb9178150, 0x19681cbe, 0x2f907c0d, 0xa325ff31, 0x30b3c85c, 0xb76db9fd,
	0x4fac366d, 0x12f163a8, 0xcb7743f2, 0x853dcd66, 0xb8e322df, 0x27de1db4,
	0xc31d2806, 0x9f98527b, 0xeabe9df6, 0x95b6d4b7, 0x46fc89c9, 0x17710839,
	0xb476ebf2, 0xfe6aff83, 0x7fb4667b, 0x479dd495, 0x2fc9fcff, 0x4afb436d,
	0xbba8a349, 0x2fe1eb87, 0xcd862758, 0x50d6e7e0, 0x3486f784, 0x21f3027f,
	0x1df79fee, 0x5e0ad9fd, 0x402bbbda, 0xebf05841, 0x5f209c17, 0x716f36ce,
	0xbf69dc02, 0xdbbfeadf, 0xf4303fc3, 0xbc0ff728, 0x73c114fd, 0xc0ff644d,
	0xca0ff0b3, 0xf4584f28, 0xaea481fe, 0x7497ea0f, 0x08be199e, 0xfa5d1ff7,
	0x9e2fb6f9, 0xb6f6ff05, 0x0b3dcf97, 0xfbfc2ef3, 0x3f82cf67, 0xc567d912,
	0xc5e4af7d, 0xb81fd1b7, 0xf7c1dceb, 0x2fadf6bd, 0xfb753fa0, 0xf40f66fb,
	0x54f7bed6, 0xb5a5f80a, 0x013af8ef, 0xf64b99ec, 0xdef68cde, 0x27273b25,
	0x86fb0892, 0x06fd029a, 0xdb9fc0af, 0x0d43b788, 0xea6fd087, 0x90778a53,
	0x9f7e5d83, 0x4fe622a1, 0x9efee6eb, 0xe7fd91f5, 0x3677f87b, 0x8dc775dc,
	0x981bff20, 0x3f59793e, 0x9f1463cf, 0x1e015dd7, 0x6f3fb9eb, 0xf56ff6e8,
	0xfe14fcf3, 0xc475f141, 0x1a2fc780, 0x29f2fe16, 0xd3e86ba8, 0xf8679fab,
	0xfaa7e00a, 0xbc5957e7, 0x8f805aef, 0xfa15fe5e, 0xa6fe02d7, 0xfa3f61bb,
	0x37de0522, 0xe73b969c, 0xb9d3fec2, 0x63f18cd7, 0x8bbef7f2, 0xf3bed4fc,
	0x09a9da28, 0x276f93f7, 0x9fcc7f5d, 0xadebe059, 0x50ff3075, 0x1ff0078e,
	0x9cb13b75, 0xba3289fb, 0x7b47fd56, 0xb68d1bf3, 0x7d5bfd32, 0xfb545037,
	0xecc7f701, 0x09909bc6, 0xadf13af8, 0x1c2ab97e, 0x772e5c5c, 0xf64745fb,
	0x8bf2edd3, 0xf00de036, 0x9754fb09, 0xf7cd33df, 0xc93b434f, 0xecfc91bb,
	0x3f986bdb, 0xf91cbb75, 0x27eaaafd, 0xf835651d, 0xccaf0747, 0xeb72fa3f,
	0xfa70aef8, 0xc68a506f, 0xdb5784f6, 0xfbe59137, 0x0ff0ab28, 0xdebbef9d,
	0xc60a14df, 0xad233df7, 0xe48fc163, 0xbb33da04, 0xbd7cdfce, 0xdefedc6d,
	0x7e88a2f6, 0x8743abb3, 0xe51bbe50, 0x01c43147, 0xefdf3089, 0x3716f9f1,
	0xeda3fdb2, 0x4ed04765, 0xb83b69fb, 0xb8bae91b, 0xedfa04fe, 0x6bf751be,
	0x3fe345a5, 0x5047fb01, 0xedb69eb3, 0x3ca34607, 0x8c46f1e7, 0xc7cedce3,
	0x3c8a6929, 0x79fd494e, 0x810538dd, 0x5fb2e290, 0x92b3bc7e, 0xefe86ef7,
	0x13d3336c, 0x69c486cf, 0x799fde91, 0x0fbf32ac, 0xdd2960ab, 0x8aae3147,
	0x1151c583, 0x77a8519d, 0xbe64712e, 0xa9071d17, 0xe543fe82, 0xd1bfb9cb,
	0x80493c4f, 0x6dc772ef, 0x0abbe604, 0xffb1abe0, 0x013f2ec8, 0xf24e557d,
	0xc1dd83a5, 0x38947728, 0xf06a0913, 0x2d31c4bd, 0x22f78dd1, 0xcf80fee1,
	0x64a7a9e3, 0x8343f7e8, 0x8943eafd, 0xf3a44eac, 0x782030fb, 0xc97ed396,
	0xf00f1f37, 0xdff67a39, 0x223c37a5, 0xc54decea, 0x70e3cee6, 0xadfb215e,
	0xee211f78, 0x8a3c62b3, 0xb8ad6792, 0xbf3b43de, 0xeef51e7a, 0xbb099a5f,
	0x1aa7a21f, 0x62e58388, 0xf9da9c7d, 0x057fb3d5, 0xa63e1abd, 0x4b3ce7e3,
	0xa279c3db, 0x9fe786de, 0x47a3978e, 0xffbcfea3, 0xd72019e1, 0x1e8c6c72,
	0x0c4a5e73, 0x5afed396, 0x75be59e3, 0x7f8c00db, 0x03b2f050, 0xed0f18fd,
	0xf618a57c, 0x6c97f6a9, 0xda4066e0, 0xfffd73f7, 0x535e3c57, 0xfad6ec95,
	0xc911e733, 0x52677dad, 0x8f567900, 0x2ff055ef, 0xd811f383, 0xf1a31ab1,
	0x8bd50a7d, 0x2a7cfd75, 0x41e43e77, 0x65f40e3a, 0x7dc272ef, 0xdb181e41,
	0xb91bf5a9, 0xd3312dbc, 0xedddecef, 0x6cce944b, 0xcbe8af96, 0xb63349e4,
	0x73a54e7f, 0x5fb3df5e, 0x3ac6bed6, 0xfd4ed748, 0x4bc798be, 0x76efd231,
	0xd9dfc0ab, 0x48eaedfe, 0xcc2240f1, 0x247fcb1f, 0xf4098090, 0x8c561d96,
	0xfdef0503, 0x977e8fc1, 0x0abfeec2, 0xc78c619d, 0xe3cb87b2, 0xc630a8c2,
	0xe7cbe987, 0x4f21ed01, 0x01db2d2c, 0x58af45ef, 0x2a17c409, 0x02f0efda,
	0x7d768bbe, 0x3a74fad5, 0xd0d9c9f8, 0xffb457ae, 0x8a0e903f, 0x18b9e1cc,
	0x99876d6f, 0xb6b63c40, 0x00a66f1d, 0xe1c9b6bf, 0xb96fd894, 0x990a2bd7,
	0xf9d4eff5, 0x0596ce3a, 0x7e3bc087, 0x7e67fdf5, 0x1cc6722f, 0x3febf4c5,
	0xad47bd5a, 0xb8faefc8, 0x1acb6743, 0x83df6b07, 0xcb23bbe7, 0xf2ac4fc5,
	0xedc7273f, 0x7e51de3d, 0x94f9f302, 0x01802734, 0xe3ea98b2, 0xebf3cf20,
	0xfb028fce, 0xea5187c1, 0x3477797b, 0x2a1f47ec, 0xfe40a39d, 0x39d2987d,
	0x9ccfbb4a, 0x25b8b32e, 0x983aed19, 0xcf9cd476, 0xafc04bee, 0x923b3ad1,
	0x6acafbdc, 0x3fe47843, 0x7a46f362, 0x31452987, 0x63056aba, 0x171b3c40,
	0xf71d43f8, 0x72882543, 0x1b944578, 0x07fbf3eb, 0xa82f2815, 0x0b583ddb,
	0x02a93c87, 0x453e51db, 0x4a91e678, 0xbf235d25, 0x96f2f1d5, 0xbe12ddda,
	0xbbfe9777, 0x6ec55e8b, 0x5911a33c, 0xee8f0f13, 0x566768b8, 0xb2482bdf,
	0x53f002cf, 0x8925cf88, 0xc8152a40, 0x842451ef, 0x5daa9da9, 0x2956fe2c,
	0x9a793901, 0x1d83efdf, 0x786ed20c, 0x1fb9432d, 0xd0c84018, 0xc0bf1081,
	0xc0d2ed1d, 0xeb2e062f, 0x52cc7ce9, 0x62f26129, 0x4ff40bba, 0x9727e021,
	0x97953d28, 0x71660dd5, 0xde178825, 0x4b0aa1c7, 0xbd74e7e7, 0x41e835f1,
	0x5c594e94, 0xb0489bbb, 0x0c7f005c, 0x08932796, 0xf6b6c78b, 0x7f3da23d,
	0x7c094464, 0x8e5007fd, 0x5ff749d9, 0x5883cd27, 0x1e5b7905, 0xb84cf7fd,
	0x48bbb39f, 0x9b43f418, 0x346d849d, 0xce948fb5, 0x99dff96a, 0xba1af34e,
	0xd7d04d74, 0xca82f91b, 0x21b8c335, 0xf7ed1f84, 0x9fbf4373, 0xfcfdfa1b,
	0xe155fadb, 0x3c196254, 0xac1ce210, 0xb8710b2a, 0x1c2cf1b1, 0xc33e146e,
	0x311c6e21, 0xbdf87945, 0x8a35c239, 0xed0cc6cf, 0x45975e29, 0xfd38440d,
	0x275f7a34, 0xb892e5f8, 0xe1e7022a, 0x3f1a8295, 0x9aecf892, 0x82cb88ef,
	0x1f28f87c, 0x77a71967, 0xcf7d9df5, 0xbfd456f6, 0xf6b7b47a, 0x722a3ed6,
	0xf36f477b, 0x4f9e45b1, 0x57fd2f4c, 0xfff622d8, 0xf152e55d, 0x0f7f77fe,
	0xf25dbbf7, 0xaf4145c9, 0x459733d7, 0xd3199e81, 0x2c16f7fa, 0xa5a67a61,
	0x51df1ebf, 0xde94df40, 0xcbe886a2, 0x8112748d, 0x74c9ecbe, 0xf1f0f7dd,
	0xbd8479ee, 0x20e9528b, 0x4a6faf8b, 0xbf27bb2d, 0xe3b3096f, 0x17a363d1,
	0xf5e5efea, 0xfd3155f7, 0x4447bef1, 0xc63587bc, 0x9ff13a4b, 0xfdc3ae2c,
	0xedf94050, 0x3042a5fe, 0x1c52303c, 0x862c7228, 0xcf8f3bf6, 0xc95718c7,
	0xd753dc4f, 0x2ae2918a, 0xdf54ba31, 0x29e3197b, 0x1e3e202c, 0xfe5f4b2f,
	0xc98bab77, 0x54a82961, 0xc7deec8c, 0xdd29eb02, 0xe949fe83, 0x44bfee1e,
	0x3897befe, 0x3dc7e615, 0xff27562b, 0x47770c2e, 0x5e4d7ec3, 0x562ee5e3,
	0x3b9c78be, 0xdf234631, 0x5d368ba5, 0xd972995c, 0x4df20493, 0x712d78be,
	0x2e543e53, 0x4d6e21f6, 0x915bd53d, 0x13cdc1f9, 0x149254e5, 0xb928b904,
	0xf407247c, 0xcf4618de, 0x6e257b6a, 0xf99e9744, 0x476ffd16, 0xe5f23c54,
	0x44ee45e2, 0xcd98e718, 0x49e81077, 0xfc7a6674, 0x10f49ef6, 0x5dd6c6d8,
	0xd81eeb0e, 0x8ae53d73, 0xf6fa83c7, 0x3c38aef8, 0x689f9816, 0x86ebbf76,
	0x2656fdf9, 0x09e98760, 0x20e9cf1f, 0xec10bfad, 0x62247e87, 0x3061f4f4,
	0x729f1abe, 0xa4afc42d, 0x1e4ac0fb, 0x8f2572cf, 0x8f18f95f, 0xc79aba37,
	0x67e154b5, 0xdc6054f1, 0xd610cb44, 0xf1c5c5bf, 0xf0e26713, 0x657ea3f1,
	0x7bc52a49, 0x34abab45, 0x48c7f10c, 0xc0afba7f, 0x08155db4, 0xd045c53f,
	0x63db499e, 0x9a790cde, 0x112355ca, 0x94ab920f, 0xedfad0e4, 0x801b7f36,
	0xc7d6ead2, 0x0d273457, 0x1b23dc32, 0xd3d2a9e0, 0xe3472626, 0xe1193d38,
	0x78b0a713, 0xf51d2aa6, 0x739587a6, 0x1e72dfff, 0xe21cae4f, 0x6cb8511a,
	0x5a62f328, 0x951be3ce, 0xbcb1f853, 0x7e78d307, 0xcb2f2cce, 0xf927fac4,
	0x365e5bbe, 0x3659d30d, 0x99c5cfb6, 0x00c80f4a, 0xecc258a7, 0xd20171a6,
	0x5730833f, 0x0a4bf853, 0xd5e43710, 0x3d5ac87b, 0xc92e887d, 0xfdcf1710,
	0xf2a9e024, 0xf704d94d, 0xefd2e2c4, 0x8aa3deeb, 0x6031bdb3, 0x7eed1387,
	0x9fcff601, 0xfce99e02, 0x6279d3d6, 0x1f4e599c, 0xac1d38ab, 0x28f1f4e1,
	0x33fa778f, 0xd38f274e, 0xdcbe4275, 0xac2bdec3, 0xeafcc69b, 0x3c4d52e2,
	0x68985c2e, 0x3c62d6fd, 0x75d0a221, 0xc6ed0ea2, 0x91fee314, 0x3f48ccf7,
	0x2bc491b6, 0xcb7bfd42, 0xa78e2c82, 0xddf6192f, 0xe76e3518, 0x1ccc7704,
	0x961b887c, 0x913c7c78, 0x239a5b9d, 0xf72cbbc6, 0xf9c0b41c, 0x1cf9b7bf,
	0xc08bb998, 0x21d7d978, 0xbf1f487a, 0x9a42ce6f, 0xfd5157b7, 0x3cd9fe9d,
	0x40558cfe, 0x020e55df, 0x3a76727e, 0x9d0d1cff, 0x23b17ad8, 0xeaddb49c,
	0x9f7e51b5, 0xc50a8a08, 0x06aa2fef, 0x14ce015b, 0x97b06ee6, 0xc97d906c,
	0xc4361720, 0x8cfbb644, 0xb9f3b1b0, 0x8e847d33, 0x2f652bce, 0x909ae77e,
	0x4a87e3a6, 0xa7628f2e, 0xab95d78c, 0xc6ce27f2, 0x3663f7f4, 0x4d1b2cff,
	0x214e2e13, 0xb8bdca84, 0xa3cb233b, 0x40095972, 0x51f2829c, 0xb205fe4c,
	0xf5a7a614, 0xed042f90, 0xc3fc17f1, 0x45bd8336, 0x8415b3a5, 0x6100b3c9,
	0xaeba8bfa, 0x28f7408d, 0xff485c77, 0x681f812b, 0xb0a21c5e, 0x99f7ad78,
	0x9abbbcf0, 0x9c63dbf3, 0xfe71d6cf, 0x97f039fa, 0x7aefe219, 0xe705fd30,
	0x43e04aab, 0x31b0ae9a, 0xcf18c87d, 0x0d25857a, 0xdb95dce3, 0xa49f284d,
	0x3b41cdf7, 0xc607a1e8, 0x20cec0b9, 0x7e5dd23a, 0x5ba7d407, 0x110f70bc,
	0xba02ee93, 0xe0b1d2f9, 0xbbf36faa, 0x78c7e8a4, 0x878f12ab, 0x2ebfc6ad,
	0x21aaefe7, 0x45d8363e, 0xb52b8c9f, 0xd9179c02, 0x2aac79d8, 0x4ee1032b,
	0xa6c6b1f1, 0xce240f39, 0x4e2badbe, 0x64ff7419, 0x9fb3ef2f, 0x87bd31b0,
	0x21900ff4, 0xc551391a, 0x7711e0e3, 0xc8d70c80, 0xa743158b, 0xf523b012,
	0xc8bd1394, 0x6e4c2dcd, 0x3f7c0b96, 0x9cbde032, 0xe55727c7, 0x8f7804a6,
	0xd56c1f10, 0xef74d355, 0xf72e64c9, 0x6deaed8d, 0x9ab65cec, 0x42fd3a78,
	0xa70a7acf, 0x949c2d7a, 0xcebadbb8, 0xb08bdfc5, 0x3c7ca30e, 0xc826fb0d,
	0x718fc91c, 0xee281652, 0xdc81c727, 0x8fe62ff9, 0xa15e9bd3, 0x3173978e,
	0xeca5f70f, 0x5f50e38b, 0x15baadc8, 0xb70243f7, 0xe3f79a00, 0xe47faaa7,
	0xaa9ebc04, 0xd5b3f7e2, 0x63fc1072, 0x2aad554e, 0xd5857cc6, 0xf899380d,
	0x884e658b, 0x59e0b32b, 0x4f6bef11, 0xd0520547, 0x4b9bf0bf, 0xff8d4497,
	0x359af2c5, 0x0b874029, 0xf7c1af36, 0xbd63a77f, 0x3c9a7cc3, 0xbea37749,
	0xcb9bc6a8, 0x05ecce7e, 0x7a37af7d, 0x6c8eaecd, 0x7f87284f, 0x3c4c1e82,
	0x3dcf41c3, 0x19df1ce0, 0xfd3ff8a6, 0x9dea2b0b, 0x1da04ae5, 0x6d9be5f2,
	0x8f2905f0, 0x64bf1c8d, 0x77e6edbb, 0xb76cbe40, 0x94843f79, 0x3ef163d8,
	0x61fe77a1, 0x2d82b7e3, 0x9ef5ee17, 0x285c71e2, 0xecea669e, 0xaf5eec7a,
	0x8869db95, 0x28fa97a5, 0xa5eeef5e, 0x70fcc9de, 0xfd722b88, 0x18df6c3f,
	0x20fce3d9, 0x50fce1d8, 0xfbf56e75, 0x53b7a258, 0xdfe7e19f, 0xc16d9b05,
	0x92f41115, 0xe51dfc05, 0xa31f7e02, 0x2e99e3d2, 0xb1d18ffd, 0x4a42ff3a,
	0x068f4897, 0x185e17ba, 0xd9fe7485, 0x37f71961, 0x311b85e1, 0x45f14d8e,
	0x42ffca2b, 0xf838f3d1, 0x44b793a7, 0xdf0783e4, 0x71f78b1c, 0x9a78866d,
	0x4f4cec63, 0x8becd351, 0x397d3a05, 0x015f383b, 0x62fb227d, 0xb013e331,
	0x8161839f, 0x5131bfc4, 0x1e3cf4e2, 0xba998fbe, 0x69cbb682, 0x2644fc61,
	0x3ed18a04, 0x80f3635a, 0x1f48cd1d, 0x9d6eec63, 0x4b4e635f, 0x1ecefb21,
	0xff1a7120, 0x2e3c0585, 0x1645ce7d, 0x02b8923f, 0x88f80924, 0xfa6ebfcb,
	0x6e0fc7d7, 0x307a3133, 0x5f0a77ae, 0xf5ae94e7, 0x7acbd0de, 0xe5eb626f,
	0xcb4e49fa, 0x9ebac338, 0x5d69171e, 0x8099ebdd, 0xbc790bed, 0xc31342e7,
	0x645f5abb, 0x4d5e7267, 0x1366cb5b, 0x79a7952f, 0x7664fe3c, 0xe40541f0,
	0x4c757648, 0x6759a0ac, 0x3abdd54e, 0xaaec9b3f, 0x96538c2c, 0x3ca59d53,
	0x2edbe1a0, 0x3a3c053c, 0xbbad153c, 0xd274f116, 0x07639be6, 0xe8be7cfe,
	0xf40957a1, 0x5a76f0cb, 0x452e8c09, 0x33a0f739, 0x229d3bd2, 0xed58dbc0,
	0x86de387c, 0xed48c804, 0x918ba97b, 0x6eb67de3, 0xee087829, 0xb1375beb,
	0xcbbd2ba8, 0x34f8c8b3, 0xc72d71c2, 0x52b69aa3, 0x457fc23d, 0xe756bc70,
	0x1c2bd5ef, 0x3855fe39, 0x0f54e5a9, 0x60720e5c, 0x58ecf02d, 0x15dc6fe8,
	0xfc7bafc1, 0x77bdbc09, 0x8f9026d8, 0x9f031e54, 0xa7fe799e, 0x6ddfb5a3,
	0x19fc4db7, 0xae2a438c, 0x64d05eec, 0xbc046ff7, 0x0e792606, 0xb031f9c3,
	0xd394f459, 0x3f45e775, 0xd5c61ed5, 0x55d3f7ea, 0x83878765, 0xacbcb89d,
	0xeb995319, 0xbbf40477, 0x7eae2c81, 0xbb5d78a4, 0x2aaedd39, 0x2e76666b,
	0xc0b8804b, 0x5f18499e, 0xd063d392, 0xf5d927ee, 0xfb22897a, 0x5467605d,
	0x596f3bf8, 0x981daff2, 0xb8f2e70e, 0xbe0680d4, 0x3c59d8af, 0x074975af,
	0x363f605d, 0xdec1fed3, 0x5d2fe960, 0x5e29d9d0, 0x28381693, 0x5a61a9dd,
	0x2bc848a3, 0xb9b76808, 0x5cdbb060, 0xae23cdd0, 0x35d76759, 0x38b245c2,
	0x2247bef1, 0xe1c75edc, 0xc94efea1, 0x2b872e1a, 0x236fddb9, 0x8286fbd8,
	0xfdc4ea9e, 0x2655f56e, 0x48b1ce76, 0xdc068718, 0x12bda090, 0x0561d6cd,
	0xe708b17b, 0x1de6308c, 0xc447b110, 0xe40267d0, 0x805b8863, 0x5e121f7c,
	0xc7737a0d, 0xa08796c4, 0x7fd5917c, 0xcbe1e814, 0x02e3e6e4, 0xfe7d7fd8,
	0x55ce01ab, 0x4dd52062, 0xec52ffdb, 0x2976854c, 0x58bdeab4, 0x7e055e96,
	0xbdcd7ee1, 0xda978b12, 0xe67b179d, 0x192a5aaf, 0xb9be59ee, 0x47ff5b5a,
	0xe805b7ab, 0x357bf8cc, 0x280b1f71, 0xaab19eef, 0xdf0f99fb, 0xf1c37d37,
	0xf401f489, 0x03e99875, 0x74772417, 0xba1fb32c, 0xc9d9d35f, 0x34d7ee2d,
	0x3cfc49e3, 0x15e94b56, 0x3a5403ee, 0x4d792219, 0x2b434f40, 0x2e96b968,
	0xb17de822, 0x1c1b0c76, 0x9d453ef1, 0x006fbc1f, 0xa7178a78, 0xa46a3ee2,
	0xf65d3d8b, 0x367bf657, 0x93c25473, 0x0c7cb256, 0x9cf0ff51, 0x7d977ef2,
	0xbbcb257f, 0x01e4ae58, 0xa7f89f76, 0xcbf468ac, 0xa731e753, 0xe8334d69,
	0x929a7379, 0xd2fdc3e7, 0x3fabdc9c, 0xdc8f7481, 0x7206d079, 0xde2c47e2,
	0xbf6f3de9, 0xba68db26, 0x7c66d8f3, 0x60e89e2f, 0x749738fc, 0x3f7f80ca,
	0x7eec2971, 0x0fe58820, 0x87cf0f10, 0xdf773864, 0xe0fe0e17, 0xffbb9a76,
	0xa0ede0b5, 0xdc3dccbe, 0xcba03af9, 0x454d721f, 0x5dfabc1b, 0x960de7a3,
	0xad75df67, 0x7ae0b25f, 0xc16bd7ba, 0xa3ebabf5, 0x77f84533, 0x63c787c1,
	0x6931e152, 0x1cf75b3e, 0x91b7bddb, 0xe76bd16f, 0xc27d4658, 0x7cd89ffc,
	0x1cf9f08c, 0x4c5ca8aa, 0x1cd37871, 0xf0e1deb4, 0xd0b4818e, 0x0d2299d2,
	0x1eb97e42, 0xffa2c5f2, 0xfeba04aa, 0xaff8074f, 0x3438078e, 0xfd22b9f7,
	0xc995b8f5, 0xdf40e381, 0x03e3bc74, 0x8f06f3d5, 0x87185f8b, 0xe9c79aeb,
	0x53cef56c, 0x7e0f5f6f, 0x38b26f49, 0xfba24553, 0x8ed1878e, 0x71489227,
	0x38f4d56a, 0x1cfb2f3f, 0x20d67bea, 0xf8c3ef8f, 0x0d835e65, 0x5bcc0ddf,
	0x5de2ea2a, 0xfcca5bcf, 0x3cd48907, 0xef4e967a, 0x3f6bd95d, 0xf6379e70,
	0x64e97f33, 0x52ede73c, 0x7cf1135c, 0xb3a32cff, 0x22bc53f9, 0x5f8f5df8,
	0xe7bde02b, 0xc6ee93b8, 0x1f9f9a16, 0x9b00f18c, 0xc7f65fce, 0xa24f10c1,
	0xf9d999b8, 0xa945c512, 0x86e9a13f, 0x85ff6c83, 0x938022fc, 0x6bb6ebdd,
	0x726ddfec, 0xe80baa69, 0x17bb7ef9, 0x2cd640e4, 0x5780fbef, 0xeaaf7cf5,
	0x7dd0af11, 0xb2e8fc19, 0x026773ee, 0xac85649d, 0x442d4c5e, 0x2d72a28a,
	0x4816224b, 0x59221513, 0x16228d21, 0xb0563348, 0x55d9e2b8, 0x773f7133,
	0x8814fa66, 0xf4d59c2f, 0x7df017c2, 0x203e148e, 0xab2ae868, 0xf1afcde9,
	0x87d7925d, 0xd6d7927e, 0xd4f3ba29, 0x7f3e90a8, 0x9f3ea35d, 0xc7e7d61a,
	0x8fe7d61c, 0xe943ba83, 0x3dff3c69, 0xcd7b83b0, 0xa82f7e04, 0xfa3325e0,
	0x7b0abeed, 0x5a3ffa05, 0x2e4e2e51, 0x7b80ca68, 0x1ddb73e5, 0xedbbb026,
	0xf1afdbf9, 0x9b73ba5e, 0xd65f808d, 0x91453f81, 0x7c7bf028, 0xea19bac9,
	0x609f680b, 0xc9782c67, 0x07fe035a, 0x74a846bb, 0x91ff441a, 0xef677f5d,
	0x9ab73a03, 0x7d4f7083, 0xdb0bf76e, 0x6dcf2e81, 0xd17a87ed, 0x04c042ab,
	0x651e05fd, 0xc51f1f78, 0x147c7ee8, 0x3a82fba3, 0x57f2f9fd, 0x7adf550e,
	0x7bec046f, 0xbc1963e3, 0xb04ecb5b, 0xaeeb8f3c, 0x79e353ea, 0xc5177e3c,
	0xbb2347e7, 0xf39c3cf1, 0x01f0764d, 0x5af88bc5, 0xacf2051e, 0x0f328ce3,
	0x57572bec, 0xd2a8e1e9, 0x7d4135f7, 0x7f970379, 0xf94d100f, 0x77dfb840,
	0xfd824eaf, 0xf11239fb, 0xce1ee77d, 0xa8be2f6f, 0xf220fca8, 0xadc471f8,
	0x2dd68779, 0x7e92c9f7, 0xf8017fe0, 0x5e5dd41a, 0xed571860, 0xffde61ff,
	0x7fe61667, 0x70e1c71d, 0xea30ecb6, 0x717a5d0d, 0x453bd799, 0x3aaecf93,
	0xf0859090, 0x80f0903b, 0xf5b83cf6, 0xe0bdc250, 0xe1275457, 0xce1583ef,
	0xe3e7fe79, 0x0c5ca0e3, 0x1ea13cc1, 0x7a16d8e0, 0xa8ed09dd, 0xf5a69bde,
	0xbaa9c9d3, 0xc3453bd9, 0xce95dff7, 0xbb8ee2bb, 0xc95e5c18, 0x3b75ddf4,
	0xe8b55dd0, 0xa1056681, 0x147f7c1f, 0xc65abbc0, 0x3b85c7f7, 0x5f838c64,
	0xda037352, 0x8fea0a4b, 0x8a78c54e, 0x303cb29b, 0xf8890caf, 0x753434c4,
	0x74f482cc, 0x3f8c4ed3, 0x4a97f058, 0xe5094205, 0x8ee9e954, 0x8fc231d2,
	0x77195a6a, 0x97794f02, 0x5ab09fa3, 0x5e6fc46e, 0x11bdff50, 0x5053b24f,
	0xd70eb2e3, 0xaed8dbe2, 0xbe00f4cf, 0x4a5c2d17, 0x1ec69de5, 0x02b27856,
	0xe38d12fd, 0x977dcdc0, 0x037a657c, 0x6d7f0371, 0xf429fe63, 0x7064b04f,
	0x2cc1ddff, 0x8112718f, 0x23fd60ae, 0xbc3714c8, 0x4c93bd37, 0x1b955483,
	0xd1a1996d, 0xa155fed0, 0xb1a7f9e5, 0x6bf2073f, 0x718c2b9b, 0x77f2fb23,
	0x966e6db8, 0x433f7f57, 0xb26fcfad, 0xb9cb3fa2, 0xa394154f, 0x0e8fc1cb,
	0x9ab76fda, 0x3b8f544c, 0x24cfa3b7, 0x0b6ccff0, 0x67c3b8b1, 0x29267d43,
	0x1b3fb2df, 0x6fba82e5, 0xd27f809e, 0xd38475fd, 0x7a09d43b, 0xbfe64ad5,
	0x34a7d89a, 0x9e0234b5, 0x94e2efd4, 0xb73854d2, 0xf76fde74, 0x0538466c,
	0x87684a06, 0x423b424e, 0xdc9bb716, 0x39a5f2e6, 0x6da7bf61, 0xd8bff4bd,
	0xa066e2c3, 0xcf458faf, 0xddc1ae43, 0xd20b93f7, 0x096ef8fd, 0x8e82e87f,
	0x61225f3f, 0xf3c5ea89, 0x8d19bf61, 0xe717dc79, 0xc7e80b57, 0x7e9d60b5,
	0x56f7103d, 0x92e64fbb, 0x9f37ec0a, 0xadcd3084, 0xc1e7d7d6, 0x95e142be,
	0x0afe616f, 0x7afab5f9, 0x61543df5, 0x247325fd, 0xd4417db8, 0x03a779f5,
	0x2d3b84dc, 0x3707bf38, 0x17fbb344, 0xdf617885, 0x40e0dcec, 0xfc405e39,
	0xf87b8f38, 0x2cb25dfe, 0xa680bbcb, 0x7be74b1d, 0xf781f417, 0x439f6cc8,
	0x64be4196, 0xa60ab371, 0x1600f090, 0xfec084c7, 0x8424d059, 0x42de4147,
	0x5634ce02, 0x601cf10e, 0x3c77dafd, 0xdd61faea, 0x8c7272da, 0xde1f37e1,
	0xdd6c888b, 0x0e42fada, 0xb37ac28f, 0xbe317ece, 0xae38085e, 0x2d257783,
	0xc3715df8, 0x5faeb325, 0x7dd33fbe, 0xde29589d, 0x88d6e7c6, 0x5d0d98b0,
	0x4d7838f2, 0xc70277a4, 0xfc371c39, 0xf8193b20, 0x53d071f6, 0x674072fb,
	0x0818f212, 0x210cf1cf, 0xd45e3a16, 0xd63cae98, 0xf960ac67, 0x4df9fcff,
	0x3aa3d0b7, 0xde1f4efc, 0x7d17cccf, 0xb3fbc06f, 0x15fe5c8f, 0x4df37f40,
	0xf90914de, 0xed0c3bd7, 0x1c194b80, 0xbd2b4c9e, 0xb9c234a6, 0x46f3c559,
	0xa7f78421, 0xbf6cdd81, 0xca77a475, 0xd555f7da, 0x1f452e5c, 0x1777c16c,
	0x7c053b9d, 0x3849b9f7, 0x3722ef81, 0x7026eadd, 0x78a24fae, 0x49b9b902,
	0x6e212b20, 0xccc37a59, 0x9e03af45, 0x703ca3d3, 0x30d45b2f, 0xe3b22c51,
	0x663e99fa, 0x7b81ad2b, 0xc379c492, 0xe9de80d3, 0x49dde7ba, 0xdd3b37cb,
	0x3b64af38, 0x8ad27bc3, 0x23c5c0c0, 0xa2df7c61, 0x471f81d7, 0xe13be145,
	0x472b0a44, 0x416ba62c, 0xa9224acf, 0x27be4007, 0x81a7774d, 0x938379ad,
	0x126f138d, 0x3d04cde7, 0x63e58d30, 0x9bbc111f, 0xe3d70891, 0xf6668938,
	0x0e5054d3, 0xec05a37a, 0xbe0d760c, 0xc2a69727, 0x598389f8, 0xfb84a71a,
	0xba473f43, 0xbd47eef0, 0xa08b897b, 0xf5f25ebc, 0xdf3844c4, 0x07a3691d,
	0x8ec72a6e, 0x9fcf57f4, 0xe9ea3b61, 0xf6b38643, 0x9258df5c, 0xc425deca,
	0x127aa8a5, 0x7b21d76b, 0x5c80c7a3, 0xf5f4ca3d, 0xb45eedcf, 0x44a0decf,
	0xc23e83f6, 0xd17254f1, 0x7d9a8246, 0x97f664a1, 0x5c9647a8, 0x21caea74,
	0x9fd69f0e, 0x20f730b6, 0x222f49c6, 0x5d97e8cd, 0xfffbd214, 0x791510de,
	0x4bce955c, 0x10248a2e, 0x5f455c71, 0x090fb17e, 0x2ed489f4, 0x517e5f41,
	0xbf1be7d0, 0x2c24ede2, 0x4e2d9927, 0x874e0738, 0x3be688fd, 0x7c80a682,
	0xda5e375d, 0x7dba2d5d, 0xf2cddda8, 0x4bbefc1d, 0x6ffb57ad, 0xf7f0ad9f,
	0x725e2c49, 0x4015195b, 0x354f3e14, 0x6c3b479d, 0x8401d361, 0xdd174a8f,
	0x8091b270, 0xe5094e06, 0xe51361cd, 0xc0f1f171, 0x50d7919a, 0xf9c83b12,
	0x8d62b039, 0x026ff297, 0xf0d787c4, 0x8bbd2db7, 0x6cdc51df, 0x5edc8930,
	0xca66be5a, 0xb79e4d04, 0xb03efaef, 0x942996f2, 0xb247d2b6, 0xaf8f1def,
	0xf00acdfa, 0xb7f2e899, 0x39f14cee, 0x218b7934, 0x51f9a76f, 0x50cbbc9a,
	0x4fa8671f, 0xb3fbe432, 0x708e6df6, 0xd5a1e88a, 0x0b7a3f8f, 0x5b602efc,
	0x442e7872, 0xae27585c, 0x377e05bb, 0xfd9d28b4, 0x9371660e, 0x723411e0,
	0xeec3d8b4, 0x169eece9, 0x8048fe65, 0x201bf343, 0x051b0a0f, 0xec039c17,
	0xcc611da1, 0xcd6e77c3, 0xce762177, 0xc09d0c2c, 0x7fed7aef, 0xf9f909b8,
	0x611fe1b1, 0xbbddcbbb, 0xdffae990, 0x1eede9c5, 0xf7e4c926, 0xc777c744,
	0xf1db6e67, 0x12eff76e, 0x64f6f2d2, 0xa79421ef, 0x25baf786, 0x377b1f30,
	0x7c70a8bf, 0x8c05f86c, 0xa8c1f957, 0x3d41b7a6, 0xbf392db0, 0xbfcdf41c,
	0x0b1a9d14, 0xbcc417fa, 0xa363fd84, 0xf606bc10, 0xff88a7a5, 0xfef7181a,
	0xe007a1a2, 0xcb8e7b27, 0x2840cf2d, 0x6f8f798c, 0x071a45b9, 0x0196bbe7,
	0x594fd3f0, 0xc7c421d1, 0x8c16f8f1, 0x7a2fb180, 0x680fcb07, 0xf9a26019,
	0xb21fd185, 0x9e5b43f6, 0xa2cffc81, 0xa3f2c37f, 0x2e88065a, 0xbe1c5238,
	0xbf6d0a65, 0xef9915c5, 0xcecd187f, 0x0efcea5d, 0x04cef10c, 0xb64290b8,
	0x5073c0ef, 0x73ab950b, 0xdb6ecff3, 0xf731e142, 0x779436c7, 0xbaeeda5b,
	0x01cde98d, 0x2575f81f, 0xbee37872, 0x425df288, 0xf619227d, 0x7c6ed8c2,
	0xdd9a523a, 0x288c6fb8, 0x43fa01dd, 0xb891dce2, 0x7a760c6f, 0xed8f47f7,
	0x678def4e, 0x1768fee9, 0x09a2df93, 0x1f1207fd, 0xf55ea076, 0x4e738f38,
	0xc3e90ef9, 0x1052f1ce, 0xa2fcfdcd, 0x36e939d9, 0xcfd8cde7, 0xaddf5c3d,
	0xd5b8347c, 0x27ffe14a, 0x9ebc7cf5, 0xd6f7cfe9, 0x0d13b950, 0x64de11fe,
	0x82f72790, 0x7764793d, 0x540f3d5e, 0xbdbcd2a6, 0x39569cfb, 0xbdac9bd3,
	0x61acadff, 0xaabcaaf5, 0x57bec81c, 0x72c4adf7, 0xc7c49f06, 0xeb0cd9af,
	0xfd0449b0, 0x1ece1769, 0xea3979b6, 0x47ee7701, 0xc9bd7bf8, 0x993f5e70,
	0x7a04c837, 0x939f8aaa, 0x70abbc43, 0x481efc3d, 0xfe3a93c5, 0xf9eebe7e,
	0xe823d522, 0x3f2ec33a, 0x15ea9fae, 0x3fe5d9a3, 0xd3f62bd3, 0x55de02b5,
	0x65a912f8, 0x1fff942c, 0x508bd382, 0xe9c2cfff, 0x35e7be1f, 0x6f2a21c8,
	0x8a7cc1f6, 0xbfd29e96, 0xdf70e247, 0xc4e58428, 0x18fc4d74, 0xd1e70e5a,
	0xebff4e35, 0xcd7b9ad1, 0xa1170fb9, 0xc7aea9fe, 0x4caf1ff6, 0xe4f49bbb,
	0x787ea34f, 0x75964ffc, 0x42547768, 0xdf8f8f28, 0xcc5df046, 0x4bcf1e71,
	0x7e336fd5, 0xce04705c, 0x112e6973, 0xe95563e1, 0xc8edf041, 0x947df0a6,
	0xeef0e76e, 0xf993303e, 0x75fba8f9, 0x5bdf8f25, 0x7c5aecb9, 0x5a41d2af,
	0xc81e9cf0, 0xbb3f2824, 0xc30ce7ea, 0x01274a7a, 0xbc89c82b, 0x831dfc28,
	0xef8254ca, 0x8ce72a6b, 0xdf387ac0, 0x1cd13fa2, 0x39538e0b, 0x6561d193,
	0x1bda2c5e, 0xdc02ee41, 0x84a3a37a, 0x21176672, 0xf6b47792, 0x62e1defe,
	0x7a5b7976, 0x4177cecb, 0x45675daf, 0x885016bd, 0x891532f7, 0x87a51e38,
	0xd4be902f, 0xc913dcf3, 0x5c70c7c1, 0xd609da0f, 0x2859bc38, 0x73627ee7,
	0xadabfcc3, 0x0d25ad64, 0x2564438e, 0x1f3e4bca, 0xd124f152, 0xcc3f73da,
	0x3d00e0bd, 0xea097244, 0xe178cbef, 0x6100fedc, 0x210ffff5, 0x0004212a,
	0x00000421, 0x00088b1f, 0x00000000, 0x7dc5ff00, 0xd554780b, 0x733ef0b5,
	0x9267bcce, 0x9924c933, 0x124e3c84, 0x0c020108, 0x51680869, 0x62311087,
	0x16a4076a, 0xe121c5ad, 0x44c92891, 0xe96c5adb, 0x08149065, 0x791a8622,
	0x0b84e915, 0x1fed6d8a, 0x40d4522c, 0x6f4a4407, 0xb6a87fb5, 0x6f7f6d57,
	0x151f1484, 0x6b4b3e32, 0x6b5affad, 0x99cc93ef, 0xedaa9524, 0xd87b3f4d,
	0x1fb3ef67, 0x5ad7bdeb, 0x4add4f7b, 0x24d22be7, 0xca56eac6, 0x630a6b31,
	0x8195fd6c, 0xbfa31b5e, 0xd3f88a8f, 0x8858c996, 0x716dbf89, 0x94227077,
	0xff683bf1, 0x757f0d3f, 0xc32c2e6b, 0x8b0fd0f7, 0x83a5f7c0, 0xf0a967df,
	0x16c60c8f, 0xac4581ca, 0xcabdfe02, 0xa095eda9, 0x18aeff0e, 0xf0a9667c,
	0xb7d42a72, 0x8e240d6f, 0xdc938fa7, 0xe0351cef, 0xe67da153, 0xf54b161a,
	0x8eff1632, 0x0d2ddd1c, 0x12d7af9d, 0xf50ec7bf, 0x9ec9570b, 0xfde10abb,
	0x57ad370a, 0x59cdef9f, 0xf158cbf1, 0x3acffed0, 0x5c152b9b, 0xc6748aff,
	0xd2b9e1b2, 0xb80602ca, 0x32cb0658, 0xfc584b63, 0xe61a4984, 0x8a3b12bd,
	0x91da5ff3, 0xfffd3df0, 0xed89addf, 0x27040260, 0xf34949a6, 0x5d073767,
	0x55b15ef4, 0x431c7bc2, 0xf12c5183, 0xa1b2c185, 0x39e1d6f3, 0xb809355b,
	0xb2ae96b3, 0x8d9ef0a1, 0x0a18cef0, 0x37a5af6f, 0xad0dfb0f, 0x929c12b0,
	0x4a2c67fb, 0x676ada78, 0x901a7b11, 0x00fd0483, 0xe9ddb75e, 0xf801ae8c,
	0x0fe3dbf6, 0x47c33c22, 0x9f7c22ae, 0x0c68746f, 0xc0b0ec9a, 0x391ca102,
	0xc5ee8ee2, 0x25bd2576, 0x1e7dd60c, 0xfc0010e6, 0xee567f9c, 0x24fa488c,
	0x567e6b18, 0xda01bdde, 0x6afc7f9d, 0xa76acfde, 0x461ca0c6, 0xe1b8c308,
	0x18ab07c8, 0x679a55c0, 0x1ccff1a3, 0xac56a294, 0xd670043f, 0x9dff0be7,
	0xca1aff87, 0x29a8bc61, 0x4f0c9e62, 0x1c79c0ac, 0x603cd272, 0xde348da5,
	0x036c1c57, 0x926cdf8c, 0x6fa82602, 0x747c65be, 0x8d8f9f0d, 0x8b967c01,
	0x589b35a9, 0xe5fd04ab, 0x9b36b808, 0x5edc974e, 0x6814ebc6, 0xf8e32b77,
	0x25c77681, 0xdb72e798, 0xe9191ec6, 0xea00f917, 0xc2fac16f, 0x6f343c41,
	0xb887d3fc, 0x4603e68e, 0x63fe58fa, 0x496e3ae3, 0x41c2aba4, 0x7056717a,
	0x166ab178, 0x75f3031d, 0xa6b3b28b, 0x3c232a27, 0x6762cc56, 0x8f4d073e,
	0x3a46cef5, 0xb1745772, 0x5f86783a, 0xcc288163, 0xceeed2fb, 0x7b4146a7,
	0x1e4f4d4f, 0xe2bc372e, 0xcfbee2b9, 0x9f59e20d, 0x9bdd25e7, 0xf1a2e665,
	0x4a983be8, 0xda8bbf60, 0x31379b8d, 0x7d1779f1, 0x89926197, 0x15f17b6e,
	0xc8128ff2, 0x2d9c6096, 0xc426458d, 0x578153ab, 0xed25d730, 0x26af7763,
	0xe64a0738, 0x3fbb19b9, 0xe09de805, 0x3944afe9, 0xdaad5a73, 0xe4de7c89,
	0x66aadaa9, 0x6e8271f0, 0xe5f03e5c, 0x5ae94325, 0x93f00e7f, 0xdc559768,
	0x35c5a532, 0x33e03b72, 0x7b7c5b82, 0x8a23972a, 0xbfa5e544, 0xa06e7732,
	0x374429f9, 0x18503fb7, 0xb037f9c5, 0xf9d20b76, 0x20b51672, 0xb1b52f1d,
	0xc5d00a48, 0x0a966852, 0xacdb65cf, 0x5fc04b4c, 0x5e58d463, 0xadc2e42e,
	0xbfbe87ac, 0x7d525f75, 0xa1b98b35, 0x62c6c9be, 0x19767c4e, 0x9c599beb,
	0xfa1f0fc6, 0x9ef89ac8, 0xdef5f075, 0xa9eef02c, 0x5821ca8e, 0x633b76f7,
	0xf0c0afc8, 0x574b9f84, 0x533e1276, 0xdf8503cb, 0x7fc57585, 0x06eff669,
	0xc0a3fdba, 0x399f0e97, 0xc227556a, 0x689b21df, 0xced5f1fd, 0x7f586ee8,
	0x2035899f, 0xb0f5effe, 0xf3c1e79b, 0x18162afc, 0x4d30266d, 0x86483a42,
	0xec2786f3, 0xa737480d, 0xd0252e50, 0x4cd55ad5, 0x6b0b5ee5, 0xbcaa7e40,
	0x904bfa0b, 0xbbd7cd57, 0x0bddf842, 0xfc007eba, 0x67f8875f, 0xd86f086b,
	0xf1cce91e, 0xbfd4fe39, 0xbe5d1ffb, 0xa9fccdb1, 0xd2dfbe70, 0xfc44e8e8,
	0x89a3d20d, 0x05963d11, 0x27a7082d, 0x64589c84, 0x3ef8d3fb, 0x4013e500,
	0x220f2820, 0x2f2e765d, 0x0ae17514, 0x5af13f28, 0x86837f99, 0xc7e5c374,
	0xd83a3713, 0xc9e4305d, 0xf7787e37, 0xedfea1af, 0x159a2cd7, 0xed2317ea,
	0x909e3e00, 0x8bc70058, 0xa28d663c, 0xec0e5bfe, 0x7e59f38c, 0xe5146264,
	0x684b41de, 0xe71c12fb, 0x2f7fb351, 0x253cb77c, 0x5483f0fa, 0x0a07ed9f,
	0x399a4f65, 0x771e467d, 0xd11deff2, 0x8bc4fd1f, 0x08fe59f5, 0x1ec27fb4,
	0x23f910fa, 0x92a5aac7, 0xcc95fd9e, 0x12b138f8, 0x34efc00f, 0x9e152bae,
	0x38e12550, 0x07ea6edd, 0x097b2ef8, 0x2da673f4, 0xf203d68b, 0x9ce38034,
	0x8ddd64d9, 0xc0cb74f2, 0x3fb512b8, 0xcece0e6d, 0xc7e9f286, 0x4357f8a6,
	0x12d07f55, 0x867d00b3, 0x19f5bdef, 0xdea2fa06, 0xf842eda4, 0x5a4e23b0,
	0xf08f8e87, 0x58b565a6, 0xe565be1f, 0x46ef28b5, 0xdf945be2, 0x9e0e412c,
	0xe47cf167, 0x450d1d8f, 0x13d4315d, 0xa4fce3dd, 0x900f992e, 0xf2a1f40f,
	0x0e667db6, 0x3361f8df, 0xf6c5eff1, 0x54a1748f, 0xe382bd72, 0x32ce4184,
	0xce489f9d, 0xe1e59426, 0xe18f1cca, 0x2e48b227, 0x75afd724, 0x007b2687,
	0xfbdfcd2f, 0x342bcbf3, 0x724e2f1c, 0x1067b58e, 0x0399f59f, 0x3d6e910b,
	0x5d4b31d5, 0xe55fdd02, 0xdebbfae1, 0x630cf5ca, 0x977e0b31, 0x65595f5c,
	0xfd01fba4, 0xe2fce1ee, 0x7af2e1ee, 0xf049bd68, 0xd45675d3, 0x29f2974b,
	0x0bd402b3, 0xa35fec2e, 0x2d7d2ffe, 0x7287a966, 0x6598cac1, 0x9f2278a9,
	0x3663bc00, 0x76df7758, 0x0403c937, 0x74b3f603, 0xb7fd233a, 0xb6ad6654,
	0x1daf7c72, 0x9cbc05ea, 0xf443cc7d, 0x5006fec5, 0x622f7801, 0xad959da2,
	0xfa5c81b7, 0xb314ab59, 0xdb45bb41, 0x85edbbac, 0xd901d7c8, 0x407cf88d,
	0xa8b4b922, 0x76c96675, 0x6072df28, 0x653fe122, 0x5bcba73a, 0x73d21ea2,
	0x57790a97, 0x145a8d6f, 0x923f87d4, 0xfd465ed8, 0xcbff62b7, 0xf2eca3e1,
	0x394070a1, 0x6887a06d, 0x9dec1942, 0x9cb8bb4b, 0x599f2064, 0xcba41d82,
	0x2ccb946f, 0xd233aec9, 0x2fd74447, 0x5a638edc, 0x8389dcd6, 0x1a8e7672,
	0x7843ddbc, 0xf8859d18, 0x3d727c05, 0xb8225fb4, 0xd216b136, 0x1f5cba0f,
	0x85e85718, 0xeb8472b3, 0x7a66eb1f, 0x1214f3ae, 0x5d616f5e, 0x3d741fa4,
	0xac1d1231, 0x12347413, 0x7417ac1d, 0x1635fcb0, 0x5bc60cbb, 0x9ac592be,
	0x7ba7f126, 0xae3be912, 0xef5c6cf7, 0x1171d3e1, 0xdf592ffa, 0x64b7eb25,
	0xe16596bd, 0xb3c74bfa, 0xcd649f6e, 0xd2fd7ae2, 0xc1995195, 0x04a4e6fa,
	0x18c8ca1e, 0x2fc253b4, 0x64da6cd8, 0x1159072c, 0x994e2bb4, 0xdf059599,
	0x40161585, 0x5c0272be, 0x03fde13a, 0xb3959ec2, 0x167d7af8, 0x2566bf4e,
	0x10b8a6c8, 0x13313d2f, 0xa98325e2, 0x3c3a8f48, 0x77c3701f, 0xd71df8e5,
	0xdbdf0337, 0xe123ab58, 0xec27aafb, 0x7fde7fa4, 0x92b51ddc, 0xf02a117d,
	0xbf997f40, 0x79dd92b7, 0xe93709fe, 0xb666f3c7, 0x7bda0ba0, 0x7a24bed1,
	0x3dfd4b59, 0x40cd788e, 0xc51aaa6a, 0x39a5f690, 0xea0450a3, 0x879356f6,
	0xed434ddb, 0xd85f511b, 0x2ba73d73, 0xf1f286ab, 0x1def4f7d, 0x30f98658,
	0x05fb3fd4, 0x6607c39e, 0xbc36f94d, 0x7e5d070f, 0x14d0fd0e, 0xfcab57a4,
	0x406debf5, 0x95e5b35f, 0x1d613bf1, 0x152e794d, 0xc1755bf5, 0x03777e1f,
	0x603f5f94, 0xf3c45666, 0x580b59de, 0xb7f2c8d1, 0xdd3e6a31, 0xb72fc09b,
	0x9b9633ee, 0xf0e58cba, 0x05f96321, 0x767bdb8f, 0xff0ec902, 0x56d74047,
	0x9d6bcb6b, 0x93eb5f30, 0x8f47d256, 0x8fff4278, 0x7e29ade4, 0x2d6ce102,
	0x08527378, 0x2dfba0e9, 0x60569f09, 0x0e329ea3, 0xf7ebe47f, 0xd40a8bed,
	0x0836e061, 0x1133663f, 0xe6fac19c, 0x6173924f, 0x4b5e27c1, 0xb0a3f5e0,
	0x1cf3a5fe, 0x26f45dea, 0x12b53b50, 0x239a43ed, 0xfabb6f0b, 0x4147dc75,
	0xffc446bb, 0x0ed0b9d9, 0x8db0d5e6, 0xace5c3eb, 0xb6f90527, 0x1b48ec19,
	0xc69fd8a0, 0x6b6b70f1, 0xff0632bc, 0x19ab48ec, 0x3e54f387, 0x1f488254,
	0x04dfb0eb, 0xc69cd7bb, 0x7dd6f7f9, 0x033ef6f6, 0xe50c793f, 0xf6eca1f0,
	0x0bb844be, 0x2572c3f9, 0xe37f7125, 0x69cc8533, 0x7a5f2819, 0xfc61332d,
	0x977c3e2b, 0x15b2fde4, 0x00bed14f, 0xdb88b1d6, 0xe50d76c9, 0x8f3bb2d3,
	0x1f7d7bd2, 0x45cf3676, 0xb6a7b0fb, 0x63d9795b, 0x07d9f2a1, 0x59713ef8,
	0x75c51497, 0xa42ef34a, 0xf0bd44cf, 0xb2b55980, 0x864d70a1, 0xff3babe3,
	0x52c1853b, 0xe3a0255f, 0xf6e24dfe, 0x4292da98, 0x25ad01fb, 0xf0ceed05,
	0x475eabb6, 0x01ecb8f9, 0x02f68fd9, 0x8ff6ec3b, 0x72be5861, 0xf61712dc,
	0x4cfa4ef3, 0xaec74798, 0xde99552b, 0x739441cb, 0x5cf60f60, 0x5d95ef01,
	0xc7e434d3, 0xf9f00fe3, 0x1ed8f32f, 0xe2ba3a44, 0x4bf89943, 0xda10b131,
	0xc0961dbd, 0x6d6be438, 0x88d9dee7, 0xe6e7579f, 0x23fda898, 0x2e115312,
	0xf899159e, 0x04a4997e, 0xb61b8f91, 0xda26d635, 0x647b4f3d, 0x0599cbe2,
	0x5d7b332b, 0xa3d757c4, 0x007a6d3e, 0x9fc708f8, 0x6eefd2f7, 0x95f20ef0,
	0xb5db6f34, 0x0fff6297, 0x77c8fd99, 0xceccf603, 0xe17d102f, 0xb5e00c5f,
	0xd3ebc04c, 0xa9d599f2, 0x094b49f3, 0x7765d5ca, 0xc3a894b5, 0x7c0319d8,
	0xe5f393b2, 0xfb126935, 0x957484c8, 0x8c47d866, 0x9572efb4, 0xd8cf489a,
	0x17b02cfc, 0xedb0599e, 0x4b75fdc5, 0x69f0429a, 0x3b50b349, 0xefb72fe5,
	0xf5d6167b, 0x4374279e, 0x602fbc1a, 0xd7a82981, 0x055ab8b4, 0x9a822d66,
	0x93b630ec, 0xd760d7db, 0x25bb1d91, 0x21b83d83, 0x1cbdbf61, 0x724a9bfb,
	0x39fb0ea2, 0x4edfe2ff, 0xf39b7c20, 0xf6849cdf, 0xbbc2f842, 0xebd60d16,
	0xbe4896ea, 0x8641fcbb, 0x9eee1374, 0x0d9716cb, 0x9fb0e5ca, 0x75e48deb,
	0xe6669e3d, 0xa71bd472, 0x73a4f67e, 0x30f0ee7e, 0x2b1da7a2, 0xefef641c,
	0x38ed46f0, 0x6f967fe9, 0xd1a9fb75, 0xdb6cf1c6, 0x8c80d3f3, 0xd4951e74,
	0x38d65831, 0x2c37f47f, 0xce30ca8c, 0x238a7beb, 0xd3303e54, 0x6b9d432f,
	0x2fae7fcf, 0x321d3842, 0xcbbdb1fb, 0xeb829bdf, 0x99cf7d7b, 0xc35f5c14,
	0xddd6991e, 0x732b7d10, 0x9ca0d949, 0x6d429b30, 0x4aa62f08, 0x975f1c2e,
	0x79efaf17, 0x8bb17327, 0x9f4803fb, 0x970f0c56, 0x4dcccf26, 0xb8ae5728,
	0x8de5e39c, 0x9451ac47, 0x41d86f83, 0xdfc825df, 0xff5cdc37, 0xfdf4d345,
	0xea3e575b, 0x32b2819f, 0xe27284ce, 0xbf5f2aeb, 0x8f95d2d7, 0xc927f97c,
	0xeb2dcfd8, 0xb9051665, 0x625eb8d4, 0x6ff99051, 0x7cb3fc3c, 0xefafff94,
	0x5d7e59fd, 0xbf92fcc2, 0xd43f9fd3, 0xb1fe13c7, 0x178fa63a, 0xeaf1c5cb,
	0x97ee56fc, 0xaa5fc11c, 0xb8db67b7, 0xb81fb3df, 0xff50e916, 0x11c1bfae,
	0x9fb77b40, 0x42e8a2d9, 0xfe16ebab, 0xb46040d7, 0xfa35f717, 0xf7fd49f7,
	0x0e927a0b, 0x701fe449, 0x3e49c596, 0xeff9627f, 0xc8267c05, 0xadf3c07f,
	0x5b26e788, 0x4628c4fc, 0xb84161f4, 0x0a5d9a59, 0x35ccabea, 0xdfe2be9c,
	0xcb3ed130, 0xc49948eb, 0xe4b2bec0, 0xdf285cf8, 0xb47128ae, 0x7df1529a,
	0xe7db147e, 0x77d294e5, 0xff4e2a91, 0x7e464c91, 0x22d66cb5, 0xed55df91,
	0xee503f25, 0x806ea674, 0xb73a4a62, 0xbfcc7d5f, 0xfc262e4d, 0xd207e84b,
	0x07eba2e1, 0x979423a4, 0xa236486f, 0x225ba923, 0x7536547b, 0x477ec42d,
	0x253faba2, 0xfe9fd5d1, 0xdef574cd, 0xd2157488, 0xb67cae88, 0xf84ae9e1,
	0x3dba2f85, 0x5f71048b, 0x75e0259b, 0xf13f90af, 0x3f74d86f, 0xadeb84b9,
	0xdad5fd15, 0xf519315c, 0x66fcdf88, 0x2777bfa2, 0x7fb8c5d8, 0x1ebb46ca,
	0x2cd6a39e, 0xac6f08d2, 0x08fd17a7, 0xd23669ce, 0x7a9b7797, 0xc98ed10a,
	0x1fb2df1a, 0x616b23e9, 0xda1af959, 0x507ae617, 0x25aea02f, 0x598ace7f,
	0x40476e41, 0x734748bf, 0x69cfb42d, 0x906673be, 0xc43511db, 0x768de12f,
	0xace0f50d, 0x48d5c2ee, 0xcc95e11f, 0xee3a256f, 0xfd14bedc, 0x7e5df3b3,
	0xf4767594, 0x607ee0d3, 0xdaef91bd, 0xd7b22ea4, 0x3f335723, 0xffdd75ca,
	0xdde9e1db, 0xffd46df5, 0x37e4658d, 0x8f07f019, 0x3a37a466, 0x34ec813c,
	0xbfc1eb80, 0xc765ff73, 0xf3c32814, 0x8ecf8149, 0x0f6c81b9, 0xda36eb94,
	0x9d1dee09, 0x0ddfbebc, 0x7e4c9a00, 0xa58fea61, 0x1a1eb8da, 0x9fc81f2a,
	0xe99d399c, 0x9cb0db7f, 0xb7db97a3, 0xf3a41d92, 0x9f21477f, 0x582cbb8f,
	0xf7f91688, 0xa4e6ff37, 0x1327e803, 0xb37c71fd, 0x00fdc116, 0x997981f9,
	0x9bf7c4dc, 0x58392260, 0xf543647c, 0x6f32c48c, 0x8cfdf83f, 0xf41eb06b,
	0x4e3d40ef, 0x5eb2f41b, 0x1e61d80e, 0xf583dceb, 0xb6c1d80a, 0xfef89243,
	0x8257398d, 0xc497eeaa, 0xda4791f8, 0xb417e802, 0x8978c333, 0xfa9253f3,
	0x2eff4337, 0x6cff6f4d, 0x61a395cd, 0xb97ae5be, 0xf3002db4, 0xec6cd7bb,
	0xbe2a408f, 0xde3e82c7, 0xdcdf2dc4, 0xa0c671b0, 0xc2f6007d, 0x8319e9cd,
	0x97bac276, 0xc327db6a, 0x1df54e58, 0x5d5fea0b, 0x12bd87df, 0xfcc921d9,
	0xf73a5b7a, 0xf9627ca3, 0xafb10daa, 0xf9274b6f, 0x591b3bda, 0x2425f612,
	0x832bc3bf, 0xb05bed0c, 0xf381be4b, 0x9be2ff3d, 0xfd428f67, 0x3d7f79f9,
	0x76c34a31, 0x7dc42db7, 0x4282f855, 0x4fbc37f2, 0x37c04a8e, 0x576e6eb6,
	0xff273e83, 0xb73f4ebf, 0x3c7e82a8, 0xcbfe8611, 0x54d2c38e, 0xa8b077a4,
	0xb804bff2, 0x103d297c, 0x7ec471a1, 0xdbdd7933, 0x287fb9d3, 0xbdb55a5c,
	0x23dffb04, 0x3617b431, 0x5cce9e94, 0x57a9fb4c, 0x7c249732, 0x7ee878d7,
	0x3ee36782, 0xdc70b0f3, 0xdc932e9e, 0xb1fc7e6b, 0x378dca00, 0x84c912a2,
	0x86da2506, 0x83436d76, 0x56422d09, 0x03745d11, 0x581633c5, 0xdf5818d8,
	0xc2efa12a, 0x5c8baefb, 0xff86eb8a, 0x23b57824, 0xc4e494b8, 0x1736058e,
	0xeb4a85c5, 0xa838236e, 0x61c2008e, 0x36556943, 0x773cd38e, 0x10714ab6,
	0xbeb0e7b0, 0xc91bcef9, 0x6bcfa45f, 0x0d7321c3, 0x60953bda, 0xe614fdd7,
	0xa736979d, 0x3d7c0fc6, 0xe53fde4a, 0x32de506b, 0xcf2f1c82, 0x55bc72e0,
	0x58be460a, 0x9651fe41, 0x382cefe8, 0xfdc7edc4, 0xd57edce9, 0xe74fefdf,
	0x488ced76, 0x97242ccf, 0x13af4a23, 0x0b30eaed, 0x6afb85bc, 0x7b697416,
	0x7e5c4f09, 0xe4695779, 0x7b79b337, 0xf58c9eef, 0xcfda1433, 0x3ef7a530,
	0x9b7cf71c, 0x0981bfd7, 0x9df2c03e, 0xc7945165, 0x0474379a, 0xd852ace9,
	0xbf1fe7ab, 0x17fa0a6a, 0x6dabfb75, 0xf18a3baf, 0xf6b736d0, 0x93941abd,
	0x4e48517f, 0x67bc5b32, 0xf8d3f416, 0x6bf51a41, 0x897e8572, 0xa3d9b4fd,
	0x9107486d, 0x79da994e, 0xd862d9e7, 0xba0febcf, 0x34ced13b, 0xd219db7b,
	0xc85f6c31, 0x06f3628f, 0x6785c619, 0x12291645, 0xbb248bea, 0xb1fa1666,
	0x25e2df68, 0xe0956e3f, 0x0540318f, 0x0ac46d67, 0x0fa51fad, 0xff2739da,
	0x97c15f36, 0xb263fdba, 0xf57bbf71, 0xf1c30702, 0x09f8dad9, 0xbdf1fa13,
	0xe1ed0c3d, 0xc6892ea6, 0xd47d2a69, 0x5b97fb82, 0x877f38bb, 0xe0037ec5,
	0xa5f14f97, 0x83f0a774, 0x677a72b6, 0x2146273d, 0xf1cc7f9c, 0x4bb418c9,
	0xb632bbf0, 0xd103cb9a, 0x1fc4459f, 0x09bf849a, 0x9fd52134, 0x15e3d74b,
	0x3b678977, 0xb7718a7f, 0x19013d48, 0x324539e1, 0xa7f5c9f8, 0xa7dfe5e2,
	0x46cf8b1e, 0x7d038dfe, 0xbb69dfa1, 0xa7b6f734, 0xa7db7d61, 0x29a3f78e,
	0x927203e6, 0x903df1cb, 0xe2bdc022, 0x91b35bd0, 0x230d586e, 0x343e6d7e,
	0xf1726e53, 0x0bda0d38, 0x4e96ce59, 0xb9bacfac, 0xc633f494, 0xe2de304d,
	0x66b872f0, 0xcf1fb8bb, 0x10a45777, 0xc7a99ae3, 0x8d3db782, 0x90744fe3,
	0x700b361f, 0xe7a34ee3, 0xf97bf47a, 0xa8a394d8, 0x5ab57d9f, 0x8f47ce39,
	0x6ffc61df, 0x71c9196e, 0xa5f9a72a, 0x3fdc6ec0, 0x6fdc3d79, 0x38356567,
	0x751f7c5f, 0xd113c60d, 0x62e3879f, 0xe79f0ebc, 0xf90a63b3, 0xaeef59ff,
	0xb7efb4bd, 0xdaaf08aa, 0x0178bf43, 0x8dad6ff5, 0x357c5175, 0x24796ec9,
	0x2f3cbae5, 0xee7fd38c, 0xe2efaeec, 0xd074bebc, 0x18fc221f, 0x2e2b91ed,
	0x1bf9f6e7, 0xda1a9d7b, 0xdc85bb91, 0xf891fb06, 0xdf08f224, 0x91db264f,
	0xbf1d5e15, 0x281c8edc, 0x2476e67f, 0x2f645f9f, 0xe5d09bcf, 0xffec587b,
	0x4ede1bfa, 0x1815fd41, 0xffe80f98, 0xa83b41ca, 0xefc88f6e, 0xbf3e1ee8,
	0xce83e4e3, 0xdbc3d208, 0x4bf2765d, 0x75ee222a, 0x03bf1dce, 0x39ead481,
	0xdbca3d71, 0xfc6f2df0, 0xa7fc04c4, 0x9238f274, 0xd3388922, 0xe3c6652f,
	0x31350162, 0x6678a7ee, 0x286502fb, 0x97baf91f, 0xf2d1bf0b, 0xc78d12b4,
	0x6fbc78bb, 0x04ac4a79, 0x8527a9ed, 0xe0ee5a1e, 0x8f7eaaf1, 0x7d788625,
	0x805a1ec2, 0xf2b1cc78, 0xadcfd9ef, 0xab5c625a, 0xbaedca33, 0x98a6a533,
	0x89d9d605, 0x6de201f6, 0x0d6f8f23, 0xb11c07e4, 0x9e695a76, 0x6dfdca8c,
	0xeb272485, 0x11d5b8f5, 0x17ab8fee, 0xf333a9f1, 0x4300fe96, 0x4b52ad95,
	0xdecfee0d, 0xfc9330df, 0x6f7c77e8, 0xd7eb3d2e, 0x4bfefd1b, 0x3c5f4fd1,
	0xfdd61718, 0x6fcc75ef, 0xa0f2f6e1, 0xf604d11f, 0xa95eb68b, 0xc8597d42,
	0xfe50bbd4, 0xd6c0116b, 0xc2b67834, 0xc9768d13, 0xa39da124, 0x881d79b4,
	0x26ad75df, 0x569153d2, 0xe9db0053, 0x72f56e70, 0x2f4ed23f, 0xaa006bf7,
	0xfe8e38a2, 0xb88b356c, 0x356fe883, 0x69f0c533, 0x9d73f892, 0xa70cd4aa,
	0x5afef5af, 0xf4362dcd, 0x4cf3c5d3, 0xdf7ef7e4, 0x7e405812, 0x1612b4e3,
	0xbab67801, 0xf0d7d65b, 0xf79de27a, 0xd520f1ed, 0x4370a65f, 0x28696992,
	0xe5e5bf3f, 0xdc3244f6, 0xcb1bb496, 0xc698f1c9, 0xcf5cb1a8, 0x8bb36342,
	0xf120fc79, 0x7e50b7fd, 0x153c454d, 0x2dfb780a, 0xf5f56728, 0x70e5ceaf,
	0x67f1e533, 0x02d55e51, 0x8f2283a4, 0x8a31f285, 0x0abfdc3c, 0x17f9a12b,
	0x8895e65d, 0xdbe6923e, 0xd21b468a, 0x878f1b57, 0x4ff3b3fe, 0x6f1ef79e,
	0x80dbe0a6, 0xf597e30f, 0xd1e285aa, 0x7927eb17, 0xcfdc6bda, 0xfb3f940e,
	0x27df2cfd, 0x6f22c9b5, 0x54392546, 0x9cb5f2a7, 0xc60ffc91, 0xec0bbdf0,
	0x9b475c04, 0xcb768e5c, 0xb45cebac, 0x7623e68e, 0xad3703f2, 0x3d47cdec,
	0x5bd55cde, 0x649b7182, 0x156ce2f8, 0xbb417e5d, 0x3fec2f3a, 0x6c484ed0,
	0x8caff227, 0x4bc0d671, 0x37ee2728, 0x0bffd99d, 0xedfb57d4, 0x5fe0afa4,
	0x67e8ad47, 0xec90bc79, 0xa1dc1ba8, 0x27b45ed3, 0x0f5db11d, 0xc2dda215,
	0x6ea6a6ed, 0x85da276b, 0x7109ad75, 0x8dbffc3e, 0x5b1fb8c6, 0x77fe469f,
	0xdf7c61d6, 0xbbe933b0, 0x76c07121, 0x4b16f3c2, 0x3bf21c68, 0x3fca1de8,
	0xa268d738, 0xd97a81bc, 0xede514bf, 0x1ed1bb39, 0xf8e6e73f, 0x3c743292,
	0xcf104bfb, 0x7821e503, 0x9e2097f6, 0x942c4deb, 0xe2134fd8, 0x5cbbf019,
	0x63dcf9e0, 0xcf104ad3, 0x569fee6f, 0x62de7882, 0xdf200f6e, 0xe643569c,
	0xdf67980c, 0xa7b24195, 0xf9072f30, 0x31e962e8, 0x17a8c32b, 0x22ffca07,
	0xfa48caff, 0x5e0078b0, 0xb5e87d46, 0x0f28b968, 0x7fd66cea, 0x6ff117a8,
	0xcd9e3f58, 0x238efe4a, 0xd3677b7f, 0xba072883, 0xf447b265, 0xa1288efe,
	0x8e87b462, 0x47f3e0bc, 0x7ffb91a4, 0xa9d8ed06, 0xa08c2714, 0x07df455f,
	0xb264f6e8, 0xd6269e3c, 0x60466d73, 0xd827fa5f, 0xe37eea8f, 0x16cef106,
	0xb9db877d, 0xf73f247b, 0x1f91771b, 0x22f0f9b9, 0xafc4fd15, 0xb8dfb945,
	0xe429b1f9, 0x3e8c6e37, 0x313cc315, 0xb8a92dd6, 0xf3dc68ff, 0x03e60a4a,
	0xd85cfbe8, 0x83217ed7, 0xefdc6cf0, 0x933d16be, 0x3003f982, 0x6f383def,
	0x416e37a7, 0xfd866fba, 0x3605e61e, 0xd813f12b, 0x5197b36f, 0x21c54b9e,
	0x8f4ffee3, 0x5a08eef3, 0xe8eeee48, 0xaf28a296, 0xc2a12d33, 0x2c6bd45c,
	0x1ceb3d57, 0x64afb3e4, 0xf185be04, 0x7af8c1df, 0x1919abe0, 0xbd5df983,
	0x7e8953db, 0xa02ccd7b, 0xeedb3ca2, 0x214cf216, 0x4edef6f9, 0x7be7944f,
	0x45eff6f1, 0xa8d09db9, 0x2c2979e7, 0x96be00a6, 0x88bc0fce, 0x1f7946f8,
	0x89f7924b, 0x7f6e3d65, 0x5e918b2b, 0x274cc26a, 0xd895ef91, 0x8fae392e,
	0x3f4370f1, 0x868a65ac, 0x5c9bb07e, 0xc60f9c7e, 0x11f58dc7, 0x7e064fbe,
	0x483e5158, 0x741e3abf, 0x7e166dfa, 0xe9c370e8, 0xe1bf48b5, 0xf68a9243,
	0xa73f72dd, 0xdfb0e5df, 0x64d8bcc2, 0xc65d677e, 0xf891d03c, 0xdf00eb7f,
	0x3adffe71, 0xd7fa9ca2, 0x277757f8, 0x7ebebdf1, 0xb03f6fdd, 0xf3896ece,
	0x92bad265, 0xfec9a9f7, 0x799f7d76, 0xf1f0f2b1, 0xfe3c7824, 0x48c7862f,
	0x01e9f0f2, 0x0f2c9cb9, 0x7f8cf18d, 0x8bfe1e5a, 0x383f1ae3, 0xf70535bc,
	0xe3c7681d, 0x5efd653e, 0x009fcf33, 0x8bc627f0, 0x00aecb67, 0x7aca9f8f,
	0xaf0e31bd, 0x787116cd, 0x3d4fd7ce, 0x9ade1326, 0xe9b89c44, 0x4d8fdbb0,
	0x28cb5c1b, 0x3f1c9b4e, 0x9fed85bd, 0x8e4aa88d, 0x7e472ea3, 0x78f8fe2e,
	0x40c67f6a, 0xe62142de, 0x6de7242d, 0x277ae53d, 0xf780943d, 0x10d832aa,
	0x36df430c, 0x12d2c225, 0xc1987fde, 0x894fffe3, 0x859f22fc, 0x95bcc7ad,
	0x00cedd7b, 0x267c67ee, 0x52f4ff9e, 0x9423f07a, 0xc04d3683, 0x332ff1f5,
	0x07e5c013, 0x2b922ee6, 0x1f972691, 0xbfeea0e5, 0x4afffbd1, 0x8bd7a73a,
	0x4999ffd6, 0xff2f5ffa, 0x50bff89b, 0x8d9fef1f, 0xd8036ddb, 0x1182f818,
	0xf1833f1d, 0xf4a1c2a5, 0x233f523b, 0x664571d1, 0xb7267270, 0xbe5127f3,
	0x19ca45c2, 0x0cfc4567, 0x01d889fa, 0x4d7e86ab, 0x7e9093f4, 0xf22d98dc,
	0x7395fd51, 0x5fdaef29, 0x2f63f989, 0x192f3fe3, 0x939c8ed9, 0x0723b469,
	0x1d919fca, 0xb5835319, 0xdf5fd099, 0xf7e500cc, 0xfcc373af, 0x30f87f71,
	0x69da3bcf, 0x53b9f4e7, 0x9fa974e2, 0x7f38f8af, 0x51a65d4b, 0x388dd68e,
	0x1cad7fef, 0x4694ce6d, 0x6b3f2bb0, 0x14d7fa39, 0xdc8e9ff4, 0x7fe4444f,
	0xe2dc10f6, 0x3bb62587, 0xee1dafc1, 0xab7bf9e1, 0xf7f57cc4, 0xf03d0a37,
	0x0881995f, 0x2f9be3d2, 0x152c6cda, 0xcb82b3e8, 0x8ba0e6c5, 0x5dcd0ae2,
	0x79a5ff3c, 0xde392325, 0x5c537e8c, 0x0cb9a1ff, 0x3cf7beed, 0xfdf80da1,
	0x115c97ba, 0xedfd1539, 0x79da18f3, 0xe5e45fe7, 0x4da13c47, 0xd95e1f58,
	0x8e8c714b, 0x1e506f79, 0xef47e556, 0xa0a9adac, 0xc13f92f9, 0x4f9e356b,
	0xcb933c79, 0x7079fd33, 0xf201de00, 0xc0d9bfe7, 0xdec3b5f3, 0x097e8a80,
	0xd4ee1fdd, 0xd0ae287a, 0x6f1b807c, 0x0f5f3295, 0xd12e76fb, 0x9981f353,
	0xca6fd053, 0xd053ecba, 0xbdfcadde, 0x6f7df68b, 0x794399de, 0xb4379a12,
	0xaeebe717, 0xf68d5e88, 0x838c0169, 0xfb9bef76, 0xf3829eaf, 0x16dfe5d6,
	0xfb439bf4, 0x3fa36e2d, 0x1e78d99c, 0xa343e37d, 0x4ff9bf74, 0x08b60f90,
	0xf6ae643e, 0xf0c3b9ca, 0x59efcebd, 0xcffa89b2, 0xe28d8afa, 0xd83cbae3,
	0x5b216662, 0xb91ca0f1, 0x7ee3533f, 0x6fc8af6a, 0xf3cb9eec, 0xe5d94453,
	0x5e79e635, 0xfde5719b, 0x33fb8f38, 0xc7174f95, 0x13c90d72, 0xc7933fb8,
	0x4fb82cb1, 0xbf928c07, 0xdb8179c5, 0x85aa45d1, 0x9ebdc8e8, 0xd014f8f1,
	0x33f3da11, 0xf0b33de2, 0x8ee8d6bc, 0xef840cd8, 0xc2260b91, 0x19f73293,
	0x4aa4cb8a, 0x8de2bc7c, 0xd1636dbd, 0x7f3ea30f, 0x6b52a219, 0xc430ab57,
	0xf8279ef7, 0x7df12642, 0x578e294b, 0xcf335bf5, 0x24ec3cab, 0xfe4742ff,
	0x3cabca72, 0x70d592ff, 0x19f926ce, 0x1e517761, 0xe7a1d165, 0x3ee03e28,
	0x1f9b0d20, 0x8ba64efb, 0x3d22adc7, 0x66b729b3, 0xabe49786, 0x11f7f872,
	0x369437b4, 0x6b0f2505, 0x784c0735, 0x9ab22cce, 0x4c7f3f91, 0x7c426a87,
	0x98bc8815, 0x4c1f23fe, 0x457ed10a, 0xe944078f, 0xd77b98a9, 0x594c3ee2,
	0x04797bdd, 0x63c071f1, 0xa9bf466a, 0xfe4cde39, 0xf24ec396, 0x2a1c16af,
	0x50f3ebbe, 0x52af582e, 0x89ffabfc, 0x8f280b5b, 0x6639d61f, 0x21fe7598,
	0x3ffbccd3, 0x1ea134ec, 0x3f333653, 0x3278aa8e, 0xf7de68ab, 0xf9fa1943,
	0x33a7265d, 0x7e8a5e3d, 0xff4fd428, 0x61b21995, 0xf9c0ec9e, 0x7e0e15a2,
	0xfee148be, 0x978af712, 0x3b73c11e, 0xf71f84bb, 0xf30991d8, 0xa6d7efc8,
	0xf7878848, 0xd2af3c3d, 0xc832659b, 0x1ff8419f, 0xa2d5fca3, 0x7d71cfc3,
	0xff616306, 0x8bd3998a, 0x44ede6d2, 0x4a7162ff, 0x2f75f288, 0x14c98d6b,
	0xeefb532f, 0xf612d1ab, 0x7eb8db39, 0xf7c7de69, 0x9afbc9e5, 0x132bd38f,
	0x657a8cb3, 0xb26ffca0, 0x1967a657, 0x7a7ff2ed, 0xfb8cc2bf, 0x25bb64bc,
	0xc4375f79, 0x6fea4f0e, 0xcf45fb24, 0x1c1aa93f, 0x6ed1db87, 0x188a3edd,
	0x5caa73f2, 0xcda0fce2, 0x6907ffd8, 0xcf57ad2a, 0xa35cc9d7, 0xfd7cc6ad,
	0xf91877f8, 0x227cf4eb, 0x52287f3d, 0x227cf3c5, 0x2f9d1b26, 0xca76b1f4,
	0x62c51a1b, 0xb57e4492, 0x67df865e, 0x7c10fe61, 0x1156657f, 0xe601ffcd,
	0xdc932f5f, 0xbf9c24d4, 0xd24ef31d, 0xedd1de71, 0x2fbc714b, 0x3b3c68b9,
	0xd3a49de6, 0x39f882fe, 0x55f3c827, 0x78f03567, 0x65e80e43, 0xe68ce72c,
	0x605f6974, 0x3d55fca1, 0x3bcf449f, 0x2552e1d1, 0x76339de0, 0x45ca2169,
	0x8b653f3d, 0xf6895fc3, 0xf6049b50, 0xd1a7ae35, 0x784df221, 0x458d1dbf,
	0x4ff7a451, 0x0c928f9a, 0x252f3d67, 0x855a129c, 0x579fa3fc, 0x7449f3d4,
	0x27c049ba, 0x61c76bcd, 0x3557df6e, 0xfd1d6858, 0x4fc8738d, 0x6268dfd9,
	0x75540768, 0x261d395b, 0x8163b78d, 0x5fb0c585, 0x79476a25, 0xc7c3d3aa,
	0xdf80b7d9, 0x1f03f452, 0xb8afb55b, 0xf8ff780f, 0xf67a2eaa, 0x792ea5db,
	0x5d279d32, 0x1eeb9288, 0x51af6fdf, 0x9b3cc12e, 0x2404be78, 0x0ffb2bb4,
	0xee364ab5, 0x632fe2ab, 0x966de1f9, 0x98fd502f, 0xda092ef8, 0x51d7dcff,
	0xcda4654b, 0x75bf681c, 0xf5c46d7d, 0xdfdff429, 0xc71e7258, 0xc832b30f,
	0x87b6b39f, 0xff4247fc, 0xc8f97055, 0xee51adaa, 0x8fc8d2bf, 0x90bb2a76,
	0x695702ec, 0xac1e81d1, 0xdf92b5cf, 0xfe89ea0d, 0xc9998d4f, 0x7f8e35eb,
	0xf9e6eb96, 0x8237ac1c, 0xe154edf2, 0x375ff24c, 0x7d807f21, 0x7a1dc335,
	0x4e7af102, 0xf903b9ea, 0xdf95d4e1, 0x3f3a432c, 0xa3dbf077, 0x655cfe51,
	0x187dbb01, 0x9b2eb379, 0xb37e9bcb, 0xfd04bd6b, 0x7a15ddfc, 0x82f1d70a,
	0x3c6ce173, 0x7d20b002, 0x1a8f05a6, 0x32c3c8b0, 0xe04337ae, 0xdb9f33cf,
	0xa0ea9e93, 0x6ba17984, 0x191e7cec, 0xf6402521, 0xf4be684d, 0x1aff5825,
	0x4c3bd849, 0x497da54b, 0x718a96a9, 0x5ce2e5c1, 0x5bf82ca9, 0x9bfdfc16,
	0x15a3bd55, 0xe92ee030, 0xb70f2cda, 0x692ebddf, 0xff3fa1ff, 0x3ce6e42c,
	0xf4889b59, 0xfb9f35e1, 0x5be02d55, 0x08a3f8b6, 0x6e7935ef, 0x751ee78a,
	0xa17afa57, 0x3be0a95f, 0xbd679815, 0x153bef26, 0xd3937718, 0x4260befc,
	0x6e78cff9, 0x679e2a63, 0x3f087680, 0xfa054b67, 0xfeb33f63, 0xb2bfa152,
	0x40dfde4f, 0xaf3e563f, 0x3e78b6e5, 0xcdbf4f9e, 0xf100fa1e, 0x57a2fef7,
	0x477b5e28, 0x3197a9ce, 0x9994e2df, 0x9e48e7cb, 0x1d6793c8, 0xae8052b3,
	0x447b144e, 0x8b8f08be, 0xfdcb189e, 0x785f209b, 0x8938e75e, 0xe76b03f2,
	0xd7a7f3f3, 0xded69eb0, 0xce2f3c42, 0xbd3d9bfb, 0x5ad3ec90, 0xfb31bf91,
	0xe20a6085, 0xe397f671, 0x48e1d20a, 0x3e55d6f6, 0xc09bd6b3, 0xc66b5767,
	0xc6a535f2, 0xc6fc17f2, 0x7fa717f2, 0xfcb13638, 0xf3e03d9c, 0xc839454d,
	0x972347f3, 0x70ec9530, 0xbb4114af, 0x72cfc268, 0x9e5db9c4, 0xb143f8e7,
	0x74d9fb8f, 0xfb99f546, 0x586dbb6c, 0xb2e2fc2f, 0x63e09fa8, 0x823482b6,
	0xb8d1e907, 0xbd25f224, 0x07622b14, 0x7fb9536f, 0xa05ada18, 0x348b839f,
	0xe997f73a, 0x91cbb132, 0xc46c2b6f, 0xac7f3ab7, 0x039d03b1, 0xd9472b1c,
	0x6bf7481c, 0xd86dfecc, 0x6ab0ec97, 0xa66737a8, 0xf96fa8d8, 0x3bd2143f,
	0xa656edab, 0x3dd8f942, 0x3b432a0e, 0xa6c71f92, 0x2fe8a25a, 0x85f4235f,
	0xe9133dfc, 0x05854add, 0xda03ff31, 0xb1fdf0c5, 0x83b51b6c, 0xf7c7cd25,
	0x3f3acca7, 0x1f2854ce, 0xe75dcc54, 0xde911843, 0x2e7c156f, 0x0e3b7e0b,
	0x7f71a0f3, 0x3f927729, 0x09bb54ad, 0x36db7ffb, 0x852bce96, 0x2961ce07,
	0x54ac1c26, 0x9ba27215, 0xf9d3979f, 0x2033975a, 0xa8634715, 0x50e31253,
	0xf5133e98, 0x5d3b2338, 0xae3d73e7, 0xdbd36798, 0x3fec0129, 0x2df77c5b,
	0xbce1a15f, 0x2f78a65a, 0x2fe2ff75, 0x3cba8f48, 0xf49d65d8, 0x70f66d4c,
	0x06fd2ef0, 0x55b8e795, 0xb9b1ef0e, 0x63b277c8, 0xadea2e6c, 0x16bf1e35,
	0xc297284c, 0x1a416676, 0x41da03c2, 0x579abaf9, 0x71892b46, 0x73e71f67,
	0x07481768, 0x6bb31f78, 0xc39fc8b9, 0xc7c4db8c, 0xe3b67e75, 0x685c60fa,
	0xe30dcc77, 0x763dbb42, 0x3294cc6b, 0x35d3f8dc, 0xc6e3ef1c, 0xc4462c65,
	0x15c04733, 0xfe8220e8, 0x136e63a7, 0x911ce3d1, 0x832c7c27, 0x8d4ac78f,
	0x81a33779, 0xd7944d0e, 0xb9b3cc65, 0x8ad9da4a, 0x3dab727a, 0xddd23765,
	0x9c5d042f, 0x68c7fe70, 0xb17e93b4, 0xc938e4b0, 0xadd5d491, 0x58732448,
	0x5d13c917, 0xfd9fbdce, 0x4196254a, 0xbe476dde, 0xd4e8a3bf, 0xb8fcec42,
	0xd468eb67, 0x760f207b, 0x9d0ea6f8, 0xfa7f4ebf, 0x910e91bc, 0x30e807de,
	0x1d3afe69, 0x28bb6bb1, 0xb001f141, 0xdba9f133, 0xf0b58c9d, 0x6f2d747c,
	0xc4407d70, 0x7c2d6db3, 0x9a118d1d, 0xfb9e55f7, 0x47ed5f28, 0x83ffa139,
	0xf9305af3, 0x1b057cad, 0xc58d16fb, 0xb7cc15fd, 0xbff197cb, 0x3b64df37,
	0xb2f2e3fb, 0x7d63e247, 0x3ede697c, 0xcf0ecbca, 0xf69e5177, 0x1a97912c,
	0x3f91306e, 0x6463f61e, 0x5b3337c7, 0xa5eee514, 0xcfd62ec2, 0x71213c0b,
	0x31e4673f, 0xc137b6ab, 0xaf9a1ebe, 0x783e51ad, 0xebcf2564, 0x9b9fb01e,
	0x079fb234, 0x9f3898f4, 0xcb8531d0, 0x34db8eee, 0xa4f3773a, 0x1647dbc4,
	0x1d8bd231, 0x12fd4573, 0x3fdfaa35, 0xe60e6522, 0x327477cd, 0x770effa2,
	0xc8e7d511, 0xcfb0df5c, 0x51d37d73, 0x1d97f7c8, 0xfd509437, 0x1c744716,
	0x788907e5, 0xfb8c0efe, 0xfeb883ff, 0x7f467cdf, 0x33f940ec, 0x569ec7f2,
	0x9d211f43, 0xe40b292d, 0xf58f404b, 0x0597ee16, 0xc3d9dd7a, 0x65b04d30,
	0xae93ee34, 0x9bcf2d66, 0xcd5e898a, 0xc17ed0d9, 0x62d7a004, 0xb25abd03,
	0xc6dcb833, 0x3af4e979, 0xc9a5a740, 0x54a177f9, 0xe9e1df6c, 0xee337dfa,
	0x7eadba2b, 0xf3cc7f9e, 0x43e59329, 0x2b167cc2, 0x595e3e7c, 0x0d64f9a6,
	0xe18b9f37, 0xcd3a449b, 0x463f9c62, 0x852c9fe2, 0x83e5dc45, 0x3d9cf3fc,
	0x0ee38254, 0xbe5ad1f0, 0x6f321c9f, 0x74f445d9, 0xee3c0dfd, 0xbd727614,
	0x6ca7f18f, 0x18ae7f18, 0x60b6faff, 0xcddb07b5, 0x621c3895, 0xff983ff0,
	0xb73f513c, 0xcff289bb, 0x4f9b55e6, 0xba39da27, 0x5de3d4bc, 0xebfb440b,
	0xcc66b9d4, 0x6b5f9f07, 0xb82d338c, 0xaeb9c789, 0x67ec6f9f, 0x16f8db01,
	0x16b249e5, 0xc16fc233, 0x59fac64d, 0xa9f103d9, 0x3a9f18b1, 0xfd30fc2e,
	0x47c827c0, 0xdb2c674f, 0xf9d01b79, 0x9597efd8, 0xcaeedfa3, 0x9b3dc6cc,
	0x8ed0fca1, 0x3a7e54f1, 0x3f5f2bf3, 0x4abbf585, 0x978d5ca8, 0x11bee121,
	0xacf810f9, 0x3986f2b4, 0x4fa82985, 0x31b7bf44, 0x8473ef7a, 0x3b42e63a,
	0xca22a4df, 0x7e16ad1f, 0xbc25fe85, 0x6ec99afe, 0xb37c229e, 0x6ada7e46,
	0xe8f7bf07, 0x5dff2999, 0xd5ccf98e, 0xfe5ca245, 0x1f2c78e4, 0xfba2de97,
	0xb937ce14, 0x7343c414, 0x4f6ff70e, 0xe3629528, 0x69d52e00, 0xbe26ffa2,
	0x87f2daae, 0xaa4f9073, 0x133f78ab, 0x8adb33fc, 0x6de99db1, 0xb1cf9f2a,
	0x75fc20a5, 0xb65afb7e, 0x37614fe0, 0xf89c8506, 0xd695e059, 0x6837e874,
	0xc4b8fc93, 0xc857f4e0, 0xfc5cc12f, 0x50305e5c, 0x7c7fa0a8, 0xbbe78056,
	0x6756d956, 0x36bc3ca3, 0x75c0a964, 0xc729b6a9, 0x75211f31, 0x94a9ccfa,
	0x84636d1f, 0x6fffa05f, 0x7b4ffd12, 0x89053f2b, 0x7fa465ce, 0xeae6be9d,
	0xa46d5f74, 0xefdbe06f, 0x271ff7e0, 0x6df40dbf, 0x91efa41f, 0xd79879ec,
	0x6bd46c86, 0xb5ea379f, 0xf8927181, 0x91dc7933, 0x25fe06e4, 0xf9c1dfca,
	0xe61f1175, 0x31615662, 0xcebb69f2, 0xf5c7dfa7, 0x743d4c59, 0xf240a92e,
	0xbd83a78f, 0xd236fdd3, 0xaafc497b, 0x7d0f2fcf, 0xe743e5d6, 0x6e8a7f85,
	0x2f3ff297, 0x457231fa, 0x60177c3d, 0x82f38369, 0x72447ff1, 0xcf9f2d71,
	0x970b5203, 0xa1df6233, 0xf59a3ffb, 0xae321ef5, 0xefc1d2b7, 0xbfa1f00f,
	0x5316628a, 0xfbcc0fc6, 0xafa0f022, 0xf9f42c27, 0x6dd05b7c, 0xc97db581,
	0xf3f44f53, 0x1ea8d065, 0x1ddf8b80, 0x8ebe218a, 0x71872299, 0x0584b73f,
	0xf40d6e28, 0xc13b3471, 0xd7f01a6e, 0x79a9c124, 0xbc9ab904, 0x0cf8649e,
	0x1b27ade2, 0xbfb9fa9f, 0xe45ef581, 0x15ed933a, 0x37e8c5af, 0xbdfe134c,
	0x5e7f41b4, 0x32d7d629, 0x79fc9f87, 0x73f6897e, 0xa07f60b5, 0x61adae9c,
	0x734957e4, 0xa79fc899, 0xf12321db, 0x739715c9, 0x9cbb55b9, 0x7c86f389,
	0x98f4c97d, 0x81bf7ac5, 0xb69b5acf, 0x7ff2317d, 0xdf90cb83, 0xf1e2eb5f,
	0x39740f80, 0xa2a77ac2, 0x0f281fde, 0x53bdfbd1, 0xdf250e51, 0x817b56e3,
	0x2ed39dfb, 0xf5acf448, 0xf51532bf, 0xef4d5a7e, 0xbf679454, 0x0dfc0d4a,
	0x1365f2e9, 0xc327cff7, 0xd26396d3, 0x451798e3, 0xa47cc9a7, 0xb8671fc7,
	0x8c9cce43, 0x39d4bf41, 0x9cfc87a9, 0xe8aae9fd, 0xf488543f, 0x670b51ec,
	0xbe697fa2, 0x768cc5ad, 0x94350af1, 0xe8e5c39e, 0x66e11f47, 0x1c029b15,
	0xfa1d54bf, 0x2587c2ae, 0xe02edc38, 0xb3d0a570, 0x6994ef6f, 0x281d521f,
	0x98a18add, 0x8b3349f0, 0x4806df12, 0xaff7ea3f, 0x1f240dbd, 0x763ff6c3,
	0xf65dbe93, 0x538a7acb, 0x6266dd8d, 0x1cbe825a, 0xee187517, 0x2fb0991d,
	0xd89e50cd, 0x3f686395, 0xa19150f9, 0xbc6c4a7e, 0x2773fea1, 0xa9e50dcb,
	0xda1a973d, 0xcaa17b4f, 0x77a4be50, 0x83fda18e, 0x8e01efa8, 0x9e6d7f9f,
	0x769ffde1, 0x71893ecc, 0x37e2cbe1, 0x233fbe1a, 0x122c0cfc, 0xf58529e8,
	0xf5e9d62f, 0x7be19d42, 0x52626b30, 0xff3df225, 0xe791bc5b, 0x8804cfbb,
	0xa4b7f625, 0x5c4f68dd, 0x2794e2c9, 0xfc951cd8, 0x6ef98631, 0x43c6fac6,
	0x8fd7049d, 0xac606fbb, 0x4d099177, 0xc072ebf5, 0x808718ce, 0x5f30d360,
	0xff7e246f, 0xb097fc38, 0xff089fd1, 0xff119f56, 0x7f88cd76, 0xff11a967,
	0xff11bf6e, 0xf88dd3a9, 0xf88c04f7, 0xe231af4f, 0xc468233f, 0x2302d67f,
	0x4643b3fe, 0x306a8ffc, 0xc5af3de2, 0x1582ef88, 0x4616bc46, 0x27d4316e,
	0x4f4e81d3, 0x5e2cfcba, 0x3db1bb7f, 0x4094c500, 0x2d9d3a17, 0x1e50360e,
	0x6ff698d4, 0xa64bc619, 0xe44cb18f, 0xfa4a7e6f, 0xc2e90fb8, 0xa0174839,
	0xa6723a97, 0x15b19d92, 0x0ac60b9f, 0xbc383ffb, 0xafcba19d, 0xb89ebd44,
	0xae491e6f, 0x6257d10d, 0xbea23d1f, 0x7db47dc2, 0x123d1f70, 0x40c8befd,
	0x1be0d2cf, 0x83763fc9, 0xcc71e7ca, 0x77f9edc1, 0x6812eab0, 0xc3a66d07,
	0xf5c45f7c, 0x3a2ff8c0, 0xe41f9026, 0xc665d646, 0x3d626f71, 0xe2c85cf4,
	0xd5310cf4, 0x3164ae70, 0x5f845a0b, 0xb4e11ba4, 0x895bd6dc, 0x45fdff7a,
	0xf8a65ea7, 0x17e933d8, 0x69c70f75, 0x618cbf8c, 0x2790acec, 0x8187187d,
	0xf0bb79f2, 0xe6980613, 0x59e7804d, 0x9bacd7e1, 0x659e9125, 0xc7f283b2,
	0x912cbeea, 0x33fbaa9e, 0x8736fe7f, 0xe7e4b5eb, 0x5c3a159a, 0xc07d85db,
	0x1e0704ed, 0x1df8a576, 0x1ec8b90b, 0x6f88abf5, 0x45c78fe8, 0xfb42d3fe,
	0xcf8d9f76, 0x298911f3, 0xb8e8d3d3, 0xf11de11e, 0x7ccae78f, 0x47bf3e36,
	0xf086cccc, 0x6442c09d, 0x80adde1f, 0x8efde3c8, 0x2a9efde7, 0xc3a17f42,
	0xaa17db71, 0x74f3c12f, 0x9fe4d591, 0xfa332aff, 0x916a6fe7, 0x55ff3fc8,
	0x7d3c3798, 0x7a87dfaa, 0x947f2f59, 0x3f7f71a3, 0x59f783b6, 0xfd0916be,
	0x7f599f63, 0xdbc5be07, 0x06fec27d, 0x5e7c61fa, 0xd4f887f8, 0x40b9affd,
	0x97a056df, 0xe4655f3d, 0xc3f64c3f, 0x8341928e, 0x9996de60, 0x53e007df,
	0xf17df1b6, 0xf06abf09, 0x07b33133, 0x9c7e6fcf, 0xd6f9873d, 0x47ce1367,
	0x7b0d1d00, 0xa3abed4f, 0x66b29db8, 0xd1294f55, 0x7e7b88a3, 0x2a49d577,
	0xf29f8acb, 0x2d9ef121, 0x16f7c24f, 0xc827d42f, 0xdf05c517, 0xb33dc827,
	0xc697482b, 0x43d55dac, 0xb8b346f1, 0xee5d6c0f, 0xc1286aed, 0x147e32bf,
	0x6cc4b73f, 0x3266a611, 0xdfc3da61, 0xd218b36b, 0x672aac8f, 0xecd1f713,
	0xb844e4a4, 0x793e0935, 0x3e8ff059, 0xc60fab6f, 0xcbd7984b, 0x36cf6e76,
	0x5c163da9, 0xfa85cbc7, 0x19bd3bbd, 0xee5d8fe4, 0xb376f925, 0x80f583c0,
	0x30f3c314, 0x2acf0556, 0xbfbd2f63, 0xb17c069d, 0xc33359f6, 0x3bdae0f8,
	0x72893aaf, 0xe2d692c4, 0x7c7d018f, 0x6a25d9ed, 0xeab81868, 0x794fab4f,
	0x570e513f, 0x007e128f, 0x99878721, 0xafe5e90f, 0xaf9bfca9, 0xfda669dd,
	0xcabed7f4, 0xad9f2f28, 0x41cabf80, 0x3f306538, 0x8b0f53c9, 0xab8dcbd3,
	0x32c7b180, 0x8d9561b6, 0x7fa0ac85, 0x7dd90b59, 0xf4402c99, 0x5c7fd1b4,
	0xa7ba7245, 0x3e20f9e2, 0x69ee9437, 0xeef3f347, 0xf83d03b2, 0xc08c6174,
	0x514e794b, 0x8dd5a2bc, 0xa947cc65, 0xef8c3281, 0x008ef510, 0xbd453b2f,
	0x9f6f3a73, 0xf2c9ef1c, 0xe16693cf, 0x9a9bf5d3, 0xb52f9462, 0x16af9f8c,
	0x71e834f7, 0x6fd70c91, 0xce50b382, 0xb7113355, 0x8bf7f5e5, 0x76bba675,
	0xfac22faf, 0xfbfac619, 0xb5c7bd44, 0xfb0abdbb, 0xdfac6d1f, 0x754ffa2c,
	0xee927a3d, 0x8e35c9e5, 0xb7a8af7f, 0xa1ed1ebb, 0xefc6bdef, 0xd5bd44db,
	0xe0a8f3c5, 0xccee22df, 0xf189d7eb, 0xb1326f33, 0x7a9d0250, 0x28583be7,
	0xb569ef01, 0x19b28669, 0x7cf1c3fb, 0xb5615efc, 0xbdf0c73a, 0xc577ffde,
	0x8a3329f8, 0x46dbdf0c, 0x9fb6378f, 0xf07a469f, 0x4b770176, 0xfea1b96e,
	0xf4af1ebc, 0xb607bcf0, 0x7957b447, 0xa97bc57b, 0x4bb7ffa1, 0x7bcc54b5,
	0xbb320b38, 0xf8ac7107, 0xb7cfc86d, 0x90b28bbb, 0xa6aba34e, 0x720271a3,
	0xe2b23e03, 0x9f4f1553, 0x7289af78, 0xe9fb28a9, 0xabfc2859, 0x50d5566b,
	0x2bd03779, 0x2ab07f3e, 0xa007cf40, 0xdf77c1ac, 0x28357e87, 0xb17e876f,
	0xc5fa15bc, 0x2fd0fde7, 0x7e83ef3e, 0xf4337eb1, 0x617be58b, 0x07be583e,
	0xddf2c1fa, 0xdb963fd0, 0xbca90556, 0x7a02d56e, 0x8855777e, 0x35566b9e,
	0x51d1fd50, 0xdbcba7d2, 0x5b4100ab, 0x385bc869, 0xe0ea6a3a, 0x6f3d1439,
	0xfc32d3a1, 0x42b7f13e, 0xe0b015fe, 0x0157f451, 0x9abdd37d, 0x8ebb1b79,
	0x3d3a7ee2, 0xbd93f1c8, 0x3dea85b1, 0xfd1c7c35, 0xb08de63b, 0xec7e4adc,
	0x979ddb16, 0x9f28bbb4, 0xdff71c67, 0x69845f33, 0x65bafc95, 0xa4e253fa,
	0xa3529447, 0x0eb42d5c, 0x1ff98f7f, 0xe8f238c4, 0xc72e0096, 0xc3183d36,
	0x3f9776bc, 0x1411f744, 0x930d985c, 0x70bafe04, 0xe9e0d339, 0xebda35ad,
	0x06e5d569, 0xd0be587b, 0xb96ced4c, 0x59da1a37, 0x768675bc, 0xae16b775,
	0x463c21f5, 0x375875f1, 0x30d966ae, 0xcd8e92ee, 0x9725ae34, 0xcbd60de3,
	0x2fdf3def, 0x7b0af5f1, 0xac5521f0, 0xe491b6d7, 0x2f0f58e9, 0x4c46a496,
	0xfcdf0728, 0xc3f12a69, 0x91303f83, 0x8b1c73df, 0x135f109a, 0xfd633d40,
	0xe54bd644, 0xa15528c9, 0x3269853c, 0xe2c73f96, 0x3d832764, 0x9851f7f8,
	0x7e8728b7, 0xb9f28760, 0x3c43d0bc, 0xfa462a5f, 0xa3e044a4, 0xb78bb744,
	0x437ec929, 0x42fc9725, 0xc955f3c6, 0xeed5ed71, 0x3bb42cca, 0xdf908fce,
	0xf99df4e6, 0xc1cfe2c5, 0x7a15fb33, 0xd6efefea, 0x3b9ec34c, 0x3e95c82e,
	0xdb867ddd, 0xe9192e40, 0xfa1720bd, 0x9bf6573b, 0xcd1fd44c, 0x1fb4e3a3,
	0xe5d66359, 0x5cca9686, 0x2a7f6589, 0x83c7584b, 0x56285eab, 0x08872048,
	0xd3aab26e, 0xfcaf5f31, 0xe62a2997, 0x3c889559, 0xb2ab7dcf, 0x498f5747,
	0xf588d3f0, 0x93aeb294, 0xbd4a1fa8, 0x57ed3f26, 0x7f61aa03, 0x1edd1f6b,
	0xf22df3c0, 0x1cc7e678, 0x9dac71a0, 0x7fcb85ce, 0xc91e4997, 0x1a66aec7,
	0x350e1bd8, 0x498f30ca, 0x7d8997ef, 0x5c85d7f2, 0x4d55d77d, 0x75f397f3,
	0x3b201dbd, 0xafd55de7, 0xbbd71e62, 0x48fa661d, 0x2fac6d3e, 0x842ffd55,
	0x1e974e80, 0x7a71fa70, 0xba76d28e, 0x25de50cf, 0xe60a1c31, 0xd334f3c1,
	0xde6dfdb8, 0x8022c956, 0xa14c6bcf, 0xaf6f820a, 0x2ba4d076, 0x94d7687d,
	0xfbfba16e, 0x5c5c22c7, 0x461b9708, 0xa3d0e357, 0x4b8e094b, 0x8917bac4,
	0xd3c9ac75, 0xc3e62fe1, 0xffbc0102, 0xbe876970, 0xf3ae37bf, 0x2faab2ee,
	0x8f6b7d62, 0xc9da794c, 0xf2973cf0, 0x401494bb, 0xee04dd78, 0x2e79828f,
	0x382a79c2, 0x2f8474ef, 0x532ddb8f, 0xb73c512d, 0xaaea5e7c, 0xd133fd21,
	0xc9b6f944, 0xcb90d974, 0x4737d0ed, 0x4ed7c4a9, 0xe7a259df, 0x2fdf72c1,
	0x7ed3a716, 0xb731eb84, 0x2058f5c2, 0x11fa25a0, 0x1afee837, 0x21c0be71,
	0x3f703be6, 0xe79e78da, 0xdb3d62e8, 0xa4678f30, 0xe47fd27d, 0x93ed2616,
	0x3f483500, 0xf7946d53, 0xc3cf41b2, 0x94694ed2, 0x3c4f0e77, 0x7413621f,
	0xbc6dceba, 0xac53b62f, 0xa3e053af, 0x87e7a6df, 0x24a76a04, 0xeba8579c,
	0x80bf27ae, 0x17eaf71e, 0x877e98fe, 0x28d54e31, 0x78ffa148, 0xe303957b,
	0xee3ced2d, 0x0d7dd8d5, 0xf0f39fbf, 0x29bf747d, 0x3d21a9f4, 0xf5f68bd4,
	0x817e8deb, 0xc442fb25, 0x877ec9af, 0x40033f64, 0x78f682ce, 0x57619fb2,
	0xfd67b0ae, 0xb5c60a6c, 0x3e2c6cce, 0x5b7980e1, 0x739d190a, 0x4a3f251d,
	0x358307f7, 0x82f78eda, 0x0f7e32b2, 0x7cfd90ce, 0xb2e0859e, 0x18efc74f,
	0xbec1f117, 0xec0e5ca9, 0xb5f6fa3b, 0x6f9fa063, 0x7ee1926b, 0x666b6ffb,
	0x0c39eefa, 0x2efbc020, 0xcb866ac6, 0x9ae58b67, 0x9f9e9d3e, 0x8a9dfc61,
	0x27bd43a6, 0xbfc91a9c, 0xf7dd239f, 0x4a6bf89f, 0x9c51f119, 0x03e1577e,
	0xe707cf8d, 0xf64ce78d, 0x985ade9b, 0xe5cf0f48, 0xa6de622a, 0xab8f274f,
	0x573af38d, 0x1ce67cf6, 0xa0dfaf3e, 0x3b1f397e, 0x7e78999d, 0xfed79f40,
	0xff35ee11, 0xcf9da7e3, 0x487ea374, 0xce1f5380, 0xed382467, 0x9f3f0cb7,
	0xfdbc0abf, 0x9fbf38e8, 0xa7fd6863, 0x8c3adfb4, 0xe3f73df3, 0x6c51eb9e,
	0x4aff7cc3, 0x65f5f3f0, 0xc04d8c52, 0xd042abaf, 0x3f908567, 0xb12bda7e,
	0x28d34bf0, 0x614bad6f, 0xae58b5e9, 0xad5fec5c, 0x12f7de0d, 0x79893d06,
	0xeb25ec71, 0x6a6ff2b0, 0xfb0b971e, 0xe161a473, 0x47f517e0, 0x402ba99f,
	0x0bf7733d, 0xa1728656, 0xdd9fe455, 0xf0d976ad, 0x8e1d5cbe, 0x67872e58,
	0xea5f12d8, 0xbbc572c7, 0xcc35cd36, 0xde3e2678, 0xa37c49bd, 0xc73fa78f,
	0x7d7295e7, 0xf1971d28, 0x33bdc15c, 0xac7ba79e, 0x4850adee, 0xf8627ef6,
	0x7f824c6f, 0x6bccf9ec, 0xcf8cbd39, 0x4b37f803, 0x22f94c7f, 0xfc52c394,
	0xff1865d7, 0xfd6884b7, 0xa7638061, 0x194e1434, 0xf45e9c79, 0xd7ebe9f5,
	0x6cbeede7, 0xfdc1e131, 0x869495a2, 0xdfa4cf3f, 0x35724917, 0x5c3fe855,
	0x198be917, 0x31973f0a, 0xdfbc2155, 0x3a52fd3b, 0xc45fb347, 0x5897e3df,
	0x843dfd86, 0xeeff1890, 0xe0f5cf0b, 0x6dd233be, 0x600c7ba6, 0x0ebbef9f,
	0x567e51ef, 0x81917ba1, 0x5ef06a9e, 0xbccfa3a6, 0xde76829d, 0x3cb8f357,
	0x8790aafb, 0x1ae417fd, 0xccf2df3a, 0x409caabb, 0x64f30bff, 0xf4f49f61,
	0x4d95b9e0, 0xdf3f3ce5, 0xd701ec25, 0x380d7d33, 0x6ff4d77f, 0x7a04a559,
	0x4acf36bb, 0xc4b26ddf, 0x5fd0fd33, 0x62ccb0f8, 0xd2f41764, 0xe70372fd,
	0x870e54f2, 0x0ce38ae6, 0x37571ded, 0x616e77bf, 0x2ce5c69e, 0xbc20fbcc,
	0x577b8c77, 0x0afac7ad, 0xf068af18, 0xf1cab77b, 0xefca98e9, 0xc677b97d,
	0xd7bc546f, 0x7462552e, 0x628bf35f, 0x2cbcfa9d, 0x5d0f1c85, 0x683d3d15,
	0x855445c7, 0x62ba7ff2, 0xded0dbb7, 0xbba2f9d7, 0x9d7baf90, 0xdd787fb8,
	0x9e28d2f4, 0xf8e9d193, 0xedd0bca3, 0x809b3748, 0xfb251e2f, 0x8b3827ab,
	0xc14ea3e0, 0xa447dcbc, 0x275fba1e, 0x22a2d532, 0x4c9a961f, 0x02c273c6,
	0x3013fa6f, 0x37cf7649, 0x7aeaed04, 0x31b4ee5f, 0xdef7873c, 0x68a9b985,
	0xba79ca9f, 0x1157e7bd, 0xe6b9ef8e, 0xeaf89d93, 0x898daed3, 0x72030df9,
	0xb1b9f616, 0x25e583b1, 0x6c6ce0fe, 0xd68594bf, 0xb4ba5da2, 0x4fdc3643,
	0xf3e0aaf0, 0x2c9c1725, 0x2fe76096, 0x9d237e99, 0x21725aaf, 0x2abfde85,
	0x155ea0f2, 0xb1514ff9, 0xe78b1f8e, 0x694fbca1, 0xf493fbff, 0xfdff03cd,
	0x97971d60, 0x538c3cd1, 0xdc16bd4a, 0xf4ba6d4f, 0xe5ae74af, 0x8f7fb08f,
	0x3ad1ff59, 0x612c59d3, 0x177681dc, 0x9e962cec, 0xe68d1788, 0x175eb83d,
	0x9571ffd5, 0x38e063ef, 0xc1c700ca, 0x700d8bfe, 0x097fda1c, 0x5571ffd5,
	0x3ff4c7e9, 0x0bfe8461, 0xec1ff30d, 0x3fbd3477, 0x21eeac7f, 0xb1cbf027,
	0x9e3b5dd8, 0x23be3cc4, 0x9fefba56, 0xa2aaea1d, 0x308f76f3, 0xc779873a,
	0x8cbcbf91, 0xec7779f9, 0x8c71f8b6, 0xa17c737e, 0x30fd187f, 0xbc11a99a,
	0xfe7f4af7, 0xad315e57, 0x4dbdf927, 0x6f98aa89, 0x54552b67, 0xd6364fd4,
	0xf70bbd13, 0x9236151d, 0x5f9fba4f, 0x5cc1f7ef, 0xf51f20d9, 0x175e4dfb,
	0x2b9368f1, 0xf6fc8bd4, 0x57ef83ba, 0xa136b381, 0x3ff1ad1f, 0xc1e79565,
	0xa23f687b, 0xdc15b9fb, 0x6ba315e7, 0x7cf0c828, 0xf42d5cca, 0x7dff7e2a,
	0xf7e80710, 0x09ee2796, 0x3dd29e61, 0x8f77ff62, 0x4fe7c7bd, 0xf2177b90,
	0xefa74f94, 0x77e893db, 0x8c1eefea, 0x01737d71, 0xf724d1e7, 0x10aea4fc,
	0x8af559cf, 0xb234ae7b, 0x4e2aeb7b, 0x75787dd0, 0x7d7e7efa, 0xcf3efc72,
	0xdd78fb83, 0x79829f2f, 0x37efa856, 0xead27bf1, 0xff5cbc9d, 0xefca74ab,
	0xb38c7d87, 0x7ed0e50c, 0x41efcfd9, 0x6fbe0954, 0xdbf7398b, 0x7c23e536,
	0xdf9c05fb, 0xee8a7eee, 0xfd7b7c5d, 0xfa83a218, 0xee9b7f9f, 0x239fdb51,
	0xbb0ec0f2, 0x5bd50f49, 0xaf7895fd, 0x6e1cfedf, 0xb129766f, 0xfb04f294,
	0x156e5d73, 0xd737d7c9, 0x7da1318f, 0x97d5c3ae, 0x26c2e5cf, 0x895d9f3d,
	0x92b9e257, 0xbf622b37, 0xc0783d26, 0x6477bf4e, 0x4a97f83a, 0x9371ffba,
	0xafd1ee95, 0xcb6e383a, 0x2a6fa802, 0xaa5e5131, 0xe69da0e9, 0xbf036e73,
	0x45bf0a8f, 0x7074dd7d, 0x542efd14, 0xf94e33bd, 0x7f0e4d63, 0xea49c609,
	0xee9e7e0f, 0xcf733fbf, 0x9b947cb8, 0x7cb433a7, 0x1ef7efba, 0xfbac3a00,
	0xfcb1e1f4, 0x3a34db7d, 0xe4dee9df, 0xd7e70d0c, 0xf249f5d0, 0x73fb577d,
	0x843f9ca6, 0xf36719f0, 0x12f286ef, 0x71633efd, 0xc9fd597f, 0xf30d3cf8,
	0xaafec5b9, 0x87c6f5de, 0xc75d4f74, 0x7a71372b, 0x7d01f1e6, 0x6e3c967f,
	0xfb3bd0bd, 0xf885f12d, 0x6bf55d3b, 0xefc5fc04, 0xa69bd607, 0xe9d7efd0,
	0x7494dff0, 0xc0506c1f, 0x799e7f5d, 0xf67ba146, 0xc7c81ec0, 0x2399d278,
	0x33b7a256, 0xf9d0269b, 0x7abc7d6e, 0x7c0a8d80, 0x9b4d3a7a, 0x72fdf884,
	0x7fefc6be, 0x9df7c35b, 0xd37afbfa, 0x77c41ae6, 0x794cb0fc, 0x3c6afd3c,
	0x7a20e305, 0xb03cbd3b, 0x7e996e9e, 0xce7f6a6f, 0xd03bc251, 0x32ba4315,
	0xfa4ddcfd, 0xfe73fc36, 0x566f55bb, 0xe91388b0, 0xed2b05f7, 0xb61d8ed3,
	0xffdc1d92, 0x3c273f22, 0x5731dee4, 0xd9ef1f3c, 0x147cff0c, 0xbcfeb5c9,
	0x376e2ef8, 0xbb9ee9db, 0x69a153fe, 0x2d966e22, 0x46cbf1ee, 0xc3fded7b,
	0x6bda18f6, 0x47f8a4f0, 0xd1f1ed84, 0xba4e23fb, 0x749e04af, 0x0749831e,
	0x2dbbf47c, 0xdf7c5dac, 0x91dfdf43, 0x728b1a1f, 0xe8628efa, 0xf7df85df,
	0x8bf7bb51, 0x0cb19342, 0xbc62397f, 0x2f37ea1c, 0xa5ef4054, 0xf7fc7d77,
	0x7d45da48, 0xad87d50f, 0x8eb469a1, 0xe759bbdf, 0xb4fceb30, 0xcd2dd5f7,
	0xd03a274f, 0x26700de7, 0x2e192ffb, 0xcedcf91d, 0x4c91e1d5, 0xfcf80397,
	0x3fa1f998, 0x1f39ce85, 0x30dc78e6, 0x49e5c2ce, 0x73b204db, 0x849386e9,
	0x87d5a97c, 0xecba255f, 0xa2b60737, 0x329f8a5e, 0x1c0f7e33, 0x67e80658,
	0xd5dbce98, 0xe93f393b, 0xe44378f3, 0xf1b63751, 0x1e37aa7c, 0x917f357e,
	0xbef1cf0b, 0xabc7386a, 0x93a0fdfb, 0xb8abf414, 0x5d4a5afc, 0x65b7b719,
	0x3dff179a, 0x8d664dac, 0x722caf7e, 0x27f238cf, 0x0768b19c, 0x0dca1ee9,
	0x4f484d13, 0x7b2e7e6d, 0x5d7ced22, 0xfa52fdfa, 0x70c9513d, 0x98bf2e79,
	0x0b0f8eff, 0x8c778cdd, 0xa65a669f, 0x7dd1b208, 0x2ff80d79, 0x68c37900,
	0xf3cec053, 0x0c2f497c, 0xf2ce97bd, 0xf667bf31, 0xb17e5bbf, 0xdb3ad180,
	0xd41491fc, 0x7ca9afab, 0xd5a747df, 0x7ccbbf51, 0x6fe7749d, 0xe0ebea36,
	0xa833f3ef, 0x6be0e49e, 0xa64faf12, 0x0dde5d33, 0x0dd20781, 0x41df8bf6,
	0x0bf2e7df, 0x9902dc79, 0x63f9ef1f, 0xe7e60b11, 0x2c2afae9, 0x773c2629,
	0x52d1e7de, 0xdafb2e90, 0x6356d38a, 0xcb4783de, 0x93a04f2c, 0xe74671f0,
	0x073c35ad, 0x977f0d31, 0xfd093025, 0x8cd3fb79, 0xf9e4847e, 0x77b33a3c,
	0x9ffd6261, 0xc0ffb9f3, 0x69f9c05c, 0x30cf80b2, 0x744743bf, 0x41d04cb0,
	0x39743f9b, 0xda932bed, 0x2a96db2d, 0x7de923e8, 0xa4df93fb, 0xc69d97fc,
	0x8a4f167b, 0x693b5ef1, 0xf1934889, 0xe6bca0e9, 0xde5ccd86, 0xb6b2fc35,
	0xa65e4ee4, 0x7666097b, 0xcf7e977e, 0x2beef166, 0x5f97184b, 0x3e9d1784,
	0x4a07e717, 0x6f8bbed0, 0x93e45597, 0xcd326d86, 0xb7694da7, 0x67f7876d,
	0xeec999b7, 0x39f3106b, 0x214a1b9b, 0xb14c29bc, 0x2acfdc00, 0x6bb214a1,
	0xeddf8bb7, 0xb4075a49, 0x1f295e7b, 0x8e363e06, 0xf14f8267, 0xca707430,
	0xec5a7844, 0x8b77fc60, 0x4f3a253a, 0x742f3672, 0x60fb9633, 0x65f74f3f,
	0x3dd237b7, 0x3ef0c930, 0xbd110b6b, 0xd1eb132e, 0x8e3c99e1, 0x847ecf0e,
	0x274fda27, 0x0bfe9077, 0x05232fdf, 0xefdda3b3, 0xe67b3ed0, 0xfe5f2be1,
	0x0cdfbe3c, 0xfa868c76, 0x5fd7e8b6, 0x72077d41, 0xba98ed0a, 0x2c99c5c3,
	0x7ee36f49, 0xf9d9eeb2, 0x7d04a629, 0x5321d6d9, 0xf46da59c, 0xd42594bc,
	0x916bedfe, 0xfe6b4ebe, 0x7684f2cc, 0xbf4902c1, 0xaf80c087, 0xa41fcdfa,
	0x1b0d38e0, 0x1d2eb4cd, 0x2730fd2f, 0xceedc392, 0x7f7fd228, 0xd5fa9c6e,
	0xdf4034f1, 0x9e9d0788, 0x028adda0, 0xfdc38c55, 0xa1857db5, 0x7430ff4a,
	0x183ef4b2, 0xe6dbfb17, 0x2f3ffba6, 0x1e1d5c76, 0x7c16f803, 0xe3c4654d,
	0x8ff242ae, 0x94294e9b, 0xfdba7e64, 0xe3e47caa, 0xd00fb07a, 0xc52f510f,
	0x587ba65f, 0x9ee95b0f, 0xb7cdfae2, 0xd5e38cde, 0x613568bf, 0xab91df7d,
	0x92bcd126, 0xca700af0, 0xfbde8e1f, 0xfef9e30b, 0x5d81f804, 0xafadfc41,
	0x34de6127, 0xd167d80f, 0x85fd3e3d, 0x3904cf80, 0x1f814df0, 0x885aaf68,
	0x523df9be, 0x9355eb03, 0xad26abd6, 0xf44679f7, 0x5a21fccd, 0xac97e2cf,
	0xf8bf7c26, 0xa094d77b, 0xc36faddf, 0x5f575a2c, 0xf212605a, 0xf43e5f57,
	0x5cbc8c3f, 0x67583dfc, 0x67583fd9, 0x35f09dbb, 0xe2d33ae2, 0x583fd8bb,
	0xb7014767, 0xfe75f533, 0xe852d151, 0x971e3ff7, 0xc251fa19, 0x9f4dc179,
	0xbdfa65e7, 0x1bc8b0b5, 0xd2766f08, 0xddf3abf9, 0x5d7f3efc, 0x1778c00e,
	0xa2260f49, 0x6d2abe87, 0xafa474cb, 0xe315647b, 0x3e1b7d15, 0x3dfc6bf7,
	0xb24dbebc, 0x5f43768a, 0xc81f8715, 0x7de3d203, 0xa96bc1f9, 0xbf4cc47c,
	0xfda676eb, 0x7dd1df83, 0xf4cd8709, 0x85fdd57b, 0xb00b4dc1, 0xb945f30c,
	0x9eb97006, 0x5a66addb, 0xfbfadb7f, 0x647d63d7, 0x273a64db, 0x1b5f5432,
	0x51b0dce1, 0x5321f036, 0xfc2f1a34, 0xff7451bd, 0x90670e89, 0x3fb825b0,
	0xe581e1d2, 0xe10713f9, 0x03f71612, 0xefc09da0, 0x0cf2130f, 0xf5c453e1,
	0x41979e04, 0x76e78639, 0xc957d246, 0xef5927f2, 0xb901dffe, 0x8dc79462,
	0x7ab3bf49, 0xd6f9524b, 0x3cb1b924, 0xa929bea9, 0xb5f3f41e, 0xafa5f9c3,
	0xad728cd0, 0xf751c04e, 0xc3dff68f, 0x29d7bbcf, 0x41f7059a, 0xfae4ce8f,
	0xb6615eb9, 0xf92f89cb, 0x853aa039, 0xf1cb5ab5, 0xb892dfbd, 0x5afe825f,
	0x765069ad, 0xed043970, 0x65092c6a, 0xf3eade5d, 0xb7d050f9, 0x7ec4fcfe,
	0xe311da82, 0x0c161f18, 0x9729ef13, 0x0cfa7e8b, 0x971eb3ee, 0xfe199f69,
	0xff3fd725, 0xb89ea81f, 0x008000ee, 0x00000000, 0x00088b1f, 0x00000000,
	0x7db5ff00, 0xd5547c09, 0xb3b9ffbd, 0x84eb2665, 0x08109084, 0x2481d933,
	0x2a22c24c, 0xa20900ea, 0x088b0d22, 0x8059388a, 0xda808d90, 0x066d5697,
	0xda2d1612, 0x2d8a8cf0, 0x510140ea, 0x50542f23, 0xe0ffd1a8, 0x8da97142,
	0x9a56b16b, 0x46b20a80, 0xd3df4b50, 0x7f7dfffa, 0xdee4dee7, 0x7beb5121,
	0x87a3e7cd, 0x67b9ef73, 0xe77efdf9, 0xe2339fb7, 0xb40f73eb, 0xfb510bc6,
	0xdbb89a42, 0x26efc425, 0x238b9b8a, 0x7f16f885, 0x6796f457, 0x4e8b9cf6,
	0x0fa7e7a5, 0x28c5c2d8, 0xe3db4a21, 0x85a2d926, 0x7ba039d8, 0xe3ed5f7a,
	0x03108a5c, 0x6d3bfb7b, 0xa19e8ce9, 0x745a776b, 0xe9cccf46, 0x39ee97ad,
	0xa8f220d7, 0xb9bf08b4, 0x7d35fa80, 0xde98a0be, 0xe07e791f, 0x2f3d3324,
	0x24f06d7b, 0xd0e39513, 0xee2158ef, 0xbb7ebab5, 0xdfede68e, 0x4ad9e61b,
	0xeafd3ef3, 0x3fbe135c, 0x5a856afd, 0xe5cbd4fe, 0x30524727, 0xf849b47e,
	0x8de374da, 0x9fb89974, 0x23d75332, 0xf2a18d97, 0x8ddc83f7, 0x65f7deee,
	0xe5cc82a6, 0xdad5bed4, 0x3ef300bd, 0xcab588ad, 0xc67ede80, 0xfdfc5cb9,
	0x1f47bde9, 0x71e69db9, 0x05a1dee4, 0x567a8166, 0x9fde8f9e, 0xa67460fe,
	0x7d3dfa93, 0xa567924f, 0x3f5c7e82, 0xcceed415, 0xcd9e515d, 0x30fedeee,
	0xdffa1d4e, 0x1f38d17b, 0x7ce40fca, 0x93e79ea9, 0x8295fae3, 0x4da37ede,
	0xa04d5fae, 0x566bc47e, 0x962a56cf, 0x2836937f, 0xd1b3eb16, 0x43c0fabc,
	0xe130dad9, 0xf7fc16ca, 0x257fff2d, 0x7854bbcf, 0xbe4d226c, 0xf7def617,
	0x9f98a2e5, 0x3e366c2f, 0xf8ea245f, 0xc60de2f9, 0x79a215e7, 0x6fad2775,
	0x5cf8c049, 0x9fdd8458, 0xd0a54420, 0xc56cdafe, 0x6d544251, 0xd0cc36ff,
	0x4e99f84e, 0x578263f8, 0xe04a3de9, 0x29efea6e, 0x09581025, 0xe665defc,
	0xebae8675, 0xbf9b9756, 0x9fe2307b, 0x78753a0b, 0x96126c3d, 0x61eb8244,
	0x1627b09b, 0x14211fa0, 0x7cffd7ea, 0x7d2b6058, 0xaff0f772, 0x30734a52,
	0xd049a25e, 0xd2756efc, 0x2b95093f, 0x829a3f9e, 0x16d6ca7e, 0xf3753b79,
	0x3ef5633b, 0xdf7d3b78, 0x6c5596fd, 0x278776a6, 0xd1279a05, 0x6ddf0ebc,
	0x31f634f6, 0xcd6be3af, 0xf0471022, 0x81114bb8, 0xfc7f54d1, 0xe1094a68,
	0x47adb3e5, 0xf4f54a53, 0x7ab988af, 0x9a4ad47a, 0x36e7e309, 0x61e50b1a,
	0x13d60b5a, 0xbf17aeda, 0xf06af9c6, 0x5d459874, 0x0eb0f45f, 0xb3ef4f74,
	0x2f0b31bf, 0xd6f3fdf6, 0x6233e800, 0xdc0f17d3, 0xb76cfa08, 0xf634dd3a,
	0x5ecde7d2, 0xec5bad33, 0xdc320735, 0xba247e78, 0xdd2fde92, 0xd669da3b,
	0x5ee97bad, 0xf4007173, 0x425ce7be, 0x33f70e59, 0xef8915dd, 0x7e80f7ef,
	0x23c79bfb, 0xafaf332e, 0xf9a3bb6a, 0xd67d1d63, 0xea1ac5b4, 0x3524f74b,
	0x5f5bac7f, 0x4491fe15, 0x608979ff, 0xad5109c6, 0x9ca9d752, 0x06ae1377,
	0x69f4d81f, 0xbb0130a6, 0xb45c47be, 0x5f99d3ce, 0xa21750db, 0x8fe81c73,
	0xa2ed17e6, 0x7c099e79, 0x5e682d15, 0x37b376f6, 0xda1e07d0, 0xddffb65c,
	0xfcd2a6fc, 0x47e77a12, 0x7cc369f3, 0xbad679b4, 0x95226dba, 0xce8f61e6,
	0x05a53f03, 0xc04fcb4d, 0x58f494be, 0x4d365eda, 0xdc2d7f10, 0x83a570bb,
	0x59a670f0, 0xf3d184f1, 0x1b8276f2, 0xa37ca1e1, 0x502d8039, 0x8bc77598,
	0xdd97aa0e, 0xd3e9ef4f, 0xef09e629, 0x8bf6a5cf, 0x7d7331ef, 0xbe9fa6df,
	0x375e056f, 0xf018455a, 0x59bd1e18, 0x7e604f1d, 0x2df9d44b, 0x33e6bf69,
	0xfc5bc685, 0xc413d9bc, 0x3ca35bf7, 0xd6b65e78, 0x5f4f587a, 0xea0ff10b,
	0x2506e16f, 0x4f837410, 0x1e9fdf18, 0x44f957eb, 0xab4df3c8, 0x8f18be67,
	0x171422d2, 0x3df185f8, 0xf9a65efe, 0xbdff552c, 0x60dd633d, 0x43b4e7e0,
	0x57ec0e88, 0x4082674b, 0x014cec19, 0xfdef4f1e, 0x5c780524, 0x67bffbfa,
	0xd7f03e8a, 0xa3da9fb3, 0x108d3fe2, 0x8dc910e2, 0xf741536f, 0xf717a6e7,
	0x10c77ed1, 0x5bb62fb9, 0xf43d83fd, 0x5f4dc5fe, 0xb3383f31, 0xd9cc37d7,
	0xeef6fd07, 0x94c3bf57, 0x10e83288, 0x39b4c728, 0x793ec6af, 0x1bbceac1,
	0xf579b1f4, 0x7754cdcc, 0xe485673c, 0x22334b12, 0x7f60bf79, 0xabf5d42c,
	0xe0ed93ed, 0x4ac7280b, 0x8863b0fe, 0xabb7a394, 0xbefb6f72, 0xfa33d3b3,
	0x2eedcf98, 0x31dbb72b, 0x198df244, 0x5c6fe2ae, 0xfc9b8654, 0xf087c0d1,
	0x04f15d7a, 0xafa5455f, 0x053afac6, 0x334513cf, 0x1b444397, 0xe10b0f97,
	0xe17b448b, 0x42ce0271, 0xfc058d0c, 0x7af3cf78, 0x6f37cc7d, 0x5e077153,
	0xc7f07a0d, 0xfa56c08a, 0x5d9379b7, 0xb0846398, 0x47c77c91, 0x7f33b951,
	0x5bde8c35, 0x149b35df, 0x50f317a2, 0x271e9f0d, 0xe465fbf0, 0xfe3d18ec,
	0x3a51bdf6, 0xecd5fd15, 0xea308b36, 0xab2ed4ef, 0x3da24608, 0x676a17ed,
	0x9b0be37d, 0x5da97c1b, 0x8eb41911, 0xf3c754a5, 0xde2c13a5, 0x6e2e0e80,
	0x10e195b7, 0xb864ceeb, 0x0f78b69c, 0x39fd034c, 0x177e6d4b, 0x0a9f29fa,
	0x2c4d6379, 0xfb5e61b5, 0x776498de, 0x16b16f03, 0xdbab37de, 0x9c3b71b5,
	0xf4db3fe8, 0xbd2273b6, 0x116b1eef, 0xd1f1e99b, 0x61d72257, 0x55e3691f,
	0x3e9e25ba, 0xc84a2069, 0x70be7dea, 0xf829eccc, 0xadf0917e, 0x6a2d1d06,
	0x8ea08b31, 0x255a8fee, 0x8f9e17be, 0xbad1c110, 0xf26712ef, 0x8f9e16ba,
	0x1d47e7e6, 0x28d1ddb2, 0xaa571749, 0xcb52cde3, 0x47f2d59b, 0x918f2bf3,
	0xf87a9d5f, 0x254adbcf, 0x4dd2badf, 0x9d28d6fd, 0x10d32653, 0xdacf13ab,
	0x693fd7c0, 0xd8608a70, 0x4e33ad77, 0xf6e37504, 0x10ef3bb4, 0xdc3d38c1,
	0xdeef3c5c, 0xfbf246f5, 0xbf121a4f, 0x06c98e07, 0x9ff6f638, 0x85e38066,
	0xfbf267fd, 0xbfb21a4f, 0xfd91ffa7, 0xcc36eff4, 0x74dfb7bf, 0x6394de7e,
	0x5744d112, 0x02c3074d, 0x52ecd9bc, 0xfba9854e, 0x685829ae, 0x7fb1f577,
	0x5930a2fd, 0xbbf7a78c, 0xc74153cc, 0x4ea59ca7, 0x2c6b73ec, 0xe88ba5f1,
	0xea77ab7b, 0x586fd4a5, 0xd03880ec, 0x1a7752ef, 0xd8abebaf, 0xafe3a63a,
	0xbbf4fd48, 0x315d4831, 0xca434dea, 0x9b37bccd, 0xbf3e641f, 0x8fc72ed4,
	0x7accde7a, 0xaed8b896, 0x9c77f5ca, 0x50cf9865, 0x6c7b935f, 0xc6a27cef,
	0x67802cbe, 0x0c37c7b1, 0x938d607c, 0x07ef2df6, 0x5eb4d7da, 0xf47be29b,
	0x1fa1e852, 0x67e80984, 0x597c395f, 0x6e3edd4e, 0xbd54db71, 0xbe0c982e,
	0x5c2d17e8, 0x8e73dd2e, 0xfda2ece1, 0xef69758b, 0x866e8a97, 0x18b5f63b,
	0xb8b49a04, 0x5f1efdf8, 0xef6e7156, 0x8ef47a3c, 0x4dfa443f, 0x9ec2ffb4,
	0xf01a26ff, 0x9ee9633c, 0xadb2a1ee, 0x87a11cdd, 0xc96e93ef, 0xfd0d2737,
	0x9e93af22, 0xe23be2d7, 0xa17d3f4f, 0xa7fc0b2a, 0x0f3bac36, 0x85f17ef3,
	0xbf03c9ff, 0xaaf9eaff, 0x9dbe7861, 0x609eb3da, 0xe8f5aeeb, 0x4e174bfa,
	0x6f7c69bf, 0x187805b9, 0xedf3e17b, 0xc60e37cf, 0x0d895a3c, 0x6adfd209,
	0xfb4f5feb, 0xe0e40e38, 0x467c0fbd, 0xbb617f10, 0x332ccf65, 0x7bed4af8,
	0x7d509ba4, 0xdf295ecc, 0x01150cc7, 0xd9fa1b93, 0xaf81737b, 0xa736b1da,
	0x9e129689, 0x717ac1df, 0x13bb58f8, 0x10db7472, 0xf20dbe39, 0x17df0d3c,
	0x1f6f01c5, 0x5ffd9f10, 0x218d83f1, 0x76f820fc, 0x578d2b6d, 0x0e9cee63,
	0xe17c403e, 0xda85f035, 0x66f17e3f, 0xba2d0b8e, 0x57bf5813, 0xed477dc7,
	0xefb76be7, 0x9f2ba04f, 0x8b9ef3bd, 0x7375dda8, 0xc7605292, 0x9476a894,
	0xb9404698, 0x9c557418, 0x2fb7333b, 0x95ed2af9, 0x0f9f14e7, 0xd927f070,
	0x2333903d, 0x693d8593, 0x20541800, 0x7b8d2675, 0xe9526dc8, 0xcd1d768d,
	0xa6ba847b, 0x2db706a7, 0x1679658f, 0xfa3a0018, 0xee3dc757, 0x75827ef6,
	0x9bdfed6a, 0xafae6373, 0xe9abfd8f, 0xdb5b36dd, 0xbbb3cc32, 0xbced9226,
	0xbe8af177, 0xb09cedfb, 0xf61a39a0, 0x855ae444, 0xc460efe8, 0x0903fd82,
	0xf48cff1e, 0x73ff439d, 0x356abfaf, 0x718bcaea, 0xe7a0e5ae, 0xc071ce92,
	0xef8732e7, 0x6d5f78ef, 0xa04b0df7, 0xea1a9e25, 0x30818acb, 0x78938e2e,
	0xc5b9c512, 0xce5fce7d, 0xe39144a7, 0x1e3a9897, 0x3dfe88b9, 0xa4a7ca21,
	0x566abad2, 0xd3bd48c6, 0xf78e31d2, 0xee40d357, 0x544d94ef, 0x6bafa5f4,
	0xaea438f0, 0x5c559f67, 0xb9d69e7e, 0xa78c7d6f, 0xbe5de691, 0x4b05fae6,
	0x2a685ca9, 0x0d9a084e, 0x78c18ff3, 0x6192fed5, 0x9d7fa449, 0xaff3aab2,
	0x716fe757, 0x75f7ea66, 0x351bfce8, 0x854ee2fd, 0xa3fe37ed, 0xd8feb3fa,
	0x0f54ddc0, 0x777b9d33, 0xae72e416, 0xbcb903c9, 0x18f69c31, 0x527f7dd9,
	0xed30f9e7, 0x7e00fb3f, 0x13cf16be, 0x89f7e5c3, 0xb002980f, 0xed278bf7,
	0xb6fd7c65, 0xa663d236, 0x29044ab1, 0x32bf34fe, 0xf63d65e1, 0xf3ff8993,
	0x2bad277c, 0x8d97d537, 0x671cdc75, 0xe797794a, 0x03391be1, 0xb904d1fa,
	0x0fd0ef8e, 0x85331d79, 0x944acad3, 0x3c826758, 0x4b94e998, 0x7dc8a859,
	0xad784b32, 0xe13aef18, 0x9f6f76e3, 0xffa179b6, 0x85db0dbf, 0xf0bd7de6,
	0x2279f3f3, 0x228de5c0, 0x126fedc8, 0xe0d75c9d, 0x7372744d, 0xa393a4bc,
	0xff0ccc83, 0xb7ef302b, 0xd686f222, 0x3c663ad3, 0xf6c19598, 0x8640cb50,
	0x7bcdf7cf, 0xb43f4a86, 0xaaa6a78f, 0xf53678fb, 0x90eaf333, 0x50385c7d,
	0x77c667c3, 0xb38ea7ed, 0x644ef63d, 0x4ae1c112, 0x7a57a515, 0x29ded8ab,
	0x3f0a4732, 0x8263a7e1, 0xe57b0039, 0x7c457780, 0x2ceb99bc, 0x663c3ab7,
	0x587fab96, 0x50c6a221, 0x56f90ffd, 0x9ecd3fa6, 0x57f6ae99, 0x72f7de74,
	0x6e9f3d0c, 0xa58a6d6e, 0x6421d4fa, 0xdef8e86f, 0x2d3bf155, 0x4eaebfb0,
	0x969f3e37, 0xae4bb463, 0xc066cd15, 0x6318fa77, 0x0b807dbb, 0x2a6555d1,
	0xe92317d9, 0x88c423df, 0x82bf196f, 0xa89fe3f5, 0x769d9c7d, 0xe68676ce,
	0xb7d539b1, 0xb440952c, 0x164fdafc, 0x11615c60, 0xbe0d1c7f, 0xfd99a6ff,
	0x6f49876e, 0xf23e92f4, 0x08490371, 0x253e1652, 0x63f50afd, 0x3ca107a4,
	0xf2e2e0de, 0x782de924, 0xc3c1ba7f, 0xc5a9fdf5, 0xa5bf473f, 0x00b73f6b,
	0x121c6b1f, 0x291c6bbe, 0x2abff801, 0x90a79ada, 0xf72a2efa, 0x5947edb4,
	0x029e2c1e, 0x40e8bb31, 0x6b947edd, 0x3aabec7a, 0xea57db3b, 0xe9516ffc,
	0x99a896f3, 0x9c12e4d7, 0xf66bd96f, 0xcce87d70, 0xa3c6d759, 0x7f7ae56e,
	0x5e7353f4, 0x1ada3e11, 0xf7bd9b8f, 0xf6de7e60, 0xb471fdae, 0xe30da3ce,
	0x359ffe79, 0x27fe7978, 0xf972a61a, 0xfbe2d4b7, 0x9cf89db8, 0x5b6bcbf5,
	0xd4c92cbb, 0x78abc8be, 0xf72f5fb1, 0xe880408a, 0xca558361, 0x07240d81,
	0xe6277fb0, 0x56f87cce, 0x7bed3e01, 0xdd79f418, 0x308a4bd5, 0x25f1f4ce,
	0xfebbb416, 0xdce2216b, 0x7df9f4bd, 0xbfadaef4, 0xa9dfc546, 0xe7861417,
	0x27eb9329, 0xaffc77d0, 0x9f6e5999, 0xa954d0b5, 0x4707b3ff, 0x0b44fc04,
	0x0da777cb, 0xdcb0de82, 0x40341aea, 0x209d07a7, 0x9e9d0abc, 0xffa9e27c,
	0xdfe9f448, 0xeafb680f, 0x1f5fe02f, 0x1a45fe49, 0x06bfa7cc, 0xe8921b7f,
	0x5a78fd81, 0xaf480fb5, 0xab9c808b, 0xe07cfd55, 0x089fa83f, 0x71d5fe97,
	0x6127923b, 0x573c60ff, 0xca7f2f56, 0xea60f1dc, 0xf1deaeed, 0xfc2db7b6,
	0x7ea9afcb, 0x5bf2602a, 0x129d0e49, 0x8f7fa76d, 0x64896d75, 0x62b65b3f,
	0x5c87af09, 0xafde0115, 0x52cb8ad9, 0xf1e7fc4f, 0xfe0f0f1d, 0x161c808d,
	0x7fbd3c62, 0xf3047d6e, 0x9eace7a7, 0xfef8f543, 0x63fdf961, 0xf0ecfef7,
	0xd4f7941e, 0xca8cfc14, 0xe00ea73f, 0x73ffca7e, 0x9bac08c9, 0xa248b6e4,
	0x567c9efe, 0x3e883a09, 0xadf65b73, 0x8cf9a24c, 0x1a65d8da, 0x16fe654c,
	0xc8e511a5, 0x400f53a1, 0xea947e5e, 0x6e8cbc62, 0xb1939b75, 0xfe0706cd,
	0x73cb0572, 0x69cf9ca3, 0x60d27cf9, 0x47ef2bd1, 0x57c76d28, 0x0cd7de10,
	0xf580bf7d, 0xf3ccd158, 0xeb3eddd8, 0x1d791b9d, 0xde6049a4, 0xcb0f3625,
	0x137f8095, 0x2f94ece8, 0x737ac3db, 0xe021ffb1, 0xc12f94f7, 0x0cf33903,
	0xa097d1d9, 0xaf0b21fd, 0x6f2dd9f3, 0x12afc345, 0x83a9f643, 0x77e4d7de,
	0x9afb414f, 0x7a012ea1, 0x95c8fa18, 0xda9f0153, 0x7137bb5d, 0x0f76d53f,
	0xdd8accec, 0x4327f6e7, 0x784abbff, 0xbb5f4032, 0x8597fd64, 0x96998f5e,
	0x4be9b15a, 0xe628ef59, 0xf569317a, 0x932fb416, 0xaa83cf7a, 0x799d133c,
	0x6498efcc, 0xfaf8bd5d, 0xfbc6bd25, 0x127f6e0d, 0x1c9acafc, 0xd225f924,
	0xf26c05b0, 0x37498efb, 0x7e5c30a6, 0xa9b2fca0, 0xefeb4872, 0x3bf09b41,
	0xf4a19fa8, 0x8dec7e1c, 0xb7772936, 0xbd00df12, 0xc6977268, 0xe58da675,
	0x97e0bdef, 0x772566c9, 0xf923c117, 0xb7c930c1, 0x73f8e07f, 0x1cb35663,
	0xa5a7f4d6, 0xc1cf92e1, 0x53ef8b07, 0xb0437ca2, 0xdcaa85be, 0x0e571616,
	0x28a88af4, 0x5f8c50ef, 0xc14eef6d, 0xba1e481a, 0x4cd6aed1, 0x4e9a54fa,
	0xf01c8a9f, 0x27a1e483, 0xef859bca, 0x49fb687f, 0x18cf3411, 0xa38fc494,
	0x14766a51, 0xf27d1559, 0x36d6d4db, 0xc3fbdbf0, 0x1a8dbf24, 0x5b457ccd,
	0x2f38e867, 0x11f77ed1, 0xe485797f, 0xfdf68f86, 0x1689c8e4, 0xa6cbebc6,
	0x5f24fdea, 0x2008e48b, 0x18ec4b68, 0x08a37bae, 0x6691858e, 0x3ec3ebe1,
	0xdbc24ad7, 0x94e75895, 0xbb4308f8, 0x1b58f8a2, 0x5d0ff1f6, 0x93c559bf,
	0x23ca5c39, 0x6f26b873, 0xb222f15c, 0xf5cbf5af, 0x3b18e2de, 0xa499f008,
	0xc775b0fc, 0x046f8b58, 0xe647279e, 0x1c9c1cb3, 0x4f90e339, 0xf04a3af0,
	0xa1bd743c, 0x1ff612eb, 0xa6dd0fa6, 0xfb09bf08, 0xfb1b73f1, 0x9daddabb,
	0xc117fe4f, 0x8e497db5, 0x33f97607, 0xb0ec2fb4, 0x58da6653, 0x8e876d5f,
	0x07dbed48, 0xcfb0033a, 0xbacab39f, 0xbdfa9e7f, 0x6b7cb043, 0xe598379f,
	0x1a30e0c8, 0xa379f608, 0x5bb4578c, 0xfc875eeb, 0xec915f6d, 0xb30819a1,
	0x8f88c4fd, 0x10fd9347, 0x51bbfc90, 0x3f08de09, 0x9b73ffbd, 0xd896fb40,
	0xaa54dac0, 0xc699dcb7, 0xf64839f3, 0x578c52f5, 0xab7cce11, 0x049bd625,
	0x3fccf4f9, 0x5a372ccd, 0xc91ea9f2, 0x4afd9d7c, 0x49bc332d, 0xabc52788,
	0x24d96b78, 0x7f860fdf, 0xf2ddef12, 0x6558bffb, 0x76d41bfb, 0x3f7e2af1,
	0xf694e950, 0xdf07f33f, 0xe80b08f4, 0xe95a677f, 0x9103c0c3, 0x31e2125f,
	0x60cf2ebf, 0x950de1df, 0x9e99b957, 0x5cc53f54, 0xfd6b9f95, 0x38fb03e2,
	0x6ff2c5e8, 0x0eadc2de, 0x1575f7d0, 0xcc922e8e, 0xcac560e2, 0xd7e9d828,
	0x30c1ccf9, 0x76625fda, 0x4f47b791, 0x5eb8c54b, 0x66b96e39, 0x00cb05ef,
	0xedba17df, 0xe3d66ee2, 0xf6f5a383, 0xcfe78693, 0xadbee5c2, 0x9f789b69,
	0x125e5ede, 0x67cff926, 0x9b3f72e1, 0xe8ad7d22, 0xab9ee97f, 0xd1dbd3ee,
	0x8aae16f3, 0x8ea87de6, 0x7bc1b27b, 0xd019c7df, 0xa972a6db, 0x378dab8d,
	0xabdda675, 0xeece9e10, 0xefc00b0a, 0xf74ab379, 0x7382c34b, 0x3a76cfc0,
	0x9c797b7c, 0xd879e3ca, 0xb333f1cf, 0x338eb063, 0x4a7a92af, 0xf4a90f6d,
	0xe38cfb00, 0x4c51755d, 0xfbad425f, 0x7b638f6e, 0x4071a149, 0x4656476f,
	0xed7e866d, 0x169379b3, 0x47979e82, 0x10f51c70, 0x3fb521f6, 0xf4cb1d54,
	0x5557ff38, 0x87af006f, 0xb74c6d8a, 0xfea5da87, 0x737ad7fd, 0xd3dff110,
	0x903fcf33, 0xbe9ddf49, 0x0db8c8e3, 0xfcae7654, 0xf982ed90, 0xe1a66b2b,
	0x7795f9bb, 0xfa9c074c, 0xabf357db, 0xa3c3718d, 0xb077de69, 0xe799f8ce,
	0xbfa89bf7, 0x0fd555c1, 0x9610e621, 0xe7883bee, 0x5aceb6b5, 0xb9f6a3c0,
	0xcf60528f, 0xd8fbd99c, 0x5a54fdce, 0x657f7da3, 0x4af2bebe, 0x66742af7,
	0x7c04cee9, 0x2f842d6b, 0x2f2a91d0, 0xf474aa97, 0x61df748b, 0xf95eafb4,
	0x23c7d607, 0x5f243a72, 0xf187e3bb, 0x5bede381, 0xbbe8519f, 0x5af6f0aa,
	0x3c81cd2e, 0x1284ebcc, 0x00d2568c, 0x9d176957, 0x63a30674, 0xce6bd873,
	0xf6d55b7a, 0xa6293890, 0x5dfaa09a, 0x36aabbe8, 0x3a01d7b3, 0xe61b0116,
	0x8abeda1f, 0x1fbb739e, 0xb452bcf8, 0x7bb1e7c9, 0xf414bdee, 0xc441116e,
	0x9e3f8e77, 0x70f419b1, 0x9963f76a, 0x6864b8fa, 0xe57ce179, 0xde824ffa,
	0xe927ae08, 0xd6f41589, 0xcfb0661a, 0xc49e3f4f, 0x31e346f4, 0x3c7e9d3d,
	0x5abae38b, 0x53fc5abf, 0xcdc6da78, 0xb6f03ec0, 0xab3e838d, 0x6f6119f1,
	0x3afb63cb, 0xf60f2dbb, 0x449fc6a4, 0x3f265b71, 0xa265b40f, 0xe92633fd,
	0xadc6d0af, 0xd379327c, 0xeaefd2dd, 0x7d418d37, 0xb5d466e4, 0x7d6fbf7e,
	0x866c1b59, 0x4840f0fa, 0x13fa5d3d, 0x9e82789f, 0x5660be4b, 0xd2e13eed,
	0x7a92e8f0, 0x03e5c332, 0x5b97069b, 0x558f8993, 0x3ca96e61, 0x9e07296f,
	0x678d7e90, 0xe0c97df2, 0x1eb1a7b3, 0xaa58e7f0, 0x914f40e7, 0x1aead6f3,
	0xbde7421c, 0xc94583f2, 0x9f5e6ff0, 0x1a1af32e, 0x357f921d, 0x5a9f243a,
	0x106e3511, 0xc95a37de, 0x3d81c85e, 0x63ed2079, 0x3e1c2f6b, 0x897af06d,
	0x17d4f725, 0x63b7c86d, 0x98de2c3f, 0x47d3d76f, 0x07d1f6e3, 0x938b7248,
	0x2c1e2ddb, 0xb812d1a1, 0xe3717a17, 0x5f9b7376, 0x97bb7bf0, 0x7c8c9fda,
	0x5bb44df1, 0x00b631b4, 0xfdf6ac7a, 0xde450de2, 0x47bcdd72, 0x37c2376e,
	0x1f58cdb7, 0x2f58c7b5, 0x7f4c1749, 0xf977eaff, 0xf47d6341, 0xe8fd6301,
	0x01ceb7bb, 0xfd985619, 0xa7a19af7, 0x00e5387f, 0x67b1cbe4, 0xbe068d9e,
	0xdf2a3eaa, 0x3423fb0f, 0xa8f081ff, 0x6ff73f40, 0x5ebe5853, 0xcfd10790,
	0xfce2d63e, 0xdd3d70a0, 0x7eff0a54, 0xf6c2fb8b, 0x1cdb4427, 0x7559d12f,
	0x90693bfd, 0x17bf5aff, 0x41b7adb7, 0xb71d0a5f, 0x222b7dbf, 0x9ff82ebd,
	0x77cbc64a, 0x164fd497, 0xbadfd047, 0x1e80a6b7, 0xb0a97e4b, 0x3a792e5c,
	0x4dd065eb, 0x5779ced7, 0x2a673973, 0x8bf343c3, 0x82576e2d, 0x8e775451,
	0x60f13d17, 0x6d2ef341, 0x85f6d30a, 0x175927cc, 0x62d24792, 0xcf78bf7c,
	0xee207fbe, 0x847f615c, 0x1b15f4e3, 0x9d69ef8d, 0xaa1ec12f, 0x4fd8263c,
	0xdbe5b952, 0xb97be330, 0x3aea85ae, 0xf845bd34, 0xe758172f, 0xf8a9b225,
	0xbe23ff18, 0xb7d3b57e, 0xaf607d29, 0xcb4972be, 0x57e03326, 0x753f7c23,
	0x1fddb1a6, 0x2cf9a08c, 0xf60c3d22, 0x5e65c90c, 0x310db9df, 0xe7a28fec,
	0xcfcf41c2, 0x90718e89, 0x4576e7d7, 0xa5dc6479, 0xea939c63, 0xf80ea98b,
	0x86668855, 0xb2f83553, 0x578dd259, 0x8c0447af, 0xed2cd175, 0x704b6aa0,
	0x2551e01f, 0xe03bf93a, 0x9aaedf51, 0x007075d6, 0xef9092f4, 0x04e38785,
	0x8c6d234b, 0xbe7ba5bf, 0xd7bfd30d, 0x4ecd31ec, 0x8fa4fcd4, 0x0e10de56,
	0x7aaab6fa, 0x815dcb65, 0x3d69fb9d, 0xebbf34ab, 0xa7f3077a, 0x7e49361b,
	0x2663fa4f, 0x7eb2d9d6, 0x06fbaf38, 0x055eebc5, 0x5d86757d, 0xef492fd5,
	0xd225fbc3, 0x267a422f, 0x49ba49fb, 0x40acdddf, 0x420b6cdf, 0xdfb96e7f,
	0xf82cfacd, 0xeff5fb24, 0xd2beb071, 0x2bea4332, 0xf107eb2d, 0x94c17ff7,
	0xca87a093, 0x93dcb4f9, 0x60f47acb, 0x0c4efcb3, 0xd23f3c12, 0xbaed334b,
	0xe7fa6979, 0x6fefa761, 0xb6f5bae9, 0x214776c4, 0xe22a23de, 0xdf9c907e,
	0x6eafcaaa, 0xf9fc0382, 0xfbc52b1f, 0xdad19711, 0xb8cba775, 0xde49b8eb,
	0xf63b6a6d, 0x669b97fb, 0xf2057ddc, 0xb9301e34, 0xf83add1a, 0x5899bd7b,
	0x1debc7ff, 0xb8d3c005, 0x737fd249, 0xf5f25f28, 0xf3823188, 0xf6a1fe51,
	0x93748ffb, 0x270c4ca1, 0x3e7ea4ba, 0xdffe922e, 0xecc531a8, 0xeddd232f,
	0x1af2bee6, 0x5e5219ac, 0x5f8adb95, 0xf98facbb, 0x85117068, 0xf1f59fd2,
	0x9cb36532, 0xd7f39797, 0x83a7fdc6, 0xab1f6cfd, 0x07c34772, 0x9658d1d1,
	0x8b1f2ac3, 0xf59fa10d, 0x0fd00ba0, 0xa7a5c2e8, 0xdc7d231f, 0x47fb48a0,
	0xb27293cc, 0x5bc25625, 0x0fd133c3, 0xe89bbde3, 0x108fd243, 0x8bef8dff,
	0x0a9ed25c, 0x75b45bb1, 0x10b767f7, 0x7433b83d, 0x7a50ce71, 0xd8c09610,
	0x94478aef, 0xa71d8f8e, 0x2d922a10, 0x70461fc2, 0xb8646c83, 0xac0965dd,
	0xb10cf9a4, 0xb50cfc48, 0x2923fa48, 0xe02f0fe3, 0xd51b5ef6, 0x2c5bee4b,
	0x24bed4bc, 0x283fb059, 0x9894f49d, 0x409dfc01, 0x1999f089, 0xf12a127e,
	0xec8c497d, 0x1ce884bf, 0x9fd45a79, 0x654034d7, 0x6f10e36a, 0xe04fac14,
	0xfe02e8fb, 0xdf926fde, 0x0e542d7b, 0xa9fb934b, 0xc318557b, 0xd0cd64af,
	0xb4cbd04c, 0x697a4649, 0xa5f490c9, 0xb922df95, 0x2793e582, 0xb4a67211,
	0x99cb3869, 0xcd714746, 0xa7d7ec6e, 0xb250bda4, 0xc76ba6fa, 0xe23b7e62,
	0xc7cad83c, 0x38e4efa7, 0xbcd36944, 0xdd83dedb, 0xcfc1ddb1, 0x8afa6487,
	0x2b37a033, 0xe9bb05ae, 0x2f75e941, 0x7be912d9, 0x538cdb5f, 0xba72a7bf,
	0xd09be77f, 0x36cfa623, 0x42e9fb73, 0x934545fa, 0xff5ae71c, 0xea4496e7,
	0x0a09daef, 0x1cbbd587, 0x886594ce, 0x9df8a83f, 0xa379d2af, 0x5dfdcc43,
	0x3435e624, 0xfe073533, 0xfb2cd27b, 0xd21f6fd0, 0x36544fda, 0x361a4f42,
	0xad43ee59, 0xbf41fa3d, 0x7d48668f, 0x170ab16a, 0xe5704ead, 0xc36be5f6,
	0x51a2d2ba, 0x5459835a, 0xa9359ebe, 0x969ceb0a, 0x006ca62a, 0xe6667fdc,
	0x872e917c, 0x6f1d3208, 0xf83c65cd, 0x1ad77744, 0x48cb6fac, 0x44d75f5e,
	0x9d72ca67, 0x29d0bc1d, 0x52e81f58, 0x390f67f3, 0x4806a33b, 0xc3db117f,
	0x7c092a65, 0x2f78df52, 0x7765aae2, 0x3720bbd8, 0x8b3fde16, 0x2d65e1e3,
	0x7c930f64, 0xf68ceb13, 0x8dabd930, 0x5da85f98, 0x82bf6a1b, 0xe5374046,
	0xbba614eb, 0x5b1e8d61, 0xc537f312, 0x4794f589, 0x0721d306, 0xce0e3dca,
	0xbec0bd6f, 0x3ce09afd, 0xc1587e0e, 0x32db43c9, 0x77d8cd7d, 0x6c25cd25,
	0xf8e4464f, 0x330d6f98, 0x6e885c13, 0x6de952df, 0xe089fc1a, 0x24ce9647,
	0x78c9c3ec, 0x700e780e, 0x1d324666, 0x6bf8043b, 0x8999d597, 0x72ad75f9,
	0x9c231098, 0x33d252b6, 0x85bb33ed, 0x22cbbfbe, 0x7dffb1c2, 0x57f3bf6a,
	0x51378a58, 0x585d887d, 0x9e8006a2, 0x639e99f2, 0x318b7db2, 0x8a7763af,
	0xca1bd0f1, 0xf397add6, 0x5841e952, 0x68e30a3a, 0xdd5b639c, 0x6bc7f005,
	0x3d9313f4, 0x9e867b69, 0x8c2b660e, 0x01cf5a7f, 0xcf5f39f8, 0xf781dd2a,
	0xe81f7cf4, 0x60a4da63, 0x645bf03a, 0xcbbce6ae, 0x03c289b3, 0x90ace27d,
	0x5aecfbfb, 0x8d43f30b, 0x83fc68af, 0x4f6bc1e8, 0xb6f7c5e8, 0xf1129a06,
	0x760dedee, 0x70689f2e, 0xbbc10b0a, 0xeb9121b5, 0x5c5c1a3b, 0xf36435b6,
	0x7835dff3, 0x61abbeb8, 0x699fd73c, 0x4f7d72f0, 0x7f2e54c3, 0xcfcc50df,
	0xf044fe35, 0xf1a43e61, 0x691f8d19, 0xa5f1a5f4, 0x405aba50, 0x80bcbe60,
	0xa7fe67bf, 0xc3ac3df1, 0x8fcbd054, 0xd75b3c34, 0x5fb1344e, 0x9173c552,
	0xcf53e4f9, 0x91150e02, 0x03d8e79c, 0xc33b4897, 0xf626c525, 0x5c6f8ec0,
	0xa35aede6, 0x5637bf93, 0xa3a2c228, 0x1cea9be3, 0xe3a3a2c2, 0x0d63eb9b,
	0xeff5f9f5, 0xfa8832bc, 0x3be31f1f, 0xfa1cfc0c, 0xff0fa7c5, 0xfa3f9e99,
	0xc019e38b, 0xeb63cd3b, 0x8ef71883, 0x9d1e7570, 0xd8775e72, 0x4c369fd8,
	0xcfe10bf5, 0x2cd7cbae, 0xf9bec771, 0xe015f418, 0x57f9e087, 0x54873f15,
	0x7e0294fc, 0xab25f744, 0xf2eb3ca4, 0x7c05012b, 0xa7dd49b0, 0x825e3cfa,
	0xd124e1e7, 0xedde0119, 0x98f10215, 0xa66677c3, 0x642b5f60, 0x5f87cd54,
	0x0e1fed6d, 0xfea53fa2, 0x3ecfeb00, 0x17e7247b, 0xa4f5bf08, 0x7ea51fbe,
	0x9d13b73f, 0x7c790c43, 0x36bc6311, 0x069a07f4, 0x5fb34abe, 0xa2dfd814,
	0x45027159, 0xf2f3eae5, 0x3f218ab5, 0xe66991d6, 0xc32538fd, 0xb16fe5c2,
	0xd10839d7, 0xa348f2cc, 0x9c1be253, 0x9cde578f, 0xe3a45b6f, 0xf3eaa5bf,
	0x21936cb2, 0x864a6f5f, 0x2dfdb7cc, 0x77951398, 0x16daa767, 0x7173bf32,
	0xbed6b8de, 0x3560bb34, 0xeba59bfc, 0xfbd33590, 0x8b4cc0fd, 0x9ca72f3a,
	0x56e49d8f, 0xf4afe714, 0xbd35ffc9, 0x79fe18e5, 0xed9fcf31, 0x4f1dcaa9,
	0xac3c40ee, 0x9630c3f2, 0x54a39543, 0x604e447f, 0x77d62cdc, 0xad0a91bc,
	0x7bc556b3, 0x451f93e1, 0xe9686f23, 0xa47fe92e, 0xed650bb2, 0xffec151d,
	0xbed0f5aa, 0x6afe0018, 0xbcbf2b8c, 0x4ee8c3e3, 0x93f85bf6, 0xce51fcd5,
	0x75ddaa83, 0xe0a3f384, 0xe18ff2a7, 0x36cf38fe, 0xcaa5fbf4, 0x12976cd7,
	0x453e1962, 0xc0997fcf, 0x2e7dd8f3, 0xe96d7c01, 0xfa12abf3, 0xed0953ca,
	0x6b9b8b47, 0x62a5b17e, 0x6f38e7dd, 0xa98ef4b1, 0x6f744547, 0x5ddfa1ff,
	0xbdc6a995, 0xb117122f, 0x3822c3ff, 0x9ab961af, 0x90367667, 0xc3be2311,
	0x0374b4af, 0x3887147d, 0xf9062baa, 0xd4c867b6, 0xf74f0bea, 0x7d394a66,
	0xe215f68a, 0xcd5a67a8, 0x699e2fac, 0x53fde28d, 0x7edf7adb, 0xb76b65c4,
	0xab061c28, 0x479c1d11, 0x2ccbbb56, 0x06f97aec, 0xff5c4ebf, 0x327aacf3,
	0xb5f40eaa, 0x6ef14da4, 0xb59cf9a5, 0xea0662bb, 0xd2a553e6, 0xdb585557,
	0xcdaff438, 0xcfce04bf, 0x96edbd81, 0xf9c7dfb4, 0x34eed480, 0x15ff2feb,
	0x9262f1c1, 0x9e626f5c, 0xf68e3627, 0xd25d8ec0, 0xf596b3b6, 0x2708d6de,
	0x56e39154, 0xff8079e3, 0x516378c0, 0x04e37d4a, 0x4fed1f4d, 0xdeb330ec,
	0x5f62798b, 0x85f3571e, 0x54eeefb5, 0x8553bbbf, 0xdca66a5b, 0x25fb5a9f,
	0xe9d15d6d, 0x9ee8fed4, 0xa35cb877, 0xd9125fb6, 0x79f90791, 0xd4c45774,
	0x99bf9700, 0x778d1cf2, 0xbc626daa, 0xbf67dba2, 0x7f72b4ce, 0x3cca36a7,
	0xc0ec3e45, 0xaf1b40f6, 0xb26b44e7, 0x0d5fbf02, 0xc0f64de0, 0x474f5d89,
	0xfb1f789b, 0x68f977ff, 0x484b1573, 0x91c1fd3e, 0x9dec63d0, 0xb77f7e6a,
	0xbff967ea, 0x7d56bfe9, 0x562a689e, 0xfaf991c7, 0x700fcb42, 0xe64576ca,
	0x77d8419c, 0xaeb9460b, 0xf3fc11bf, 0x27d79975, 0x841eb886, 0x4fe0b79d,
	0x238f6c71, 0x2ff5002f, 0x94c320de, 0xb460b3e0, 0x3b1257ca, 0xd9ffc2c7,
	0x447a96e5, 0x88325af5, 0x44556e08, 0x6d027e5f, 0x7c2cc075, 0x33397f54,
	0xd101d255, 0x22e38dbf, 0x45f84cc1, 0x9f84d90f, 0x93bf3fe3, 0x6a7573f6,
	0xe6fe1330, 0x544fd813, 0x66080f56, 0xa71fc1c6, 0x4cf549d2, 0x97a3af7a,
	0x4cc1cdea, 0x6d2749e8, 0xf788efd2, 0x0baa87b0, 0xb72ebb64, 0xb5db34f3,
	0xf404a3bb, 0x51b3d356, 0x8f35874c, 0xa07e3839, 0x4a96f3f5, 0xfb0fd4a7,
	0xe4dbfd5d, 0x3744967c, 0x55273f73, 0xde125efa, 0xa43bf3cc, 0xb12d99e6,
	0x55977ac9, 0xfba3fc70, 0xb3b630f1, 0x3c75278f, 0x3f8e7183, 0xe9e39c3e,
	0xa2c0ee5d, 0xc1defc3d, 0x9f2a70e7, 0x5e620b08, 0xc51e3d9f, 0xbfa9a77e,
	0xed00b0d8, 0x53096ecf, 0x6cf93f10, 0xc625b0a0, 0x40cddce3, 0x299fdb96,
	0x7c978e2e, 0xf71c6af6, 0xcf50d957, 0x624a8971, 0xa93fd013, 0xedbd0a9c,
	0xa50fadb3, 0x7d52ff60, 0xd13eea2d, 0xd8e7e0bc, 0xd823dba7, 0x89fc71bf,
	0xcfae19ff, 0xcacad0df, 0x95bf462d, 0xfded4f86, 0x9ed299e7, 0xda533cff,
	0x3a665f11, 0x11355e19, 0xf2a40f6d, 0x26fee4fa, 0x407db338, 0xf38129fb,
	0x26f6db1a, 0xe54fd428, 0xc85e51b3, 0x306b2ef9, 0x870c37f3, 0x445f3508,
	0xd9f93db0, 0xaff638b6, 0xfdcd3693, 0x972db67c, 0x5bc7effd, 0x99a71cad,
	0xf18d9d06, 0x2df0cb98, 0x63cc6f32, 0x0896d5ff, 0xb958f013, 0x373e22e6,
	0xfd66eb47, 0xd94772bb, 0x45eeb534, 0xe7f2bf7c, 0xf2f06bb7, 0x0245ffc3,
	0xb568f996, 0xd66b47ca, 0xfc831a5c, 0x3327f164, 0xb39fe5e7, 0x4f810678,
	0x5265c286, 0x9f47ca96, 0x6df79879, 0xf239d135, 0x726caa84, 0x284f557e,
	0xad55efac, 0xe641f4be, 0x055a6f8f, 0xb64f94f2, 0x87ad17dd, 0xe4964e7b,
	0x7bdfbd5b, 0xb5157db8, 0x1ebfdf97, 0x66d9f3cd, 0xa13e60f5, 0xdfc1faf8,
	0x51fe613f, 0x91b657df, 0xe177901e, 0x8e89cffa, 0x3e087e9f, 0xff60ead0,
	0xcf99e117, 0xb6b09cb3, 0x4ffac22d, 0xfe60e53c, 0xcd562270, 0xe7b927f7,
	0xae7cc2cf, 0xbbfb15f9, 0x20259ede, 0x8c07162f, 0xcaf36afd, 0xb9fc92cf,
	0x8313ce26, 0xf843587d, 0x9f847f40, 0x7ff7f09f, 0xa1f7f2b2, 0x77c189eb,
	0xf0fb7563, 0xc3a608a9, 0x5e258313, 0x62c8ec4e, 0x2b15d3b9, 0xcbe69ae9,
	0x5889eaf6, 0x0924e259, 0x29d2a1e8, 0xc4c4e1e9, 0x4fcfb636, 0xecb93b28,
	0x2aefcab2, 0x2d38d5eb, 0xe82269d1, 0xf88b3407, 0x075d7d94, 0xe3f00ef4,
	0x065c0571, 0xe85c06c3, 0x663a26c7, 0x2caeef3b, 0xc604df29, 0x2ae3504b,
	0xb36d87ec, 0x54fa9f81, 0xf5baafbd, 0xf01b78c2, 0x70aadd54, 0xeb42a89c,
	0xaf1d6687, 0x2e89e1f9, 0x178afcab, 0x4d5549f9, 0xee8096cb, 0xdfd6eaab,
	0xada0fd88, 0xa622caa3, 0x52ea5ec2, 0xb21f3ccc, 0x79c66fef, 0x34f1d0d6,
	0x3bd2def8, 0x726a708e, 0x7fdaf686, 0x5f18b964, 0x7f5337a8, 0x3aca4dd5,
	0xd9adc71e, 0x1a7d729f, 0x362c089c, 0xbf34ddf8, 0xd7eb7f40, 0x7cdfd9e6,
	0xf925997e, 0x9e5b9750, 0xa3feed27, 0xb9c9f999, 0x0cc747af, 0x8dbd0ef8,
	0xfeb5cd33, 0x901bfe68, 0xdcfd466b, 0x59f92598, 0xf30fcd15, 0x8c68dccc,
	0x316f64af, 0x1ab447d6, 0x8cbb39eb, 0x6376bcf5, 0xb1b2f3dd, 0xd5c757ee,
	0x18bb04e0, 0x8bb06f79, 0x762ec251, 0x18bb4985, 0x28c5d875, 0x39e31761,
	0x61d462ec, 0xbb0ea317, 0xc5d87518, 0xe3176128, 0x9c2aabf9, 0x25ff55aa,
	0x58f9c0f0, 0x7c5a1d7b, 0x99cbf79d, 0xff920979, 0x78bda45a, 0xeb0e4966,
	0xe90e5d79, 0x619ee9e7, 0x696e40f7, 0xa3ab3c79, 0x0d674f7c, 0x63b41c44,
	0xbf9b9275, 0xd2f0bf63, 0x70bf4bdf, 0x12238175, 0x55ce88fe, 0x3d435747,
	0xdbe51799, 0xac67f683, 0xdf00dbdd, 0x3897fa9a, 0xc2b9dd6e, 0x242ba7f5,
	0xa22fd8fe, 0x4094e5e5, 0x236f81ae, 0x49f1c10e, 0xd7ef5d8f, 0x88d38d0c,
	0xf43aba75, 0x3d63169c, 0xbe032e34, 0xabec35e6, 0xa3ffc666, 0xf024eed6,
	0xdb8f23fd, 0x11d47cf9, 0xe6268fd5, 0xd26f59da, 0xf9e46ef4, 0xbf2caf82,
	0x790cd947, 0x00d641fd, 0x03d9f386, 0x60f38619, 0xf9d965a1, 0xf777acd1,
	0x2629d7d4, 0xa6cc338c, 0x37df91fa, 0xf54cbc4b, 0x45ba7cb2, 0x06d6639d,
	0xc3fe6193, 0x7a06e103, 0x407db91a, 0xb0713c48, 0x3da8fda1, 0xc4f121a9,
	0xd738c611, 0x60fb15ec, 0x375acf7f, 0x9ceed0da, 0xb7383f1a, 0xcff31065,
	0x434be2f2, 0x3cea5be2, 0x2dd9f29d, 0x6a17a256, 0x24eecb7f, 0x24e50f96,
	0x8871bc5f, 0xbfce0927, 0xabfc514b, 0x526f8f99, 0x4cb16f38, 0xdea23f95,
	0x2c2b8f28, 0x9c44efc2, 0x7e87c680, 0x507bbd58, 0x4bd28560, 0xe14e157f,
	0x96fea58d, 0x83c8e88c, 0xd5e4b97d, 0x3d038edf, 0xa53798d5, 0xab760e20,
	0x8386d812, 0xec07c7be, 0xde98b84c, 0x8e7d9a27, 0x0777e86c, 0x9e39bec6,
	0xd5b27ce0, 0x2938c1ec, 0x414260d6, 0xa5dd2f64, 0xc0e19d58, 0x3366a6ff,
	0x67f011db, 0xd2f40799, 0xb8e6a6c7, 0xdec8f4f0, 0x30f46b75, 0x721c16cc,
	0x3bf5d60b, 0xa459eb07, 0x3abcb357, 0xfaccc077, 0xc544c55c, 0xbaaf7acf,
	0xf94ee5ce, 0x8f9eb69d, 0xcc50fb55, 0x75ce1af6, 0x2fbe1c9f, 0xab8d470f,
	0x98a4f61b, 0xad4dd7c1, 0xdca892db, 0x63a5f760, 0x329b153d, 0xc6813cfe,
	0x2ccf7ca9, 0xa4fea710, 0xc5f47265, 0xb29f3bd0, 0x7d51a67a, 0x6d6ff34d,
	0x2d2befd0, 0xd4ec1b01, 0xd937c78a, 0xb95e54bc, 0x5f3f137d, 0xed84bdb4,
	0x8ea2c5f5, 0x5a63ceed, 0x8f0aaebe, 0x46ca498a, 0x5d7bcd27, 0x2b8fd4b6,
	0x481e65c2, 0x2bc27991, 0x76df58f1, 0x5da79f25, 0x7386d3bc, 0xedab97e2,
	0xd9cbf742, 0x0d156637, 0x4daa1f84, 0xb7f7b861, 0x0e0bae3f, 0xeb31fde7,
	0xd9cb9bbc, 0x1db247e7, 0xeb209ef6, 0x2723f208, 0x437dfec4, 0x459fd5e6,
	0x527d0f5e, 0xcfc60b61, 0x905e1e02, 0x10d40bf7, 0x802f8cfd, 0x25c42d5d,
	0x0f231654, 0x154f6f5f, 0x7de81846, 0x23edd0ae, 0x188e6fea, 0x9ecfa86c,
	0x7f686696, 0x2191ecfd, 0xf7a0a1fb, 0x4badf33d, 0xbd53df7a, 0x4bbf0ee6,
	0x24c4bf61, 0xef2a73e3, 0xdabb3a60, 0x988d7df0, 0x740edbd9, 0x862de5be,
	0x361d10b3, 0xea154fd8, 0xbeb985f9, 0x2779f52e, 0x1885a73f, 0x34b0e5f6,
	0x9ca59fcf, 0x5f3fb2b4, 0xc5cf6ff3, 0x92fad3bf, 0xf93de193, 0x852fc885,
	0xd467c23f, 0x8ed83a43, 0x350f1214, 0x26a8bfaa, 0x6a8bfa5b, 0xe4361dfc,
	0x2dfc12ef, 0xda9204c9, 0x80fd8566, 0x3c9eded4, 0xc0efd640, 0x73c65df3,
	0x3cefe809, 0x97301fde, 0xbe84bf60, 0x4375a5af, 0xcfc2d41e, 0xa9aa7ec3,
	0xa54fd947, 0xaff6a38d, 0x39e869d1, 0xdefed0ee, 0xdf3176ce, 0x73bedcae,
	0xcf8260ff, 0x7cd8e2ac, 0xb6eaa3ec, 0x9c92d619, 0xe34de90b, 0x4c2ae7fb,
	0xf676e79c, 0xde98978d, 0x3c5856ce, 0xbbf98f32, 0x95eb52e1, 0x3a50d0fe,
	0x42eb445c, 0x2ed177fc, 0x645013c5, 0x3067c03b, 0x3e0433e8, 0x4dc07dc9,
	0xfc0f5783, 0xc62fde42, 0x5f20c63f, 0xbf7b9e41, 0xf0a12e00, 0xe459c754,
	0xd26fac13, 0xaf3c02bc, 0xf8c57e90, 0x8b78fdd0, 0x8dd8ed8d, 0xdf2a708a,
	0xe7998f0f, 0x58659fa5, 0xf77f5c9a, 0xbd03c56e, 0x0b79ce7d, 0x9fa1ef3f,
	0x3d979962, 0xbf719a7b, 0xb153d0f6, 0x9dd73fdc, 0xfeefe04f, 0x7df5745d,
	0x53c5a4f4, 0xb59df342, 0xb30743f3, 0x58e3bf55, 0x7fdbf631, 0x587b6f21,
	0xaf09b9cf, 0x2fc07e41, 0xa683ff03, 0xc1e0f42f, 0xd5898ae2, 0x242521e9,
	0xa0715d67, 0xf00921df, 0xff54fadb, 0x7da7c69f, 0x9bab7f6a, 0xf7f452d2,
	0x5956f891, 0xb29b1fd9, 0x12cb8e22, 0x72013387, 0xbc8564a4, 0x5df0e337,
	0x13c61283, 0x655e1d5d, 0x5d469f8d, 0x98d9fe1c, 0x7a8b9114, 0xd6479711,
	0xfbd5cd87, 0x6cca7bc9, 0xfcd697a9, 0xb5cb20e2, 0xa237a653, 0xaddf62e7,
	0x948d1dda, 0xef55aa9c, 0x3c92738c, 0xa2f9376f, 0x9f858f87, 0x73cb1370,
	0x0794dce1, 0x4fa6993f, 0x1a2aae54, 0xfd5fb904, 0x811e97cf, 0xb0adf7dc,
	0xfd0f4026, 0x57995dec, 0xf58cf24a, 0x490e6388, 0x46b6c7c7, 0x63b9b9f0,
	0x0e22f08a, 0x2fbcc4b4, 0xaf9069cf, 0xfe3073ed, 0xdc6d767b, 0x8c44b6c0,
	0x3e73f1eb, 0x46456fa6, 0x13fe5f4c, 0x41ba5cad, 0x34db77ea, 0x17eaaf7f,
	0x3a8f5e86, 0x25917af4, 0xa1d47af5, 0x5e84a3d7, 0xaa99e78f, 0x63587fff,
	0x52ec3e77, 0x5d9124ff, 0x3236f2c7, 0x2dfb7a1b, 0x7c07b84a, 0x33c516e7,
	0xeffee388, 0xab394ac6, 0x3e742fe2, 0x0e937597, 0x2bcfa3a6, 0x3e85dbce,
	0x88a26d7f, 0xdb27d435, 0x8bed0c93, 0xfbc36e9c, 0x1b87132b, 0xcae55fde,
	0xc9afd437, 0xfed0d8be, 0x4344cf5a, 0xafe327fd, 0xe19fb432, 0xcfa8619d,
	0xd0cf3a9a, 0x12e2bafe, 0xe7ebfbc3, 0x9fbc312e, 0xa8665be7, 0x33f158df,
	0xea9bfb43, 0x7bde1856, 0x7902d385, 0x8b7b0ed7, 0xec02fee0, 0xf96f2a2d,
	0x1ea44663, 0x9b2613af, 0xe5f7bcfa, 0xbf52e1ba, 0xde11aff9, 0xe503e1e2,
	0xe1d011f9, 0x487cf550, 0xbf1770d9, 0x4541164f, 0x491dbbda, 0x76d09ba0,
	0x4427efa1, 0x45ce78bc, 0xf8737c38, 0xe216d9fe, 0x7a2e1307, 0xd51a7471,
	0xbe889f13, 0xbe97eb8e, 0xd52a74f8, 0xcb144753, 0xcf17a8fa, 0x27e6fde1,
	0x967d65e2, 0xf3c35560, 0x7ed9cec4, 0x2b84f79a, 0xa479d752, 0xfbcfa4bf,
	0x7012b487, 0xe024de40, 0xf4483280, 0xa245f289, 0x132f944f, 0x855b967d,
	0x89f44fd8, 0x9dd900f2, 0xd91afe78, 0x20df289d, 0x9be513bb, 0xeca27764,
	0xe513bb20, 0xb9730ddb, 0xc7c1b77c, 0x50dfbddf, 0x86c1e5c1, 0x97fe7e3a,
	0xff2e7a86, 0xe7e7e0da, 0xed15c30d, 0x61fb3dbc, 0x2d54f8b4, 0xff8882e2,
	0xd49eb1ed, 0xaf156bc7, 0x3c5aa394, 0x744eb1b1, 0x769f6046, 0xb53f625a,
	0xfb09c6f7, 0xf116abe7, 0x7aff4ea9, 0x7bbde1c7, 0x8637fb38, 0xd4671138,
	0xb3121f9e, 0x9e101686, 0x9afb775e, 0x82bafef1, 0xc43155b2, 0xbaf8ae3f,
	0x797a0ace, 0x79f7d4cf, 0x4e9532e3, 0xdef08cd6, 0x5cb93a0f, 0x72e727bd,
	0xbbdbccbb, 0x08d9d2dc, 0xa5f8d47e, 0x66ef2170, 0x4fcc945f, 0xc2cbbc6f,
	0x17ca7a79, 0xc597eb82, 0x7e37ae0b, 0x7e79c1d9, 0x893d3b97, 0xbad45f2c,
	0x13d37f96, 0x2e9fc76f, 0x7f8b46af, 0x8535796b, 0x864e745f, 0xa459701e,
	0x121615cd, 0x7b9c47af, 0xdafbd45f, 0x1dbef8bc, 0xe5beae2d, 0xfdc4114b,
	0xfcfc5a65, 0x1b877b72, 0x6ecb837e, 0x79f47bb5, 0x5c9c5a43, 0x0cc3a2f9,
	0x05e5a339, 0xf368e369, 0x7f50b28e, 0x3f79bd05, 0xf2db3b97, 0x58d10f91,
	0x0dfdc913, 0x02b6e7a2, 0xf335e76e, 0xc8f96d77, 0x3aacb8d7, 0xde9423d2,
	0x7520fcf8, 0xb91651dd, 0x7c2fc2ce, 0x99709f9c, 0x7e809f9a, 0xdf3df2ec,
	0x7c5976cb, 0xf582c930, 0xf03cd9d7, 0x48ac3e73, 0x2f96b07f, 0xba11f680,
	0xa2798c7d, 0x68aff4df, 0xbddbd0be, 0x2cef865e, 0xe14fa4a7, 0xdcaaeb52,
	0x72270715, 0x8bd6acdd, 0x211f9cc3, 0xea985e0e, 0x783a083b, 0xc8cb495b,
	0x6d20bb67, 0x8cfdf620, 0xfadd7b90, 0xfe8f9fa0, 0x2bc7e86f, 0xb0443ef1,
	0x8e942d9f, 0xf468fc34, 0x3fbde1a4, 0x40e8d2ba, 0x78c5ef97, 0x52dfc9ef,
	0xb7a50bfb, 0xa34ce8fe, 0x92edcbaf, 0xe467800e, 0xa57468e5, 0xe7c6d17c,
	0xb6ab2f1b, 0xe8d3fcb3, 0x2e2e942a, 0xa7492ba4, 0xb9d9b78d, 0xaae90bbf,
	0x97001e97, 0x1d574f1f, 0x7fe3c866, 0xee6e9e95, 0xce705316, 0x6bbce4bb,
	0x53afca3f, 0x77c0657d, 0x05389899, 0xe69c2624, 0x42bdf85c, 0xa8d359db,
	0xdb0bd8dd, 0xe85fd285, 0xa1693977, 0xe8e5a7fd, 0xcaac9bbf, 0xa6efd0ca,
	0x68ddf05d, 0xdd784fce, 0x7893e5a1, 0x727e87ae, 0x779565c0, 0x646f092a,
	0xf953fa3e, 0xc75101f8, 0x59d49772, 0x5429c63f, 0xce726a49, 0x0a07b662,
	0xeb8efb23, 0x3f7ead5f, 0x26e2ebe5, 0xbc4a63cc, 0x5abedf51, 0x14afd7d5,
	0xe87fdccd, 0x73abf939, 0x3e3d64ae, 0x55fc9cf4, 0xdc3d5423, 0xf3e0dc2d,
	0xe723c285, 0x506fdea7, 0x64efeea8, 0x5cd25e95, 0x00613166, 0x2cfa1fce,
	0xe32f2e10, 0x8c3c837e, 0x55fae7eb, 0x35e5c022, 0x5cfdc822, 0xf508824b,
	0xe4aa109f, 0xfcf206bd, 0xf7d9ad66, 0xdaa9e837, 0x0e65cdb9, 0x08238ddf,
	0x4c452f8f, 0x27fb8f9f, 0x9c9e8f26, 0x2c5eef8e, 0xf77eb174, 0xf58d3da2,
	0xeb47ec4d, 0xf0fe5e80, 0xf4e7c92a, 0x108e790c, 0xa611ce25, 0x03fd1c93,
	0xafd46fc9, 0xf0215ece, 0x319714dd, 0xfefb48bf, 0x6164e71a, 0x3e5feb89,
	0x77b7935e, 0x5e2ff208, 0x442acd8f, 0xd8f5e0fc, 0xdeb10a8b, 0x990763d7,
	0xe3661964, 0xf4d9f732, 0x8d61f4be, 0x9bc77bde, 0x07f5e3c2, 0xa1ae0d67,
	0xfce0d4f0, 0xbabae023, 0x0d96b82f, 0x6b4fd217, 0x7e16ba7f, 0xc9089ab4,
	0x46cfbd57, 0x975bc409, 0x36f796ef, 0x2229867c, 0xe12edd9f, 0x52feb0b4,
	0xf1cd1961, 0xbce03f2c, 0x7e62fea8, 0x13afea1e, 0xdc344eef, 0xf76c562f,
	0xe341186d, 0x66082c9d, 0x8e27c692, 0x73e46c6e, 0x9876a7d8, 0xaa97b03d,
	0x1e75aecd, 0x375f7df8, 0xf8a51e73, 0xc414a5fa, 0xbe96c54d, 0xedabbbf3,
	0x5d9a8e12, 0x98ad3038, 0x1fb6a5f7, 0x5cae7a85, 0x84869fd3, 0xed68fcc9,
	0xfa7f737c, 0xc970b8d4, 0x498486b7, 0x6fe1ab7e, 0xeb954da3, 0xe238cfd4,
	0x0abfc993, 0xdea9fb67, 0x7c036de9, 0xfb06a109, 0x9c8ff343, 0xbc70978d,
	0x083e645c, 0x01e164ff, 0xfbd008ab, 0x78f8d8b3, 0xa4e3289f, 0x339c0f67,
	0x4517af83, 0x81cf7c29, 0x2c27ee76, 0x3a5c24d1, 0x8570e07e, 0x8d01ee1b,
	0xa8601ec8, 0x1b067947, 0x4f8cc7da, 0xf58fbc35, 0x8fbc308e, 0xa8605a9b,
	0xc4be2c0f, 0xdcd07ed0, 0x927a8649, 0xfb436aef, 0x86998ae4, 0x92afc6ba,
	0xb43123e5, 0xf7c306ee, 0x0d4beac3, 0x4afedded, 0xee337bc3, 0xf51f0435,
	0x13b23b7b, 0xfca2fd70, 0x3cbb5b4b, 0x9353fee4, 0x1deee930, 0x3cb44df9,
	0x723532d7, 0x923fdf11, 0xe373fcd1, 0x2cd3cd3c, 0xe95e54b1, 0xa2bff232,
	0x727d6344, 0x71053ee4, 0x234ec9c3, 0xb3ae4e1f, 0x23ddea18, 0xb4847de4,
	0x7fd8f327, 0xf7f87df1, 0x3fe0308d, 0x0f444e14, 0x59e35f7c, 0xcc7edf92,
	0xbe32d5eb, 0x0ef104d7, 0xef103afd, 0xf101c3d0, 0xf11d7d0e, 0xc47b7d0e,
	0x11eff43b, 0x1fbfd0ef, 0xff88c07d, 0xfc461db1, 0x88d0745f, 0xfb2e8d7f,
	0x9dc5d3c3, 0x3e10fa46, 0x077ca7c5, 0x663d2e9e, 0xfc509fa4, 0x54ea415c,
	0xa1f03c6c, 0x1fae8278, 0x91ccaf8f, 0x7e117c46, 0xece5bf38, 0x9f892890,
	0x2bce48e0, 0x16603a29, 0xe1e49fb8, 0x6a7e7590, 0xd24679f1, 0xab83ff3e,
	0xebfc1120, 0xade3210a, 0x9e4daa53, 0x105b7520, 0x8393ffd2, 0x7ed1637d,
	0x14b9dc6e, 0x5ba3e81b, 0xac567fde, 0xff2d5df2, 0xc8493fd4, 0x373f3373,
	0x7cff9007, 0x80acd4c8, 0xed1e7f3f, 0x4af90cbb, 0xf1d4e737, 0xf14512fa,
	0x37c845ce, 0x29617ffa, 0x26182fa8, 0x391499ef, 0x437e7c9d, 0x920b8be3,
	0xd1523e65, 0xed4e3548, 0x53497991, 0x533f4a47, 0xf9c9c794, 0xf23925d2,
	0x7f990a7c, 0x01720b29, 0x591c378f, 0x898b4780, 0xb4ec4def, 0xdcf862ba,
	0x8166abd0, 0x5bf41c38, 0x554393e8, 0x03f1ae7d, 0xcff31dbb, 0x720c20da,
	0x6ec07875, 0xb91dd3c8, 0xe7a869dd, 0xda1a25b6, 0x32e3da8f, 0x660fcfbc,
	0x3e8fde1b, 0xc7d431e0, 0xb4378c76, 0xd7a0e8bf, 0x73b8bf50, 0xa5fda1aa,
	0xf50d8ac7, 0x10fdd164, 0x914c3be0, 0xc8ff077e, 0xbb6f6954, 0xc171dc64,
	0xee79589a, 0x6847f554, 0xbf96bbfa, 0x38e953ed, 0x21b02ed4, 0xb3f04fc0,
	0x5cb0b5ad, 0x7daff2d0, 0x9ad6f921, 0xfe73d09d, 0xbfcc6fc3, 0x7baef2d6,
	0x4ed508ec, 0x9ef1f4d0, 0x6326ebbc, 0xb082f5de, 0xfde7efbe, 0xd0f78aa5,
	0x0af36bf9, 0xf82dff1d, 0xf6f6c6dd, 0xf7ded5bb, 0x2a0da479, 0x5e943d7d,
	0xfa741ebc, 0x7073d588, 0x1f5ffbb1, 0xabea31a7, 0xdde71f24, 0x37cff9c9,
	0x919e6e99, 0xcd85f7c3, 0xdc6e9dfd, 0x36f1d4c7, 0xdd74aae4, 0x620b38cf,
	0xedf1f8d4, 0x7edd79ea, 0x89b44dc6, 0x3701e826, 0x07bb6bad, 0x6df31ba9,
	0x5ebdeacd, 0x3ef02b01, 0x57e9126d, 0xb637c4f9, 0x9244b6d6, 0xbd48f3fe,
	0x3b4afd85, 0x3ae0fc9e, 0xf9ef7a7f, 0xc7646192, 0xc3a00e80, 0xcec9fec0,
	0x6fff7335, 0xbcfb948e, 0xfb480e57, 0xf390acf3, 0xe36f5b3b, 0x741f7238,
	0xada6f4c5, 0x4e75dfe7, 0x50cfa340, 0xeb7668f8, 0x86e73d5b, 0x0f4b5ca4,
	0x9ced7ba1, 0xb5996b86, 0x9f247378, 0x7c8a98f7, 0x61bf1eb3, 0x39774aae,
	0x07680e12, 0xbb5fd37e, 0x0c4e7322, 0x8567edfc, 0x07d9c62b, 0xbfe569bd,
	0xc304dcf1, 0x5f73bfbd, 0xfeffedfd, 0xee857dce, 0x10fe50fb, 0xfbfe770a,
	0x34c0e701, 0xc3fc68bc, 0x81e73a2a, 0x4dd2058f, 0x135fa71c, 0x39afdc65,
	0xefbe1239, 0xc57e948e, 0xc133972e, 0xcba5ee64, 0x399bf785, 0x7eac777e,
	0x4bf3df2e, 0x5f323cf2, 0xbdcbceb7, 0x509709c5, 0xab16d2bb, 0xbac2e4d8,
	0x976e582a, 0xd4ed43f8, 0xcb5fd66e, 0x5fce29d7, 0x6fbc2fbb, 0x3877d35a,
	0xb9c2e6fe, 0x3f7a9f04, 0x62ddb1bd, 0x8d0d8ed5, 0xa8e4a52f, 0x3c23d5f2,
	0xf9a96fac, 0x9b6a1503, 0xa409fa1e, 0x1c7ea8c5, 0x72548fde, 0x0f0699fe,
	0xa33de217, 0xb704eb7b, 0xdfc86cf0, 0xf99f4b26, 0x2edc1a81, 0xf99073cc,
	0x0719e21d, 0x9e5a2bdb, 0x39e449c3, 0x3c5abf00, 0xd27f6d49, 0xe466166f,
	0xe30aec5b, 0xd329fcf8, 0x2570731b, 0xe9fc4f56, 0x8895b882, 0xd9c67e46,
	0xdaf79956, 0x75f07edf, 0x34790d9a, 0xb15fbc17, 0xa92fef9b, 0xa9c64a7e,
	0x297a9faa, 0x27275d21, 0x4c2c730a, 0xdf26ed4f, 0x7b033935, 0xff2a46f3,
	0x7287903b, 0x0a1fea9a, 0x5f0f4f5d, 0xf8c8a09b, 0xf98fad2f, 0x7e7954da,
	0xc0a2f89c, 0x15f2d27e, 0x3c608866, 0xe41e2d4a, 0xe3317b5b, 0x95078b41,
	0x75e62f04, 0xd8b8d75c, 0x3b1dab8a, 0x28a3ba1f, 0x271bd5dc, 0xf32a1cea,
	0x178bfa8f, 0xcf9f3acd, 0x7f3ecdfd, 0x9953f729, 0x567a96e3, 0xa0cb3dd3,
	0x2ed88e6f, 0xa74380ac, 0xfafbefb5, 0x93eea2ff, 0x8d5f83bf, 0xad35e5d5,
	0x2f6f9850, 0xf3204e87, 0x6b6f989c, 0x6acd73f5, 0x6fd648bd, 0x9deb2559,
	0xdb56fdea, 0xd604bf54, 0x81eb1289, 0xfaaadcdd, 0x940eb02d, 0x839e0758,
	0x7e0ea15f, 0x15f83a85, 0x2857e0ea, 0xbcf0afc1, 0xc0a71454, 0x56b88a7f,
	0x209f6ea1, 0xd3a855ae, 0xd2d71077, 0xd2d711d7, 0x4b5c47b7, 0x2d711eff,
	0xb5c47bfd, 0xb5c475f4, 0xd711edf4, 0xd711d7d2, 0x5c47b7d2, 0x5c475f4b,
	0x711edf4b, 0xc47bfd2d, 0x11eff4b5, 0x11d7d2d7, 0x47b7d2d7, 0xfeff4b5c,
	0x10c57ae6, 0xbd59baf7, 0x436ca0e7, 0x6e47d31c, 0x3963f16a, 0x45bfdf84,
	0x6b36f3fc, 0xbedcf02a, 0xbcbb7404, 0xf123dc26, 0xe2553cdc, 0x9e2424dd,
	0x9e31e7bb, 0x7ac9b0ef, 0x0e87cc91, 0x8fc41fa5, 0x7e32ad0a, 0x23f11284,
	0xa11f8894, 0x30a8fc44, 0x508fc643, 0xe7847e22, 0x44a11f88, 0xe22508fc,
	0x3f112847, 0x11f88942, 0xf08fc44a, 0x2847e21d, 0x73c23f11, 0x22508fc4,
	0x87e7847e, 0x23881e68, 0x7e82f369, 0x1fb06e9e, 0xf60d0e89, 0x8750d3a3,
	0x0f6fae7e, 0x1eff5cfd, 0x3dfeb9fa, 0x1d7d73f4, 0x3dbeb9fa, 0xfd7d73f4,
	0xef1748d8, 0xfae9e833, 0xeba7a0ef, 0xfecdb9eb, 0xba7be057, 0x97e9e376,
	0x29467651, 0xfa4e288f, 0x8e6ea73e, 0x4eb1f485, 0xeb129287, 0xe2b7f921,
	0x548539b6, 0x84f9a9f7, 0x04dba279, 0x9f1c737c, 0x0a0be6f0, 0xfdce7fce,
	0xd7bf1247, 0x47fccae2, 0x25dfcf78, 0x54cfdf58, 0xdf6aa7cf, 0xccd3847b,
	0xfb6aaff9, 0xeddf7ade, 0xdad7c742, 0xcdd4bf31, 0x3e64e483, 0xeff23bf2,
	0x5e402c88, 0x229336ff, 0xca575ef3, 0xba50e3bc, 0xe32b921a, 0x3b4cdb1f,
	0x5e470c5f, 0xf9c28948, 0x711699a7, 0x38005ac0, 0x5f4015d5, 0xaac6e4b0,
	0x04bbaaeb, 0xbcda4f79, 0xf1213f35, 0x37773e09, 0xcad85ba1, 0xbecb9c69,
	0x6efc3610, 0xd49b34c1, 0xec1df017, 0xc57e91c4, 0xdf4759bb, 0xedbeaad1,
	0xa4bb2ff3, 0x6c8f9e9c, 0xe704bbad, 0xcb85a6f9, 0x347b1eef, 0xbd38e19a,
	0xfb8cd949, 0x0ab42656, 0x0ee7ce2f, 0x91baf552, 0x395b4ead, 0x73e4eb8f,
	0x25bf5a80, 0xdcf8531b, 0x2ce88962, 0x8c51bf84, 0x71fef851, 0xbeb46e0d,
	0x4cbeb197, 0xf7f02ada, 0x40f3e8fe, 0x90fe06a4, 0x8d9740f3, 0x1e422d89,
	0xf797689f, 0xa63b5e39, 0x9a40d564, 0xef202f97, 0x8becbc73, 0xbeb857ba,
	0xc8e7de45, 0xe78e33e4, 0xcb30f2c7, 0x237df0af, 0x4c9bfdd3, 0x4b9c2ef1,
	0x404d615e, 0x81e156fb, 0x6734803a, 0xd6d5ab9c, 0x4c3a2395, 0x22f4050e,
	0xd1d38a5e, 0xd98e711f, 0x8f7c97a0, 0x9b35ef95, 0xc15a7161, 0x8df5426f,
	0xd217fcd0, 0x7997ae3f, 0xe40b5696, 0x951fa6b1, 0xcf5ce538, 0xff595935,
	0xdeadd928, 0x6fa21f67, 0xa4317968, 0x90827877, 0x61aebbe3, 0xb2f5543f,
	0xe4ff38f7, 0x0db03bb8, 0x4f1e71f7, 0xbc6739dd, 0xc28b7a1b, 0x86f494fc,
	0x7103b999, 0x3e15f61e, 0x7fe9d1d7, 0x738df59a, 0xcb47f74d, 0xfe325cf3,
	0x49c2ae51, 0x542d07f3, 0xe6ae51f1, 0x906e1d41, 0xdc92e6f7, 0x68457be5,
	0x8457acbe, 0x1e9a87ea, 0x23b3dda9, 0xf87df384, 0x7d682a61, 0x78bb0338,
	0x44eac95d, 0x58fea171, 0x4b95eaa5, 0xf79cac9a, 0xb3dea154, 0x25fbfa15,
	0x53be6a55, 0xfc90f6d5, 0xfd10dca6, 0x50efbb53, 0xc7f2536d, 0xfd63ae97,
	0x71cacea7, 0xa42bf9c5, 0x8a76243e, 0xcc69ce00, 0x84d9315f, 0xefe632fb,
	0x3e947af6, 0xaa4fe7e8, 0xd3ad345e, 0x719d70c1, 0xc9f9823e, 0x5cc9f3cc,
	0x893e739f, 0xcbcfebcb, 0xf099d0bc, 0x3bbe10fd, 0xfeb9e48b, 0xe87d5477,
	0x0289e43a, 0x4c41fe8f, 0x9e8967cf, 0xca9e4431, 0x957846a7, 0x4e6ea097,
	0x2156fab3, 0x26da750f, 0xb5e5fac1, 0xffa89bd0, 0xe2a3d0b9, 0x45dc1fb0,
	0x553c9f9c, 0xd73b73e1, 0xd2a6598e, 0xc107ed3f, 0x19ef83fc, 0x08ce15f1,
	0xae68bf20, 0x7809a76f, 0xcf81f6d7, 0x57f7c5df, 0x6c57eb5e, 0xa7cfd7b8,
	0x9d1acbda, 0x0587ee87, 0x2b3faa11, 0x7aabfa52, 0x2c9859fc, 0x77f1ff2e,
	0xeebe41cc, 0x071cf802, 0xb04084ab, 0xef91ca8f, 0x31d53fb7, 0xce7489a7,
	0x98e7eb1f, 0x73c9326f, 0x71efa45b, 0x28e8bdfe, 0xb2fd841a, 0xfe40294e,
	0x869f36bf, 0xcede9351, 0xa5c5d9d3, 0xced2feea, 0x2bbf2e0f, 0x9d77d063,
	0x38232d97, 0x882d9f63, 0x214dbce9, 0x0ae474cc, 0xee22616f, 0x25da1703,
	0x39e44147, 0xffd6a0de, 0xef37d4f9, 0xf8648daf, 0xdc8dfd70, 0x5e41cdbf,
	0x87e68fcb, 0xfe8b15f3, 0xff7096f7, 0xc1f32e7f, 0x6bc029ce, 0xdf374e44,
	0x1f0a109b, 0xcff24fcd, 0x87bc975c, 0x525fc421, 0x8be52396, 0x6e52b8b0,
	0x8b8bf8e4, 0xbada8afd, 0xe78d5b0f, 0x2bf2b55b, 0xbbfc4e55, 0x603c7dce,
	0xfc0cf792, 0xf9d814da, 0x8de9d12c, 0x72c77d03, 0x46bffe69, 0xdfcf3b1e,
	0xeed3ebc7, 0x53e1e8eb, 0x1a1cfdea, 0x1fd6951d, 0xed4a6dd9, 0xb5f2a7a5,
	0x35b43f9f, 0xd801f71e, 0x7c9077f8, 0xfe79156b, 0x7b3a1fbf, 0xf79c32b4,
	0xb73fa3cb, 0x6f9dff31, 0xeec578eb, 0x87e785ee, 0x9569fff5, 0x819832fc,
	0xa86ed6fb, 0xc57df073, 0xbf8aa30d, 0x72227e01, 0xb7978c3c, 0x8fb50631,
	0x7929f189, 0x74076103, 0x5f844fec, 0xf23ff6f8, 0xdb4bc03d, 0x61ff7cdd,
	0xd5fc9ec9, 0x61a597b8, 0x7a06cf94, 0xda74892d, 0x36d467a0, 0x5ddcb2c5,
	0xb73d4830, 0xce39ba2a, 0x2523e1a6, 0x1dbbda4f, 0x6738e4a3, 0x00897b54,
	0x68619d64, 0xb15fb7d7, 0x10889ee7, 0x3faf563f, 0x6bdf0b65, 0xf2178b6a,
	0x7810e0de, 0x2b61cfc1, 0x84a3f5e8, 0xf67a3bfa, 0xdfefadab, 0x9e49fc37,
	0x5fbbc862, 0xe6af63d8, 0xbd04194c, 0x84e2bd7e, 0xd23cbb7f, 0x54c5fd75,
	0x45603f2f, 0x3698aa46, 0x45ef25c0, 0x8bde4bb9, 0x3e6b7a52, 0xc0f9adf3,
	0x6fce0149, 0xb6fbcc5c, 0xe8e5403c, 0x8df7f7fe, 0xba1a5feb, 0x7a0aeb17,
	0xb97dbcf9, 0xdfd36bd3, 0xacd65e23, 0xd04bee18, 0x49e457ea, 0x327ce1bf,
	0x9bbf0023, 0x70db756e, 0x527cd127, 0xf8ff907f, 0x21973c93, 0x38ed4c8e,
	0xaa5a63bf, 0xabef2fd8, 0xe5bb79a2, 0xfeba0578, 0xf78d9b4b, 0xd67b503e,
	0x8bcaaedb, 0x9c4afee2, 0x4a376eb4, 0xe093cf27, 0xbeea70c0, 0xf173fa87,
	0xb2f70c38, 0xc1eac060, 0x4257907c, 0x019c1bf5, 0x6d29c62b, 0xf8aff792,
	0x7c71c9d6, 0xb96d636b, 0x4e2cebd0, 0xbebd50db, 0x1bef24d7, 0x6efeaf9e,
	0xf597cd03, 0x138272e1, 0x3ce1a9ce, 0x285a6420, 0xf9d44abc, 0x1ac73797,
	0xf5e6c7f5, 0x5e67e056, 0xdc42f73f, 0x6971d2a9, 0xc73e44d3, 0xf2f16e5f,
	0x0a9f0fb9, 0x39964fef, 0x62fc46ee, 0x5683cb5e, 0xf26bd537, 0x277d9ea4,
	0x70103ce0, 0x7df0660a, 0x9c1ccb4b, 0xd9cf3d87, 0x81edebcc, 0x1f04fdf7,
	0x62ce27e8, 0x89d13786, 0xe58cf91f, 0xf6fc462d, 0xfb8a27ce, 0xe1296f2d,
	0xe2c8b7fd, 0xf3f539b3, 0x032fb0d8, 0x68f339f9, 0x293ee3df, 0x79f1f4e1,
	0xbfef4fd2, 0x0d1f7f9e, 0x317ce4f3, 0xee0a6b8f, 0x61ba224f, 0x47e8d6ba,
	0x8dae873b, 0xfd2792d7, 0xbaea2d3a, 0x5a7dd5fe, 0xf384aebe, 0x8512ca7c,
	0x7c33f707, 0xf6d53edf, 0xe75fb6a7, 0xb2c97ea9, 0x0ef83375, 0x90df8d22,
	0x5dfbaefc, 0x5b79f01f, 0xa83727e5, 0xbe7824f8, 0xbb7e742c, 0xcf5f7576,
	0x7bee354f, 0x1f7e87f4, 0x7f3df157, 0xe7033052, 0xdaf6b554, 0xc807f3b8,
	0xa0ff40ef, 0xf1d5c7b3, 0xb7397ed0, 0x46f81937, 0x68df0f59, 0xbe00955d,
	0x2efe53b1, 0xa47bf2df, 0x29fcb75e, 0xc4fd5e79, 0x9cdf67f2, 0x3f8eed43,
	0xfe8169b0, 0x507948fc, 0xa48589f2, 0x2c6f814f, 0x90fee552, 0x3c9edf4c,
	0xbf2e3edd, 0xec4ca9ef, 0xf2da1b8b, 0x6c9dc53f, 0x47be6eb4, 0x3d4fafe9,
	0xae25def7, 0xadaaf95e, 0x5bed74a3, 0x3d4892d6, 0xefbae4dc, 0xf3e52ece,
	0xec17c0e3, 0x4526b2b0, 0x6dea41c6, 0xf86a7fac, 0x1283a50e, 0x9165bfda,
	0xd457de17, 0xe1a4de9f, 0x86bfc359, 0x85fb9eef, 0x786b7c54, 0xd193eed2,
	0xef36aae4, 0xdf79d50f, 0x21efd2a0, 0x50dddf75, 0xe22db6e1, 0xe1b6eefd,
	0xa9e72877, 0x1b95e7ef, 0xc9e0f79f, 0x57dfc3d9, 0x5ce05f63, 0x7674f015,
	0x23fa559d, 0x53c02f5b, 0x36bee40a, 0xdfaac58f, 0x3feaa171, 0xc1eaa45c,
	0x7a53a784, 0x547e2d3c, 0xc76ca9e2, 0x3dc23f1f, 0x5553f367, 0xbc8f763e,
	0x6db4a0e7, 0xde6be327, 0x3756f5da, 0xcf26fbb5, 0xa44fb86d, 0x09df2eac,
	0x6b0df9bf, 0xffb15937, 0x79f951bf, 0x57cfbd28, 0xb835a2f3, 0x3a28fe42,
	0x07b5a7b9, 0xe349dbdf, 0x11ccbadc, 0xbafdffad, 0xae9251cc, 0x0762eacb,
	0xbab2bc60, 0xcf617b92, 0x743f7c68, 0xc8711ddf, 0xfd4a50fd, 0x991e5f61,
	0xe073e1e8, 0x25f5c388, 0x928e875f, 0x5637eafb, 0x72667f79, 0x80e3db44,
	0x70d2f243, 0xe9d7e20f, 0x4f7c9de9, 0xf318e82d, 0xfde499b6, 0x9dd5e99b,
	0xe91e639f, 0xa0d7e642, 0x885dfdc4, 0x7d502477, 0x4f9e49b3, 0x72cb354b,
	0x0f4928f2, 0xf7883ef4, 0xef93be22, 0x5be50bf3, 0x1a15e9fd, 0x84fd6a7d,
	0xd6fea9f2, 0x4928e977, 0xbeb7df97, 0x6fd56e23, 0xc149ed92, 0x7e0bf13d,
	0x85f7c595, 0x6d3adf7e, 0x3d8fbdea, 0xbf930deb, 0x7ac171c3, 0xd41da5d3,
	0x8a5b7aff, 0xef58fa12, 0x7565f105, 0xffb9689f, 0x6692713d, 0xa2392719,
	0xefa2dc90, 0x70732c8e, 0x2eb69b3e, 0x43ff4fcd, 0x3cdc6bcf, 0xbfea806a,
	0x3e828ce8, 0x3dfd5f39, 0x75941113, 0x7ba19f3c, 0xed7bc9ae, 0x3f8d3c3e,
	0xcaa75c7f, 0x0f79d143, 0x4fa8b3f6, 0x0e587be3, 0xc2891f35, 0x264733fd,
	0xdf69f9ca, 0x6efeaadd, 0xc6155889, 0x37a4fdf9, 0x693f86ad, 0xfd963fa1,
	0x8fd53734, 0xf7f714fe, 0x2c94d4dd, 0x7aa9a5cf, 0xff9522fe, 0xb25adc45,
	0xdfb422fa, 0x61dfe6e0, 0x6c59185b, 0xa22e1f83, 0x952d8665, 0x07695ef5,
	0x5bab7168, 0xe7cc5115, 0xc07bd4e9, 0xa5f699a6, 0xde2cde43, 0x69fff520,
	0xf116b126, 0xc58d61cd, 0x1fc09253, 0xfde4521e, 0xf78d1b1e, 0x2ccb6d82,
	0xc028d9fe, 0xbd7ee42b, 0x5e6dad5b, 0xf4829dd8, 0xf307ac0b, 0xa1fe5c01,
	0x2d43c7f2, 0xbe4f7c5d, 0x7b1fcf06, 0x0ba34a1e, 0x10b67e2d, 0xa0d19ffe,
	0xff7cf98f, 0x271ab954, 0x9932dd5b, 0xcd370beb, 0x8d4f73e2, 0x64764c68,
	0x07a2faf9, 0xc738b9fc, 0x5e51e12c, 0xf43a7933, 0x61cd8aa2, 0x526bb0b1,
	0xbd14feac, 0x69be5a1e, 0x3a839f0d, 0xe7c1c9b6, 0x339d0aa0, 0xb3d7910a,
	0x673ca368, 0x4c7bb5a8, 0x35957fdd, 0x99e70d93, 0xb89f5216, 0xb6cbf4c7,
	0xd397ce08, 0xb06d29ce, 0x1a8f36fb, 0x5d2bcf2b, 0x94e792ec, 0xabbdb892,
	0x56bd3f4f, 0xcf20da7e, 0x5dcee8bd, 0xdf479f4d, 0x1d3cd757, 0xeeaa7e8d,
	0xd39c677f, 0x1dadfec4, 0xdce7bfe8, 0xee7906d5, 0x7dfde16a, 0xeed27f9f,
	0xa3d8a8b5, 0x378ce218, 0x0f586205, 0x0d8505f5, 0x539f6df1, 0xcc7b9eb0,
	0xd721ea2c, 0x7b44bd35, 0xecf9541e, 0xfe6698b1, 0xdb25f11d, 0xe37be41e,
	0xf5928b3e, 0x7faedbf9, 0xb7c87c0d, 0xdfea4c25, 0x6dfac116, 0xcbea5f99,
	0xdc3a79da, 0xfc3b0017, 0xf21151b5, 0x5cf5287e, 0xed2f3696, 0x2ccfe11e,
	0x9c219ef2, 0x7f3d02b7, 0x042e0968, 0x7d243f3e, 0xc78f7114, 0x61f4fe54,
	0x1f7f99b3, 0x011b4fc7, 0xcd87c57a, 0x9e21474f, 0x4561e9a8, 0xeff2bfe6,
	0x2ddf2f4d, 0x3ee343cf, 0x555bbe7e, 0x3ad497f5, 0xdf2dbd25, 0xfb829d6b,
	0xe2af49a0, 0xa096d527, 0x557c2fad, 0x4f537aaa, 0xb64ed77d, 0xa55baacb,
	0xd6dd505e, 0xa6817ac5, 0x2be76867, 0x58bb5aab, 0xabbed04f, 0x52e125dd,
	0x2f3e4bb3, 0xe93bb9c1, 0xe92af16f, 0xae1597b0, 0xfdfde447, 0x7d1615fa,
	0x57ebabfd, 0xaa74a3a4, 0xd66e90fe, 0x7eceefcb, 0x9a99ed9b, 0xaa5fb526,
	0x9de3755b, 0x281ee6c1, 0xe245a79f, 0x7ec1977b, 0xed25d9ab, 0xf84d60a1,
	0xadbbce5a, 0xeff0b48d, 0xb244d4e0, 0x6758df3c, 0xbe3e46ca, 0x7d670957,
	0x17cd5dae, 0xbef5581b, 0x24827e03, 0xee12fdd1, 0xda3cfe2f, 0x38d0f267,
	0x4ca61fff, 0x8000e1a2, 0x00008000, 0x00088b1f, 0x00000000, 0x7dedff00,
	0xd554780b, 0xb3dae8b9, 0x926619e7, 0x4c90c93d, 0x08498120, 0x9dc46c10,
	0xb00d0417, 0x18081303, 0x42c144ea, 0x440130c5, 0x57c05790, 0xc193c6f4,
	0x188208f0, 0xdb151104, 0xe5a2d101, 0x1e8a84f4, 0x54076c50, 0x813d568a,
	0x55fb6a5a, 0x5b515a88, 0x1ed62124, 0xfef5b53d, 0xced6bfff, 0x0f0c9ecc,
	0xdbdef5ad, 0xaed7e2ef, 0x8f5ec7ac, 0xebfffdff, 0x242c1931, 0xfeb19931,
	0x41b1222c, 0xf0be758c, 0x80b07141, 0x3b0331b1, 0x630a613e, 0xe9a61596,
	0x258c51fe, 0xcbe990a9, 0x28e82b18, 0x7f0a5c0e, 0x02b3621e, 0xb51ec64e,
	0x114716b0, 0xec039b94, 0x603f286a, 0x8c3dbf82, 0x2927fe85, 0x7f04b8fc,
	0xa58c69e7, 0xc1dcb633, 0xe41f3ff8, 0x6dd63047, 0xb608d9e7, 0x9ff68129,
	0xe78fc29b, 0xe452f7c0, 0x97cf9c31, 0x632c6ff8, 0x50685413, 0xe6c058ca,
	0x1852916c, 0x64b24abb, 0x910e07ff, 0xc2a7ec1b, 0xf2b9027c, 0xef3085a5,
	0x528323ee, 0x169dde70, 0x3eb58ede, 0xdc61d9a8, 0x6cd86271, 0x54b10b13,
	0xbcfdacc6, 0x58cc964e, 0x387923b3, 0xa6927683, 0xff9806b1, 0xe68705dd,
	0x75d7bce0, 0xe60d99d9, 0xe92bae31, 0x65da091d, 0xb132abf7, 0x407ed8e1,
	0x7c93bf18, 0xda133666, 0x45302a1f, 0xd99ed8cc, 0xd99ed8c3, 0x7c8eb52b,
	0xb997d63e, 0xa1c98e30, 0x81d277e1, 0x412e7c5f, 0xfb3e5fda, 0xb3ac0a62,
	0xda92edff, 0xbb6a6d0c, 0x5ffa3d4f, 0x6cfcce90, 0x4f5c1ec7, 0x44b04a59,
	0xe89e7585, 0xe8277aae, 0x36957e83, 0xfbc05abb, 0x81c75d8b, 0x4e4f3e3b,
	0xd7e74535, 0xdfea75d9, 0x5304b3ff, 0x77c12abb, 0x11c80ee3, 0xf3def0db,
	0xc4c2f4e9, 0xc23b5107, 0x14d3a74f, 0xff6c2496, 0xbf385be2, 0x44677671,
	0x2cefc64e, 0xd1ec3ba7, 0xdb2f98ef, 0x0c3bea7d, 0xecbec251, 0xc426c54f,
	0x036c52e7, 0x901f75e3, 0x2eeebfa9, 0x7f419867, 0x2e9ccde9, 0xe9e9fc74,
	0xfda09aaf, 0x14aba050, 0x1056df56, 0x9aaa9f2d, 0x0553bf08, 0x0a0de79e,
	0x32bc44cc, 0xe03b3873, 0x3b34f1a2, 0xb134cbd0, 0xd12bc07e, 0x9fc62c93,
	0xcd30e026, 0x9eebe269, 0x416eb71a, 0x8ef8f10f, 0x66c3d3e2, 0xc4f146a6,
	0x397f6cee, 0x73f08725, 0x2f1c7de9, 0x3e5e1237, 0x65d56d7f, 0xd7f7ef90,
	0x7f9f84c9, 0xa6225e02, 0x9780af92, 0xd25e2376, 0xa18e239b, 0x07ae8780,
	0xa40eea4c, 0x11544477, 0xd6099aa5, 0xbe59f2c7, 0x95affa19, 0x607bd493,
	0x8024c17d, 0x93282c07, 0x826cbd75, 0x0390867c, 0x2e3aab03, 0x09ffd065,
	0xf3807ec6, 0x51b530ea, 0x2e6a13f9, 0xb58b27e1, 0x33396267, 0xed5e9477,
	0xe9fc3c42, 0x33143f92, 0x786d79b6, 0x3f427fcf, 0xa1f852cd, 0xd3ffc879,
	0xb0e3ea9c, 0x29b0ceee, 0x36718164, 0x7df0d9bb, 0x05e6fe30, 0x2c21a897,
	0xa7ef8267, 0xa1ef895b, 0xd603407e, 0xcff5e0cf, 0x7bbdfdfe, 0x067ae247,
	0xe6cf5a33, 0x2b643642, 0xe4d737e4, 0xbaf3fd53, 0xc5d7b8dc, 0x72e1afbf,
	0xd482f367, 0x0ff20870, 0xa61e1c3f, 0xde6e1d00, 0x42a665ae, 0x183934ba,
	0x27eaba46, 0x9cdbfa73, 0x6e90e503, 0x6e330291, 0xe52e7ec0, 0x9198edf3,
	0xa02793f4, 0x881e472b, 0xd13f2826, 0xe721dae0, 0xe8f5e944, 0x30e08560,
	0x43cef430, 0x38d0a708, 0xfd0f5f96, 0xa674149f, 0x31025dc3, 0xf77000d7,
	0x78eb3808, 0x93cde9d0, 0xf287f404, 0x5dd391a1, 0xcf589c68, 0x966e1612,
	0xa3acce10, 0xd6b9c00f, 0xde10faa6, 0xee094cbf, 0x2f37f9c3, 0xb8c8fc03,
	0x13878e0e, 0x963f3626, 0x45f4f49f, 0x44beabe4, 0x4bf2122e, 0x52fce32d,
	0x7484f48b, 0x14f400d8, 0x23ac8743, 0x8faa7dcb, 0xbef827a0, 0x8c3c15dc,
	0x724e2de3, 0x963ffcd2, 0x2b02357e, 0x3c9bfb5f, 0xff78d13d, 0xed0bfc85,
	0xdf04706f, 0xb37dfe20, 0x72c4e482, 0x5afb8f85, 0x28d907e1, 0xf1dc4f9f,
	0xd74c2c8b, 0x628e0724, 0xfe332dbb, 0xc6550132, 0x0b0eccc9, 0x8ce4e7ae,
	0x01f6c9ff, 0x7f1b6b3c, 0xb17ff441, 0x51e7d5f3, 0xec5682c3, 0xf40586a7,
	0x98ea0074, 0x9726a61a, 0xa79d34f0, 0xb8fc2e5d, 0x3cacf986, 0x53da4455,
	0x872d3abe, 0x51a70fca, 0xf3fa267b, 0x5e52f6ad, 0x9435e099, 0x3271fcc3,
	0xb970b14c, 0x6b49cff5, 0x07d42cec, 0xafedcce8, 0x7001dd5b, 0x2dbbf0cc,
	0x9627a41d, 0x2e5d5e91, 0x9b9022e4, 0x73f210b3, 0xb94fde05, 0x2e500382,
	0xc6e87c1f, 0x54fed801, 0x18038de5, 0x903fefa4, 0x547c4161, 0x3f503f62,
	0xd58deb77, 0x5a739748, 0x0473206d, 0x757fe1bc, 0x2194362d, 0x79a3f93d,
	0xef814b8a, 0xe93ffa8e, 0x35f1a41b, 0x6235cb92, 0x67f200bc, 0xaf37e426,
	0x6bf28b39, 0x7df8c856, 0x1f89d6cd, 0x0d3538e0, 0xa14f72c6, 0x657883cb,
	0x44bf532a, 0x24406a78, 0x9bd37aa3, 0x10c7029e, 0x00f9e9dd, 0x043c22eb,
	0x17885e00, 0x59bfaf48, 0xf227d4c2, 0x44d7a8aa, 0x41f2203e, 0xf28bd691,
	0x455b4890, 0x6da45879, 0xf2223ca2, 0x35df22ed, 0xc7694cc0, 0x9abf5108,
	0x81c1b8d1, 0x9fb7ca1e, 0x4338f890, 0x72d106d3, 0xe947682d, 0x2bc42ce9,
	0x51bb99f0, 0x4b363922, 0x7313c293, 0xa68bb77a, 0xbb636f5d, 0x77cda340,
	0x843b4c4f, 0x98a2b8ff, 0x3d34e03c, 0x61ef2635, 0xbe6c465a, 0xd47de731,
	0x8b3b0183, 0x724e19f4, 0xccbde09f, 0x58509c11, 0x9245fd4a, 0x5cab7db1,
	0xa436e34a, 0x162f5e11, 0x04fec01f, 0x123d4c1f, 0x6f9101a6, 0x14fc2135,
	0xdf389416, 0xfbe84930, 0x935347ff, 0xdb41f084, 0x3bf3e10e, 0x10b8b035,
	0xcc68a0e0, 0x4c1c0412, 0x553bf1d3, 0x9c81e50a, 0x86756f4f, 0x323c0227,
	0x72ec4aa6, 0xf5b4e3c0, 0xf6476449, 0xcaf8e2cf, 0x1d90b332, 0x0eae2dd2,
	0x6fda1793, 0xbbd4cfd9, 0x19c1fda1, 0xb410a5ab, 0x54c752df, 0xda65bf6c,
	0x89cc998d, 0x212ad472, 0x80e62a1f, 0x62bcf905, 0x05c90d6a, 0x34c30f1d,
	0xf8e509ab, 0x7f009db4, 0x9ab4a76c, 0xbcd10502, 0x6c67b45f, 0x30f1f13a,
	0x1bd7d3fc, 0x0476bfbf, 0xf60495b2, 0x4de69e9d, 0xa0262295, 0x402d0aa7,
	0xc69a64f2, 0x61c7d7fb, 0xfbd47ec2, 0xf79c72c7, 0x6439a9b4, 0xdfab9fbf,
	0x5a3f68cd, 0x09bfbb19, 0x6890d284, 0x5755fdf9, 0xbebbf0bb, 0x052736d3,
	0xda6bcc13, 0x2c763dd4, 0x9233b61f, 0x6016e98a, 0xc3ce0888, 0x7cd0741c,
	0xd3bd7c82, 0xfb26e47a, 0x3f3897fb, 0x6e5d03cc, 0x815cda99, 0x0825b67c,
	0xbde10912, 0xfa83b673, 0xc7357e99, 0x933798ab, 0x12be5267, 0xbdece8e1,
	0xfcc5fbce, 0x2c05e5a7, 0x3d43c10a, 0x34d8f688, 0xd432a98d, 0x59cd4f77,
	0xeef5f661, 0xb4095a67, 0xfc09f487, 0xa9bdd61e, 0x367ea149, 0xff297935,
	0xfb03c200, 0xc87f59dd, 0x8081fd81, 0x9eea7643, 0x4961535a, 0x8f9f9fd4,
	0xd77c547f, 0x890dfd8e, 0xe884fff6, 0xdf4eda77, 0x37f60f2a, 0xa15f9f5d,
	0x5e606004, 0xf2097433, 0xa486abc5, 0xabc7e87a, 0xf614ea41, 0xac77f43d,
	0xbfbcbf57, 0x7e9ffb5f, 0xf26816f8, 0x9ffbc99d, 0x93e90bda, 0x5a9ff7fe,
	0x597afd00, 0x30adf645, 0x9597778e, 0x53dda2fc, 0xc03ee7b7, 0x7ddfded0,
	0xe70c33c9, 0x125c71bd, 0x4980e3ce, 0xd012f9b5, 0x9f0e54cf, 0x0e1a3a78,
	0x89fe40d3, 0x62a387a7, 0x8e82ed9d, 0xd4f0109e, 0xc544f9e7, 0x02df0f83,
	0x77190efd, 0x909bd147, 0xc2dc68fe, 0xa0de709b, 0x26fa7e07, 0xc9c9ffe0,
	0x0cd8ec8f, 0xc1857ef9, 0x1c7ca23f, 0xefaee13a, 0x13f6c5ef, 0xce0f161d,
	0x15fa99cf, 0x9e8f55f5, 0x1fa428b2, 0x1791567c, 0x3d72b329, 0x7623edc3,
	0x7ff07d4e, 0x24d01a67, 0xb918bfa2, 0xfac114a8, 0x7cbcfc6b, 0xa2b6ab36,
	0xc2d95d1d, 0xf5ecdef5, 0x05a7f712, 0x3e09d61f, 0x4ed58604, 0x7e40dfc1,
	0xc3804bec, 0xbde7617c, 0xbbe8c79b, 0x30a51b77, 0xbdac3078, 0xf60b3de5,
	0x41caeef7, 0xbbffd8c9, 0x89ac832d, 0x96eccae4, 0xf79bcbf3, 0x2e801e90,
	0x09f26dde, 0x3df4e67a, 0x5abfb75b, 0xd0095724, 0xa9268d65, 0x7049a113,
	0xf686d4bd, 0x8e4b467f, 0x412bec95, 0x8c5d475f, 0x255d1dda, 0x174377a9,
	0xe46d2b07, 0xdedd1ce7, 0xe279e887, 0x98a3f74a, 0x18dbf3af, 0x0c563be6,
	0x5ecef9a5, 0xb797f859, 0x21755d60, 0xe5055a9b, 0x0a7e0bef, 0x58c97568,
	0xf23c212f, 0x9608f0a3, 0x432ddf2b, 0xea2df9f8, 0xbc28bedd, 0xf00f582c,
	0xbcc91d9b, 0xe71816fe, 0x62a490c3, 0xeb5ce628, 0x4d85677e, 0x08d0c7c8,
	0xb6ef2bd4, 0x0651bda6, 0x5cd9cdfd, 0xc7d01871, 0xc83a2b3a, 0x0764580f,
	0x3ce006bb, 0x29d9ed6f, 0x11562900, 0x5ff43492, 0x85b5ef66, 0xd987806d,
	0x9c348c80, 0x8a0e5bcf, 0x257ae80b, 0x75672718, 0xbfe3eafc, 0x8c941a1b,
	0x45bdb972, 0x2f9dfe4e, 0x2dd9c78a, 0x09bd8769, 0x51e3ade6, 0x85b3e397,
	0xdf01dacd, 0x1e01fce3, 0xbcff9c2e, 0xad9ed1b0, 0xd8314c6d, 0xfa75e39d,
	0x37f4e46b, 0x50c335a7, 0x859cff0f, 0xfe3cffd0, 0xe7e79b37, 0x1689f276,
	0xffec5ef9, 0xb66b86fd, 0x76f2848c, 0x2405b4e9, 0x5add9b14, 0xad698c98,
	0x5adfedc6, 0xe8bbd83f, 0xe9d9c7c7, 0xc1948fe8, 0x474b47d0, 0x06dd2326,
	0x7b57ba57, 0xeafc517d, 0xab61bbf8, 0x2b9e4ed1, 0x4ae0aaec, 0xf6a2bae3,
	0xbb45669f, 0xd78ede24, 0x17683ced, 0xdb555142, 0xbb07ac68, 0x6951556f,
	0x9b03ce94, 0xb9253ed2, 0xad729173, 0x41efed16, 0xabbf453c, 0xa059ed12,
	0x3d0d598b, 0x10e3cd7c, 0x0021c78c, 0xf9bfc253, 0x9eb94b57, 0x59eefdd2,
	0x3f49670d, 0xf4e46acd, 0x78c3cbaa, 0x8d514e38, 0xccaab8f8, 0x9a35a748,
	0xa9af2e91, 0x3f68681a, 0x50d4302d, 0x97e9bdff, 0x0467ea19, 0xd7f21a47,
	0x686b1fcd, 0x44fd7d7f, 0xe9bfdd23, 0xa0bc7ee6, 0xffe173d7, 0xdf57a135,
	0xf4cfb388, 0x6ff8bab4, 0x27c7c8d9, 0x36f4d86b, 0x8a31a74c, 0xe0ac9c23,
	0x1e62a0e9, 0xf31673ff, 0x45a7c238, 0x9770bf3c, 0x310ff5a3, 0xe6dc59f3,
	0xee97e436, 0x43fd6ccb, 0x0a167acc, 0x245bb2b8, 0x22d9f233, 0xb316c55e,
	0x6728018e, 0xf51f26bc, 0x91d4c4bb, 0xd64ef98e, 0x5e90ae95, 0xea5f108d,
	0x28e93af8, 0xc44cdbb7, 0x16fe3c1f, 0xc0387f1f, 0x99b7e47c, 0x25293ed9,
	0xe3d1ef1a, 0x0472bf3b, 0xe91f20cf, 0x3ce3d7eb, 0x8b8b71f1, 0xc2aeabe5,
	0x3c4567e0, 0xabd0639e, 0x5b7984ff, 0x737efb8a, 0x293b06f3, 0x5bf4b8a5,
	0xf1567799, 0xeaef0837, 0x6290e0c2, 0x1e25bc23, 0xe7c6f8e7, 0xc24dfc5d,
	0x13b0967b, 0xb509e3e3, 0x4dfdc64e, 0x7900be3d, 0x5332d3d4, 0x528bbfbf,
	0x0273ffbe, 0xa5095765, 0xef37f261, 0x51e4f5b0, 0x8bb89f7e, 0x3c801fe7,
	0xeebaefa3, 0xb4c1cdcd, 0x694f95c3, 0x5991fa98, 0x32f5f93d, 0x41923f6b,
	0x720fa0e5, 0xe5c0faa2, 0x72efc7d2, 0xe57aa60d, 0x63aede7e, 0x0bd92e4a,
	0xa8c84f5c, 0xf85da827, 0x5f688648, 0x3902ed49, 0x71d38d12, 0x9213f450,
	0xf0f76529, 0x0cf6e176, 0xdc6547ea, 0x2ea9e51e, 0x56e27f77, 0x8c9fa3a7,
	0x2a721a5b, 0xe83311a5, 0x458bb7cd, 0xcc1cd4dc, 0x03edbc24, 0x6e765ec0,
	0xb0b49fb8, 0xbbd0f184, 0x5c3b1c84, 0xbef4a66c, 0x224b6ef2, 0x9fa7b4ff,
	0x3855533c, 0x95bffd41, 0x3591fdf0, 0x73df3e2e, 0xa572738d, 0x5df7e139,
	0xf353dea2, 0x7b3e7492, 0x29996537, 0xff504e10, 0xfe3e62b7, 0x4d26b763,
	0x5673fec7, 0x05c96ced, 0x90d939fa, 0x217e8856, 0xfd19aa90, 0x24286f2c,
	0x1fef832d, 0xf831ce29, 0xdf1ab337, 0xc1e19559, 0x910a7bf5, 0x7905bf96,
	0x7e8bdc7e, 0x2f1894bb, 0xf47ac573, 0xe8a741fd, 0xb43401ef, 0xf7485d70,
	0xa36704b0, 0x9871f68d, 0xd7ec37ea, 0x62c49f30, 0xe9dbd3bf, 0x2a368dfc,
	0x7214f4e3, 0x9bf74514, 0x633a51bc, 0xff3a6748, 0x4b0ff7c7, 0xecc7250d,
	0xeb0578db, 0x48667f63, 0xfb82a303, 0xc8f45e51, 0x11a99f89, 0x9c9c4b8c,
	0x2a3f2766, 0x98737188, 0x69cfa98f, 0x1b07b78a, 0xc50a5c84, 0x4d7d1fed,
	0x21d272f9, 0xeb8bb6f4, 0x957ebd71, 0x148fdfd0, 0x7b7a7b7f, 0xf9e045c0,
	0xd28cc587, 0xb412a193, 0x016a58c8, 0x932c30c3, 0x7e432a9d, 0xbe0b2acc,
	0xd7a06c57, 0xdb84249c, 0xcb278657, 0xcd6e2852, 0xb17ebdb8, 0x52e5d4f0,
	0xd88b337f, 0x694893e0, 0x63d453f0, 0x7e296520, 0xebf3cfa1, 0x978eaff2,
	0x6c162601, 0xa61f204b, 0x3bfa8895, 0x34f9233f, 0xc51748eb, 0xd6356653,
	0x78df3c0d, 0x654d07a8, 0xf3276ab0, 0x1f23ced9, 0x2e2f387d, 0xdd225767,
	0x92fbd567, 0x95af20ea, 0x3b54b970, 0xae124875, 0x63ec02b5, 0x9da14f8c,
	0x90e262cc, 0x6c73f6b1, 0x765cf0fc, 0xd607eeb5, 0x5c00dc0a, 0x3eae3843,
	0x4ec2359f, 0x9d873e6d, 0x574066ba, 0xe9f68ab6, 0x084bb75d, 0x462d1d8f,
	0x78d19db9, 0x1d031576, 0x43b91199, 0xae6a61f2, 0x3818d497, 0x3bfe9ad9,
	0xf279e71b, 0x2576ffae, 0x86c9df82, 0x78425c4f, 0x2b5bff90, 0x272c5ffc,
	0xf8f237f8, 0xfa77fc45, 0xf3d5b6fa, 0x2e3464f9, 0x4fc83493, 0x612f599c,
	0x589d61bc, 0x6a99acd7, 0x56594504, 0xf9425841, 0xabbeab3c, 0x9dabc712,
	0xca32f5df, 0xa602dae1, 0xdb5e506a, 0xeae89070, 0xf8e0b2b9, 0x1d28d292,
	0xf606f4ea, 0x896e4bc0, 0x15887be4, 0x95549f11, 0x7d2abe00, 0x3f389d47,
	0xc5b7ddbd, 0xe3f55927, 0xa8eb1842, 0x5371e7a8, 0x94f43ba0, 0x041d7d60,
	0xa4a3732f, 0x5cdca046, 0xb07d556f, 0x86a1b93e, 0xf9e575f6, 0x76835556,
	0x888d9787, 0xb07f7ca0, 0x44711241, 0x566e1fa3, 0x83e95fea, 0x134cd176,
	0xd06ec993, 0x57dfd1aa, 0x62ad9d04, 0x58c1f681, 0xf07fc1ae, 0x5728b25d,
	0xc6abcfe6, 0x8d66b24c, 0xfc68178b, 0x6390829c, 0x918d86f6, 0xacf34c0c,
	0xae4bff06, 0x01f14d5f, 0xc687b61b, 0xfab8ac96, 0x9f6813f9, 0xe58c564c,
	0x3cb89477, 0x750fffb8, 0x74564fb4, 0xefa6f147, 0xee4a7cc1, 0x9857e6ba,
	0x823e254a, 0x371588db, 0x3f874da7, 0xba6d56cb, 0xdc1fd306, 0xcbaf97f1,
	0x7296cce7, 0x97ae7cf1, 0xcbe42cbf, 0x1cfcf905, 0x7e4e7afc, 0x93b62c69,
	0x737c169c, 0x8493f1b2, 0x37ce95f6, 0xa7ac7cf1, 0x0f202eeb, 0xc8e80dd6,
	0x713efe46, 0xfc7cc8c7, 0xf6e1b6be, 0xe5166183, 0x65c6daff, 0x6b303fb4,
	0xa4aa5326, 0xbe27f2de, 0x575f3ebf, 0xf7adc43e, 0x389c80ff, 0x8c4e4892,
	0xd987fbfd, 0xda9fa3e7, 0x8fda2eac, 0x4b447f02, 0xa5fda7a4, 0x94e40f5c,
	0x849d28da, 0xc2441e02, 0xf706f864, 0xbad6651d, 0x37d81d6d, 0x15f98163,
	0x05469bc8, 0x68728b7f, 0x406de432, 0x6e249327, 0x73370cff, 0xb3f5197d,
	0xdba5ddb8, 0xd9cfe959, 0xa298fa3b, 0x6b70d376, 0x43f40cc7, 0xc561de4e,
	0xe4ec2f93, 0xfb79fffe, 0xb2b73c76, 0x860eaedf, 0xd8518439, 0xfb3efd60,
	0xa24f3c76, 0xdb2773db, 0xe02ecec0, 0xb1ed1afa, 0xed128d59, 0x909f813b,
	0x78465ca4, 0x4571aa4b, 0xe870b6ed, 0xc06de910, 0xab9d7677, 0xfd077db7,
	0x7867ec30, 0x0564cd63, 0xdcadb5e6, 0x8f489554, 0xfa7016ef, 0xfe0bfcba,
	0x63f400df, 0x0e789e70, 0x83be664a, 0x558fdc26, 0x68be7e01, 0xc8eff07b,
	0x2286f7ce, 0x65f70d92, 0x3515e656, 0xcbb4be73, 0x2a4cfedc, 0x207dc52d,
	0x2a6e5f51, 0xf745f66a, 0xd9875885, 0xf8e7718d, 0xe7bd1973, 0x74a76665,
	0xc8478979, 0xa53d0446, 0xdbebe809, 0x94b32fd2, 0x7f79f4c4, 0x0d5f9729,
	0x674a0ea5, 0x025da079, 0xfa5b5239, 0xd7bdd9ad, 0xdbe8395e, 0xb1b7cb83,
	0xad7faa9e, 0x2c996cf5, 0x27ad4bff, 0x16bfd27d, 0x9b7f8e7e, 0xee7f01eb,
	0x35c9123f, 0x5e2fd0af, 0xa7ef3f27, 0xaf904fcb, 0xedf694cf, 0x03fea7ed,
	0xa5e7f572, 0xef8f7b7d, 0xe29539c1, 0xc5175226, 0x54a12ceb, 0x59c7fa2b,
	0xf4b8231a, 0xcbca33f3, 0xfd429768, 0x0e4c0f40, 0x031a2bca, 0x3aa73c76,
	0x186263d0, 0x546bab77, 0x256b3ca9, 0x9d822b8f, 0xbe81f618, 0x71e217ec,
	0xd7907ebe, 0xcdaabf20, 0x4237cfcc, 0xf77de31e, 0xfdb05a01, 0xed00ce3b,
	0x2baccadb, 0x0e8bf713, 0xf2a565df, 0x49f13d95, 0x8e037b56, 0x71cffa23,
	0x9f68c205, 0xc3897caf, 0xc7681def, 0x516c07bf, 0x5023b1bc, 0x99e3c396,
	0x5c8f1e36, 0x8d89cd61, 0x51840647, 0x869d91ae, 0x91fb1068, 0xd2bcbfd4,
	0x8de313bc, 0xcbb046e6, 0xd6e14787, 0x319d7cfb, 0x0bfba8ae, 0xbd5c5983,
	0x8a0617f0, 0xbe21c1f2, 0x0fd7a86f, 0x37ef1cdc, 0xf57ef2f0, 0x6793cb89,
	0x7300fd1a, 0xd3a39f88, 0x631ecdeb, 0x57417f7d, 0x8d93dc7a, 0xca837e10,
	0xb8df688a, 0xa0bb2245, 0xcb82ed0e, 0x100d76a2, 0x753fc51c, 0xc558eaba,
	0xc87082ed, 0x7d36f1c4, 0x93f20ec8, 0xbf53579c, 0xb7a07dba, 0x4ee95baf,
	0xec764d9d, 0x26de3cdd, 0x2da7e5f8, 0x0fd0ebc5, 0x9afebbd9, 0x6cfa625f,
	0x667dcdeb, 0xa95abc10, 0x9bcdbedd, 0xdebcc4ae, 0x2bd3e00f, 0xe33278f3,
	0x6f76e571, 0x2431e132, 0x033e3af2, 0x1e7f0833, 0xd3879d2b, 0x416656e9,
	0xac1ef1c6, 0x693a23aa, 0xa530f915, 0x3d7cbc47, 0xbe3c9dab, 0x1ca1f50d,
	0xcabbe76a, 0xe89b6944, 0x12feb227, 0x9fbb574e, 0x35fdb4a2, 0xcd3f6f9e,
	0xf27de0f3, 0x3895edf9, 0x7a08161d, 0xa73965bc, 0x343e7163, 0xfa2c6478,
	0xd8935ea5, 0x21d40cff, 0xed53cb1d, 0x8c37e60a, 0xfbe5e11a, 0x7bdcfc23,
	0x63d19c4f, 0xb36338a5, 0x728636eb, 0xdbd2deea, 0x47207822, 0xafe462ce,
	0xe52a59ca, 0xc601f06d, 0x43cf81f9, 0x0be90e74, 0xe8230290, 0xb3fd28dc,
	0xbc0e824a, 0x1ac7c21e, 0x1c5e6dd7, 0xdba8c364, 0x9befc2de, 0x0fea56dd,
	0x7c8e99c6, 0xf22592de, 0x55bc4f25, 0x16978317, 0xf276dde7, 0xe3cee2df,
	0x764304b7, 0xecd45f3c, 0x30fbb22b, 0xdf911675, 0xfd4ea7a2, 0x632b3e9c,
	0x171a4fb4, 0x5d3d94ff, 0xc33f744d, 0x3ac3e23d, 0xbc4376b1, 0x87a1c055,
	0xf8e3f23e, 0xc4b18be4, 0xbddfbaa7, 0xbaf9c5cb, 0xe30b1879, 0xc4b3453e,
	0xaacccaf1, 0x24abef17, 0x9ac458f9, 0x268e5bdc, 0xe2663b39, 0x1f7d643c,
	0x5cf3c045, 0xa5d9b772, 0xe7c5137a, 0x1bfbfa63, 0x815269f2, 0x1fe93f91,
	0x530937cc, 0xa93dff58, 0x3e23844f, 0xf285ec5e, 0xac6e423e, 0x655ee5f3,
	0x53db45f2, 0xdfb08317, 0x57d432d0, 0x9dd8dd3a, 0x6091cd56, 0x753cee9c,
	0x2aa21cfa, 0xfc7b9516, 0x2f37913c, 0xf4067c66, 0x2bb1788e, 0x8f87f2f1,
	0x16677fab, 0x55bf40e3, 0xc2996357, 0x5121a5fb, 0x96993a7e, 0x9bc7e31c,
	0xbafec67d, 0x6e505ef1, 0x3fc877dc, 0xdf270ece, 0x0d3b6367, 0xfe2513f1,
	0x79cd10fb, 0xf88d4ed8, 0x3f272ae1, 0xd2dcd0d7, 0x7e82625d, 0xae356e87,
	0x33e791df, 0x9d91f79c, 0xd7845f4a, 0xe9116f6a, 0x0bf3dec3, 0x72e4fa85,
	0x7a3c2180, 0xbe0e33e1, 0xf017be09, 0x166bf4e4, 0xa7ef8970, 0xdc7f7ef7,
	0x96cd0e79, 0xb26b1d70, 0xf913d8b7, 0xc6cce37d, 0xa77e2273, 0x1e09fbf1,
	0x96557d63, 0x793b2f31, 0x6857ccff, 0xe73775c7, 0x7b3b1f01, 0x7afc71f3,
	0x7e3af87b, 0x41d844bf, 0x13ee7951, 0x7077d87a, 0x7cd9c52b, 0x859ef107,
	0x2fb4055c, 0x35f914f1, 0xf92bf715, 0xbf90a07e, 0x553be26d, 0x24862fec,
	0x645fdc83, 0x7da0e715, 0x25b945bf, 0xd7195997, 0x6f072103, 0x0f32beaf,
	0x036c2ef2, 0xdda3f7f5, 0x59bb7f00, 0xd503d717, 0x24df2a26, 0x24fb8eec,
	0xd5ddca95, 0x284c2d20, 0x66bef87f, 0xb8c4d306, 0x71632bea, 0xed136adc,
	0xa2c2ae4f, 0x46b5044c, 0x2b58d9df, 0x61bbebb5, 0x27bc0ae8, 0x058377d6,
	0xd6b0486f, 0xcd6fc3ba, 0xb0f631f1, 0x73b7fea5, 0xb5b91e50, 0xf1507983,
	0x64f4e8e2, 0xdc9bbf94, 0xffc70526, 0xedfd5b89, 0xf34f985c, 0xc5ff7e14,
	0x1d8370d6, 0xef83dea7, 0x2fa4a911, 0x30565ad3, 0xada7478c, 0xfb107a1f,
	0x14ab334d, 0x66ad4e8f, 0xc0fda25a, 0x7ee48cdf, 0x90e51aea, 0x778c0e77,
	0xce9fcc3f, 0x23f58aa7, 0x9b4e905c, 0xfa204d47, 0x3e6bf6ed, 0xce6043bc,
	0x41e4b60e, 0x5c55adbb, 0xd3cd6e5f, 0x96997ff7, 0xd4f9c452, 0x901af14a,
	0x38b690a7, 0x845ce658, 0x152490cf, 0xbc3d8028, 0x22664b60, 0x7117957a,
	0xdbdf8f79, 0xebd77a8a, 0x595706e9, 0x959bea26, 0x387c4653, 0xe0f1e617,
	0xaf28db94, 0x4234fbcb, 0x71bf4c7d, 0x535dd2f1, 0xdd9bde38, 0xde6007a0,
	0x980f409b, 0x3566a011, 0xfc04eaf3, 0xaab723dd, 0xfe401eb9, 0xd699fdc5,
	0xe7f9098a, 0xab98b78b, 0xd5493eb8, 0xba9546f5, 0xf06ee302, 0x30ed047d,
	0x77cf07ec, 0x7ae1aa43, 0xb7f5245b, 0x8a725f74, 0x98f787d5, 0xd20f33ce,
	0xf8b8e61f, 0x4f8114f1, 0xa985e226, 0xda740758, 0xe4b75162, 0x532dbf41,
	0x2876ea4c, 0x945d54da, 0xad28ff70, 0x1cfbf39a, 0x1250ea8b, 0x313737d4,
	0xedd8f73a, 0x7d9b8f57, 0xd39f99e7, 0x2351af38, 0x0e9bfef9, 0x731edd07,
	0x456c7557, 0x26734bba, 0x4249b9d1, 0x8547ca1a, 0xd6f40b7f, 0x2f596882,
	0x5945fdf1, 0x726d8bec, 0x7f213d01, 0xbe74acba, 0xdca7d4d1, 0xc83c3e77,
	0x1317a0d5, 0x7eddcdc4, 0x9ff0df21, 0xffe0276e, 0x17a0cc69, 0xd20ef5e5,
	0xdef9e76f, 0x21f5d667, 0xcccd152c, 0x59ccfed8, 0xea3dfe26, 0x99b7c441,
	0xbd45ac85, 0x2657ebfb, 0x0cb4f7e9, 0xe82acbdf, 0x7f5a64d7, 0xe009f908,
	0x4278fc42, 0x10967802, 0xb5fbf0bd, 0xb979716f, 0x1617db29, 0x9f4840f7,
	0xdcaff15b, 0xfb75e3de, 0x157cf95b, 0xc89fdd16, 0xf5f5e689, 0x7e71243f,
	0x68ca5d09, 0x68fdde9c, 0x9de57fa4, 0xcecfea61, 0xd0e98e7c, 0x4da83ece,
	0x5bd39b9d, 0xdbfb76ff, 0xbc012e5a, 0xa9ea7bad, 0xda9079b6, 0x0fbecc7d,
	0xeecf71e0, 0xc53e1f1d, 0x666ff77a, 0xdf813f9c, 0x429b1d69, 0x0e51f29b,
	0xf0fbae39, 0x69833c51, 0x4127db8d, 0xb2bfa004, 0x82d83ab6, 0xdfdf1a74,
	0xabdc96a6, 0x9deb8ccc, 0x1cfbe20c, 0x40f2cb92, 0xd20f7a9f, 0x97fb9da1,
	0x46129a72, 0x1d569e79, 0x641eb854, 0x4d970879, 0x6af64502, 0xc09fe916,
	0x752f5abe, 0xe23df03c, 0x08f74663, 0xe279f7e3, 0x239ffbe7, 0xb4f784dd,
	0x07da2eaa, 0x0bd7f6e9, 0x23af817b, 0xbfe39e9e, 0x77d804f7, 0x356ddee9,
	0xcfbaafdf, 0x78c5e5d2, 0x82f77df0, 0xe76b169f, 0xece1c1c4, 0x6f5cbe88,
	0x473a3354, 0x11ccff7c, 0xbab7bc0e, 0xe1c8aaa9, 0xac764613, 0x7aa9bdbd,
	0x17dbb736, 0xec1bbb71, 0xe0ffba25, 0x8f7d06ac, 0xff611271, 0xe23189a7,
	0xa0a6fff5, 0xfdc3d7e8, 0xd7e7163f, 0x73ffb05c, 0x95b613d8, 0x3a7744a5,
	0xb71daf3d, 0x82f51325, 0xb35beebe, 0xa0e7b36f, 0x626498bc, 0x9376ff78,
	0x1eb4d738, 0x1c8effe4, 0xd7a0ff94, 0xe9ea0e88, 0x7726e79e, 0x8f41d11e,
	0xca7299be, 0xa4d9788b, 0x7a8ad88e, 0x5ceafef5, 0xfefa4e07, 0xa2d7bbaa,
	0x341d5d5c, 0x8f4c58f1, 0x3d2e735d, 0x77cefaa8, 0xebffe65f, 0xff4c7fbf,
	0x0a667ae9, 0xba06be1e, 0x62a475b8, 0x8d115738, 0xdf84041b, 0x27bf09af,
	0xaff37e3e, 0x3fc69e91, 0x395d0ec1, 0xacba302a, 0x5bef1a34, 0xfa1a5793,
	0xb5fdc31e, 0xc0377ea9, 0xd187927b, 0xa78b1b7d, 0xda2fb0cb, 0x03b6a591,
	0x2f2bb119, 0xbe7ed5bd, 0x2cb66af3, 0x60748e96, 0x4ca807db, 0x35bb7739,
	0xae28a7d9, 0xb7bddefa, 0x6e3cf9db, 0xf6f3b3b5, 0x76c1eadb, 0xbdea59ef,
	0x4d630e78, 0x77da08f6, 0x17f9066d, 0x92bf1271, 0x3479b0f0, 0x8d6a2d4a,
	0xc2dbf919, 0xdd4cbef8, 0xa9cd5baa, 0xb9f10718, 0x9cd35f69, 0xe44b3015,
	0x18672cbf, 0x09e49a8f, 0xcfa01405, 0xadf09ec9, 0x6be26d0a, 0x91e28e3c,
	0x93ffc84c, 0xe56fcccd, 0x96378cfb, 0xf2ad1d01, 0x1d63bbbc, 0x06706bc2,
	0xe1d3779d, 0xb6eb5169, 0x6e3463af, 0x1031f504, 0x1b49e925, 0x165e3fee,
	0xcfd47fdd, 0x90fbe84f, 0x8972ca5b, 0xc3aca53e, 0x1bbca39f, 0x969874ae,
	0x2c927c03, 0x07c8751d, 0x71801a6b, 0x64d60f80, 0xc0ab3f71, 0xe8f5cfc5,
	0x596c99f7, 0xd075e981, 0x3b0ee92e, 0xefe007cd, 0x71a25254, 0x17b04cbb,
	0xe558ded0, 0x11d4a1d9, 0xd6f36efc, 0x7a27d025, 0x582b3c3a, 0x7018708d,
	0xd1f90367, 0x0cf523b6, 0x2b2d95e5, 0x8afb5178, 0xf11f1816, 0x31b2736f,
	0x5583a3e7, 0x89e9d6d9, 0x613691fc, 0x83470cff, 0x877fd705, 0x6bb9e29d,
	0x56f9dff6, 0x3f74495d, 0xb7332816, 0x3ee8d2e6, 0x336e7eac, 0xb3de8e3e,
	0x39f8caaf, 0xbeae3d3b, 0x4573025a, 0x76faf8a6, 0x2a6f8be4, 0x88c6febe,
	0x12cb8fe0, 0x5b59d7c4, 0x0fed45da, 0xd3368d24, 0xb90189b9, 0xffbb182c,
	0x65c051b8, 0xea7c0f63, 0xc16fbf49, 0xe7a526cb, 0x3fd44f86, 0xc0dc6756,
	0x1f22dfe3, 0x8cbaf8a6, 0xc5064037, 0xba1de1fa, 0x0fcbd47c, 0x0767b8f2,
	0xc8f62b8f, 0x330adf4f, 0x7243c7f7, 0xb7f96c4e, 0xa55d4f2b, 0x09be1c25,
	0xa697bbee, 0x3fd10913, 0x8a3cf54f, 0xaf3b37b3, 0xa7ef6256, 0x7924f1eb,
	0x23773f3e, 0xf1104f57, 0x31498973, 0x602d347a, 0x55c933d4, 0x73af7cc6,
	0xf6fa713a, 0xcf872141, 0xecfb8994, 0x2f88d823, 0xa7e4e0f9, 0x1d738b25,
	0x0eb951ae, 0x72aac3b2, 0x0919bce9, 0x49ba1889, 0xf79df2ad, 0xe101da9e,
	0xdc4cfd9f, 0xfb888cbb, 0xfdc4878c, 0xfef097b5, 0x0ec610da, 0x7a53e537,
	0xf2a549a4, 0x84ca9b57, 0xc4321093, 0x9f022c67, 0xb85b9296, 0x6be6209f,
	0xbc05f316, 0x3a788b27, 0xa55c4bdd, 0x1ac1b8f0, 0x17413fe0, 0xd73f1e11,
	0xabfa73a6, 0xddf316bf, 0x47f72a59, 0xd397bd58, 0xb795ab61, 0x71361d0f,
	0xb88ab53a, 0x8fbc424a, 0xf7b78aee, 0xcfd8f979, 0x93ee1392, 0xfbf8b054,
	0xbc7cbc5b, 0x7ec2607d, 0x09a1952a, 0x5ef44fdb, 0x24fdb096, 0xe584c8df,
	0x4d8fe657, 0xf705cfd8, 0x7b5a428f, 0xbdf47a7e, 0x2ef29e86, 0xbbbe0ff8,
	0x5cedd041, 0xd3379f85, 0xbb886feb, 0xf9d3a5df, 0x6e7eb8c2, 0xb76c6adc,
	0xbfb8cb30, 0x7eee20b5, 0xc26542dc, 0x2ce3b107, 0xd7ac65dc, 0x8f2693f7,
	0x923df412, 0xfb2afc8d, 0xba3e7aa2, 0xe9d0134f, 0x29f78f4b, 0x46611f3c,
	0xc5c4a539, 0xd7913501, 0x7974f7f7, 0x3ef89117, 0xb3c8974c, 0x24af5e54,
	0x2a967909, 0xe8ae64e4, 0xf7f448af, 0x1f3e3cd3, 0x6b91d7d3, 0x53f277a8,
	0x457ef98d, 0xb11cfcd1, 0x5ae502ff, 0xe03b4c5a, 0xed8bcd56, 0x2ef7f3d6,
	0xac6cdeb0, 0x7a130d0f, 0x8e5312cd, 0x5247395b, 0x5a33bbf9, 0x8d27ef11,
	0xc8588bb7, 0xe377690f, 0x9fd5903a, 0x53ede22b, 0x22d0bb78, 0xf498579a,
	0x1c378e09, 0x21aaf5f3, 0x5e20adde, 0xc4a57be0, 0x03cac523, 0x4533888b,
	0xba11d2f1, 0xead6d60c, 0x2360f2e1, 0xe30903ca, 0x762c4525, 0xb7df591f,
	0xa2abf6eb, 0x19b8a95c, 0x9f9c7ff8, 0x8b76f091, 0xb88c2bf8, 0xca8fef02,
	0xae171e7e, 0x1bfa4660, 0xf0314f6f, 0xe462a559, 0x235e89f7, 0x19f24f9f,
	0xd7e41bf9, 0x3f61b32c, 0x90b37db0, 0xbe14e647, 0xc94fe80f, 0xbff8eaf9,
	0xbe657a50, 0xbd009e51, 0xd671c4ae, 0xd8a8c160, 0xda0b11f6, 0x9e6e8857,
	0x2f26cc46, 0xf2998ff1, 0xec341feb, 0x92ab5573, 0x6edee303, 0x1cd2fc0d,
	0x3b5aafda, 0x99619508, 0x40fb2149, 0xc413e9f8, 0xef016ed8, 0xc91d4ac3,
	0x98bb7bed, 0x8d90f184, 0xc2ba8b1e, 0xbb6fd007, 0xf5e50b3a, 0x33aa49c4,
	0x5955f005, 0xfa9ebf54, 0xcfb233f5, 0x9f6e355b, 0x7bf2746e, 0x3cc68a2b,
	0xec3d2073, 0xa8ce2995, 0x9f497d49, 0x27aafdb9, 0xfde88fd6, 0xbddf4a9d,
	0xfb20ea5e, 0x32abbc70, 0x7351dfa1, 0x6e418e79, 0xf5209598, 0x92ab0bfb,
	0xc6d17689, 0x820adbca, 0xb14ba694, 0xa4b3bbdf, 0x1eb5e784, 0x7446dcbc,
	0xffa9695f, 0xdb8051f3, 0xe289bf06, 0xe3fc1bd4, 0xabe60b24, 0xddc5c519,
	0xd20f8325, 0xee820a3b, 0x69f74165, 0x3e238efe, 0x9996638c, 0x9776ac54,
	0xb7027df1, 0xf9e127df, 0x6e2aeee4, 0xe4b3b84b, 0xf7ac3515, 0x46d5a9f8,
	0x4b51b67d, 0xc7efee7c, 0xdd685b97, 0x525db21b, 0x52cfce1e, 0xe5c50b7f,
	0xf1ec5db2, 0x74bce89c, 0x6b0bfcfd, 0x23c2017d, 0xb848acd9, 0xf3f7e91f,
	0x2b32eef6, 0x06e76bbd, 0x92bcc436, 0x803b0ae5, 0xae6427fe, 0xb7778862,
	0x7f408d8f, 0xb2b5a1c2, 0x07880539, 0xfc5e218b, 0xa4ea7f0b, 0x2adda06b,
	0xaca78f27, 0xe10aac62, 0xa54b587a, 0x3b4f4ef8, 0x389bfb4f, 0xd1d9d929,
	0xc2017667, 0xf4e4e823, 0xa9784a92, 0x9d6c77f6, 0x6b57e303, 0x7b45de8c,
	0x95066fb9, 0x6607f78f, 0x363d3cd2, 0xbe749e7d, 0x6669afd6, 0xf654738c,
	0xfef79cb5, 0x4a92ab43, 0x7f46d476, 0x7e8894aa, 0x86edb8f4, 0x1dbce951,
	0x0fd63bcc, 0xf88cf875, 0x973cbf28, 0xf28ec3e8, 0xfed6e301, 0xebdbd100,
	0xc6154096, 0xb52f5e95, 0x5ebcbd10, 0xce3fe7ca, 0x5af9d0af, 0x525b9977,
	0xe42fbaf8, 0xbf979d3f, 0x858eb5cb, 0xcff28f08, 0x81a35092, 0x632ede9f,
	0x067f67fe, 0x55f8c2ba, 0xb9ef5f35, 0xebfb77fa, 0xb0f51f69, 0x3c212d37,
	0x810cfc7a, 0x87f2f8c7, 0x87fe172e, 0xdf1965f3, 0x24f90c2d, 0xfedc33f2,
	0x4029f1f6, 0xd707e307, 0xaf20bbd0, 0x4cd47e97, 0xfd78c3f5, 0xbbadd778,
	0xb35a9e91, 0x77d8b0fa, 0xadf4f4d3, 0x3dae1c51, 0x7ce345fa, 0x49afe63c,
	0xba368f24, 0x0729614c, 0xee066553, 0x1d4a851f, 0x58dd4f14, 0x24235569,
	0xb8d1e69f, 0xf4c2678a, 0xc97d201b, 0x9aa3f7cf, 0x6f49b303, 0x5750d78c,
	0xa69cffc1, 0xcc8f48c7, 0xcf72499f, 0x66aeec2d, 0xd70738e7, 0xac7b4663,
	0xc4745fd5, 0xd6b5df07, 0xcdac549b, 0xe7738d72, 0x5fb87a11, 0x76f19031,
	0x95fd8503, 0x9e8567fc, 0x8c6acc99, 0x68d727df, 0x972154bc, 0x0ae165dd,
	0x84335174, 0x6f9ee2bd, 0x8f54b3a4, 0x99e1876e, 0xe257687d, 0xf8e30c78,
	0x7ec6999e, 0xa7ee1553, 0x3b8dcbc4, 0x5fec4f2f, 0xd759fae8, 0x3625adc7,
	0x1f3af392, 0x2e70fcea, 0x47dfd0ba, 0x17f84379, 0xf890ad01, 0x2ff098ef,
	0xa5ef14de, 0xc5fe171c, 0x57f792a6, 0x9fdea1a6, 0xf39f68c9, 0xfc6fe12d,
	0xbf1bf84e, 0x08637f47, 0x20ed11ca, 0x2bafc5ca, 0x25463bb7, 0xfb965d11,
	0x18478e8e, 0xea3fc98f, 0x144bb58c, 0x30aaafdd, 0x97a41599, 0x89954906,
	0x152bbb6e, 0xa959d414, 0xed050464, 0x12b0c3ee, 0x567c43b0, 0x9e95a437,
	0x3e226b42, 0x87fae089, 0x17653fa0, 0xf857947e, 0xafdd7c51, 0x24be758a,
	0xedd0e7de, 0x15d7905b, 0xc1ba5fb8, 0xa727bc62, 0x2cf951a7, 0x779086e4,
	0x199bb213, 0x208d8fea, 0xc792258f, 0xb23b5e5c, 0xea9ec98a, 0x7f9ce7cd,
	0x9e005836, 0x92cf0405, 0x19cff284, 0xf00902d0, 0x79cbbbfd, 0x238374fc,
	0xc0197330, 0x2325436b, 0xc85e36b9, 0xdd179869, 0xf56b71b3, 0x14cf908b,
	0x1bd46be0, 0x1d302d7e, 0x2cfe0fe3, 0x2e8bf117, 0x9e9c599f, 0x9da725ec,
	0xffdf14a9, 0xddb4e4a6, 0x9c21aad3, 0xc399f2a2, 0xed33e40b, 0xf25b7fef,
	0xe3e33479, 0x14ccfe8e, 0xf5f6ff46, 0xe0af51d2, 0xb7215f3b, 0xbbec1d49,
	0x2b341cb0, 0x5cd75e5c, 0x2a7e88ce, 0xca3e6765, 0x24a59bd1, 0xbe18e515,
	0xbff08761, 0x6e7e06f9, 0x77f0bfa1, 0x36dee2bc, 0xed03ac70, 0xe05dd1f6,
	0x8dc8c623, 0xd9d99fb1, 0x557818dc, 0x3f21b730, 0x68699ede, 0x18e4a95f,
	0x877a27ea, 0xf927ea19, 0x2bf90d0a, 0xda1947f3, 0x0c2b514f, 0x26caabf9,
	0x68d7da19, 0xc6bc8635, 0xf4ff7a14, 0x41aed340, 0x1c60b07f, 0x1fd06da3,
	0x5786f706, 0xd3d0edb9, 0xdcb4a03e, 0xdebbefe7, 0x9e5bfc0c, 0x1ce6e872,
	0xfcf25fc8, 0x60cdebe6, 0x3ff79737, 0xb00e49f4, 0x0ff3c160, 0x1ceffaf0,
	0xf21724fa, 0xc2df9fc3, 0xc180afeb, 0xfd7581fa, 0x87d783fc, 0xcc7fce00,
	0x015e1609, 0xb3f6be70, 0x8e5197fa, 0xd5c57aff, 0xf8c8e437, 0x764d5dfe,
	0x97e7cc3e, 0x5821c139, 0xf67d2d3f, 0xfd8014aa, 0xe9ea2fd8, 0xaf77e19e,
	0x9e75dfe0, 0x767aefe5, 0x78efe59e, 0xc44231e2, 0x314dd7db, 0x68fa8a9e,
	0x39cd071c, 0x34957ddf, 0xc6007efe, 0xe60ee67d, 0x314c1f71, 0xc62983ee,
	0xb8c5307d, 0x8f0b5ccf, 0x718a60fb, 0xb8c72c1f, 0x35afa60f, 0xd1be9469,
	0x7b694554, 0x9ed28053, 0xa84fc97b, 0xc899162d, 0x45c56bfd, 0xaad0e57f,
	0x0973a0af, 0x9dd373c6, 0x901fae96, 0x7ccb3ebe, 0xeb80bef4, 0x96fd0fb8,
	0xd13b52e6, 0xeed5d4b9, 0x797d43b3, 0x9f37cf09, 0x3ca1f76d, 0x53ee3cc4,
	0x0adbba77, 0x2f37ae51, 0x4f78aa76, 0x246cf9bb, 0xbca4f913, 0x79e2aade,
	0x57577f14, 0xd3a5f12d, 0xf23b43ea, 0x8bf0eba0, 0xaf3a3c62, 0xa32cf3bc,
	0x1d3ae9f7, 0x8c453eed, 0xb8c0fd83, 0xcb7fa839, 0xbbd3b16f, 0xeb67cd7a,
	0x333f5197, 0x4ae33d9d, 0xcfdae371, 0x2978ee3f, 0x6ebcdc66, 0x1f387718,
	0x371867d7, 0x42b9e322, 0x39464fe8, 0xbd56e9d7, 0xbcf5a728, 0xff21eb1f,
	0x1c8585a0, 0x22f7a8a9, 0x3c4dea32, 0xd70765b6, 0xa1c4033a, 0x308d8c83,
	0x476813c9, 0xbb3b04fb, 0x34cf3af9, 0x7e426e45, 0x68778bf2, 0xaefe56fd,
	0xa9253302, 0x29515fb8, 0x3fb8717f, 0x97ef97e4, 0xfbce510a, 0xc86d816d,
	0x5ccc4b8f, 0x838f30de, 0xe665d7de, 0x823f05f6, 0xfbd2c776, 0x5620f7ab,
	0xbcb2cfbd, 0x697ef862, 0x89fa0155, 0x13bcf0c7, 0x3936777c, 0xe3f901b8,
	0x3d7a829a, 0x78fd405e, 0x40ecfaab, 0x85f3be3f, 0x47c8a5a1, 0xcf7cdb57,
	0x1ec58780, 0xe255fe78, 0x7c53abcf, 0xf98292a5, 0xabdfe276, 0xe0cf7c33,
	0xf4252c11, 0xccfef5ea, 0x405ee07f, 0x7b4664b5, 0x8a98916c, 0x8edc14d7,
	0xf55c5bf3, 0xafcf95b1, 0xf6fe8acb, 0x08f85713, 0x310f7d7e, 0x6bb9877a,
	0x03bc2b92, 0x56919be6, 0x33fb885f, 0xef47c0ac, 0x74b00e5f, 0x3bfc2325,
	0x2defe0bf, 0xa9e4cb40, 0x3f2bfb31, 0x7c272038, 0x39416187, 0xe697a7b7,
	0x1e23d739, 0x76ed7896, 0x9d9c0f4a, 0xe6e19b40, 0x479e1e40, 0x566cacd5,
	0x5d7d3d22, 0x39d3d739, 0xc724adab, 0x94c27448, 0xe7a624b5, 0xd2f40c43,
	0xe0a0dbf6, 0xe00f5e72, 0x26c1d664, 0xa8f33f91, 0xaf686cdf, 0x3d68fb61,
	0xfa7c10d3, 0xe2b9bff7, 0xe65747dd, 0x5e90f189, 0xde30b1e6, 0x3bd78d7f,
	0xa353a3b9, 0xcf0057e7, 0xdb1c7a8f, 0x3279cf11, 0x9481a7df, 0xd35fb829,
	0xfa83c607, 0x84773ffe, 0x769e819b, 0xe73d383a, 0xd3ba7899, 0x935bdbc4,
	0xfa97bbf8, 0xa315ed7b, 0x4bcb6783, 0xf5089fa9, 0xac29ef23, 0xdb6a2277,
	0x7e3c79c4, 0x976f500e, 0x84907a05, 0x086bb995, 0x365cabe2, 0x8ae78425,
	0xa2bf8af2, 0x14d33a7c, 0xe8c7ef62, 0x927d339b, 0xb7f1621b, 0xc677bf04,
	0xbe8e377e, 0xdc5fbfd3, 0x4fbd9e30, 0xa211069b, 0x2679c5a3, 0x25f8fd0d,
	0xa2497b32, 0xbd3b5af8, 0x777fa5c3, 0x8e2de41c, 0x5fc826f7, 0xb902df4c,
	0xed05befb, 0xfe94e9e4, 0xe54829be, 0x53e69a27, 0x4f54d1da, 0x3536efe5,
	0x75ed7a50, 0x9fe412ae, 0xb056fba5, 0x7de863f7, 0xd8259b71, 0x5e3f9311,
	0x728e9891, 0x5f008e90, 0xd71273c7, 0x8fd7ae5f, 0xbcecf8e1, 0x00979f81,
	0xa4a95cba, 0xe8eedb9e, 0xcc41ef14, 0xd3a224d4, 0xef9e4cce, 0xbca16e5f,
	0xf15b6266, 0x4f7899fb, 0x35cffb1a, 0x2d7ac7cd, 0x7c7bf795, 0xb1de8988,
	0x322bf936, 0x3a5a8f11, 0xf3451794, 0xf5e12fc7, 0xae5e3f5a, 0x3faf57cf,
	0x73f0ae5b, 0x9def0270, 0xa0165de2, 0x6f5fea77, 0x3e38e0ff, 0xe1f6f8bf,
	0x97f1c4bc, 0x4b7c137f, 0xe8fe817c, 0xa57f7e3c, 0xf8962f87, 0x3a742f88,
	0x772fe9d4, 0x3cd7e734, 0x3ef3a09b, 0x7f6afefc, 0x5df085d4, 0xed070cff,
	0x345c0257, 0x29de1fdc, 0xe7897e09, 0xce514807, 0xf3a0fceb, 0xfdef4e81,
	0x6a6c20f1, 0xe3a31d74, 0xc74f55e8, 0xb775f397, 0x256ebba7, 0x28b01ebc,
	0x6346b7a8, 0x65e71ca0, 0x3ae37eea, 0x9774cfe4, 0x95fb630f, 0x89f59c6b,
	0xfaffd8e4, 0xcba1e147, 0xa3c07385, 0x3cac1c17, 0x2070aafd, 0x1c728739,
	0xdc8137e9, 0xcbae5f9a, 0x2bbf4e2d, 0xd8d9b5ca, 0x30e4a74f, 0xe9df63a3,
	0xc8aefc48, 0x43af8d4c, 0x345ca3a7, 0xff62fbfc, 0x38ce74ed, 0xebe9ee5e,
	0x8de759e9, 0x5e5fe48c, 0xc78f2f12, 0x18aebeb3, 0xde50d7f9, 0xc64f0a37,
	0x7e81fec0, 0xe93916b2, 0x72d9c8fe, 0xfb3ab7ae, 0x91bb507e, 0x632fd745,
	0x88f77c39, 0xd07a2649, 0xb94f4bf5, 0x29aacf24, 0x861de830, 0x0bd750f6,
	0x88f7e236, 0x29ffcd89, 0xf638f77c, 0xf39fb319, 0xdd43d0ac, 0x784d4bd3,
	0x5fcce1be, 0xd23ef49c, 0x275d7e99, 0xb339ded0, 0x17e742d5, 0x04943ef0,
	0xf406f77a, 0xd3c8609d, 0x81833fe8, 0xa7f447f1, 0xb6bb4287, 0xded027b3,
	0x4c90fa5a, 0x87e4ef47, 0xe916bd3e, 0x160bde69, 0xadafec85, 0x3d208e9b,
	0xf92bda9e, 0xb3392ed0, 0xed0f9617, 0x71166f17, 0xfb63c84b, 0x61c9771b,
	0x19d5c49f, 0xde3179e9, 0xb9258efb, 0x7f8f9768, 0xc23356e8, 0x8976de7d,
	0x17bfb9e1, 0x387cdeb7, 0xb6a7f213, 0x9a2077f1, 0x703bc91d, 0xf5e413fe,
	0x7e507ed6, 0xbe5e76d3, 0x23e139c8, 0xd3719f3c, 0x4ee28c93, 0x9171ed37,
	0xb36f3c5f, 0x188edde5, 0x36fe63bb, 0x6b017e63, 0x6f4977a3, 0x5f2c69da,
	0x31f21bb4, 0xb94f79f2, 0x8c3587b8, 0x66dc5215, 0xe84b8f33, 0x7db7bdf2,
	0x69bc221d, 0x66dcb9cb, 0xf4e9cfec, 0x7c2f0bfb, 0x275de03a, 0xfc88d7cf,
	0xf8ff903b, 0x1d178e53, 0xd8c44b2e, 0x92b2671f, 0x92e75836, 0xfe0a1c17,
	0xfd92c28e, 0xc03325ef, 0x8ea4d2ff, 0x3eff12ef, 0xef682b27, 0x8727ddad,
	0x0f8bbe10, 0xf3c31e38, 0x399e4b00, 0xc4f8a56a, 0xaf6465de, 0xd5a1644c,
	0x4c4747e8, 0x744ed626, 0x3b256ed4, 0x879aeb46, 0xefd99cfd, 0x580ed050,
	0x0e6fdcf2, 0x67f9875f, 0x8eef8624, 0x20eec99e, 0x10f7993a, 0x7fc7e09d,
	0xaeefb8d5, 0x788c89d3, 0xa5b73c45, 0x46ef3c50, 0x19e23bc4, 0x0af78ef0,
	0x842c87e5, 0xca4f79f7, 0xb5bcdf54, 0x4fed8ad9, 0x757e3985, 0x1b904fbc,
	0x3d37cf09, 0xfe39f1ca, 0xe0b7c7a1, 0x9ef3c23b, 0xfe3d90b4, 0x8fd77c22,
	0x03a0677f, 0xffbc0beb, 0xf7f38f33, 0x60e87b2a, 0x0e87adbf, 0xa2179e70,
	0xd253e003, 0x83a217fb, 0xef8ce535, 0x9c5fc843, 0x70ed047a, 0x2de29597,
	0xe846effa, 0x77d113bf, 0xf197f1e1, 0xdec1e17d, 0xaeeec9a7, 0xe2d3fd4d,
	0x9f7e8c65, 0xb728afe4, 0x7d7a4c4e, 0xd8efa215, 0xd2171fe4, 0xc74b0d3d,
	0xfc520fe3, 0x3c8a8fa1, 0xb35399dc, 0xc39f7f0d, 0x80f9fa9f, 0xa58eb03d,
	0x7429b33f, 0xa9b470e6, 0x73c37ec7, 0xc7198b9f, 0xce9de003, 0x603e2e63,
	0xf63af7e3, 0x7eb16a56, 0xa7266768, 0x576b4af3, 0x188dc62d, 0x48e387f4,
	0x174ff71a, 0xdfbfe01e, 0x0b93fba0, 0xd871dff5, 0x4f1f7c6d, 0x76a75e52,
	0x1e3cd1be, 0xb4632832, 0xe6f2ed0f, 0x34982c19, 0x82fa7ce8, 0x5479f79f,
	0xb4e745f8, 0x37a1cf27, 0x85923b74, 0x12c1dee2, 0x1e46eb72, 0xdf2f61fb,
	0xe319aaf6, 0x253b9d9a, 0x0382cbc2, 0xb83caf20, 0xc8316e5f, 0xfda2259d,
	0xc97f4807, 0xfd6ecef8, 0x563926b3, 0x8fdefcbe, 0x927a2cfd, 0xe904b3f7,
	0x91bee28a, 0xdfd0492d, 0xed0b36e9, 0x84c4de73, 0x52e7d9bc, 0x2f581ef1,
	0xfb73b2f9, 0xe3df346a, 0xd8216ae9, 0x7888b899, 0xd7b25afa, 0xdd1b4ed8,
	0xc52e7723, 0x8d579ffb, 0x40fee267, 0x0a9dc448, 0xecdfd052, 0xe414be66,
	0x287d1eef, 0x4398e319, 0xc7cb02b7, 0x6c2c3bf4, 0x22507be7, 0x8a5d9dff,
	0x9b697f21, 0xb2fed0d7, 0x7d433e7d, 0x50df2461, 0x35447c5f, 0xcbdb4be4,
	0xbe47ed0c, 0xa3f219a5, 0xed0caa3a, 0x6030f8af, 0xc01777c8, 0x0fb3ce7a,
	0x192bd132, 0x39f24fda, 0x995ffd0c, 0xbbe436ef, 0xc23e029d, 0xdfedd4ce,
	0x7db9a325, 0xf0ea9f14, 0xc71aa29d, 0xabf6fdd1, 0xd5e38cca, 0x2ef1c668,
	0x8ef82f16, 0xd84419bb, 0x98b7d02e, 0x7804d53e, 0x77623f00, 0x3ff29793,
	0xda51f269, 0xe54f94d6, 0x29526d3f, 0x8ca9b7bf, 0x5f82cff2, 0xe07df982,
	0x1cfa60a7, 0x7e5827f8, 0x161df821, 0xe3111ee3, 0xfdc62abe, 0x4d7a70ba,
	0xe886f7f4, 0xc793df0f, 0x5c5faf54, 0x0cfa6a55, 0x8fd4bfed, 0xd13f18ac,
	0xc04c7796, 0x2bd74638, 0x7c01db32, 0x23e182c3, 0x6fd41e4d, 0x8c0f7469,
	0x697eba05, 0x8333fcc2, 0xb9e73c14, 0xdeafdf76, 0x7b33fac0, 0x1cd78a65,
	0x325ef7da, 0xb3fa73f6, 0x4b71b43e, 0x8bf2117a, 0x7f28973e, 0x3ee3d40f,
	0xb23da4e7, 0x8dbb1f78, 0x3ce9ddf4, 0xe2b61f3d, 0xf760653e, 0x7bff7a1e,
	0x543daee1, 0xb5f00aff, 0x76d77ea1, 0xed82bd43, 0x0e685d21, 0x8fe15c53,
	0x22fef4fb, 0x9e517ed4, 0xfeb8f744, 0xd5c5ebb8, 0xde3ea057, 0xfb869753,
	0x1f770b5f, 0x1e739f4d, 0xecfc7c7c, 0x0f500b8f, 0x8b2fde2c, 0xbfbcb373,
	0x222dfbc5, 0x28bfe7cf, 0x5484cf6f, 0x25bb1c54, 0x9a7ebbba, 0xd5b9d2b5,
	0x5f1efb85, 0x61767284, 0x8a1675fe, 0x22c9b57f, 0x5fdfc1de, 0x6e30a45b,
	0x927db5d7, 0x3fc5fb8c, 0xbbf97b6f, 0xc0f7e21a, 0xa0af748b, 0xf06caf73,
	0xcd1cdea7, 0x4737e5ed, 0xf4efff73, 0xf19317de, 0xb6daf07e, 0xcddc3917,
	0x21ff5a11, 0x9484ef91, 0xa64fbde0, 0x4cf82ff5, 0xfde83c26, 0x05c7049d,
	0x6fb49bfb, 0x75d70bb0, 0xf78f8dac, 0x7a0fa811, 0x6eaf2847, 0x55ffce2e,
	0x99528cef, 0xfbd393ef, 0x5c979de4, 0xd9ca38f9, 0x96b26d85, 0xabfbdfc8,
	0xd8b0f7e8, 0xef2579b7, 0x00fdc3e9, 0xa556afee, 0xf79ec615, 0x33f844ff,
	0x3cc1ac13, 0x9cc723d4, 0x9c3dfa3e, 0xb906abbb, 0x3087bf10, 0xc7aaf2c5,
	0xa6e95f68, 0x63bc7cbd, 0xd2327b4a, 0xc5bdb1dd, 0x3f662872, 0x371c63e7,
	0x78a3fe86, 0xe69e110b, 0x3ed3b787, 0xbc7f147a, 0x0ad1a3fc, 0x7c357fb5,
	0xb3b45af4, 0x21f7e58e, 0x95b0e4fb, 0x70bd7f91, 0x8f93b737, 0x3dbfe81d,
	0x23f63f76, 0xf99d6fc1, 0x99c61cfc, 0xeed1167d, 0xa199c7ba, 0x4fdff71d,
	0x47ce34ef, 0x01b3bf09, 0x8f45f3ed, 0xe156f4ca, 0x3a7d4b22, 0x6d83ffae,
	0x17cdf9c6, 0x89645e70, 0xd0c7a7a4, 0x3dfda2eb, 0x3a24e37c, 0x89f3afdf,
	0xe3a9f08f, 0xccbe58f1, 0xd1b5e5e7, 0x7b45c37d, 0xeeba271e, 0xf1e25f1d,
	0xdbb7fedb, 0x5d2f8a55, 0xedd69fc0, 0x8b7f1886, 0xa968ffa1, 0xf78a541a,
	0xe0fb7587, 0xe0dad1d6, 0x0fd17d31, 0x799f900b, 0x0b7d818c, 0xfb462e63,
	0xf2e5053a, 0xb8e0b7ef, 0x742d7bdd, 0x7db1616e, 0x007f4dff, 0x8156ed3a,
	0xddde6051, 0x143ef8db, 0x9da323ee, 0xb9d84f3b, 0x2382f81f, 0xc5835df0,
	0xbeb44c2b, 0xb0e5bb45, 0x51e30723, 0xbc7dee5c, 0xa42ae727, 0x644745d7,
	0xf1a3fd05, 0x95f7396d, 0x277e9097, 0x1b49757b, 0xec9793b7, 0xd62ec892,
	0xc2c590ed, 0xec25390e, 0xba2b53e0, 0x82fc7db8, 0xbb4136c4, 0x8f604975,
	0x1717bcc0, 0x76bb264c, 0x757ebcb1, 0x0f9e1f7f, 0x0b0dda34, 0x77a41c0e,
	0x31cec040, 0x65dc2f94, 0x336e2fcc, 0x717f75e6, 0x2fb118ca, 0x430d8c3d,
	0x2e52a6ff, 0x987e40cf, 0x55e3863d, 0xbe6e77f7, 0xbe40cd54, 0x4df66b5f,
	0x0812e3d6, 0x3c2fa5af, 0x1de700bd, 0x92a4945e, 0x3cf0d1ff, 0xcff3b5c1,
	0xc4e9afdc, 0x67e438bd, 0xb9dbe1c6, 0x52f9d38f, 0x8bc6148b, 0x57514bb2,
	0x29767f60, 0xcee302bc, 0x9264eea1, 0xc3bce24f, 0x7fdc19f2, 0xed1e7745,
	0x4463a1c2, 0xaf4e2adc, 0xc877318e, 0x713918ee, 0x9a5c98fb, 0xcfcadfbf,
	0x52ecdf6b, 0xb40dbf49, 0xa07d7b73, 0x03ebdb9d, 0xe82b5dcd, 0x49fb24f7,
	0xf8639f7c, 0xb07fb473, 0xf693896e, 0x9d6f2417, 0xaeb1e119, 0x6f9d1d5f,
	0xe5b4a819, 0xe7a75fa3, 0x105f58fd, 0x38260fb5, 0x671c6683, 0xf624a667,
	0xad3eb811, 0x77162b31, 0x6c657e8c, 0xe7d7b505, 0xf1bfbfa7, 0x029f9f4f,
	0xe74673f3, 0xc14ef807, 0x51293fef, 0x50186ec9, 0xe49c3a03, 0x7635bd42,
	0xd034f73f, 0x45701fbb, 0xdd022b6f, 0x9076da2c, 0xacc5cbfc, 0x377e357d,
	0x63af9921, 0x5fbf9582, 0xa789213a, 0xf2e18c8f, 0x4d22f7eb, 0xec192b1b,
	0xd58fefd8, 0xfc818db6, 0x1f81b1a8, 0xd6bb218e, 0x9377f0c9, 0x932ebf96,
	0xf72f175f, 0xe9e89ca1, 0x9443e013, 0x4bd7d77f, 0x73825e4a, 0x51794b1d,
	0x7c2d1f0f, 0x13e231fd, 0x7ceefcfd, 0xa4bbc4c6, 0x862f250e, 0xbf22962f,
	0x801fbda1, 0x9c6046ff, 0xaf9bff80, 0x24f3a02c, 0x057486c1, 0xf2a5bafd,
	0xf897da69, 0x74b77caa, 0x711f319f, 0xb88ffa70, 0x7e93f224, 0xeec7a63e,
	0x201c7e27, 0x907b63f8, 0xf6ca6eff, 0x9e3ccc2f, 0xf8a25337, 0x6c2834dd,
	0xc4931548, 0xe82bf376, 0xc634e45e, 0xcdb3a88f, 0x82bfbe1e, 0xa99eb095,
	0xccd3dd62, 0x57288391, 0xe5b4b65e, 0xe5e93c60, 0xfb1576c5, 0x377e219f,
	0xbdf8a66d, 0x967de3b4, 0xcea1133c, 0x7748d943, 0x28da09bf, 0xe57db59e,
	0x71177a0e, 0xe0a95b38, 0x6280227e, 0x17c597d7, 0xbfa8efbf, 0x72f60323,
	0xe027d206, 0xffe204ff, 0xb78dc043, 0x0bf7f7a8, 0xfd0cfd7f, 0x6e9fc6ee,
	0xbc5afa79, 0xeb13751f, 0xa6ea3f22, 0x3bf415fa, 0xed4e401e, 0x78a223f9,
	0xe3aef1d5, 0x3eaf07ad, 0xaf162ff8, 0x84d47e1e, 0x486ba7c9, 0xa650fd2e,
	0xc21750f3, 0xb1f70eab, 0xee373f02, 0x1e2bf2e7, 0xbe1e3adf, 0x374bbf87,
	0x36eef488, 0x91b313c2, 0x87a78cbc, 0x080be10b, 0x8d562673, 0x0fc8d8f7,
	0xf2e26fed, 0x893cffb4, 0xb1d795e2, 0x901d0be0, 0xf7e7db5e, 0x954f7e16,
	0xc0a66de3, 0x78586fdb, 0xfeffbe0a, 0xfbede14d, 0x63e90363, 0x3c6df013,
	0x2f8b9e9f, 0xffd4f917, 0x9865f5d2, 0x188fefd1, 0x5f8e39f9, 0xc2a8f07b,
	0x0c78317f, 0x5f132436, 0xde5be0f6, 0x117a717d, 0xd638c0ff, 0xef8c293e,
	0x5f905fde, 0xe0085825, 0x51ac64b3, 0xd378ea6f, 0xb8ae72e1, 0xf22cdbe0,
	0xbed122b2, 0xdbe3e70a, 0x4d1f746c, 0xf7d157df, 0x390aa64f, 0x0dbe9f19,
	0x57ee12f6, 0x8c7f93dd, 0x6e3945de, 0xfbe1fbd5, 0x68af6fbf, 0xddf7c6cf,
	0xe9e0aedf, 0xddff2b71, 0x25af3d51, 0xdbe4b8f1, 0xc210b699, 0xd8696de9,
	0x6f33d438, 0x977fb74b, 0x3eac33e7, 0x18c8cfcc, 0x8ecdf787, 0xe638f45b,
	0x876e42dd, 0x8c663cf9, 0x893b53f4, 0xf0f084bd, 0xe3402c49, 0x156a5248,
	0x5bede7cc, 0xfee11707, 0xc6becf44, 0x57876e58, 0xa07ae58c, 0x877fee27,
	0x59ff7144, 0x7f709aa8, 0x5583dc62, 0xe27e50b9, 0xb48541ce, 0x38dcba6f,
	0x1cfdea3e, 0xa46e978a, 0xd67cc67e, 0xd18ba965, 0xd6fa3d6f, 0xcf97967f,
	0x9d21352d, 0xd43817cc, 0xff718752, 0x05283c3c, 0xcfae97f5, 0xed3c8fba,
	0x7ee78d8c, 0x3ddfe224, 0x0ef761f9, 0x0787d588, 0x0437589f, 0x0d6f99fb,
	0xfca1570d, 0x0c8fedc3, 0xfe65bb40, 0x90866b13, 0xdac4fd3d, 0xcd17e821,
	0x886eb1df, 0x413ef946, 0x7ccccbf2, 0xf7fa7fdd, 0x507e7451, 0xc155cfef,
	0xf6998afd, 0xb7a89583, 0xe3e77f27, 0x307fb855, 0xe2894ef8, 0xf6b3d77f,
	0x6b67a855, 0xb15f39f3, 0xff9276cd, 0xd7ed1fd0, 0x0a6c3e3e, 0x6af687bd,
	0xb9967bfe, 0x7c61eed0, 0xbe2fb588, 0x8f5e1dbf, 0x16b2c4ef, 0xd17ee289,
	0xffb4d9f6, 0xb252b75b, 0xd75313e2, 0x9ee9bbd7, 0xdd63c3e2, 0x2dd9c704,
	0xbcb18785, 0x4f9791b6, 0x1ef785b6, 0xb41e7ec3, 0x904f39d2, 0xf7b1b943,
	0x6b1e1fdf, 0xae6eefe5, 0xd08fc897, 0x25bc19c7, 0x3aec7b7d, 0x67f8161f,
	0x7c93bfa1, 0xa5e04abb, 0x4be8f1ba, 0xe94a7bf8, 0xe5186096, 0x9c0f1bc9,
	0x8c308bca, 0xe7447e83, 0x835b070e, 0x75c02f0f, 0x9c51b0ef, 0x7f7864b4,
	0x17da0339, 0x09b152dd, 0x758d59d3, 0x39402f0f, 0xc85ed5bc, 0xf9f2578f,
	0x1354972d, 0xb717e9ca, 0xc2366f7f, 0xf807c3ed, 0xdf2f86ef, 0x2583343e,
	0xfd3d53e0, 0x371fe011, 0xb26c9e34, 0x26e3fa53, 0x84d5e185, 0x52f26f7f,
	0x7c9a3ffe, 0x9ce9b294, 0xcfdff4be, 0xc57f573d, 0x3e61f59f, 0x5a4b8bb0,
	0x8c57cc1c, 0xe7b4a4e7, 0x06bc02c7, 0xc778b25f, 0x3c2eb15a, 0xca18567f,
	0x28708f19, 0x7e8cbb59, 0xa847eb47, 0xbf1e0060, 0x0032d63c, 0x8d8df585,
	0x7f00fcef, 0x6c7baf8f, 0xdefc25e0, 0xc52cedbe, 0xbfdc5e29, 0x3de116a6,
	0x973f077f, 0xc3fbafad, 0x3c648607, 0x57e5f18c, 0x5837142c, 0x1f9dedba,
	0xce7485ac, 0xdf8665fa, 0xf5d8bb5b, 0xb9f3121e, 0x0b9d5f10, 0xaf9d5f0e,
	0xfe200dd6, 0x557c01d9, 0x6af9f5f0, 0x820ae369, 0xfc0b579f, 0x43ebe909,
	0xf200684b, 0x46c387d3, 0x5e879d13, 0xbafe0890, 0x9f99ef1c, 0x5342ef58,
	0x9cf2fadb, 0x94ff1ca8, 0x0f7c1095, 0x0860ffee, 0xee9fcfda, 0x75de719b,
	0x8eeb0b3f, 0x9d78c50c, 0xfaf8d29d, 0x20e0d611, 0xe237d615, 0xffffef1c,
	0x18a4006f, 0x008000fe, 0x00000000, 0x00088b1f, 0x00000000, 0x5aa5ff00,
	0x559c500b, 0xffffbe96, 0x6e8683f7, 0x3cd00868, 0x0849d212, 0x93b048c1,
	0x24d1c640, 0x4863cd36, 0xb125d998, 0x24464dd6, 0x3678628d, 0x6cadd460,
	0x12345acd, 0x053a8359, 0x31f1ab2b, 0xf89224da, 0x0d1db320, 0x3da24491,
	0xa366c359, 0x44aa616b, 0xd52a6ab7, 0x9091d66a, 0x763e09a5, 0xe7ba89ac,
	0xd2dfff3b, 0x7667504d, 0x3ede3353, 0xb9ee71f7, 0x9df39ee7, 0x02cfcf73,
	0x8a442ca7, 0x86637fa0, 0x7fe08b4a, 0xcd10aa52, 0x11e14fea, 0x44909bc2,
	0x881488f4, 0xf87a27cd, 0x78ba1367, 0xf892fd6a, 0xf39d4628, 0xa3f736ad,
	0xe8568d5c, 0xd377f8ff, 0x80b6de5f, 0xf17072cf, 0xc4285109, 0x45903e4f,
	0x9f767720, 0x4563069f, 0x12df6220, 0xf3fb7083, 0x19f507e8, 0x3a98840a,
	0xbddfde9e, 0xfd1d6884, 0x35f4192f, 0x184f41fb, 0xc7e30fa8, 0x12c75f24,
	0x6eb2bd75, 0xc7139cf6, 0x799df327, 0xe5b79f57, 0xa08e64c4, 0x7fe1e6fe,
	0xf9f12cbc, 0xf2e84d37, 0xbffcfc7f, 0x1f99383b, 0x7d5f1334, 0xd6959d70,
	0xf982194f, 0x5e5b6a0e, 0xfb0b2a7b, 0x087aa5fc, 0x483c37f7, 0xe34b5907,
	0x9bbc8c52, 0x2e552ce4, 0x5ce1263d, 0x48c2f467, 0x7e396ae7, 0x3a39e8e0,
	0x9c48ccf7, 0x6885d843, 0x6ccac795, 0xf6dfc912, 0xe88da8e1, 0x82473499,
	0x9dfcccd5, 0x65fadbd0, 0xf4254762, 0xdace9ba7, 0x9b884ab2, 0xd8850f61,
	0x4fdb83b7, 0xafb085db, 0xb37f1f00, 0x3f22be20, 0xbf100c4e, 0xdc31ed8b,
	0x497bbd5f, 0x7ff51a57, 0x43594bea, 0xe56f16c7, 0x7a05a9ff, 0xce237a6e,
	0x9e812caa, 0xfee237a8, 0x4f873bbe, 0xfd08ce11, 0x271f3d35, 0x5af3119c,
	0xc6bff60d, 0x1567ad7e, 0x5afda5e1, 0xc5186e57, 0xe484e23e, 0xf0e74e58,
	0x219df9ec, 0x4ddf822d, 0xc766bd4e, 0xe6f72c3d, 0x2594fe37, 0x0dae28e8,
	0x449cdbce, 0xcc4c91c7, 0x27c12d2f, 0xba3cda49, 0x064d16ff, 0x8ea488f3,
	0xde3c2b97, 0x7488ac3a, 0xf8b349ac, 0xca39d396, 0x2c4e8f45, 0xbfc2be23,
	0xbaa0e05e, 0xa46fafe0, 0x94378af1, 0x0644ddb5, 0xd247a44c, 0x3bac596b,
	0x73e9177b, 0xbd34965c, 0xd7a00bfa, 0x394f9cb0, 0xbd739625, 0xdfb13922,
	0x6f9c7a74, 0xda6d753f, 0xbc82a9e6, 0x651b79e1, 0xa9f11e75, 0x4df6fb67,
	0x7f816fe7, 0xb7f3a606, 0xdde7665a, 0x9b5c46f2, 0x5fc2e30f, 0x3ec44b70,
	0xaf034e83, 0x215b6cff, 0x17eb49db, 0x0eb8af66, 0x31e572f6, 0x75ddf689,
	0x0245ec92, 0xcbef25ff, 0xe92f0e74, 0x493af719, 0x1234eaf7, 0x3a70b73b,
	0x52ab3fe1, 0xd69ff07c, 0x15d092c3, 0xfb8cbec0, 0x8b5e6863, 0x7b0a983e,
	0x9efc3bde, 0x3adcf601, 0xbec1aef4, 0xc8e9eb0a, 0x2313c87a, 0x56adbf43,
	0x1afb89fa, 0xadfef15e, 0x4673cfc4, 0xf7457151, 0x3fc041ae, 0x6bf63e68,
	0x0ca47a3a, 0x7408b374, 0x079b3ec1, 0x2666eda3, 0x9d609ecd, 0x9d066fc7,
	0xd8ff28f6, 0x8ff54fb4, 0xe6d1145b, 0x2772f337, 0x9a5371ec, 0x8a5bbfad,
	0x3af1275c, 0x80f932a7, 0x2d0ae48d, 0xb1121c95, 0xf77ac50a, 0x1c8fa158,
	0x8b403ac9, 0x54bfaf43, 0xc5f193b0, 0x9d337057, 0x7c10642f, 0xec1e9b1f,
	0xf21129d5, 0x9c511a6c, 0xac5087b8, 0xf7c63fa8, 0xfb885eee, 0xe5437c78,
	0x217f616f, 0x373bf4c3, 0x992196d2, 0x3eaf9bd6, 0x2aa36d87, 0x353259cf,
	0xee4d6fbe, 0x154ccc8a, 0xed8f84cf, 0xf7565468, 0x8a753727, 0x75ebb335,
	0x52faea45, 0xa416cf25, 0xc3925df1, 0x9f679d66, 0xf4907b70, 0xf4f74b5e,
	0xda37dd3c, 0xa2addb17, 0xb066f096, 0xdfe98d3d, 0xf5b9dbb6, 0xff72e7b7,
	0xa60eedcb, 0xcf5fb68f, 0x2776b1f4, 0xe5edc3d3, 0xaf689edc, 0x10b3fee4,
	0xa7fc06f5, 0x18bb07d9, 0xcc65af85, 0x7349e3d2, 0xf9e88ce8, 0x345249e3,
	0xfcf1219d, 0xcfb36771, 0x06d1744b, 0x764f86ab, 0x63e9254b, 0x5f3e3622,
	0x9b210824, 0xa677bfdd, 0x09f2ce80, 0x969f4f8a, 0xfe0c7a3f, 0xbdb49254,
	0x93367e0a, 0xa3c0146c, 0x8fee4505, 0x99ccef31, 0xc65eece2, 0x48c39349,
	0xcbfe3ef7, 0xefa0136b, 0x422bbfd0, 0x728b2da1, 0x2029eed7, 0xb12cc8ba,
	0x5c5e12fd, 0xb1714957, 0x4f893f15, 0x814d48f1, 0xeb07c54e, 0x6f7a0972,
	0xbb3ec5ae, 0x816b4dd2, 0x746d0fc3, 0xec23394f, 0x2ea32cb2, 0xe87d0ddb,
	0x34cbefed, 0x7a1ffbcf, 0xeef34031, 0xeca238b6, 0xa2c6cb7a, 0x536f902b,
	0x6b3db2ee, 0x0d9c9fc0, 0x3cee4778, 0x729cf908, 0xf8c9d49c, 0x0f01d765,
	0xec7668ae, 0x7f6c4bb2, 0x975d8301, 0xb103fc44, 0x5a5ec945, 0xf3ddaa37,
	0xcf9eed19, 0x36fcf76a, 0xfb5097f5, 0x1da3f50e, 0x97b47ea3, 0xd5fa6bd7,
	0xbf40e74d, 0x1a56713f, 0xd3df588a, 0x7a43a059, 0xb7f60db1, 0xe2a5fe19,
	0x86f2164e, 0x4f7ecd6c, 0xada87700, 0xa2d2a9bb, 0x9f33f3ae, 0xb269c426,
	0x8fac49c7, 0xbaf0cbb0, 0xdb82f5d9, 0x6f09d7ad, 0x55fef00c, 0x127a0f93,
	0x212f290b, 0x36abeb7a, 0x662523c6, 0xf205e572, 0x056badf3, 0xc578a8e3,
	0xb34bcea8, 0x484fc217, 0x94cfbc47, 0xc9eaf64f, 0x63493c3e, 0xc3884939,
	0xe9857f9a, 0x8c28df63, 0x44359edb, 0xa49afb53, 0x75b3cf9e, 0xeb11272c,
	0xfb0c9325, 0xc757ecf2, 0xe7fe69cf, 0xd3f1aa59, 0xfc6223ce, 0xd08fb859,
	0x6eb357c9, 0x1cdbba27, 0x7fe2a9d8, 0x5b718720, 0x02b67204, 0x79ff251f,
	0x72c210e1, 0xfba35f4a, 0x7fe1f429, 0x29e27406, 0x474b4aa3, 0xc7235bce,
	0x9259fc53, 0xa341b415, 0xe8933c8f, 0x2ff5a088, 0xe1b8c79f, 0x094d637e,
	0xdf4615d1, 0xcdd87699, 0x65f6a8bf, 0x09f43c3a, 0xdc74d6f4, 0xeb81f9c8,
	0x97a5d0f0, 0x2c879f11, 0x457cc00e, 0x77d612d1, 0x0f43f1e7, 0x8ea6dec3,
	0xba1fd9e8, 0xe67bdf07, 0x28cf3c57, 0x46156e60, 0x7da0817f, 0xb80d4f52,
	0xc744e975, 0xbd073ff9, 0x72c495c2, 0xfd502c54, 0x5295cf3a, 0x86de85e3,
	0xfc1dff0e, 0x784122af, 0x25e2b761, 0xd46247ba, 0x2535caf8, 0x29a7f282,
	0xf83558cb, 0x7468bcb7, 0x5f1b4ec0, 0xb7e0b9b1, 0x72968adb, 0xd9586adc,
	0x2b788593, 0xe0e1789f, 0xcf3192af, 0x6b6f2024, 0x35ef9a92, 0xeeebfd2a,
	0x703bfbe2, 0xfdc829f0, 0x27ec4982, 0x03c40d3e, 0x5c1c35fb, 0xd1d2f3ee,
	0xe3fafb5e, 0xa943dc6a, 0xf441f4f2, 0x499cfe7f, 0x19ce1e86, 0xe01b099c,
	0x8ef4e787, 0xe8d3ac01, 0xaa05f186, 0x32c1713c, 0x9ee4bfbe, 0xc6dbc42c,
	0x57ff7f05, 0xe942bb90, 0x9c49e679, 0x205190e7, 0x40bc4c3e, 0x1375a37a,
	0xb835fa03, 0x2c17a9e5, 0xa4cbd83a, 0x24fd53d4, 0xf3a80ff8, 0xac3d4d26,
	0x0ac0ef4f, 0x9e68fd81, 0x949e3c40, 0x27faa37a, 0xbbe50e06, 0x5f177f49,
	0x4773c8ac, 0x5fd86fd8, 0x46339f1a, 0x024645c5, 0xed46a5c2, 0x857ab0b7,
	0x836ee299, 0xf63c5e46, 0x6293d4c4, 0x41c5fd76, 0x3a40c07d, 0x3d8a306a,
	0xfeb34931, 0xb3f998d0, 0x51af9c72, 0xfe41cfee, 0x5836b0d2, 0x3098bf0d,
	0x9a349889, 0xb71696f7, 0x6c768f1a, 0x7dfc1e41, 0x716bf4f2, 0x35348be8,
	0x6c317d7e, 0xefa579f2, 0x6fbf438f, 0x97b7d617, 0xb5b7d2cf, 0x0f973919,
	0xe0cb7bf3, 0x5f20766f, 0xe3f1524d, 0x241fcd3c, 0x48b67b1c, 0xec768fcd,
	0x57df9e8e, 0x2dfdc494, 0xe20e6086, 0x6f7f985f, 0x82d71851, 0xb9abc039,
	0x96902aeb, 0x925e4700, 0x8f1a4718, 0xf12a1f4a, 0x67534a9a, 0xe318d9f5,
	0xf3f929f5, 0x3ada43df, 0xd7881eed, 0x57ea972a, 0xa726838d, 0xc534f889,
	0x2f91e306, 0xf1825b35, 0x4ea683c8, 0x76bf6228, 0xfe61c97d, 0xabf7674b,
	0xf7ea11e7, 0xf9a69deb, 0x08e3a3f6, 0xdf87579a, 0x6b970aa4, 0x3f57ef29,
	0x09fbc71c, 0xec1d706b, 0xe8e9feb6, 0x35a73875, 0x86a71fc2, 0x23baa40f,
	0x86a8cfe2, 0x43e92107, 0xd7d09bf6, 0x0ec1651f, 0x47b1651a, 0xa45ed522,
	0xa624a635, 0x7b4a8c45, 0x8df9644d, 0x61639a5f, 0x68bf173f, 0x929e3f66,
	0xf7738c82, 0xf8c65a9c, 0x320fa530, 0xaeb835ce, 0x4c7e01a9, 0x81ab0625,
	0x6eb8f75b, 0x83d3c750, 0xdf1a76d5, 0x8be31a0a, 0xf701e704, 0x9e32729f,
	0x6fd32854, 0x038a6e21, 0x24fc2b7a, 0x4d3aefac, 0x383c424f, 0x10efcede,
	0xa1f11dbd, 0x796925d3, 0xfcf66182, 0x4d3facca, 0xa3e1fb09, 0xb37acff0,
	0x7d478063, 0x0f232f83, 0xe8ea9edc, 0x37ad5fb6, 0x2672439e, 0x13b57d27,
	0x7165d4f7, 0x79be224f, 0xcefc82f2, 0x38e76b20, 0x91baf2d4, 0xfd219bdf,
	0xd7e041f4, 0x843b8b76, 0xb186cd79, 0xe91202ae, 0x8a383e92, 0xec337ed4,
	0xb544718d, 0x03bca9b7, 0x47d3e606, 0x7ff3a54a, 0xa083ddab, 0xec3f4e47,
	0xf9ef5243, 0x795f875f, 0x3533781b, 0x7a718cb6, 0x0c4d3fae, 0xdc0f1a3f,
	0xbbe280f8, 0xff6cc577, 0x0c873507, 0x7cf6dfe8, 0xd2ef01bf, 0x9f44f7db,
	0xcdcae66f, 0x0f142efc, 0x1ec3f447, 0xb9e9a2fb, 0x065d817a, 0xcbc0fca2,
	0xfc0377fe, 0xd726da8d, 0xf0f40b58, 0x6895bd1d, 0x353e8225, 0x5f339e87,
	0xc3f9aa54, 0xf582450d, 0x3028bcd1, 0xc3f8efce, 0xef7c017a, 0xf4c6b8a4,
	0xef0f9c50, 0xc530f919, 0x6e3564ad, 0xc5345e21, 0x5ee3558f, 0x568c86a6,
	0xf8ffbfcc, 0x7e70b21f, 0x9c2cc7b2, 0xabf8e9b7, 0x57df78a9, 0x3f79d914,
	0x18a98f8a, 0x9e3a1a6f, 0xb848f78a, 0xe7f659bf, 0x94ca2e40, 0xe11f81f2,
	0xc8128f7e, 0xd24dfc81, 0x2bc63e58, 0x659bb934, 0x9ad015a2, 0xf7ea92dc,
	0x38c2b8e2, 0x36def73f, 0xf84af66a, 0xf07c8f90, 0xfd6a13fe, 0x0d078c20,
	0x429cae1a, 0xffea9e7f, 0x4e1a75d6, 0xf806d2d0, 0x31383cfd, 0xd13dc612,
	0x1b9df5c6, 0xe1dcaa5c, 0xdf97ccf5, 0x6f1e5e17, 0x7f326d79, 0xd9d61e69,
	0x781175b5, 0x5f166cb4, 0x8c690380, 0x53ebf703, 0xcf8d5ce9, 0x5a4e8e48,
	0x51d550d2, 0x9d45d346, 0xe832aeee, 0xf9785eb5, 0xae57373d, 0x1ef476b9,
	0x7e0294f4, 0xf1bc3bea, 0x24ebe4a0, 0xd6122eb9, 0xbc61ada7, 0xea7f0009,
	0xe0ca3a4a, 0x7b26777f, 0xe5ef910c, 0xb3bfe31f, 0x6bae9a2f, 0xcdb328eb,
	0xbb8de7e3, 0xc453477b, 0xdc1afcd5, 0xf6a965fd, 0x72c3fbab, 0xe585345f,
	0x2253e974, 0xa3adb1f5, 0xbada852c, 0x3eabff98, 0x3c5f73d4, 0xee200c6e,
	0x380d7e92, 0xb63fc6ff, 0xfb712219, 0x0835f8c7, 0xc975995f, 0xb73fcbf7,
	0xe302966d, 0xf2092ba8, 0x33f601af, 0xfd889bf2, 0xa9cd17ce, 0x2cd7d44f,
	0xdc2dde46, 0xeb238b35, 0x025b7313, 0x7af90cca, 0xc96e37b6, 0xf31dab0f,
	0xff3c23e8, 0x76c29721, 0xabf35e78, 0x27a68a8c, 0xd75c165e, 0x7a22e7d9,
	0xfe732283, 0x7e9f773e, 0x52c69fcd, 0x9ec2f72d, 0x2b7a2342, 0xa28364fc,
	0x9e5333ea, 0x98fe0779, 0x77b16a99, 0xe2d2bf12, 0x49de7538, 0x9ff51593,
	0xb2afc9d0, 0xf437c49c, 0xd71b7980, 0x91667457, 0x69a3e34e, 0xbfdf18ab,
	0xab153bab, 0xa815c4fb, 0xae6b4ef9, 0x4beb87fe, 0xeaef9679, 0xe46f9c4b,
	0x7396f9c5, 0xe38cfe1c, 0xd0a4685b, 0xef81d8aa, 0xadfc333e, 0x49ffebf5,
	0x1a9e1c45, 0x3b78aff9, 0x1fcaeb70, 0x7b3f61e2, 0x078e3f87, 0x5e1a9c3e,
	0x6e7b4166, 0x7f416ecc, 0x32e3fca8, 0xdad6ebcc, 0x5a82fad9, 0xe1b70b1f,
	0x8eb87377, 0xd3377e10, 0xf434fa3b, 0xfbdd603a, 0x439202eb, 0x03acf4c4,
	0x3a3bd02e, 0xb663f109, 0xcdb760be, 0xac898f57, 0x572f642f, 0x51680beb,
	0xabd6c85f, 0xa8d005f5, 0x7d45a02f, 0x2fa8fd01, 0x017d4680, 0xa00bea34,
	0x8b405f51, 0x3ffa02fa, 0xe48b3d47, 0xa6f2510d, 0x8ccd3fd6, 0x280f77ff,
	0x77f5e43e, 0xba54549f, 0xbee1f25f, 0x88fed12f, 0xd5cfa183, 0x450857fa,
	0x8ff3bc43, 0x107df9ea, 0x2f96f7f2, 0x290dbdc5, 0x45d55c0e, 0xc5324dc4,
	0x69f4fd56, 0x8f5a85d4, 0x3b0e8e48, 0x1cb1b7fa, 0xdf0a477b, 0x80ff42af,
	0x71db21de, 0xa2a45f5f, 0x3238d5ee, 0x12abf5c0, 0xdf0349db, 0x5024a0f3,
	0xa8c5bd77, 0x0a3d93be, 0xe3dc92f5, 0x68f39906, 0xdf8c718f, 0x4bcf4d2f,
	0x3c88dad6, 0xcbfaf5b4, 0xa69d138c, 0xd790fdf8, 0x6b5937e3, 0x93abe2a3,
	0x7e0f3ef3, 0xcebc7ee2, 0x77a25cb1, 0xc78453aa, 0x9c01365c, 0x22247ce0,
	0x6d69da3f, 0x33f239f8, 0xe1d15ca1, 0xe87a1efc, 0xeaf9202e, 0x0a3fe9f6,
	0xe0dfec46, 0x471ba68b, 0x0a65748e, 0x8fdd19c8, 0xb2e2034a, 0x6fdd1fc7,
	0x7f24b62e, 0x563f4712, 0xb7c8d58b, 0xf6b9ffca, 0x37ed10f0, 0x7ce463d3,
	0x7b914165, 0xd7d93141, 0xeb93bd69, 0x9a4fa72f, 0xa175bdf8, 0xfd544577,
	0xc85954a5, 0x7a5d8ff5, 0x43f8e389, 0x58e9dd1b, 0x077e5c57, 0xd38a5dd7,
	0x61cfec2c, 0xb1b2dc3b, 0xbbe31332, 0xeeb9d956, 0xf7146a55, 0x7bf23f32,
	0x3d11e7be, 0xa7695bfb, 0xae8993e4, 0xfc030e11, 0x93a9076b, 0x7e6f49ed,
	0xd87f2250, 0x45557b41, 0x5eaed5d8, 0x2e0af389, 0xab9e9040, 0x18ee7d35,
	0x24afb7f9, 0x8c3b97f2, 0x299c1e6a, 0xb33fcccb, 0xcd16e29b, 0x0db853bf,
	0x1475d788, 0x9c52d157, 0xfd483d7d, 0x5985b8ee, 0xb76f9e6a, 0x59cd7f81,
	0x949e00bd, 0xe3917eda, 0x625f78e6, 0x5bee84fd, 0x7caadc0a, 0xe10fed7b,
	0x127c4ea8, 0xd69ed791, 0xfa43f8ab, 0x28d6f7e4, 0x3eeb95ec, 0xb6cf6e6e,
	0x797b73d7, 0xd9ef8abd, 0x67b79a8a, 0x93595dd3, 0x04716eb8, 0xcd5b4beb,
	0x8c3fe80e, 0xf969cf0b, 0x2d4cb67d, 0x562e7bcd, 0xc7440d6d, 0x6a22ff50,
	0x0bf31245, 0xa36f3158, 0x5330f19d, 0x0ed6b73e, 0x76697c7d, 0xb6a51f40,
	0xeef1ab93, 0x77f1a658, 0x82dca86d, 0x0bc672fb, 0xf7c7f62f, 0x6fd21e9a,
	0xa1240e19, 0x2a77ee9e, 0x949f8fa8, 0x5fd778ac, 0x0fbda78d, 0xd967e158,
	0xdb751592, 0xd29ed8b2, 0xb65fe254, 0x78038974, 0xf5caf84e, 0x556a29b0,
	0xa7d1b83b, 0x5d5aea48, 0xeaf8ea2a, 0xc1be3e3d, 0x385c5b5d, 0xf9a15fdb,
	0xb3e46851, 0x3fd7c478, 0x1cfb5ea3, 0xc9857bf8, 0x87f1a031, 0xbb5c541d,
	0x61b6eb88, 0xb4199a3b, 0xed1d87ed, 0x5545e2d6, 0xe47abbd5, 0xb9377513,
	0xaa1e86ef, 0x903f2f6b, 0xbf9ce7ca, 0x9bb8465e, 0x5b9ddc00, 0xf8e30b2f,
	0x0eeead41, 0xf569d5bc, 0xcf569d5c, 0x5cf569d5, 0xd5cf569d, 0x9d5cf569,
	0x69d5cf56, 0x569d5cf5, 0xf569d5cf, 0x09d71d5c, 0xa77db8db, 0x63b7377d,
	0xa71e5eed, 0xfc5dd138, 0x7b5bd5e7, 0xb7a9e78b, 0x027b188a, 0x77f25bc7,
	0xa73dbeb5, 0x2e7e4abe, 0xf179f847, 0x0fede248, 0x33e91f22, 0x510c4838,
	0xdf677066, 0x785c666d, 0xaeaffc0a, 0x66f586b3, 0x8cecbae6, 0xfe81ad30,
	0x74cbb95d, 0x680f8d32, 0x73ae10f7, 0x3e705fc2, 0xf85a0bf8, 0xacf96e8b,
	0x40c6fcbf, 0xe6a05d2e, 0x0fce5e07, 0x5daf7c4c, 0x4427841d, 0x51ac21df,
	0x0e697278, 0xe643d09e, 0xe7639097, 0xab745188, 0x37e025fe, 0xb8fe6a2e,
	0xf17c1e66, 0x28b2f8ab, 0xf602ffd6, 0xeb12d459, 0x7e4c3e40, 0x7a75f6ce,
	0x5e7ec4af, 0xdf792a2b, 0x1e267079, 0x82c771f7, 0xd14ff3e9, 0x321e3bfc,
	0x95d39e73, 0xffdd73be, 0xc57c6707, 0x6f1e3eaa, 0x205e340f, 0x7f604a59,
	0xd877f1d7, 0xcb87ae5c, 0xa507ecb1, 0xbe12c3ca, 0x4dbaeec7, 0x977dc6ac,
	0x869f2b18, 0x73f2369c, 0x6b26f77e, 0x58dd5d75, 0xcfa221c3, 0xf03a66a5,
	0xda616d1d, 0x16bd9131, 0x079e5438, 0x7a273c9c, 0x1cbbac24, 0xf84ffeef,
	0x7479cde9, 0xcfd6796a, 0xfb71e56c, 0x563ef9bb, 0xb7dee214, 0xa843ed1a,
	0xa78b0433, 0x35b0aeb9, 0x3a885ec1, 0x4bf8b043, 0x87d9b695, 0x3f9e0724,
	0x6d2f5cd3, 0x73d4de7a, 0x7abe2221, 0x745189fc, 0xcf7a70eb, 0x94efc885,
	0x73ef41f8, 0x274973f1, 0xa793be22, 0xb04beec9, 0x7ff94f43, 0x3178efab,
	0x72f1f1cd, 0x95f59db1, 0x60044a72, 0x2c9bd3cf, 0xb6cfbdfc, 0xea356da0,
	0x5ecf226c, 0xcf947988, 0x1d7ce0ce, 0xa19f9deb, 0x6dced4cd, 0x054fd7c3,
	0x426631d6, 0x0efb567b, 0xabbb2a39, 0x7bc596d0, 0xfb2fdc75, 0x25bed00a,
	0x3f41effb, 0x9037c5f9, 0xd5d1eca7, 0xce89732b, 0xb757fa34, 0x9d271199,
	0xbdff82df, 0x24a29c1b, 0x7f7aeae5, 0x923e76a7, 0xf1f18747, 0xfbf3991c,
	0x1b6a95f1, 0x12cc8bb6, 0x585fff35, 0xfad1faa2, 0xf23bf54e, 0x5859fb5c,
	0xf9386b22, 0xbc9372c3, 0x2c2fd8c9, 0x29a9e8bf, 0x6f243c80, 0x6f2a894a,
	0x4e615a2a, 0xf7cc3ae2, 0x9357abdb, 0xc253b54b, 0x2a0ba6c5, 0xa39b722e,
	0x5f2225f3, 0x97cfb8c8, 0xfa337908, 0x6a764da7, 0x9b4ef59f, 0xfb3c3790,
	0xf426d30f, 0xe514eb3f, 0x757ee1f3, 0x737cc289, 0xfaf34fd6, 0x8c7bf4c5,
	0x89d307df, 0xea72dbc8, 0xc97834df, 0xa3ec576e, 0xb6f2a37d, 0x8b5f8e5c,
	0x7c5a5b35, 0x0f602c9f, 0x9c109f8b, 0x64928aa7, 0x518c6f1e, 0xbef1bffd,
	0xd1d8647b, 0x3b923e35, 0xec56fec2, 0xa304cdd3, 0x5d7806f8, 0x941b8693,
	0x7b8d45a7, 0xe4f23988, 0x908f0d0c, 0xde115637, 0xfcdfea78, 0xc19eff8a,
	0x8fc39faf, 0xc38c29b0, 0xfdd6f102, 0x3f0ed07a, 0xf3b79e88, 0xe1755fd6,
	0xd55f5b5d, 0x7177e06b, 0xb42e91ed, 0x1aefcdcd, 0xcaf3826c, 0x5794f9a8,
	0xc957d146, 0x968e4739, 0xd9772e7b, 0xec97d9e6, 0xed236fe0, 0x7fdeb4e0,
	0xa7a9de0d, 0x2f0eb13d, 0x5dff11c7, 0xcdfd97c0, 0xcae20766, 0xb1727f81,
	0x82ed857d, 0x9d80efd6, 0x751db8fd, 0x4baf7cf2, 0x7e6fc2e4, 0x1e029dac,
	0x43c28f2e, 0x372bd72f, 0x5ae7185b, 0x4b5ff7b5, 0x90f395ad, 0xe8b75fb0,
	0x61761ffc, 0xbf85b25e, 0xe6dc1043, 0xce56efe2, 0xee8e19c9, 0xdce27c88,
	0xd03e65e6, 0x00fe9da9, 0x42ff4ef8, 0x5c7ea072, 0x6ae2a712, 0x7cd95ca9,
	0x94dfc688, 0xbf1b8c03, 0xf8287e01, 0x6e368a3b, 0xbf57af2f, 0xbf09a4ab,
	0x82fdfea4, 0xf4ef10bd, 0xbeb477f0, 0x4723bebd, 0x7c97cef1, 0x5d44ec4f,
	0x2ccc6ff4, 0x7b27c84f, 0xbe9e74f5, 0xddb8c144, 0xe3873db7, 0x5654484e,
	0x67bc85dd, 0x4fd72c5b, 0x8fed12fb, 0x5f697be0, 0xe7ce4ac3, 0xc6a37d8f,
	0x312de9fb, 0x7d6fe40e, 0x381dedab, 0x767ddf57, 0x524d7f1e, 0x511f79f9,
	0x45b7d3f5, 0x435f673d, 0xc2cbbf12, 0xefd7d0f7, 0xb777c74c, 0x3ef778d6,
	0xf6867bdc, 0x096fb1dd, 0x98fb53f5, 0x4efdb954, 0xcaa559f0, 0x9dbd797b,
	0xf6f4e6f1, 0x541c8f95, 0xf7c019f5, 0x16cdd6af, 0x2fffb77e, 0xfb20ee11,
	0x000024f0
};

#endif /*__BNX2X_INIT_VALUES_H__*/
